@@ -12,15 +12,15 @@
 /* Basic information about this app */
 $setup_info['activesync']['name']      = 'activesync';
 $setup_info['activesync']['title']     = 'eSync';
-$setup_info['activesync']['version']   = '14.1';
+$setup_info['activesync']['version']   = '16.1.001';
 $setup_info['activesync']['enable']    = 2;
 $setup_info['activesync']['app_order'] = 99;
 
 $setup_info['activesync']['autoinstall'] = true;	// install automatically on update
 
 $setup_info['activesync']['author'] = array(
-		'name' => 'z-push Project',
-		'url'  => 'http://z-push.sourceforge.net/soswp/'
+		'name' => 'Z-Push Project',
+		'url'  => 'http://z-push.org/'
 	);
 $setup_info['activesync']['note']   = 'ActiveSync protocol for EGroupware based on Z-Push';
 $setup_info['activesync']['license']  = 'GPL';	// GPL2 as in class.about.inc.php
@@ -38,6 +38,7 @@ $setup_info['activesync']['hooks']['verify_settings']	= 'activesync_hooks::verif
 
 /* Dependencies for this app to work */
 $setup_info['activesync']['depends'][] = array(
-	 'appname'  => 'phpgwapi',
-	 'versions' => Array('14.1')
+	 'appname'  => 'api',
+	 'versions' => Array('16.1')
 );
+	$setup_info['activesync']['tables'] = array('egw_zpush_states','egw_zpush_users','egw_zpush_settings');
