@@ -1,33 +1,34 @@
 <?php
 /**
- * EGroupware: GroupDAV access: addressbook handler
+ * EGroupware: CalDAV/CardDAV/GroupDAV access: Addressbook handler
  *
  * @link http://www.egroupware.org
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package addressbook
- * @subpackage groupdav
+ * @subpackage carddav
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2007-15 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Acl;
+
 /**
- * EGroupware: GroupDAV access: addressbook handler
+ * CalDAV/CardDAV/GroupDAV access: Addressbook handler
  *
- * Propfind now uses a groupdav_propfind_iterator with a callback to query huge addressbooks in chunk,
+ * Propfind now uses a Api\CalDAV\PropfindIterator with a callback to query huge addressbooks in chunk,
  * without getting into problems with memory_limit.
  *
- * Permanent error_log() calls should use $this->groupdav->log($str) instead, to be send to PHP error_log()
+ * Permanent error_log() calls should use $this->caldav->log($str) instead, to be send to PHP error_log()
  * and our request-log (prefixed with "### " after request and response, like exceptions).
- *
- * @todo check/fix contacts in LDAP (no carddav_name column!)
  */
-class addressbook_groupdav extends groupdav_handler
+class addressbook_groupdav extends Api\CalDAV\Handler
 {
 	/**
 	 * bo class of the application
 	 *
-	 * @var addressbook_bo
+	 * @var Api\Contacts
 	 */
 	var $bo;
 
@@ -63,13 +64,13 @@ class addressbook_groupdav extends groupdav_handler
 	 * Constructor
 	 *
 	 * @param string $app 'calendar', 'addressbook' or 'infolog'
-	 * @param groupdav $groupdav calling class
+	 * @param Api\CalDAV $caldav calling class
 	 */
-	function __construct($app, groupdav $groupdav)
+	function __construct($app, Api\CalDAV $caldav)
 	{
-		parent::__construct($app, $groupdav);
+		parent::__construct($app, $caldav);
 
-		$this->bo = new addressbook_bo();
+		$this->bo = new Api\Contacts();
 
 		// since 1.9.007 we allow clients to specify the URL when creating a new contact, as specified by CardDAV
 		// LDAP does NOT have a carddav_name attribute --> stick with id mapped to LDAP attribute uid
@@ -77,12 +78,12 @@ class addressbook_groupdav extends groupdav_handler
 			$this->bo->contact_repository != 'sql' ||
 			$this->bo->account_repository != 'sql' && strpos($_SERVER['REQUEST_URI'].'/','/addressbook-accounts/') !== false)
 		{
-			groupdav_handler::$path_extension = '.vcf';
+			self::$path_extension = '.vcf';
 		}
 		else
 		{
-			groupdav_handler::$path_attr = 'carddav_name';
-			groupdav_handler::$path_extension = '';
+			self::$path_attr = 'carddav_name';
+			self::$path_extension = '';
 		}
 		if ($this->debug) error_log(__METHOD__."() contact_repository={$this->bo->contact_repository}, account_repository={$this->bo->account_repository}, REQUEST_URI=$_SERVER[REQUEST_URI] --> path_attr=".self::$path_attr.", path_extension=".self::$path_extension);
 
@@ -104,7 +105,7 @@ class addressbook_groupdav extends groupdav_handler
 	 * @param array &$options
 	 * @param array &$files
 	 * @param int $user account_id
-	 * @param string $id=''
+	 * @param string $id =''
 	 * @return mixed boolean true on success, false on failure or string with http status (eg. '404 Not Found')
 	 */
 	function propfind($path,&$options,&$files,$user,$id='')
@@ -125,6 +126,7 @@ class addressbook_groupdav extends groupdav_handler
 		if ($GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts']) $filter['account_id'] = null;
 
 		// process REPORT filters or multiget href's
+		$nresults = null;
 		if (($id || $options['root']['name'] != 'propfind') && !$this->_report_filters($options,$filter,$id, $nresults))
 		{
 			return false;
@@ -135,7 +137,7 @@ class addressbook_groupdav extends groupdav_handler
 
 		// check if we have to return the full contact data or just the etag's
 		if (!($filter['address_data'] = $options['props'] == 'all' &&
-			$options['root']['ns'] == groupdav::CARDDAV) && is_array($options['props']))
+			$options['root']['ns'] == Api\CalDAV::CARDDAV) && is_array($options['props']))
 		{
 			foreach($options['props'] as $prop)
 			{
@@ -176,17 +178,17 @@ class addressbook_groupdav extends groupdav_handler
 		else
 		{
 			// return iterator, calling ourself to return result in chunks
-			$files['files'] = new groupdav_propfind_iterator($this,$path,$filter,$files['files']);
+			$files['files'] = new Api\CalDAV\PropfindIterator($this,$path,$filter,$files['files']);
 		}
 		return true;
 	}
 
 	/**
-	 * Callback for profind interator
+	 * Callback for profind iterator
 	 *
 	 * @param string $path
 	 * @param array& $filter
-	 * @param array|boolean $start=false false=return all or array(start,num)
+	 * @param array|boolean $start =false false=return all or array(start,num)
 	 * @return array with "files" array with values for keys path and props
 	 */
 	function &propfind_callback($path,array &$filter,$start=false,$report_not_found_multiget_ids=true)
@@ -236,13 +238,13 @@ class addressbook_groupdav extends groupdav_handler
 					unset($requested_multiget_ids[$k]);
 				}
 				// sync-collection report: deleted entry need to be reported without properties
-				if ($contact['tid'] == addressbook_bo::DELETED_TYPE)
+				if ($contact['tid'] == Api\Contacts::DELETED_TYPE)
 				{
 					$files[] = array('path' => $path.urldecode($this->get_path($contact)));
 					continue;
 				}
 				$props = array(
-					'getcontenttype' => HTTP_WebDAV_Server::mkprop('getcontenttype', 'text/vcard'),
+					'getcontenttype' => Api\CalDAV::mkprop('getcontenttype', 'text/vcard'),
 					'getlastmodified' => $contact['modified'],
 					'displayname' => $contact['n_fn'],
 				);
@@ -250,7 +252,7 @@ class addressbook_groupdav extends groupdav_handler
 				{
 					$content = $handler->getVCard($contact['id'],$this->charset,false);
 					$props['getcontentlength'] = bytes($content);
-					$props[] = HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'address-data',$content,true);
+					$props[] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'address-data',$content,true);
 				}
 				$files[] = $this->add_resource($path, $contact, $props);
 			}
@@ -270,11 +272,11 @@ class addressbook_groupdav extends groupdav_handler
 				$accounts_filter = $filter_in;
 				$accounts_filter['owner'] = '0';
 				if ($sync_collection_report) $token_was = $this->sync_collection_token;
-				groupdav_handler::$path_attr = 'id';
-				groupdav_handler::$path_extension = '.vcf';
+				self::$path_attr = 'id';
+				self::$path_extension = '.vcf';
 				$files = array_merge($files, $this->propfind_callback($path, $accounts_filter, false, false));
-				groupdav_handler::$path_attr = 'carddav_name';
-				groupdav_handler::$path_extension = '';
+				self::$path_attr = 'carddav_name';
+				self::$path_extension = '';
 				if ($sync_collection_report && $token_was > $this->sync_collection_token)
 				{
 					$this->sync_collection_token = $token_was;
@@ -309,8 +311,8 @@ class addressbook_groupdav extends groupdav_handler
 							$etag .= ':'.implode('-',$filter['owner']);
 						}
 						$props = array(
-							'getcontenttype' => HTTP_WebDAV_Server::mkprop('getcontenttype', 'text/vcard'),
-							'getlastmodified' => egw_time::to($list['list_modified'],'ts'),
+							'getcontenttype' => Api\CalDAV::mkprop('getcontenttype', 'text/vcard'),
+							'getlastmodified' => Api\DateTime::to($list['list_modified'],'ts'),
 							'displayname' => $list['list_name'],
 							'getetag' => '"'.$etag.'"',
 						);
@@ -318,7 +320,7 @@ class addressbook_groupdav extends groupdav_handler
 						{
 							$content = $handler->getGroupVCard($list);
 							$props['getcontentlength'] = bytes($content);
-							$props[] = HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'address-data',$content,true);
+							$props[] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'address-data',$content,true);
 						}
 						$files[] = $this->add_resource($path, $list, $props);
 
@@ -382,6 +384,7 @@ class addressbook_groupdav extends groupdav_handler
 				$options['filters']['attrs']['test'] : 'anyof';
 			$prop_filters = array();
 
+			$matches = $prop_test = $column = null;
 			foreach($options['filters'] as $n => $filter)
 			{
 				if (!is_int($n)) continue;	// eg. attributes of filter xml element
@@ -389,7 +392,7 @@ class addressbook_groupdav extends groupdav_handler
 				switch((string)$filter['name'])
 				{
 					case 'param-filter':
-						$this->groupdav->log(__METHOD__."(...) param-filter='{$filter['attrs']['name']}' not (yet) implemented!");
+						$this->caldav->log(__METHOD__."(...) param-filter='{$filter['attrs']['name']}' not (yet) implemented!");
 						break;
 					case 'prop-filter':	// can be multiple prop-filter, see example
 						if ($matches) $prop_filters[] = implode($prop_test=='allof'?' AND ':' OR ',$matches);
@@ -413,7 +416,7 @@ class addressbook_groupdav extends groupdav_handler
 							{
 								case 'i;unicode-casemap':
 								default:
-									$comp = ' '.$GLOBALS['egw']->db->capabilities[egw_db::CAPABILITY_CASE_INSENSITIV_LIKE].' ';
+									$comp = ' '.$GLOBALS['egw']->db->capabilities[Api\Db::CAPABILITY_CASE_INSENSITIV_LIKE].' ';
 									break;
 							}
 							$column = $this->filter_prop2cal[strtoupper($prop_filter)];
@@ -454,7 +457,7 @@ class addressbook_groupdav extends groupdav_handler
 						}
 						// fall through
 					default:
-						$this->groupdav->log(__METHOD__."(".array2string($options).",,$id) unknown filter=".array2string($filter).' --> ignored');
+						$this->caldav->log(__METHOD__."(".array2string($options).",,$id) unknown filter=".array2string($filter).' --> ignored');
 						break;
 				}
 			}
@@ -462,7 +465,7 @@ class addressbook_groupdav extends groupdav_handler
 			if ($prop_filters)
 			{
 				$filters[] = $filter = '(('.implode($filter_test=='allof'?') AND (':') OR (', $prop_filters).'))';
-				if ($this->debug) error_log(__METHOD__."($path,...) sql-filter: $filter");
+				if ($this->debug) error_log(__METHOD__."(path=$options[path], ...) sql-filter: $filter");
 			}
 		}
 		// parse limit from $options['other']
@@ -496,11 +499,11 @@ class addressbook_groupdav extends groupdav_handler
 				case 'sync-level':
 					if ($option['data'] != '1')
 					{
-						$this->groupdav->log(__METHOD__."(...) only sync-level {$option['data']} requested, but only 1 supported! options[other]=".array2string($options['other']));
+						$this->caldav->log(__METHOD__."(...) only sync-level {$option['data']} requested, but only 1 supported! options[other]=".array2string($options['other']));
 					}
 					break;
 				default:
-					$this->groupdav->log(__METHOD__."(...) unknown xml tag '{$option['name']}': options[other]=".array2string($options['other']));
+					$this->caldav->log(__METHOD__."(...) unknown xml tag '{$option['name']}': options[other]=".array2string($options['other']));
 					break;
 			}
 		}
@@ -515,7 +518,7 @@ class addressbook_groupdav extends groupdav_handler
 					$parts = explode('/',$option['data']);
 					if (($id = urldecode(array_pop($parts))))
 					{
-						$ids[] = groupdav_handler::$path_extension ? basename($id,groupdav_handler::$path_extension) : $id;
+						$ids[] = self::$path_extension ? basename($id,self::$path_extension) : $id;
 					}
 				}
 			}
@@ -524,7 +527,7 @@ class addressbook_groupdav extends groupdav_handler
 		}
 		elseif ($id)
 		{
-			$filters[self::$path_attr] = groupdav_handler::$path_extension ? basename($id,groupdav_handler::$path_extension) : $id;
+			$filters[self::$path_attr] = self::$path_extension ? basename($id,self::$path_extension) : $id;
 		}
 		//error_log(__METHOD__."() options[other]=".array2string($options['other'])." --> filters=".array2string($filters));
 		return true;
@@ -535,11 +538,13 @@ class addressbook_groupdav extends groupdav_handler
 	 *
 	 * @param array &$options
 	 * @param int $id
-	 * @param int $user=null account_id
+	 * @param int $user =null account_id
 	 * @return mixed boolean true on success, false on failure or string with http status (eg. '404 Not Found')
 	 */
 	function get(&$options,$id,$user=null)
 	{
+		unset($user);	// not used, but required by function signature
+
 		if (!is_array($contact = $this->_common_get_put_delete('GET',$options,$id)))
 		{
 			return $contact;
@@ -559,8 +564,8 @@ class addressbook_groupdav extends groupdav_handler
 	 *
 	 * @param array &$options
 	 * @param int $id
-	 * @param int $user=null account_id of owner, default null
-	 * @param string $prefix=null user prefix from path (eg. /ralf from /ralf/addressbook)
+	 * @param int $user =null account_id of owner, default null
+	 * @param string $prefix =null user prefix from path (eg. /ralf from /ralf/addressbook)
 	 * @return mixed boolean true on success, false on failure or string with http status (eg. '404 Not Found')
 	 */
 	function put(&$options,$id,$user=null,$prefix=null)
@@ -575,9 +580,9 @@ class addressbook_groupdav extends groupdav_handler
 		}
 
 		$handler = self::_get_handler();
-		$vCard = htmlspecialchars_decode($options['content']);
 		// Fix for Apple Addressbook
-		$vCard = preg_replace('/item\d\.(ADR|TEL|EMAIL|URL)/', '\1', $vCard);
+		$vCard = preg_replace('/item\d\.(ADR|TEL|EMAIL|URL)/', '\1',
+			htmlspecialchars_decode($options['content']));
 		$charset = null;
 		if (!empty($options['content_type']))
 		{
@@ -614,7 +619,7 @@ class addressbook_groupdav extends groupdav_handler
 		$is_group = $contact['##X-ADDRESSBOOKSERVER-KIND'] == 'group';
 		if ($oldContact && $is_group !== isset($oldContact['list_id']))
 		{
-			throw new egw_exception_assertion_failed(__METHOD__."(,'$id',$user,'$prefix') can contact into group or visa-versa!");
+			throw new Api\Exception\AssertionFailed(__METHOD__."(,'$id',$user,'$prefix') can contact into group or visa-versa!");
 		}
 
 		if (!$is_group && is_array($contact['cat_id']))
@@ -647,7 +652,7 @@ class addressbook_groupdav extends groupdav_handler
 			{
 				$contact['owner'] = $user;
 			}
-			// check if default addressbook is synced and not accounts, if not use (always synced) personal addressbook
+			// check if default addressbook is synced and not Api\Accounts, if not use (always synced) personal addressbook
 			elseif(!$this->bo->default_addressbook || !in_array($this->bo->default_addressbook,$this->home_set_pref))
 			{
 				$contact['owner'] = $GLOBALS['egw_info']['user']['account_id'];
@@ -659,7 +664,7 @@ class addressbook_groupdav extends groupdav_handler
 			}
 			// check if user has add rights for addressbook
 			// done here again, as _common_get_put_delete knows nothing about default addressbooks...
-			if (!($this->bo->grants[$contact['owner']] & EGW_ACL_ADD))
+			if (!($this->bo->grants[$contact['owner']] & Acl::ADD))
 			{
 				if ($this->debug) error_log(__METHOD__."(,'$id', $user, '$prefix') returning '403 Forbidden'");
 				return '403 Forbidden';
@@ -685,7 +690,7 @@ class addressbook_groupdav extends groupdav_handler
 			{
 				if (($contact = $this->bo->read_list($save_ok)))
 				{
-					$contact = egw_db::strip_array_keys($contact, 'list_');
+					$contact = Api\Db::strip_array_keys($contact, 'list_');
 				}
 			}
 			else
@@ -731,8 +736,10 @@ class addressbook_groupdav extends groupdav_handler
 			{
 				$new_members = array($new_members);
 			}
-			foreach($new_members as &$uid) $uid = substr($uid,9);	// cut off "urn:uuid:" prefix
-
+			foreach($new_members as &$uid)
+			{
+				$uid = substr($uid,9);	// cut off "urn:uuid:" prefix
+			}
 			if ($oldContact)
 			{
 				$to_add = array_diff($new_members,$oldContact['members']);
@@ -807,6 +814,7 @@ class addressbook_groupdav extends groupdav_handler
 			$lists_ctag = $this->bo->lists_ctag($user);
 		}
 		//error_log(__METHOD__."('$path', ".array2string($user_in).") --> user=".array2string($user)." --> ctag=$ctag=".date('Y-m-d H:i:s',$ctag).", lists_ctag=".($lists_ctag ? $lists_ctag.'='.date('Y-m-d H:i:s',$lists_ctag) : '').' returning '.max($ctag,$lists_ctag));
+		unset($user_in);
 		return $ctags[$path] = max($ctag, $accounts_ctag, $lists_ctag);
 	}
 
@@ -828,38 +836,40 @@ class addressbook_groupdav extends groupdav_handler
 	 * </D:supported-report-set>
 	 * @link http://www.mail-archive.com/calendarserver-users@lists.macosforge.org/msg01156.html
 	 *
-	 * @param array $props=array() regular props by the groupdav handler
+	 * @param array $props =array() regular props by the Api\CalDAV handler
 	 * @param string $displayname
-	 * @param string $base_uri=null base url of handler
-	 * @param int $user=null account_id of owner of collection
+	 * @param string $base_uri =null base url of handler
+	 * @param int $user =null account_id of owner of collection
 	 * @return array
 	 */
-	public function extra_properties(array $props=array(), $displayname, $base_uri=null, $user=null)
+	public function extra_properties(array $props, $displayname, $base_uri=null, $user=null)
 	{
+		unset($displayname, $base_uri, $user);	// not used, but required by function signature
+
 		if (!isset($props['addressbook-description']))
 		{
 			// default addressbook description: can be overwritten via PROPPATCH, in which case it's already set
-			$props['addressbook-description'] = HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'addressbook-description',$props['displayname']);
+			$props['addressbook-description'] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'addressbook-description',$props['displayname']);
 		}
 		// setting an max image size, so iOS scales the images before transmitting them
 		// we currently scale down to width of 240px, which tests shown to be ~20k
-		$props['max-image-size'] = HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'max-image-size',24*1024);
+		$props['max-image-size'] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'max-image-size',24*1024);
 
 		// supported reports (required property for CardDAV)
 		$props['supported-report-set'] = array(
-			'addressbook-query' => HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'addressbook-query',''))))),
-			'addressbook-multiget' => HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop(groupdav::CARDDAV,'addressbook-multiget',''))))),
+			'addressbook-query' => Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'addressbook-query',''))))),
+			'addressbook-multiget' => Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop(Api\CalDAV::CARDDAV,'addressbook-multiget',''))))),
 		);
 		// only advertice rfc 6578 sync-collection report, if "delete-prevention" is switched on (deleted entries get marked deleted but not actualy deleted
 		if ($GLOBALS['egw_info']['server']['history'])
 		{
-			$props['supported-report-set']['sync-collection'] = HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop('sync-collection','')))));
+			$props['supported-report-set']['sync-collection'] = Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop('sync-collection','')))));
 		}
 		return $props;
 	}
@@ -887,6 +897,7 @@ class addressbook_groupdav extends groupdav_handler
 			$databaseFields['X-ABSHOWAS'] = $supportedFields['X-ABSHOWAS'] = array('fileas_type');	// Horde vCard class uses uppercase prop-names!
 
 			// Apple Addressbook pre Lion (OS X 10.7) messes up CLASS and CATEGORIES (Lion cant set them but leaves them alone)
+			$matches = null;
 			if (preg_match('|CFNetwork/([0-9]+)|i', $_SERVER['HTTP_USER_AGENT'],$matches) && $matches[1] < 520 ||
 				// iOS 5.1.1 does not display CLASS or CATEGORY, but wrongly escapes multiple, comma-separated categories
 				// and appends CLASS: PUBLIC to an empty NOTE: field --> leaving them out for iOS
@@ -944,17 +955,17 @@ class addressbook_groupdav extends groupdav_handler
 	 * the same UID and/or carddav_name as not deleted contacts and would block access to valid entries
 	 *
 	 * @param string|int $id
-	 * @param string $path=null
+	 * @param string $path =null
 	 * @return array|boolean array with entry, false if no read rights, null if $id does not exist
 	 */
 	function read($id, $path=null)
 	{
-		static $non_deleted_tids;
+		static $non_deleted_tids=null;
 		if (is_null($non_deleted_tids))
 		{
-			$non_deleted_tids = $this->bo->content_types;
-			unset($non_deleted_tids[addressbook_so::DELETED_TYPE]);
-			$non_deleted_tids = array_keys($non_deleted_tids);
+			$tids = $this->bo->content_types;
+			unset($tids[Api\Contacts::DELETED_TYPE]);
+			$non_deleted_tids = array_keys($tids);
 		}
 		$contact = $this->bo->read(array(self::$path_attr => $id, 'tid' => $non_deleted_tids));
 
@@ -1000,7 +1011,7 @@ class addressbook_groupdav extends groupdav_handler
 			$contact = null;
 		}
 
-		if ($contact && $contact['tid'] == addressbook_so::DELETED_TYPE)
+		if ($contact && $contact['tid'] == Api\Contacts::DELETED_TYPE)
 		{
 			$contact = null;	// handle deleted events, as not existing (404 Not Found)
 		}
@@ -1011,7 +1022,7 @@ class addressbook_groupdav extends groupdav_handler
 	/**
 	 * Check if user has the neccessary rights on a contact
 	 *
-	 * @param int $acl EGW_ACL_READ, EGW_ACL_EDIT or EGW_ACL_DELETE
+	 * @param int $acl Acl::READ, Acl::EDIT or Acl::DELETE
 	 * @param array|int $contact contact-array or id
 	 * @return boolean null if entry does not exist, false if no access, true if access permitted
 	 */
@@ -1042,7 +1053,7 @@ class addressbook_groupdav extends groupdav_handler
 	/**
 	 * Return calendars/addressbooks shared from other users with the current one
 	 *
-	 * @param boolean $ignore_all_in_one=false if true, return selected addressbooks and not array() for all-in-one
+	 * @param boolean $ignore_all_in_one =false if true, return selected addressbooks and not array() for all-in-one
 	 * @return array account_id => account_lid pairs
 	 */
 	function get_shared($ignore_all_in_one=false)
@@ -1063,7 +1074,7 @@ class addressbook_groupdav extends groupdav_handler
 				$this->home_set_pref[$key] = $id;
 			}
 		}
-		foreach($this->bo->get_addressbooks(EGW_ACL_READ) as $id => $label)
+		foreach(array_keys($this->bo->get_addressbooks(Acl::READ)) as $id)
 		{
 			if (($id || !$GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts']) &&
 				$GLOBALS['egw_info']['user']['account_id'] != $id &&	// no current user and no accounts, if disabled in ab prefs
@@ -1086,15 +1097,15 @@ class addressbook_groupdav extends groupdav_handler
 	 */
 	public static function groupdav_root_props(array $data)
 	{
-		$data['props']['addressbook-home-set'] = groupdav::mkprop(groupdav::CARDDAV, 'addressbook-home-set', array(
-			groupdav::mkprop('href',$data['caldav']->base_uri.'/'.$GLOBALS['egw_info']['user']['account_lid'].'/')));
+		$data['props']['addressbook-home-set'] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV, 'addressbook-home-set', array(
+			Api\CalDAV::mkprop('href',$data['caldav']->base_uri.'/'.$GLOBALS['egw_info']['user']['account_lid'].'/')));
 
-		$data['props']['principal-address'] = groupdav::mkprop(groupdav::CARDDAV, 'principal-address',
+		$data['props']['principal-address'] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV, 'principal-address',
 				$GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts'] ? '' : array(
-				groupdav::mkprop('href',$data['caldav']->base_uri.'/addressbook-accounts/'.$GLOBALS['egw_info']['user']['person_id'].'.vcf')));
+				Api\CalDAV::mkprop('href',$data['caldav']->base_uri.'/addressbook-accounts/'.$GLOBALS['egw_info']['user']['person_id'].'.vcf')));
 
-		$data['props']['directory-gateway'] = groupdav::mkprop(groupdav::CARDDAV, 'directory-gateway', array(
-			groupdav::mkprop('href',$data['caldav']->base_uri.'/addressbook/')));
+		$data['props']['directory-gateway'] = Api\CalDAV::mkprop(Api\CalDAV::CARDDAV, 'directory-gateway', array(
+			Api\CalDAV::mkprop('href',$data['caldav']->base_uri.'/addressbook/')));
 	}
 
 	/**
@@ -1115,8 +1126,8 @@ class addressbook_groupdav extends groupdav_handler
 		if (!isset($hook_data['setup']) && in_array($hook_data['type'], array('user', 'group')))
 		{
 			$user = $hook_data['account_id'];
-			$addressbook_bo = new addressbook_bo();
-			$addressbooks += $addressbook_bo->get_addressbooks(EGW_ACL_READ, null, $user);
+			$addressbook_bo = new Api\Contacts();
+			$addressbooks += $addressbook_bo->get_addressbooks(Acl::READ, null, $user);
 			if ($user > 0)  unset($addressbooks[$user]);	// allways synced
 			unset($addressbooks[$user.'p']);// ignore (optional) private addressbook for now
 		}
