@@ -1,15 +1,21 @@
 <?php
 /**
- * Addressbook - admin, preferences and sidebox-menus and other hooks
+ * EGroupware Addressbook - admin, preferences and sidebox-menus and other hooks
  *
  * @link http://www.egroupware.org
  * @package addressbook
  * @author Ralf Becker <RalfBecker@outdoor-training.de>
- * @copyright (c) 2006-13 by Ralf Becker <RalfBecker@outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker@outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+
 /**
  * Class containing admin, preferences and sidebox-menus and other hooks
  */
@@ -41,21 +47,21 @@ class addressbook_hooks
 				));
 			}
 			// Magic etemplate2 favorites menu (from nextmatch widget)
-			display_sidebox($appname, lang('Favorites'), egw_framework::favorite_list('addressbook'));
+			display_sidebox($appname, lang('Favorites'), Framework\Favorites::list_favorites('addressbook'));
 
 			$file = array(
-				'Addressbook list' => egw::link('/index.php',array(
+				'Addressbook list' => Egw::link('/index.php',array(
 					'menuaction' => 'addressbook.addressbook_ui.index',
 					'ajax' => 'true')),
 				array(
-					'text' => lang('Add %1',lang(egw_link::get_registry($appname, 'entry'))),
+					'text' => lang('Add %1',lang(Link::get_registry($appname, 'entry'))),
 					'no_lang' => true,
 					'link' => "javascript:egw.open('','$appname','add')"
 				),
 				'Advanced search' => "javascript:egw_openWindowCentered2('".
-					egw::link('/index.php',array('menuaction' => 'addressbook.addressbook_ui.search'),false).
-					"','_blank',870,480,'yes')",
-				'Placeholders'    => egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements')
+					Egw::link('/index.php',array('menuaction' => 'addressbook.addressbook_ui.search'),false).
+					"','_blank',870,610,'yes')",
+				'Placeholders'    => Egw::link('/index.php','menuaction=api.EGroupware\\Api\\Contacts\\Merge.show_replacements')
 			);
 			display_sidebox($appname,lang('Addressbook menu'),$file);
 		}
@@ -63,20 +69,22 @@ class addressbook_hooks
 		if ($GLOBALS['egw_info']['user']['apps']['admin'] && $location != 'preferences')
 		{
 			$file = Array(
-				'Site configuration' => egw::link('/index.php',array(
+				'Site configuration' => Egw::link('/index.php',array(
 					'menuaction' => 'admin.uiconfig.index',
 					'appname'    => $appname,
+					'ajax'       => 'true',
 				)),
-				'Global Categories'  => egw::link('/index.php',array(
+				'Global Categories'  => Egw::link('/index.php',array(
 					'menuaction' => 'admin.admin_categories.index',
 					'appname'    => $appname,
 					'global_cats'=> True,
+					'ajax'       => 'true',
 				)),
 			);
 			// custom fields are not availible in LDAP
 			if ($GLOBALS['egw_info']['server']['contact_repository'] != 'ldap')
 			{
-				$file['Custom fields'] = egw::link('/index.php',array(
+				$file['Custom fields'] = Egw::link('/index.php',array(
 					'menuaction' => 'admin.customfields.index',
 					'appname'    => $appname,
 					'use_private'=> 1,
@@ -95,7 +103,7 @@ class addressbook_hooks
 	}
 
 	/**
-	 * populates $settings for the preferences
+	 * populates $settings for the Api\Preferences
 	 *
 	 * @param array|string $hook_data
 	 * @return array
@@ -116,7 +124,7 @@ class addressbook_hooks
 			'label'  => 'Default addressbook for adding contacts',
 			'name'   => 'add_default',
 			'help'   => 'Which addressbook should be selected when adding a contact AND you have no add rights to the current addressbook.',
-			'values' => !$hook_data['setup'] ? ExecMethod('addressbook.addressbook_ui.get_addressbooks',EGW_ACL_ADD) : array(),
+			'values' => !$hook_data['setup'] ? ExecMethod('addressbook.addressbook_ui.get_addressbooks',Acl::ADD) : array(),
 			'xmlrpc' => True,
 			'admin'  => False,
 		);
@@ -140,7 +148,8 @@ class addressbook_hooks
 			'xmlrpc' => True,
 			'admin'  => false,
 		);
-		$fileas_options = ExecMethod('addressbook.addressbook_bo.fileas_options');
+		$contacts = new Api\Contacts();
+		$fileas_options = $contacts->fileas_options();
 		$settings['link_title'] = array(
 			'type'   => 'select',
 			'label'  => 'Link title for contacts show',
@@ -153,15 +162,18 @@ class addressbook_hooks
 			'admin'  => false,
 			'default'=> 'org_name: n_family, n_given',
 		);
-    	$settings['link_title_cf'] = array(
-			'type'  => 'select',
-			'label' => 'Add a customfield to link title',
-			'name'  => 'link_title_cf',
-			'values' => addressbook_bo::cf_options(),
-			'help'  =>  'Add customfield to links of addressbook, which displays in other applications. The default value is none customfield.',
-			'xmlrpc' => True,
-			'admin'  => false,
-		);
+		if (($cf_opts = Api\Contacts::cf_options()))
+		{
+			$settings['link_title_cf'] = array(
+				'type'  => 'select',
+				'label' => 'Add a customfield to link title',
+				'name'  => 'link_title_cf',
+				'values' => $cf_opts,
+				'help'  =>  'Add customfield to links of addressbook, which displays in other applications. The default value is none customfield.',
+				'xmlrpc' => True,
+				'admin'  => false,
+			);
+		}
 		$settings['addr_format'] = array(
 			'type'   => 'select',
 			'label'  => 'Default address format',
@@ -203,6 +215,22 @@ class addressbook_hooks
 			'admin'  => false,
 			'default'=> 'infolog',
 		);
+
+		$settings['geolocation_src'] = array(
+			'type'   => 'select',
+			'label'  => 'Default GeoLocation source address',
+			'name'   => 'geolocation_src',
+			'values' => array(
+				'browser' => lang('Browser location'),
+				'one' => lang('Business address'),
+				'two' => lang('Private address')
+			),
+			'help'   => 'Select a source address to be used in GeoLocation routing system',
+			'xmlrpc' => True,
+			'admin'  => false,
+			'default'=> 'browser',
+		);
+
 		$settings[] = array(
 			'type'  => 'section',
 			'title' => lang('Data exchange settings'),
@@ -221,7 +249,7 @@ class addressbook_hooks
 				'name'   => 'default_document',
 				'help'   => lang('If you specify a document (full vfs path) here, %1 displays an extra document icon for each entry. That icon allows to download the specified document with the data inserted.', lang('addressbook')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','n_fn').' '.
-					lang('The following document-types are supported:'). implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:'). implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -233,7 +261,7 @@ class addressbook_hooks
 				'name'   => 'document_dir',
 				'help'   => lang('If you specify a directory (full vfs path) here, %1 displays an action for each document. That action allows to download the specified document with the data inserted.',lang('addressbook')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','n_fn').' '.
-					lang('The following document-types are supported:'). implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:'). implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -273,10 +301,11 @@ class addressbook_hooks
 				}
 				catch (Exception $e)
 				{
+					unset($e);
 					// permission error
 					continue;
 				}
-				if ($title = $definition->get_title())
+				if (($title = $definition->get_title()))
 				{
 					$options[$title] = $title;
 				}
@@ -298,7 +327,7 @@ class addressbook_hooks
 				'type'   => 'select',
 				'label'  => 'Charset for the vCard import and export',
 				'name'   => 'vcard_charset',
-				'values' => translation::get_installed_charsets(),
+				'values' => Api\Translation::get_installed_charsets(),
 				'help'   => 'Which charset should be used for the vCard import and export.',
 				'xmlrpc' => True,
 				'admin'  => false,
@@ -316,10 +345,12 @@ class addressbook_hooks
 	 */
 	static function search_link($location)
 	{
+		unset($location);	// not used, but required by function signature
+
 		$links = array(
-			'query' => 'addressbook.addressbook_bo.link_query',
-			'title' => 'addressbook.addressbook_bo.link_title',
-			'titles' => 'addressbook.addressbook_bo.link_titles',
+			'query' => 'api.EGroupware\\Api\\Contacts.link_query',
+			'title' => 'api.EGroupware\\Api\\Contacts.link_title',
+			'titles' => 'api.EGroupware\\Api\\Contacts.link_titles',
 			'view' => array(
 				'menuaction' => 'addressbook.addressbook_ui.view',
 				'ajax' => 'true'
@@ -333,20 +364,20 @@ class addressbook_hooks
 				'menuaction' => 'addressbook.addressbook_ui.edit'
 			),
 			'edit_id' => 'contact_id',
-			'edit_popup'  => '859x550',
+			'edit_popup'  => '870x610',
 			'add' => array(
 				'menuaction' => 'addressbook.addressbook_ui.edit'
 			),
 			'add_app'    => 'link_app',
 			'add_id'     => 'link_id',
-			'add_popup'  => '859x550',
+			'add_popup'  => '870x610',
 			'file_access_user' => true,	// file_access supports 4th parameter $user
-			'file_access'=> 'addressbook.addressbook_bo.file_access',
+			'file_access'=> 'api.EGroupware\\Api\\Contacts.file_access',
 			'default_types' => array('n' => array('name' => 'contact', 'options' => array('icon' => 'navbar.png','template' => 'addressbook.edit'))),
 			// registers an addtional type 'addressbook-email', returning only contacts with email, title has email appended
 			'additional' => array(
 				'addressbook-email' => array(
-					'query' => 'addressbook.addressbook_bo.link_query_email',
+					'query' => 'api.EGroupware\\Api\\Contacts.link_query_email',
 					'view' => array(
 						'menuaction' => 'addressbook.addressbook_ui.view',
 						'ajax' => 'true'
@@ -369,6 +400,8 @@ class addressbook_hooks
 	 */
 	static function getAppExportLimit($location)
 	{
+		unset($location);	// not used, but required by function signature
+
 		return $GLOBALS['egw_info']['server']['contact_export_limit'];
 	}
 
@@ -380,9 +413,11 @@ class addressbook_hooks
 	 */
 	static function calendar_resources($args)
 	{
+		unset($args);	// not used, but required by function signature
+
 		return array(
 			'type' => 'c',// one char type-identifiy for this resources
-			'info' => 'addressbook.addressbook_bo.calendar_info',// info method, returns array with id, type & name for a given id
+			'info' => 'api.EGroupware\\Api\\Contacts.calendar_info',// info method, returns array with id, type & name for a given id
 		);
 	}
 
@@ -394,6 +429,8 @@ class addressbook_hooks
 	 */
 	static function group_acl($args)
 	{
+		unset($args);	// not used, but required by function signature
+
 		// addressbook uses group-acl, only if contacts-backend is NOT LDAP, as the ACL can not be modified there
 		return $GLOBALS['egw_info']['server']['contact_repository'] != 'ldap';
 	}
@@ -406,22 +443,26 @@ class addressbook_hooks
 	 */
 	static function not_enum_group_acls($data)
 	{
+		unset($data);	// not used, but required by function signature
+
 		return true;
 	}
 
 	/**
 	 * ACL rights and labels used
 	 *
-	 * @param string|array string with location or array with parameters incl. "location", specially "owner" for selected acl owner
-	 * @return array acl::(READ|ADD|EDIT|DELETE|PRIVAT|CUSTOM(1|2|3)) => $label pairs
+	 * @param string|array string with location or array with parameters incl. "location", specially "owner" for selected Acl owner
+	 * @return array Acl::(READ|ADD|EDIT|DELETE|PRIVAT|CUSTOM(1|2|3)) => $label pairs
 	 */
 	public static function acl_rights($params)
 	{
+		unset($params);	// not used, but required by function signature
+
 		return array(
-			acl::READ    => 'read',
-			acl::EDIT    => 'edit',
-			acl::ADD     => 'add',
-			acl::DELETE  => 'delete',
+			Acl::READ    => 'read',
+			Acl::EDIT    => 'edit',
+			Acl::ADD     => 'add',
+			Acl::DELETE  => 'delete',
 		);
 	}
 
@@ -433,19 +474,94 @@ class addressbook_hooks
 	 */
 	public static function categories($data)
 	{
+		unset($data);	// not used, but required by function signature
+
 		return true;
 	}
 
 	/**
-	 * Hook returning options for deny_acl groups
+	 * Called before displaying site configuration
 	 *
 	 * @param array $config
+	 * @return array with additional config to merge and "sel_options" values
 	 */
-	public static function allow_account_edit($config)
+	public static function config(array $config)
 	{
-		$accountsel = new uiaccountsel();
+		$bocontacts = new Api\Contacts();
 
-		return '<input type="hidden" value="" name="newsettings[allow_account_edit]" />'.
-			$accountsel->selection('newsettings[allow_account_edit]', 'allow_account_edit', $config['allow_account_edit'], 'groups', 4);
+		// get the list of account fields
+		$own_account_acl = array();
+		foreach($bocontacts->contact_fields as $field => $label)
+		{
+			// some fields the user should never be allowed to edit or are covert by an other attribute (n_fn for all n_*)
+			if (!in_array($field,array('id','tid','owner','created','creator','modified','modifier','private','n_prefix','n_given','n_middle','n_family','n_suffix')))
+			{
+				$own_account_acl[$field] = $label;
+			}
+		}
+		$own_account_acl['link_to'] = 'Links';
+		if ($config['account_repository'] != 'ldap')	// no custom-fields in ldap
+		{
+			foreach(Api\Storage\Customfields::get('addressbook') as $name => $data)
+			{
+				$own_account_acl['#'.$name] = $data['label'];
+			}
+		}
+
+		$org_fields = $own_account_acl;
+		unset($org_fields['n_fn'], $org_fields['account_id']);
+		// Remove country codes as an option, it will be added by BO constructor
+		unset($org_fields['adr_one_countrycode'], $org_fields['adr_two_countrycode']);
+
+		$supported_fields = $bocontacts->get_fields('supported',null,0);	// fields supported by the backend (ldap schemas!)
+		// get the list of account fields
+		$copy_fields = array();
+		foreach($bocontacts->contact_fields as $field => $label)
+		{
+			// some fields the user should never be allowed to copy or are coverted by an other attribute (n_fn for all n_*)
+			if (!in_array($field,array('id','tid','created','creator','modified','modifier','account_id','uid','etag','n_fn')))
+			{
+				$copy_fields[$field] = $label;
+			}
+		}
+		if ($config['contact_repository'] != 'ldap')	// no custom-fields in ldap
+		{
+			foreach(Api\Storage\Customfields::get('addressbook') as $name => $data)
+			{
+				$copy_fields['#'.$name] = $data['label'];
+			}
+		}
+		// Remove country codes as an option, it will be added by UI constructor
+		if(in_array('adr_one_countrycode', $supported_fields))
+		{
+			unset($copy_fields['adr_one_countrycode'], $copy_fields['adr_two_countrycode']);
+		}
+
+		$repositories = array('sql' => 'SQL');
+		// check account-repository, contact-repository LDAP is only availible for account-repository == ldap
+		if ($config['account_repository'] == 'ldap' || !$config['account_repository'] && $config['auth_type'] == 'ldap')
+		{
+			$repositories['ldap'] = 'LDAP';
+			$repositories['sql-ldap'] = 'SQL --> LDAP ('.lang('read only').')';
+		}
+		// geolocation pre-defined maps
+		$geoLocation = array(
+			array('value' => 'https://maps.here.com/directions/drive{{%rs=/%rs}}%r0,%t0,%z0,%c0{{%d=/%d}}%r1,%t1,%z1+%c1', 'label' => 'Here Maps'),
+			array('value' => 'http://maps.google.com/{{%rs=?saddr=%rs}}%r0+%t0+%z0+%c0{{%d=&daddr=%d}}%r1+%t1+%z1+%c1', 'label' => 'Google Maps'),
+			array('value' => 'https://www.bing.com/maps/{{%rs=?rtp=adr.%rs}}%r0+%t0+%z0+%c0{{%d=~adr.%d}}%r1+%t1+%z1+%c1', 'label' => 'Bing Maps')
+		);
+		$ret = array(
+			'sel_options' => array(
+				'own_account_acl' => $own_account_acl,
+				'org_fileds_to_update' => $org_fields,	// typo has to stay, as it was there allways and we would loose existing config :(
+				'copy_fields' => $copy_fields,
+				'fileas' => $bocontacts->fileas_options(),
+				'contact_repository' => $repositories,
+				'geolocation_url' => $geoLocation
+			)
+		);
+
+		if (empty($config['geolocation_url']))	$ret ['geolocation_url'] = $geoLocation[0]['value'];
+		return $ret;
 	}
 }
