@@ -62,8 +62,8 @@ app.classes.addressbook = AppJS.extend(
 				var content = this.et2.getArrayMgr('content').data;
 				if (typeof content.showsearchbuttons == 'undefined' || !content.showsearchbuttons)
 				{
-					this.show_custom_country($j('select[id*="adr_one_countrycode"]').get(0));
-					this.show_custom_country($j('select[id*="adr_two_countrycode"]').get(0));
+					this.show_custom_country(jQuery('select[id*="adr_one_countrycode"]').get(0));
+					this.show_custom_country(jQuery('select[id*="adr_two_countrycode"]').get(0));
 
 					// Instanciate infolog JS too - wrong app, so it won't be done automatically
 					if(typeof window.app.infolog != 'object' && typeof window.app.classes['infolog'] == 'function')
@@ -90,6 +90,75 @@ app.classes.addressbook = AppJS.extend(
 		});
 	},
 
+/**
+	 * Observer method receives update notifications from all applications
+	 *
+	 * App is responsible for only reacting to "messages" it is interested in!
+	 *
+	 * Addressbook checks for CRM view to update the displayed data if you edit
+	 * that contact
+	 *
+	 * @param {string} _msg message (already translated) to show, eg. 'Entry deleted'
+	 * @param {string} _app application name
+	 * @param {(string|number)} _id id of entry to refresh or null
+	 * @param {string} _type either 'update', 'edit', 'delete', 'add' or null
+	 * - update: request just modified data from given rows.  Sorting is not considered,
+	 *		so if the sort field is changed, the row will not be moved.
+	 * - edit: rows changed, but sorting may be affected.  Requires full reload.
+	 * - delete: just delete the given rows clientside (no server interaction neccessary)
+	 * - add: requires full reload for proper sorting
+	 * @param {string} _msg_type 'error', 'warning' or 'success' (default)
+	 * @param {object|null} _links app => array of ids of linked entries
+	 * or null, if not triggered on server-side, which adds that info
+	 * @return {false|*} false to stop regular refresh, thought all observers are run
+	 */
+	observer: function(_msg, _app, _id, _type, _msg_type, _links)
+	{
+		// Edit to the current entry
+		var state = this.getState();
+		if(_app === 'addressbook' && state && state.type && state.type === 'view' && state.id === _id)
+		{
+			var content = egw.dataGetUIDdata('addressbook::'+_id);
+			if (content.data)
+			{
+				var view = etemplate2.getById('addressbook-view');
+				if(view)
+				{
+					view.widgetContainer._children[0].set_value({content:content.data});
+				}
+			}
+			return false;
+		}
+		else if(_app === 'calendar')
+		{
+			// Event changed, update any [known] contacts participating
+			var content = egw.dataGetUIDdata(_app+'::'+_id);
+			if (content && content.data && content.data.participant_types && content.data.participant_types.c)
+			{
+				for(var contact in content.data.participant_types.c)
+				{
+					// Refresh handles checking to see if the contact is known,
+					// and updating it directly
+					egw.dataRefreshUID('addressbook::'+contact);
+				}
+				return true;
+			}
+			else if (!content)
+			{
+				// No data on the event, we'll have to reload if calendar column is visible
+				// to get the updated information
+				var nm = etemplate2.getById('addressbook-index').widgetContainer.getWidgetById('nm');
+				var pref = nm ? nm._getPreferences() : false;
+				if(pref && pref.visible.indexOf('calendar_calendar') > -1)
+				{
+					nm.refresh(null,'update');
+				}
+			}
+		}
+
+		return true;
+	},
+
 	/**
 	 * Open CRM view
 	 *
@@ -122,7 +191,7 @@ app.classes.addressbook = AppJS.extend(
 	{
 		// Find the infolog list
 		var list = etemplate2.getById(
-			$j(this.et2.getInstanceManager().DOMContainer).nextAll('.et2_container').attr('id')
+			jQuery(this.et2.getInstanceManager().DOMContainer).nextAll('.et2_container').attr('id')
 		);
 		var nm = list ? list.widgetContainer.getWidgetById('nm') : null;
 		if(nm)
@@ -166,6 +235,7 @@ app.classes.addressbook = AppJS.extend(
 	{
 		var extras = {
 			filter: 'all',
+			cat_id: '',
 			owner: []
 		};
 		var orgs = [];
@@ -224,7 +294,7 @@ app.classes.addressbook = AppJS.extend(
 		}
 		else
 		{
-			var ids = "";
+			var ids = egw.user('account_id')+',';
 			for (var i = 0; i < _senders.length; i++)
 			{
 				// Remove UID prefix for just contact_id
@@ -461,20 +531,6 @@ app.classes.addressbook = AppJS.extend(
 		egw.json('addressbook.addressbook_ui.ajax_check_values', [values, widget.id, own_id],this._confirmdialog_callback,this,true,this).sendRequest();
 	},
 
-	add_whole_list: function(list)
-	{
-		if (document.getElementById("exec[nm][email_type][email_home]").checked == true)
-		{
-			email_type = "email_home";
-		}
-		else
-		{
-			email_type = "email";
-		}
-		var request = new egw_json_request("addressbook.addressbook_ui.ajax_add_whole_list",list,email_type);
-		request.sendRequest(true);
-	},
-
 	show_custom_country: function(selectbox)
 	{
 		if(!selectbox) return;
@@ -489,7 +545,7 @@ app.classes.addressbook = AppJS.extend(
 			{
 				selectbox.value = "-custom-";
 				// Chosen needs this to update
-				$j(selectbox).trigger("liszt:updated");
+				jQuery(selectbox).trigger("liszt:updated");
 
 				custom_field.style.display = "inline";
 			}
@@ -594,19 +650,6 @@ app.classes.addressbook = AppJS.extend(
 		}
 	},
 
-	filter2_onchnage_email: function ()
-	{
-		this.form.submit();
-		if (this.value && confirm('Add emails of whole distribution list?'))
-		{
-			this.add_whole_list(this.value);
-		}
-		else
-		{
-			this.form.submit();
-		}
-	},
-
 	/**
 	 * Method to enable actions by comparing a field with given value
 	 */
@@ -819,6 +862,28 @@ app.classes.addressbook = AppJS.extend(
 			egw.open('',this.appname,'list',{'favorite': safe_name},this.appname);
 			return false;
 		}
+		else if (jQuery.isEmptyObject(state))
+		{
+			// Regular handling first to clear everything but advanced search
+			this._super.apply(this, arguments);
+
+			// Clear advanced search, which is in session and etemplate
+			egw.json('addressbook.addressbook_ui.ajax_clear_advanced_search',[], function() {
+				framework.setWebsiteTitle('addressbook','');
+				var index = etemplate2.getById('addressbook-index');
+				if(index && index.widgetContainer)
+				{
+					var nm = index.widgetContainer.getWidgetById('nm');
+					if(nm)
+					{
+						nm.applyFilters({
+							advanced_search: false
+						});
+					}
+				}
+			},this).sendRequest(true);
+			return false;
+		}
 		return this._super.apply(this, arguments);
 	},
 
@@ -868,5 +933,160 @@ app.classes.addressbook = AppJS.extend(
 	{
 		var widget = this.et2.getWidgetById('n_fn');
 		if(widget) return widget.options.value;
+	},
+
+	/**
+	 * Enable/Disable geolocation action items in contextmenu base on address availabilty
+	 *
+	 * @param {egwAction} _action
+	 * @param {egwActionObject[]} _selected selected rows
+	 * @returns {boolean} return false if no address found
+	 */
+	geoLocation_enabled: function(_action, _selected)
+	{
+		// multiple selection is not supported
+		if (_selected.length>1) return false;
+
+		var url = this.getGeolocationConfig();
+
+		// exit if no url or invalide url given
+		if (!url || typeof url === 'undefined' || typeof url !== 'string')
+		{
+			egw.debug('warn','no url or invalid url given as geoLocationUrl');
+			return false;
+		}
+		var content = egw.dataGetUIDdata(_selected[0].id);
+
+		// Selected, but data not found
+		if(!content || typeof content.data === 'undefined') return false;
+
+		var type = _action.id === 'business'?'one':'two';
+		var addrs = [
+			content.data['adr_'+type+'_street'],
+			content.data['adr_'+type+'_locality'],
+			content.data['adr_'+type+'_countrycode'],
+			content.data['adr_'+type+'_postalcode']
+		];
+
+		var fields = '';
+		// Replcae placeholders with acctual values
+		for (var i=0;i < addrs.length; i++)
+		{
+			fields += addrs[i] ? addrs[i] : '';
+		}
+		return (url !== '' && fields !== '')?true:false;
+	},
+
+	/**
+	 * Generate a geo location URL based on geolocation_url in
+	 * site configuration
+	 *
+	 * @param {object} _dest_data
+	 * @param {string} _dest_type type of destination address ('one'| 'two')
+	 * @param {object} _src_data address data to be used as source contact data|coordination object
+	 * @param {string} _src_type type of source address ('browser'|'one'|'two')
+	 * @returns {Boolean|string} return url and return false if no address
+	 */
+	geoLocationUrl: function (_dest_data, _dest_type,_src_data, _src_type)
+	{
+		var dest_type = _dest_type || 'one';
+		var url = this.getGeolocationConfig();
+
+		// exit if no url or invalide url given
+		if (!url || typeof url === 'undefined' || typeof url !== 'string')
+		{
+			egw.debug('warn','no url or invalid url given as geoLocationUrl');
+			return false;
+		}
+
+		// array of placeholders with their representing values
+		var	addrs = [
+
+			[ // source address
+				{id:'r0',val:_src_type === 'browser'?_src_data.latitude:_src_data['adr_'+_src_type+'_street']},
+				{id:'t0',val:_src_type === 'browser'?_src_data.longitude:_src_data['adr_'+_src_type+'_locality']},
+				{id:'c0',val:_src_type === 'browser'?'':_src_data['adr_'+_src_type+'_countrycode']},
+				{id:'z0',val:_src_type === 'browser'?'':_src_data['adr_'+_src_type+'_postalcode']}
+			],
+			[ // destination address
+				{id:'r1',val:_dest_data['adr_'+dest_type+'_street']},
+				{id:'t1',val:_dest_data['adr_'+dest_type+'_locality']},
+				{id:'c1',val:_dest_data['adr_'+dest_type+'_countrycode']},
+				{id:'z1',val:_dest_data['adr_'+dest_type+'_postalcode']}
+			]
+		];
+
+		var src_param = url.match(/{{%rs=.*%rs}}/ig);
+		if (src_param[0])
+		{
+			src_param = src_param[0].replace(/{{%rs=/,'');
+			src_param = src_param.replace(/%rs}}/,'');
+			url = url.replace(/{{%rs=.*%rs}}/, src_param);
+		}
+
+		var d_param = url.match(/{{%d=.*%d}}/ig);
+		if (d_param[0])
+		{
+			d_param = d_param[0].replace(/{{%d=/,'');
+			d_param = d_param.replace(/%d}}/,'');
+			url = url.replace(/{{%d=.*%d}}/, d_param);
+		}
+
+		// Replcae placeholders with acctual values
+		for (var j=0;j<addrs.length;j++)
+		{
+			for (var i=0;i < addrs[j].length; i++)
+			{
+				url = url.replace('%'+addrs[j][i]['id'], addrs[j][i]['val']? addrs[j][i]['val'] : "");
+			}
+		}
+		return url !== ''? url : false;
+	},
+
+	/**
+	 * Open a popup base on selected address in provided map
+	 *
+	 * @param {object} _action
+	 * @param {object} _selected
+	 */
+	geoLocationExec: function (_action, _selected)
+	{
+		var content = egw.dataGetUIDdata(_selected[0].id);
+		var geolocation_src = egw.preference('geolocation_src','addressbook');
+		var self = this;
+
+		if (geolocation_src === 'browser' && navigator.geolocation)
+		{
+			navigator.geolocation.getCurrentPosition(function(position){
+				if (position && position.coords)
+				{
+					var url = self.geoLocationUrl(content.data,_action.id === 'business'?'one':'two', position.coords, 'browser');
+					window.open(url,'_blank');
+				}
+			});
+		}
+		else
+		{
+			egw.json('addressbook.addressbook_ui.ajax_get_contact', [egw.user('account_id')],function(_data){
+				var url = self.geoLocationUrl(content.data,_action.id === 'business'?'one':'two', _data, geolocation_src === 'browser'?'one':geolocation_src);
+				window.open(url,'_blank');
+			}).sendRequest();
+
+		}
+	},
+
+	/**
+	 * Get geolocation_url stored in config|default url
+	 *
+	 * @returns {String}
+	 */
+	getGeolocationConfig: function()
+	{
+		// This default url should be identical to the first value of geolocation_url array
+		// defined in addressbook_hooks::config
+		var default_url = 'https://maps.here.com/directions/drive{{%rs=/%rs}}%r0,%t0,%z0,%c0{{%d=/%d}}%r1,%t1,%z1+%c1';
+		var geo_url = egw.config('geolocation_url');
+		if (geo_url) geo_url = geo_url[0];
+		return geo_url || default_url;
 	}
 });
