@@ -10,7 +10,7 @@
 /* Basic information about this app */
 $setup_info['addressbook']['name']      = 'addressbook';
 $setup_info['addressbook']['title']     = 'Addressbook';
-$setup_info['addressbook']['version']   = '14.1';
+$setup_info['addressbook']['version']   = '16.1';
 $setup_info['addressbook']['app_order'] = 4;
 $setup_info['addressbook']['enable']    = 1;
 $setup_info['addressbook']['index']    = 'addressbook.addressbook_ui.index&ajax=true';
@@ -41,7 +41,7 @@ $setup_info['addressbook']['hooks']['deletegroup'] = 'addressbook.addressbook_bo
 $setup_info['addressbook']['hooks']['delete_category'] = 'addressbook.addressbook_bo.delete_category';
 $setup_info['addressbook']['hooks']['search_link'] = 'addressbook_hooks::search_link';
 $setup_info['addressbook']['hooks']['calendar_resources'] = 'addressbook_hooks::calendar_resources';
-$setup_info['addressbook']['hooks'][] = 'config';
+$setup_info['addressbook']['hooks']['config'] = 'addressbook_hooks::config';
 $setup_info['addressbook']['hooks']['group_acl'] = 'addressbook_hooks::group_acl';
 $setup_info['addressbook']['hooks']['not_enum_group_acls'] = 'addressbook_hooks::not_enum_group_acls';
 $setup_info['addressbook']['hooks']['export_limit'] = 'addressbook_hooks::getAppExportLimit';
@@ -51,12 +51,8 @@ $setup_info['addressbook']['hooks']['groupdav_root_props'] = 'addressbook_groupd
 
 /* Dependencies for this app to work */
 $setup_info['addressbook']['depends'][] = array(
-	'appname' => 'phpgwapi',
-	'versions' => Array('14.1')
-);
-$setup_info['addressbook']['depends'][] = array(
-	'appname' => 'etemplate',
-	'versions' => Array('14.1')
+	'appname' => 'api',
+	'versions' => Array('16.1')
 );
 
 // installation checks for addresbook
