@@ -6,11 +6,15 @@
  * @link http://www.egroupware.org
  * @package admin
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2006-13 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Vfs;
+
 chdir(dirname(__FILE__));	// to enable our relative pathes to work
 
 if (php_sapi_name() !== 'cli')	// security precaution: forbit calling admin-cli as web-page
@@ -60,9 +64,10 @@ switch($action)
 	case '--change-account-id':
 		return do_change_account_id($arg0s);
 
+	/* ToDo: get this working again
 	case '--subscribe-other':
 		return do_subscribe_other($arg0s[2],$arg0s[3]);
-
+	*/
 	case '--check-acl';
 		return do_check_acl();
 
@@ -84,7 +89,7 @@ switch($action)
 				list($name,$value) = explode('=',$arg,2);
 				if(property_exists('admin_cmd',$name))		// dont allow to overwrite admin_cmd properties
 				{
-					throw new egw_exception_wrong_userinput(lang("Invalid argument '%1' !!!",$arg),90);
+					throw new Api\Exception\WrongUserinput(lang("Invalid argument '%1' !!!",$arg),90);
 				}
 				if (substr($name,-1) == ']')	// allow 1-dim. arrays
 				{
@@ -174,8 +179,8 @@ function run_command(admin_cmd $cmd)
 		{
 			$url = $GLOBALS['egw_info']['server']['webserver_url'].'/json.php?menuaction=admin.admin_hooks.ajax_clear_cache';
 			if ($url[0] == '/') $url = 'http://'.(!empty($domain) && $domain != 'default' ? $domain : 'localhost').$url;
-			$data = file_get_contents($url, false, egw_framework::proxy_context($user,$arg0s[1]));
-			//error_log("file_get_contents('$url') returned ".array2string($data));
+			$data = file_get_contents($url, false, Framework::proxy_context($user,$arg0s[1]));
+			error_log("file_get_contents('$url') returned ".array2string($data));
 			if ($data && strpos($data, '"success"') !== false)
 			{
 				error_log('Instance cache cleared.');
@@ -186,7 +191,7 @@ function run_command(admin_cmd $cmd)
 			}
 		}
 	}
-	catch (egw_exception_wrong_userinput $e) {
+	catch (Api\Exception\WrongUserinput $e) {
 		echo "\n".$e->getMessage()."\n\n";
 		exit($e->getCode());
 	}
@@ -270,7 +275,7 @@ function load_egw($user,$passwd,$domain='default')
 			_check_pw($GLOBALS['egw_domain'][$_GET['domain']]['config_passwd'],$passwd))
 		{
 			echo "\nRoot access granted!\n";
-			egw_vfs::$is_root = true;
+			Vfs::$is_root = true;
 		}
 		else
 		{
@@ -299,11 +304,12 @@ function _check_pw($hash_or_cleartext,$pw)
 /**
  * Give a usage message and exit
  *
- * @param string $action=null
- * @param int $ret=0 exit-code
+ * @param string $action =null
+ * @param int $ret =0 exit-code
  */
 function usage($action=null,$ret=0)
 {
+	unset($action);
 	$cmd = basename($_SERVER['argv'][0]);
 	echo "Usage: $cmd --command admin-account[@domain],admin-password,options,... [--schedule {YYYY-mm-dd|+1 week|+5 days}] [--requested 'Name <email>'] [--comment 'comment ...'] [--remote {id|name}] [--skip-checks] [--dry-run]\n\n";
 
@@ -373,15 +379,16 @@ function do_edit_group($args)
 	try {
 		admin_cmd::parse_account($account,false);
 
-		foreach($data as $name => &$value)	// existing account --> empty values mean dont change, not set them empty!
+		foreach($data as &$value)	// existing account --> empty values mean dont change, not set them empty!
 		{
 			if ((string)$value === '') $value = null;
 		}
 	}
 	catch (Exception $e) {	// new group
+		unset($e);	// not used
 		$data['account_lid'] = $account;
 		$account = false;
-	};
+	}
 	run_command(new admin_cmd_edit_group($account,$data));
 }
 
@@ -404,7 +411,7 @@ function do_change_pw($args)
  * Edit or add a user to EGroupware. If you specify groups, they *replace* the exiting memberships!
  *                    1:                     2:             3:                         4:         5:        6:       7:    8:                                         9:                                 10:                            11:                                  12
  * @param array $args admin-account[@domain],admin-password,account[=new-account-name],first-name,last-name,password,email,expires{never(default)|YYYY-MM-DD|already},can-change-pw{true(default)|false},anon-user{true|false(default)},primary-group{Default(default)|...}[,groups,...][,homedirectory,loginshell]
- * @param boolean $run_addaccount_hook=null default run hook depending on account existence, true=allways run addaccount hook
+ * @param boolean $run_addaccount_hook =null default run hook depending on account existence, true=allways run addaccount hook
  */
 function do_edit_user($args,$run_addaccount_hook=null)
 {
@@ -437,12 +444,13 @@ function do_edit_user($args,$run_addaccount_hook=null)
 	try {
 		admin_cmd::parse_account($account,true);
 
-		foreach($data as $name => &$value)	// existing account --> empty values mean dont change, not set them empty!
+		foreach($data as &$value)	// existing account --> empty values mean dont change, not set them empty!
 		{
 			if ((string)$value === '') $value = null;
 		}
 	}
 	catch (Exception $e) {	// new account
+		unset($e);	// not used
 		$data['account_lid'] = $account;
 		$account = false;
 	}
@@ -453,8 +461,8 @@ function do_edit_user($args,$run_addaccount_hook=null)
  * Delete a given acount from eGW
  *
  * @param int/string $account account-name of -id
- * @param int/string $new_user=0 for users only: account to move the entries too
- * @param boolean $is_user=true are we called for a user or group
+ * @param int/string $new_user =0 for users only: account to move the entries too
+ * @param boolean $is_user =true are we called for a user or group
  * @return int 0 on success, 2-4 otherwise (see source)
  */
 function do_delete_account($account,$new_user=0,$is_user=true)
@@ -505,8 +513,9 @@ function list_exit_codes()
 	error_reporting(error_reporting() & ~E_NOTICE);
 
 	$codes = array('Ok');
-	foreach(file(__FILE__) as $n => $line)
+	foreach(file(__FILE__) as $line)
 	{
+		$matches = null;
 		if (preg_match('/fail\(([0-9]+),(.*)\);/',$line,$matches))
 		{
 			//echo "Line $n: $matches[1]: $matches[2]\n";
@@ -528,9 +537,11 @@ function list_exit_codes()
  */
 function do_subscribe_other($account_lid,$pw=null)
 {
+	unset($account_lid, $pw);
+	/* ToDo: this cant work, not even in 14.x
 	if (!($account_id = $GLOBALS['egw']->accounts->name2id($account_lid)))
 	{
-		throw new egw_exception_wrong_userinput(lang("Unknown account: %1 !!!",$account_lid),15);
+		throw new Api\Exception\WrongUserinput(lang("Unknown account: %1 !!!",$account_lid),15);
 	}
 	$GLOBALS['egw_info']['user'] = array(
 		'account_id' => $account_id,
@@ -562,14 +573,14 @@ function do_subscribe_other($account_lid,$pw=null)
 
 		if (!$pw) $mailbox = str_replace('INBOX','user'.$delimiter.$account_lid,$mailbox);
 
-/*		$rights = $icServer->getACL($mailbox);
-		echo "getACL($mailbox)\n";
-		foreach($rights as $data)
-		{
-			echo $data['USER'].' '.$data['RIGHTS']."\n";
-		}*/
+		//$rights = $icServer->getACL($mailbox);
+		//echo "getACL($mailbox)\n";
+		//foreach($rights as $data)
+		//{
+		//	echo $data['USER'].' '.$data['RIGHTS']."\n";
+		//}
 		echo "subscribing $mailbox for $account_lid\n";
 		//$icServer->subscribeMailbox($mailbox);
 		//exit;
-	}
+	}*/
 }
