@@ -5,11 +5,13 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package admin
- * @copyright (c) 2012 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2012-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * admin command: check categories for not (longer) existing accounts
  */
@@ -20,7 +22,7 @@ class admin_cmd_check_cats extends admin_cmd
 	/**
 	 * Constructor
 	 *
-	 * @param array $data=array() default parm from parent class, no real parameters
+	 * @param array $data =array() default parm from parent class, no real parameters
 	 */
 	function __construct($data=array())
 	{
@@ -30,7 +32,7 @@ class admin_cmd_check_cats extends admin_cmd
 	/**
 	 * give or remove run rights from a given account and application
 	 *
-	 * @param boolean $check_only=false only run the checks (and throw the exceptions), but not the command itself
+	 * @param boolean $check_only =false only run the checks (and throw the exceptions), but not the command itself
 	 * @return string success message
 	 */
 	protected function exec($check_only=false)
@@ -39,7 +41,7 @@ class admin_cmd_check_cats extends admin_cmd
 
 		admin_cmd::_instanciate_accounts();
 
-		return lang("%1 categories of not (longer) existing accounts deleted.", categories::delete_orphans());
+		return lang("%1 Api\Categories of not (longer) existing Api\Accounts deleted.", Api\Categories::delete_orphans());
 	}
 
 	/**
@@ -49,6 +51,6 @@ class admin_cmd_check_cats extends admin_cmd
 	 */
 	function __tostring()
 	{
-		return lang('Check categories for not (longer) existing accounts');
+		return lang('Check Api\Categories for not (longer) existing accounts');
 	}
 }
