@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupWare - Admin - importexport
+ * EGroupware - Admin - importexport
  *
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package admin
@@ -11,13 +11,14 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * class admin_egw_user_record
  * Record class needed for export
  */
 class admin_egw_user_record implements importexport_iface_egw_record
 {
-
 	private $identifier = '';
 	private $user = array();
 
@@ -28,8 +29,6 @@ class admin_egw_user_record implements importexport_iface_egw_record
 		'select' => array('account_status'),
 	);
 
-
-
 	/**
 	 * constructor
 	 * reads record from backend if identifier is given.
@@ -82,7 +81,7 @@ class admin_egw_user_record implements importexport_iface_egw_record
 	 *@return string title
 	 */
 	public function get_title() {
-		return common::grab_owner_name($this->identifier);
+		return Api\Accounts::username($this->identifier);
 	}
 
 	/**
@@ -114,14 +113,14 @@ class admin_egw_user_record implements importexport_iface_egw_record
 	public function get_icon() {
 		return 'user';
 	}
-	
+
 	/**
 	 * saves record into backend
 	 *
 	 * @return string identifier
 	 */
 	public function save ( $_dst_identifier ) {
-
+		unset($_dst_identifier);	// not used, but require by function signature
 	}
 
 	/**
@@ -131,7 +130,7 @@ class admin_egw_user_record implements importexport_iface_egw_record
 	 * @return string dst_identifier
 	 */
 	public function copy ( $_dst_identifier ) {
-
+		unset($_dst_identifier);	// not used, but require by function signature
 	}
 
 	/**
@@ -142,7 +141,7 @@ class admin_egw_user_record implements importexport_iface_egw_record
 	 * @return string dst_identifier
 	 */
 	public function move ( $_dst_identifier ) {
-
+		unset($_dst_identifier);	// not used, but require by function signature
 	}
 
 	/**
@@ -160,5 +159,4 @@ class admin_egw_user_record implements importexport_iface_egw_record
 	public function __destruct() {
 		unset ($this->user);
 	}
-
-} // end of egw_timesheet_record
+}
