@@ -10,6 +10,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+
 /**
  * Static hooks for admin application
  */
@@ -18,10 +21,10 @@ class admin_hooks
 	/**
 	 * Functions callable via menuaction
 	 *
-	 * @var unknown_type
+	 * @var array
 	 */
 	var $public_functions = array(
-		'register_all_hooks' => True,
+		'ajax_clear_cache' => True,
 	);
 
 	/**
@@ -55,59 +58,55 @@ class admin_hooks
 
 			if (! $GLOBALS['egw']->acl->check('site_config_acce',1,'admin'))
 			{
-				$file['Site Configuration']         = egw::link('/index.php','menuaction=admin.uiconfig.index&appname=admin');
+				$file['Site Configuration']         = Egw::link('/index.php','menuaction=admin.admin_config.index&appname=admin&ajax=true');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('account_access',1,'admin'))
 			{
 				$file['User Accounts']              = array(
 					'id' => '/accounts',
-					'icon' => common::image('addressbook', 'accounts'),
+					'icon' => Api\Image::find('addressbook', 'accounts'),
 				);
 			}
 
 			if (! $GLOBALS['egw']->acl->check('account_access',16,'admin'))
 			{
-				$file['Bulk password reset']        = egw::link('/index.php','menuaction=admin.admin_passwordreset.index&ajax=true');
+				$file['Bulk password reset']        = Egw::link('/index.php','menuaction=admin.admin_passwordreset.index&ajax=true');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('group_access',1,'admin'))
 			{
 				$file['User Groups']                = array(
 					'id' => '/groups',
-					'icon' => common::image('addressbook', 'group'),
+					'icon' => Api\Image::find('addressbook', 'group'),
 					'child' => 1,
 				);
 			}
 
-			if (! $GLOBALS['egw']->acl->check('applications_acc',1,'admin'))
-			{
-				$file['Applications']               = egw::link('/index.php','menuaction=admin.admin_applications.index');
-			}
 			if (! $GLOBALS['egw']->acl->check('global_categorie',1,'admin'))
 			{
-				$file['Global Categories']          = egw::link('/index.php','menuaction=admin.admin_categories.index&appname=phpgw&ajax=true');
+				$file['Global Categories']          = Egw::link('/index.php','menuaction=admin.admin_categories.index&appname=phpgw&ajax=true');
 			}
 
 			if (!$GLOBALS['egw']->acl->check('mainscreen_messa',1,'admin') || !$GLOBALS['egw']->acl->check('mainscreen_messa',2,'admin'))
 			{
-				$file['Change Main Screen Message'] = egw::link('/index.php','menuaction=admin.uimainscreen.index');
+				$file['Change Main Screen Message'] = Egw::link('/index.php','menuaction=admin.admin_messages.index');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('current_sessions',1,'admin'))
 			{
-				$file['View Sessions'] = egw::link('/index.php','menuaction=admin.admin_accesslog.sessions&ajax=true');
+				$file['View Sessions'] = Egw::link('/index.php','menuaction=admin.admin_accesslog.sessions&ajax=true');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('access_log_acces',1,'admin'))
 			{
-				$file['View Access Log'] = egw::link('/index.php','menuaction=admin.admin_accesslog.index&ajax=true');
+				$file['View Access Log'] = Egw::link('/index.php','menuaction=admin.admin_accesslog.index&ajax=true');
 			}
 
 			/* disable old EGroupware error_log, as it is not used anymore
 			if (! $GLOBALS['egw']->acl->check('error_log_access',1,'admin'))
 			{
-				$file['View Error Log']  = egw::link('/index.php','menuaction=admin.uilog.list_log');
+				$file['View Error Log']  = Egw::link('/index.php','menuaction=admin.uilog.list_log');
 			}*/
 
 			if (! $GLOBALS['egw']->acl->check('applications_acc',16,'admin'))
@@ -122,24 +121,24 @@ class admin_hooks
 
 			if (! $GLOBALS['egw']->acl->check('asyncservice_acc',1,'admin'))
 			{
-				$file['Asynchronous timed services'] = egw::link('/index.php','menuaction=admin.uiasyncservice.index');
+				$file['Asynchronous timed services'] = Egw::link('/index.php','menuaction=admin.admin_asyncservice.index');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('db_backup_access',1,'admin'))
 			{
-				$file['DB backup and restore'] = egw::link('/index.php','menuaction=admin.admin_db_backup.index');
+				$file['DB backup and restore'] = Egw::link('/index.php','menuaction=admin.admin_db_backup.index');
 			}
 
 			if (! $GLOBALS['egw']->acl->check('info_access',1,'admin'))
 			{
-				$file['phpInfo']         = "javascript:egw.openPopup('" . egw::link('/admin/phpinfo.php','',false) . "',960,600,'phpinfoWindow')";
+				$file['phpInfo']         = "javascript:egw.openPopup('" . Egw::link('/admin/phpinfo.php','',false) . "',960,600,'phpinfoWindow')";
 			}
-			$file['Admin queue and history'] = egw::link('/index.php','menuaction=admin.admin_cmds.index');
-			$file['Remote administration instances'] = egw::link('/index.php','menuaction=admin.admin_cmds.remotes');
-			$file['Custom translation'] = egw::link('/index.php','menuaction=admin.admin_customtranslation.index');
-			$file['Changelog and versions'] = egw::link('/about.php');
+			$file['Admin queue and history'] = Egw::link('/index.php','menuaction=admin.admin_cmds.index&ajax=true');
+			$file['Remote administration instances'] = Egw::link('/index.php','menuaction=admin.admin_cmds.remotes&ajax=true');
+			$file['Custom translation'] = Egw::link('/index.php','menuaction=admin.admin_customtranslation.index');
+			$file['Changelog and versions'] = Egw::link('/index.php','menuaction=api.EGroupware\\Api\\Framework\\About.index&ajax=true');
 
-			$file['Submit statistic information'] = egw::link('/index.php','menuaction=admin.admin_statistics.submit');
+			$file['Submit statistic information'] = Egw::link('/index.php','menuaction=admin.admin_statistics.submit');
 
 			if ($location == 'admin')
 			{
@@ -157,7 +156,7 @@ class admin_hooks
 	}
 
 	/**
-	 * Clears instance cache and register hooks
+	 * Clears instance cache (and thereby also refreshes hooks)
 	 */
 	function ajax_clear_cache()
 	{
@@ -165,20 +164,18 @@ class admin_hooks
 		{
 			$GLOBALS['egw']->redirect_link('/index.php');
 		}
-		egw_cache::flush(egw_cache::INSTANCE);
+		Api\Cache::flush(Api\Cache::INSTANCE);
 
-		$GLOBALS['egw']->hooks->register_all_hooks();
+		Api\Image::invalidate();
 
-		common::delete_image_map();
-
-		if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+		if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// Egw object in setup is limited
 		{
 			$GLOBALS['egw']->invalidate_session_cache();	// in case with cache the egw_info array in the session
 		}
 		// allow apps to hook into "Admin >> Clear cache and register hooks"
-		$GLOBALS['egw']->hooks->process('clear_cache', array(), true);
+		Api\Hooks::process('clear_cache', array(), true);
 
-		egw_json_response::get()->apply('egw.message', array(lang('Done'), 'success'));
+		Api\Json\Response::get()->apply('egw.message', array(lang('Done'), 'success'));
 	}
 
 	/**
@@ -213,10 +210,62 @@ class admin_hooks
 			$actions[] = array(
 				'description' => 'Deny access',
 				'url'         => '/index.php',
-				'extradata'   => 'menuaction=admin.uiaclmanager.list_apps',
+				'extradata'   => 'menuaction=admin.admin_denyaccess.list_apps',
 				'icon'        => 'cancel',
 			);
 		}
+
+		// currently no way to deny Admins access to administrate mail
+		// we could add a deny check as for other admin functionality
+		{
+			$actions[] = array(
+				'id'      => 'mail_account',
+				'caption' => 'mail account',
+				'url'     => 'menuaction=admin.admin_mail.edit&account_id=$id',
+				'popup'   => '720x530',
+				'icon'    => 'mail/navbar',
+			);
+
+			$emailadmin = Api\Mail\Account::get_default();
+			if ($emailadmin->acc_smtp_type && $emailadmin->acc_smtp_type !== 'EGroupware\Api\Mail\Smtp')
+			{
+				$actions[] = array (
+					'id'       => 'mail_activeAccounts',
+					'caption'  => '(de)activate mail accounts',
+					'icon'    => 'mail/navbar',
+					'children' => array (
+						'active' => array (
+							'caption'		  => 'activate',
+							'onExecute'	  	  => 'javaScript:app.admin.emailadminActiveAccounts',
+							'icon'			  => 'check',
+							'allowOnMultiple' => true
+						),
+						'inactive' => array (
+							'caption'		  => 'deactivate',
+							'onExecute'		  => 'javaScript:app.admin.emailadminActiveAccounts',
+							'icon'			  => 'bullet',
+							'allowOnMultiple' => true
+						)
+					)
+				);
+			}
+		}
 		return $actions;
 	}
+
+	/**
+	 * Called before displaying site configuration
+	 *
+	 * @param array $config
+	 * @return array with additional Api\Config to merge
+	 */
+	public static function config(array $config)
+	{
+		$ret = array();
+		if (empty($config['fw_mobile_app_list']) && class_exists('jdots_framework'))
+		{
+			$ret['fw_mobile_app_list'] = jdots_framework::DEFAULT_MOBILE_APPS;
+		}
+		return $ret;
+	}
 }
