@@ -5,11 +5,15 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package admin
- * @copyright (c) 2009-11 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2009-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Etemplate;
+
 /**
  * Submit statistical data to egroupware.org
  */
@@ -46,23 +50,23 @@ class admin_statistics
 	{
 		if (is_array($_content))
 		{
-			$config = new config(self::CONFIG_APP);
+			$config = new Api\Config(self::CONFIG_APP);
 			if ($_content['postpone'])
 			{
-				config::save_value(self::CONFIG_POSTPONE_SUBMIT,time()+$_content['postpone'],self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_POSTPONE_SUBMIT,time()+$_content['postpone'],self::CONFIG_APP);
 				$what = 'postpone';
 			}
 			elseif(!$_content['cancel'])
 			{
-				config::save_value(self::CONFIG_LAST_SUBMIT,time(),self::CONFIG_APP);
-				config::save_value(self::CONFIG_SUBMIT_ID,empty($_content['submit_id']) ? '***none***' : $_content['submit_id'],self::CONFIG_APP);
-				config::save_value(self::CONFIG_COUNTRY,empty($_content['country']) ? '***multinational***' : $_content['country'],self::CONFIG_APP);
-				config::save_value(self::CONFIG_USAGE_TYPE,$_content['usage_type'],self::CONFIG_APP);
-				config::save_value(self::CONFIG_INSTALL_TYPE,$_content['install_type'],self::CONFIG_APP);
-				config::save_value(self::CONFIG_POSTPONE_SUBMIT,null,self::CONFIG_APP);	// remove evtl. postpone time
+				Api\Config::save_value(self::CONFIG_LAST_SUBMIT,time(),self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_SUBMIT_ID,empty($_content['submit_id']) ? '***none***' : $_content['submit_id'],self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_COUNTRY,empty($_content['country']) ? '***multinational***' : $_content['country'],self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_USAGE_TYPE,$_content['usage_type'],self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_INSTALL_TYPE,$_content['install_type'],self::CONFIG_APP);
+				Api\Config::save_value(self::CONFIG_POSTPONE_SUBMIT,null,self::CONFIG_APP);	// remove evtl. postpone time
 				$what = 'submitted';
 			}
-			egw::redirect_link('/admin/index.php','ajax=true&statistics='.($what ? $what : 'canceled'),'admin');
+			Egw::redirect_link('/admin/index.php','ajax=true&statistics='.($what ? $what : 'canceled'),'admin');
 		}
 		$sel_options['usage_type'] = array(
 			'commercial'   => lang('Commercial: all sorts of companies'),
@@ -90,7 +94,7 @@ class admin_statistics
 			30*24*3600 => lang('one month'),
 			60*24*3600 => lang('two months'),
 		);
-		$config = config::read(self::CONFIG_APP);
+		$config = Api\Config::read(self::CONFIG_APP);
 		//_debug_array($config);
 		$content = array_merge(self::gather_data(),array(
 			'statistic_url' => self::STATISTIC_URL,
@@ -105,7 +109,7 @@ class admin_statistics
 		{
 			$content['submit_id'] = $config['statistics_submit_id'] == '***none***' ? '' : $config['statistics_submit_id'];
 		}
-		// show previous country
+		// show previous Api\Country
 		if ($config[self::CONFIG_COUNTRY])
 		{
 			$content['country'] = $config[self::CONFIG_COUNTRY] == '***multinational***' ? '' : $config[self::CONFIG_COUNTRY];
@@ -138,7 +142,7 @@ class admin_statistics
 				ceil((time()-$config[self::CONFIG_LAST_SUBMIT])/24/3600));
 		}
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('Submit statistic information');
-		$tmpl = new etemplate_new('admin.statistics');
+		$tmpl = new Etemplate('admin.statistics');
 		$tmpl->exec('admin.admin_statistics.submit',$content,$sel_options,$readonlys);
 	}
 
@@ -155,7 +159,7 @@ class admin_statistics
 		$data['country'] = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
 
 		// api version
-		$data['version'] = $GLOBALS['egw_info']['apps']['phpgwapi']['version'];
+		$data['version'] = $GLOBALS['egw_info']['apps']['api']['version'];
 		// append EPL version
 		if (isset($GLOBALS['egw_info']['apps']['stylite']))
 		{
@@ -193,8 +197,8 @@ class admin_statistics
 		foreach(array_keys($GLOBALS['egw_info']['apps']) as $app)
 		{
 			if (in_array($app,array(
-				'admin','phpgwapi','emailadmin','sambaadmin','developer_tools',
-				'home','preferences','etemplate','registration','manual','egw-pear',
+				'admin','phpgwapi','api','sambaadmin','developer_tools',
+				'home','preferences','etemplate','registration','manual',
 			)))
 			{
 				continue;	// --> ignore to not submit too much
@@ -275,8 +279,8 @@ class admin_statistics
 				$entries = (int)$GLOBALS['egw']->db->query('SELECT COUNT(*) FROM '.$table)->fetchColumn();
 				//echo "$app ($table): $entries<br />\n";
 			}
-			catch(egw_exception_db $e) {
-				unset($e);	// not used
+			catch(Api\Db\Exception $e) {
+				unset($e);
 				$entries = null;
 			}
 		}
@@ -291,7 +295,7 @@ class admin_statistics
 	 */
 	public static function check($redirect=true)
 	{
-		$config = config::read(self::CONFIG_APP);
+		$config = Api\Config::read(self::CONFIG_APP);
 
 		if (isset($config[self::CONFIG_POSTPONE_SUBMIT]) && $config[self::CONFIG_POSTPONE_SUBMIT] > time() ||
 			isset($config[self::CONFIG_LAST_SUBMIT ]) && $config[self::CONFIG_LAST_SUBMIT ] > time()-self::SUBMISION_RATE)
@@ -301,7 +305,7 @@ class admin_statistics
 		if (!$redirect) return true;
 
 		//die('Due for new statistics submission: last_submit='.$config[self::CONFIG_LAST_SUBMIT ].', postpone='.$config[self::CONFIG_POSTPONE_SUBMIT].', '.function_backtrace());
-		egw::redirect_link('/index.php',array(
+		Egw::redirect_link('/index.php',array(
 			'menuaction' => 'admin.admin_ui.index',
 			'ajax' => 'true',
 			'load' => 'admin.admin_statistics.submit',
