@@ -5,11 +5,16 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <rb@stylite.de>
  * @package admin
- * @copyright (c) 2013-14 by Ralf Becker <rb@stylite.de>
+ * @copyright (c) 2013-16 by Ralf Becker <rb@stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Etemplate;
+
 /**
  * UI for admin
  */
@@ -26,7 +31,7 @@ class admin_ui
 	/**
 	 * Reference to global accounts object
 	 *
-	 * @var accounts
+	 * @var Api\Accounts
 	 */
 	private static $accounts;
 
@@ -41,26 +46,25 @@ class admin_ui
 		{
 			$_GET['load'] = 'admin.admin_statistics.submit';
 		}
-		$tpl = new etemplate_new('admin.index');
+		$tpl = new Etemplate('admin.index');
 
 		if (!is_array($content)) $content = array();
 		$content['nm'] = array(
 			'get_rows' => 'admin_ui::get_users',
 			'no_cat' => true,
 			'no_filter2' => true,
-			'filter_label' => 'Group',
 			'filter_no_lang' => true,
 			'lettersearch' => true,
-			'header_row'   => 'admin.index.add',
 			'order' => 'account_lid',
 			'sort' => 'ASC',
 			'row_id' => 'account_id',
 			'default_cols' => '!account_id,created',
 			'actions' => self::user_actions(),
+			'placeholder_actions' => array('add')
 		);
 		//$content['msg'] = 'Hi Ralf ;-)';
 		$sel_options['tree'] = $this->tree_data();
-		$sel_options['filter'] = array('' => lang('All'));
+		$sel_options['filter'] = array('' => lang('All groups'));
 		foreach(self::$accounts->search(array(
 			'type' => 'groups',
 			'start' => false,
@@ -86,9 +90,8 @@ class admin_ui
 		{
 			$vars = $_GET;
 			$vars['menuaction'] = $vars['load'];
-			unset($vars['ajax']);
 			unset($vars['load']);
-			$content['iframe'] = egw::link('/index.php', $vars);
+			$content['iframe'] = Egw::link('/index.php', $vars);
 		}
 		else
 		{
@@ -141,11 +144,11 @@ class admin_ui
 		}
 		$group = 5;	// allow to place actions in different groups by hook, this is the default
 		// supporting both old way using $GLOBALS['menuData'] and new just returning data in hook
-		$apps = array_unique(array_merge(array('admin'), $GLOBALS['egw']->hooks->hook_implemented('edit_group')));
+		$apps = array_unique(array_merge(array('admin'), Api\Hooks::implemented('edit_group')));
 		foreach($apps as $app)
 		{
 			$GLOBALS['menuData'] = $data = array();
-			$data = $GLOBALS['egw']->hooks->single('edit_group', $app);
+			$data = Api\Hooks::single('edit_group', $app);
 			if (!is_array($data)) $data = $GLOBALS['menuData'];
 			//error_log(__METHOD__."() app $app returned ".array2string($data));
 			foreach($data as $item)
@@ -208,7 +211,7 @@ class admin_ui
 				),
 			);
 			// generate urls for add/edit accounts via addressbook
-			$edit = egw_link::get_registry('addressbook', 'edit');
+			$edit = Link::get_registry('addressbook', 'edit');
 			$edit['account_id'] = '$id';
 			foreach($edit as $name => $val)
 			{
@@ -222,11 +225,11 @@ class admin_ui
 			}
 			++$group;
 			// supporting both old way using $GLOBALS['menuData'] and new just returning data in hook
-			$apps = array_unique(array_merge(array('admin'), $GLOBALS['egw']->hooks->hook_implemented('edit_user')));
+			$apps = array_unique(array_merge(array('admin'), Api\Hooks::implemented('edit_user')));
 			foreach($apps as $app)
 			{
 				$GLOBALS['menuData'] = $data = array();
-				$data = $GLOBALS['egw']->hooks->single('edit_user', $app);
+				$data = Api\Hooks::single('edit_user', $app);
 				if (!is_array($data)) $data = $GLOBALS['menuData'];
 				foreach($data as $item)
 				{
@@ -304,9 +307,9 @@ class admin_ui
 		foreach($rows as &$row)
 		{
 			$row['status'] = self::$accounts->is_expired($row) ?
-				lang('Expired').' '.egw_time::to($row['account_expires'], true) :
+				lang('Expired').' '.Api\DateTime::to($row['account_expires'], true) :
 					(!self::$accounts->is_active($row) ? lang('Disabled') :
-						($row['account_expires'] != -1 ? lang('Expires').' '.egw_time::to($row['account_expires'], true) :
+						($row['account_expires'] != -1 ? lang('Expires').' '.Api\DateTime::to($row['account_expires'], true) :
 							lang('Enabled')));
 
 			if (!self::$accounts->is_active($row)) $row['status_class'] = 'adminAccountInactive';
@@ -320,7 +323,7 @@ class admin_ui
 	 */
 	public static function ajax_tree()
 	{
-		etemplate_widget_tree::send_quote_json(self::tree_data(!empty($_GET['id']) ? $_GET['id'] : '/'));
+		Etemplate\Widget\Tree::send_quote_json(self::tree_data(!empty($_GET['id']) ? $_GET['id'] : '/'));
 	}
 
 	/**
@@ -375,7 +378,7 @@ class admin_ui
 					}
 					if (!empty($data['icon']))
 					{
-						$icon = etemplate_widget_tree::imagePath($data['icon']);
+						$icon = Etemplate\Widget\Tree::imagePath($data['icon']);
 						if ($data['child'] || $data['item'])
 						{
 							$data['im1'] = $data['im2'] = $icon;
@@ -396,8 +399,8 @@ class admin_ui
 						$path .= ($path == '/' ? '' : '/').$part;
 						if (!isset($parent[$path]))
 						{
-							$icon = etemplate_widget_tree::imagePath($part == 'apps' ? common::image('phpgwapi', 'home') :
-								(($i=common::image($part, 'navbar')) ? $i : common::image('phpgwapi', 'nonav')));
+							$icon = Etemplate\Widget\Tree::imagePath($part == 'apps' ? Api\Image::find('api', 'home') :
+								(($i=Api\Image::find($part, 'navbar')) ? $i : Api\Image::find('api', 'nonav')));
 							$parent[$path] = array(
 								'id' => $path,
 								'text' => $part == 'apps' ? lang('Applications') : lang($part),
@@ -492,9 +495,9 @@ class admin_ui
 			admin_ui::$hook_data[$appname] = $file2 ? $file2 : $file;
 			//error_log(__METHOD__."(".array2string(func_get_args()).")");
 		}
-		self::$hook_data = array_merge($GLOBALS['egw']->hooks->process('admin', array('admin')), self::$hook_data);
+		self::$hook_data = array_merge(Api\Hooks::process('admin', array('admin')), self::$hook_data);
 
-		// sort apps alphabetic by their title / translation of app-name
+		// sort apps alphabetic by their title / Api\Translation of app-name
 		uksort(self::$hook_data, function($a, $b)
 		{
 			return strcasecmp(lang($a), lang($b));
