@@ -1,6 +1,6 @@
 <?php
 /**
- * eGgroupWare admin - UI for adding custom fields
+ * EGgroupware admin - UI for adding custom fields
  *
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
@@ -10,6 +10,10 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Etemplate;
+
 /**
  * Customfields class -  manages customfield definitions in egw_config table
  *
@@ -91,6 +95,7 @@ class customfields
 		'ajax_select' => array('cf_values' => true),
 		'radio'		=> array('cf_values' => true),
 		'checkbox'	=> array('cf_values' => true),
+		'filemanager' => array('cf_values' => true),
 	);
 
 	/**
@@ -102,10 +107,10 @@ class customfields
 	{
 		if (($this->appname = $appname))
 		{
-			$this->fields = egw_customfields::get($this->appname,true);
-			$this->content_types = config::get_content_types($this->appname);
+			$this->fields = Api\Storage\Customfields::get($this->appname,true);
+			$this->content_types = Api\Config::get_content_types($this->appname);
 		}
-		$this->so = new so_sql('phpgwapi','egw_customfields',null,'',true);
+		$this->so = new Api\Storage\Base('phpgwapi','egw_customfields',null,'',true);
 	}
 
 	/**
@@ -120,13 +125,13 @@ class customfields
 		$this->use_private = !isset($_GET['use_private']) || (boolean)$_GET['use_private'] || $content['use_private'];
 
 		// Read fields, constructor doesn't always know appname
-		$this->fields = egw_customfields::get($this->appname,true);
+		$this->fields = Api\Storage\Customfields::get($this->appname,true);
 
-		$this->tmpl = new etemplate_new();
+		$this->tmpl = new Etemplate();
 		$this->tmpl->read('admin.customfields');
 
 		// do we manage content-types?
-		$test = new etemplate_new();
+		$test = new Etemplate();
 		if($test->read($this->appname.'.admin.types')) $this->manage_content_types = true;
 
 		// Handle incoming - types, options, etc.
@@ -134,12 +139,12 @@ class customfields
 		{
 			if(count($this->content_types) == 0)
 			{
-				$this->content_types = config::get_content_types($this->appname);
+				$this->content_types = Api\Config::get_content_types($this->appname);
 			}
 			if (count($this->content_types)==0)
 			{
 				// if you define your default types of your app with the search_link hook, they are available here, if no types were found
-				$this->content_types = (array)egw_link::get_registry($this->appname,'default_types');
+				$this->content_types = (array)Api\Link::get_registry($this->appname,'default_types');
 			}
 			// Set this now, we need to know it for updates
 			$this->content_type = $content['content_types']['types'] ? $content['content_types']['types'] : (array_key_exists(0,$this->content_types) ? $this->content_types[0] : key($this->content_types));
@@ -151,7 +156,7 @@ class customfields
 			}
 			elseif($content['content_types']['create'])
 			{
-				if($new_type = $this->create_content_type($content))
+				if(($new_type = $this->create_content_type($content)))
 				{
 					$content['content_types']['types'] = $this->content_type = $new_type;
 				}
@@ -179,7 +184,7 @@ class customfields
 			$this->save_repository();
 		}
 
-		$content['nm']= $GLOBALS['egw']->session->appsession('customfield-index','admin');
+		$content['nm']= Api\Cache::getSession('admin', 'customfield-index');
 		if (!is_array($content['nm']))
 		{
 			// Initialize nextmatch
@@ -213,7 +218,6 @@ class customfields
 
 			$content['type_template'] = $this->appname . '.admin.types';
 			$content['content_types']['appname'] = $this->appname;
-			$content_types = array_keys($this->content_types);
 
 			$content['content_type_options'] = $this->content_types[$this->content_type]['options'];
 			$content['content_type_options']['type'] = $this->types2[$this->content_type];
@@ -250,10 +254,11 @@ class customfields
 		);
 
 		// Allow extending app a change to change content before display
+		$readonlys = null;
 		static::app_index($content, $sel_options, $readonlys, $preserve);
 
 		// Make sure app css gets loaded, extending app might cause et2 to miss it
-		egw_framework::includeCSS('admin','app');
+		Framework::includeCSS('admin','app');
 
 		$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps'][$this->appname]['title'].' - '.lang('Custom fields');
 
@@ -291,7 +296,7 @@ class customfields
 		$this->use_private = !isset($_GET['use_private']) || (boolean)$_GET['use_private'] || $content['use_private'];
 
 		// Read fields, constructor doesn't always know appname
-		$this->fields = egw_customfields::get($this->appname,true);
+		$this->fields = Api\Storage\Customfields::get($this->appname,true);
 
 		// Update based on info returned from template
 		if (is_array($content))
@@ -301,14 +306,14 @@ class customfields
 			{
 				case 'delete':
 					$this->so->delete($cf_id);
-					egw_framework::refresh_opener('Deleted', 'admin', $cf_id /* Conflicts with accounts 'delete'*/);
-					egw_framework::window_close();
+					Framework::refresh_opener('Deleted', 'admin', $cf_id /* Conflicts with Api\Accounts 'delete'*/);
+					Framework::window_close();
 					break;
 				case 'save':
 				case 'apply':
 					if(!$cf_id && $this->fields[$content['cf_name']])
 					{
-						egw_framework::message(lang("Field '%1' already exists !!!",$content['cf_name']),'error');
+						Framework::message(lang("Field '%1' already exists !!!",$content['cf_name']),'error');
 						$content['cf_name'] = '';
 						break;
 					}
@@ -327,8 +332,8 @@ class customfields
 						{
 							foreach(explode("\n",trim($content['cf_values'])) as $line)
 							{
-								list($var,$value) = explode('=',trim($line),2);
-								$var = trim($var);
+								list($var_raw,$value) = explode('=',trim($line),2);
+								$var = trim($var_raw);
 								$values[$var] = trim($value)==='' ? $var : $value;
 							}
 						}
@@ -342,20 +347,20 @@ class customfields
 							$update_content[substr($key,3)] = $value;
 						}
 					}
-					egw_customfields::update($update_content);
+					Api\Storage\Customfields::update($update_content);
 					if(!$cf_id)
 					{
-						$this->fields = egw_customfields::get($this->appname,true);
+						$this->fields = Api\Storage\Customfields::get($this->appname,true);
 						$cf_id = (int)$this->fields[$content['cf_name']]['id'];
 					}
-					egw_framework::refresh_opener('Saved', 'admin', $cf_id, 'edit');
+					Framework::refresh_opener('Saved', 'admin', $cf_id, 'edit');
 					if ($action != 'save')
 					{
 						break;
 					}
 				//fall through
 				case 'cancel':
-					egw_framework::window_close();
+					Framework::window_close();
 			}
 		}
 		else
@@ -365,13 +370,13 @@ class customfields
 
 
 		// do we manage content-types?
-		$test = new etemplate_new();
+		$test = new Etemplate();
 		if($test->read($this->appname.'.admin.types')) $this->manage_content_types = true;
 
-		$this->tmpl = new etemplate_new();
+		$this->tmpl = new Etemplate();
 		$this->tmpl->read('admin.customfield_edit');
 
-		translation::add_app('infolog');	// til we move the translations
+		Api\Translation::add_app('infolog');	// til we move the translations
 
 		$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps'][$this->appname]['title'].' - '.lang('Custom fields');
 		$sel_options = array();
@@ -414,7 +419,7 @@ class customfields
 		{
 			if(count($this->content_types) == 0)
 			{
-				$this->content_types = config::get_content_types($this->appname);
+				$this->content_types = Api\Config::get_content_types($this->appname);
 			}
 			if (count($this->content_types)==0)
 			{
@@ -454,6 +459,7 @@ class customfields
 	 */
 	protected function app_index(&$content, &$sel_options, &$readonlys)
 	{
+		unset($content, $sel_options, $readonlys);	// not used, as this is a stub
 		// This is just a stub.
 	}
 
@@ -493,78 +499,6 @@ class customfields
 		return $actions;
 	}
 
-	function update_fields(&$content)
-	{
-		foreach($content['fields'] as $field)
-		{
-			$name = trim($field['name']);
-			$old_name = $field['old_name'];
-
-			if (!empty($delete) && $delete == $old_name)
-			{
-				unset($this->fields[$old_name]);
-				continue;
-			}
-			if (isset($field['old_name']))
-			{
-				if (empty($name))	// empty name not allowed
-				{
-					$content['error_msg'] = lang('Name must not be empty !!!');
-					$name = $old_name;
-				}
-				if (!empty($name) && $old_name != $name)	// renamed
-				{
-					unset($this->fields[$old_name]);
-				}
-			}
-			elseif (empty($name))		// new item and empty ==> ignore it
-			{
-				continue;
-			}
-			$values = array();
-			if (!empty($field['values']))
-			{
-				foreach(explode("\n",$field['values']) as $line)
-				{
-					list($var,$value) = explode('=',trim($line),2);
-					$var = trim($var);
-					$values[$var] = empty($value) ? $var : $value;
-				}
-			}
-			$this->fields[$name] = array(
-				'type'  => $field['type'],
-				'type2'	=> $field['type2'],
-				'label' => empty($field['label']) ? $name : $field['label'],
-				'help'  => $field['help'],
-				'values'=> $values,
-				'len'   => $field['len'],
-				'rows'  => (int)$field['rows'],
-				'order' => (int)$field['order'],
-				'private' => $field['private'],
-				'needed' => $field['needed'],
-			);
-			if(!$this->fields[$name]['type2'] && $this->manage_content_types)
-			{
-				$this->fields[$name]['type2'] = (string)0;
-			}
-		}
-		if (!function_exists('sort_by_order'))
-		{
-			function sort_by_order($arr1,$arr2)
-			{
-				return $arr1['order'] - $arr2['order'];
-			}
-		}
-		uasort($this->fields,sort_by_order);
-
-		$n = 0;
-		foreach($this->fields as $name => $data)
-		{
-			$this->fields[$name]['order'] = ($n += 10);
-		}
-	}
-
-
 	function update(&$content)
 	{
 		$this->content_types[$this->content_type]['options'] = $content['content_type_options'];
@@ -626,7 +560,7 @@ class customfields
 		}
 		else
 		{
-			foreach($this->content_types as $letter => $type)
+			foreach($this->content_types as $type)
 			{
 				if($type['name'] == $new_name)
 				{
@@ -639,8 +573,8 @@ class customfields
 			{
 				if (!$this->content_types[chr($i)] &&
 					// skip letter of deleted type for addressbook content-types, as it gives SQL error
-					// content-type are lowercase, addressbook_so::DELETED_TYPE === 'D', but DB is case-insensitive
-					($this->appname !== 'addressbook' || chr($i) !== strtolower(addressbook_so::DELETED_TYPE)))
+					// content-type are lowercase, Api\Contacts::DELETED_TYPE === 'D', but DB is case-insensitive
+					($this->appname !== 'addressbook' || chr($i) !== strtolower(Api\Contacts::DELETED_TYPE)))
 				{
 					$new_type = chr($i);
 					break;
@@ -658,37 +592,37 @@ class customfields
 	function save_repository()
 	{
 		//echo '<p>uicustomfields::save_repository() \$this->fields=<pre style="text-aling: left;">'; print_r($this->fields); echo "</pre>\n";
-		$config = new config($this->appname);
+		$config = new Api\Config($this->appname);
 		$config->read_repository();
 		$config->value('types',$this->content_types);
 		$config->save_repository();
 
-		egw_customfields::save($this->appname, $this->fields);
+		Api\Storage\Customfields::save($this->appname, $this->fields);
 	}
 
 	/**
 	* get customfields of using application
 	*
-	* @deprecated use egw_customfields::get() direct, no need to instanciate this UI class
+	* @deprecated use Api\Storage\Customfields::get() direct, no need to instanciate this UI class
 	* @author Cornelius Weiss
-	* @param boolean $all_private_too=false should all the private fields be returned too
+	* @param boolean $all_private_too =false should all the private fields be returned too
 	* @return array with customfields
 	*/
 	function get_customfields($all_private_too=false)
 	{
-		return egw_customfields::get($this->appname,$all_private_too);
+		return Api\Storage\Customfields::get($this->appname,$all_private_too);
 	}
 
 	/**
 	* get_content_types of using application
 	*
-	* @deprecated use config::get_content_types() direct, no need to instanciate this UI class
+	* @deprecated use Api\Config::get_content_types() direct, no need to instanciate this UI class
 	* @author Cornelius Weiss
 	* @return array with content-types
 	*/
 	function get_content_types()
 	{
-		return config::get_content_types($this->appname);
+		return Api\Config::get_content_types($this->appname);
 	}
 
 	/**
