@@ -35,6 +35,13 @@ app.classes.admin = AppJS.extend(
 	 */
 	nm: null,
 
+	/**
+	 * Refarence to div to hold AJAX loadable pages
+	 *
+	 * {et2_box}
+	 */
+	ajax_target: null,
+
 	/**
 	 * Reference to ACL edit dialog (not the list)
 	 */
@@ -82,6 +89,7 @@ app.classes.admin = AppJS.extend(
 			case 'admin.index':
 				var iframe = this.iframe = this.et2.getWidgetById('iframe');
 				this.nm = this.et2.getWidgetById('nm');
+				this.ajax_target = this.et2.getWidgetById('ajax_target');
 				if (iframe)
 				{
 					var self = this;
@@ -98,13 +106,15 @@ app.classes.admin = AppJS.extend(
 				}
 				break;
 
-			case 'admin.categories.index':
-				break;
 			case 'admin.customfield_edit':
 				// Load settings appropriate to currently set type
 				var widget = _et2.widgetContainer.getWidgetById('cf_type');
 				this.cf_type_change(null,widget);
 				break;
+
+			case 'admin.mailaccount':
+				this.account_hide_not_applying();
+				break;
 		}
 	},
 
@@ -128,9 +138,35 @@ app.classes.admin = AppJS.extend(
 			window.open(_url, '_blank');
 			return;
 		}
+		var ajax = false;
 		if (_url)
 		{
-			this.iframe.set_src(_url);
+			// Try to load it without the iframe
+			ajax = _url.match(/ajax=true/) && _url.match(/menuaction=/);
+			if(ajax)
+			{
+
+				if(this.ajax_target.node.children.length)
+				{
+					// Node has children already?  Check for loading over an
+					// existing etemplate, and remove it first
+					jQuery(this.ajax_target.node.children).each(function() {
+						var old = etemplate2.getById(this.id);
+						if(old) old.clear();
+					});
+					jQuery(this.ajax_target.node).empty();
+				}
+				this.egw.json(
+					framework.activeApp.getMenuaction('ajax_exec'),
+					// It's important that the context is null, or etemplate2
+					// won't load the template properly
+					[_url], this._ajax_load_callback,null, true, this
+				).sendRequest();
+			}
+			else
+			{
+				this.iframe.set_src(_url);
+			}
 		}
 		else
 		{
@@ -138,8 +174,9 @@ app.classes.admin = AppJS.extend(
 			// blank iframe, to not keep something running there
 			this.iframe.getDOMNode().contentDocument.location.href = 'about:blank';
 		}
-		this.iframe.set_disabled(!_url);
-		this.nm.set_disabled(!!_url);
+		this.iframe.set_disabled(!_url || ajax);
+		this.nm.set_disabled(!!_url || ajax);
+		this.ajax_target.set_disabled(!ajax);
 	},
 
 	/**
@@ -261,6 +298,19 @@ app.classes.admin = AppJS.extend(
 		this.load(url);
 	},
 
+	/**
+	 * Callback to load an etemplate
+	 *
+	 * @param {Object[]} _data
+	 */
+	_ajax_load_callback: function(_data)
+	{
+		if(!_data || _data.type != undefined) return;
+
+		// Insert the content, etemplate will load into it
+		jQuery(this.ajax_target.node).append(_data[0]);
+	},
+
 	/**
 	 * Link hander for jDots template to just reload our iframe, instead of reloading whole admin app
 	 *
@@ -274,7 +324,7 @@ app.classes.admin = AppJS.extend(
 		{
 			if (matches)
 			{
-				_url = _url.replace(/menuaction=admin.admin_ui.index/, 'menuaction='+matches[1]).replace(/&(ajax=true|load=[^&]+)/g, '');
+				_url = _url.replace(/menuaction=admin.admin_ui.index/, 'menuaction='+matches[1]).replace(/&(load=[^&]+)/g, '');
 			}
 			this.load(_url);
 			return true;
@@ -305,7 +355,8 @@ app.classes.admin = AppJS.extend(
 		}
 		else if (link[0] == '/' || link.substr(0,4) == 'http')
 		{
-			this.load(link+(link.match(/\?/)?'&':'?')+'nonavbar=1');
+			link += (link.indexOf('?') >= 0 ? '&' : '?')+'nonavbar=1';
+			this.load(link);
 		}
 		else if (link.substr(0,11) == 'javascript:')
 		{
@@ -488,7 +539,7 @@ app.classes.admin = AppJS.extend(
 		if(content.acl_location)
 		{
 			sel_options.acl_location = jQuery.extend({},sel_options.acl_location);
-			this.egw.link_title('home-accounts', content.acl_location, function(title) {sel_options.acl_location[content.acl_location] = title;});
+			this.egw.link_title('api-accounts', content.acl_location, function(title) {sel_options.acl_location[content.acl_location] = title;});
 		}
 
 		// Create the dialog
@@ -822,19 +873,20 @@ app.classes.admin = AppJS.extend(
 		jQuery(root.getWidgetById('cf_rows').getDOMNode()).toggle(attributes.cf_rows && true);
 		jQuery(root.getWidgetById('cf_values').getParentDOMNode()).toggle(attributes.cf_values && true);
 	},
-	
+
 	/**
 	 * Activate none standard SMTP mail accounts for selected users
-	 * 
-	 * @param {type} _selected selected users
+	 *
+	 * @param {egw_action} _action
+	 * @param {array} _selected selected users
 	 * @todo remove under construction message
 	 */
 	emailadminActiveAccounts: function (_action, _selected){
-		
-		var menuaction = 'emailadmin.emailadmin_wizard.ajax_activeAccounts';
+
+		var menuaction = 'admin.admin_mail.ajax_activeAccounts';
 		var accounts = [];
 		var msg1 = egw.lang('%1 accounts being activated',Object.keys(_selected).length);
-		
+
 		for (var i=0;i< Object.keys(_selected).length;i++)
 		{
 			accounts[i] = {id:_selected[i]['id'].split('::')[1],qouta:"", domain:"", status:_action.id == 'active'?_action.id:''};
@@ -854,9 +906,241 @@ app.classes.admin = AppJS.extend(
 					}
 				}, msg1, 'Mail Acounts Activation', menuaction, accounts, 'admin');
 			}
-		}
+		};
 		// confirmation dialog
 		et2_dialog.show_dialog(callbackDialog, egw.lang('Are you sure you want to %1 mail for selected accounts?', egw.lang(_action.id)), egw.lang('Active Mail Accounts'), {},
 			et2_dialog.BUTTON_YES_NO, et2_dialog.WARNING_MESSAGE, undefined, egw);
+	},
+
+	/**
+	 * No SSL
+	 */
+	SSL_NONE: 0,
+	/**
+	 * STARTTLS on regular tcp connection/port
+	 */
+	SSL_STARTTLS: 1,
+	/**
+	 * SSL (inferior to TLS!)
+	 */
+	SSL_SSL: 3,
+	/**
+	 * require TLS version 1+, no SSL version 2 or 3
+	 */
+	SSL_TLS: 2,
+	/**
+	 * if set, verify certifcate (currently not implemented in Horde_Imap_Client!)
+	 */
+	SSL_VERIFY: 8,
+
+	/**
+	 * Resize window methode
+	 *
+	 * @returns {undefined}
+	 */
+	wizard_popup_resize: function ()
+	{
+		var $main_div = jQuery('#popupMainDiv');
+		var $et2 = jQuery('.et2_container');
+		var w = {
+			width: egw_getWindowInnerWidth(),
+			height: egw_getWindowInnerHeight()
+		};
+		// Use et2_container for width since #popupMainDiv is full width, but we still need
+		// to take padding/margin into account
+		var delta_width = w.width - ($et2.outerWidth(true) + ($main_div.outerWidth(true) - $main_div.width()));
+		var delta_height = w.height - ($et2.outerHeight(true) + ($main_div.outerHeight(true) - $main_div.height()));
+		if(delta_width != 0 || delta_height != 0)
+		{
+			window.resizeTo(egw_getWindowOuterWidth() - delta_width,egw_getWindowOuterHeight() - delta_height);
+		}
+	},
+
+	/**
+	 * Switch account wizard to manual entry
+	 */
+	wizard_manual: function()
+	{
+		jQuery('.emailadmin_manual').fadeToggle();// not sure how to to this et2-isch
+		this.wizard_popup_resize(); // popup needs to be resized after toggling
+	},
+
+	/**
+	 * onclick for continue button to show progress animation
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	wizard_detect: function(_event, _widget)
+	{
+		// we need to do a manual asynchronious submit to show progress animation
+		// default synchronious submit stops animation!
+		if (this.et2._inst.submit('button[continue]', true))	// true = async submit
+		{
+			var sieve_enabled = this.et2.getWidgetById('acc_sieve_enabled');
+			if (!sieve_enabled || sieve_enabled.get_value())
+			{
+				jQuery('#admin-mailwizard_output').hide();
+				jQuery('td.emailadmin_progress').show();
+			}
+		}
+		return false;
+	},
+
+	/**
+	 * Set default port, if imap ssl-type changes
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	wizard_imap_ssl_onchange: function(_event, _widget)
+	{
+		var ssl_type = _widget.get_value();
+		this.et2.getWidgetById('acc_imap_port').set_value(
+			ssl_type == this.SSL_SSL || ssl_type == this.SSL_TLS ? 993 : 143);
+	},
+
+	/**
+	 * Set default port, if imap ssl-type changes
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	wizard_smtp_ssl_onchange: function(_event, _widget)
+	{
+		var ssl_type = _widget.get_value();
+		this.et2.getWidgetById('acc_smtp_port').set_value(
+			ssl_type == 'no' ? 25 : (ssl_type == this.SSL_SSL || ssl_type == this.SSL_TLS ? 465 : 587));
+	},
+
+	/**
+	 * Set default port, if imap ssl-type changes
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	wizard_sieve_ssl_onchange: function(_event, _widget)
+	{
+		var ssl_type = _widget.get_value();
+		this.et2.getWidgetById('acc_sieve_port').set_value(
+			ssl_type == this.SSL_SSL || ssl_type == this.SSL_TLS ? 5190 : 4190);
+		this.wizard_sieve_onchange(_event, _widget);
+	},
+
+	/**
+	 * Enable sieve, if user changes some setting
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	wizard_sieve_onchange: function(_event, _widget)
+	{
+		this.et2.getWidgetById('acc_sieve_enabled').set_value(1);
+	},
+
+	/**
+	 * Switch to select multiple accounts
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	edit_multiple: function(_event, _widget)
+	{
+		// hide multiple button
+		_widget.set_disabled(true);
+
+		// switch account-selection to multiple
+		var account_id = this.et2.getWidgetById('account_id');
+		account_id.set_multiple(true);
+	},
+
+	/**
+	 * Hide not applying fields, used as:
+	 * - onchange handler on account_id
+	 * - called from et2_ready for emailadmin.account template
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	account_hide_not_applying: function(_event, _widget)
+	{
+		var account_id = this.et2.getWidgetById('account_id');
+		var ids = account_id && account_id.get_value ? account_id.get_value() : [];
+		if (typeof ids == 'string') ids = ids.split(',');
+
+		var multiple = ids.length >= 2 || ids[0] === '' || ids[0] < 0;
+		//alert('multiple='+(multiple?'true':'false')+': '+ids.join(','));
+
+		// initial call
+		if (typeof _widget == 'undefined')
+		{
+			if (!multiple)
+			{
+				jQuery('.emailadmin_no_single').hide();
+			}
+			if (!this.egw.user('apps').admin)
+			{
+				jQuery('.emailadmin_no_user,#button\\[multiple\\]').hide();
+			}
+			if (ids.length == 1)
+			{
+				// switch back to single selectbox
+				account_id.set_multiple(false);
+				this.et2.getWidgetById('button[multiple]').set_disabled(false);
+			}
+		}
+		// switched to single user
+		else if (!multiple)
+		{
+			jQuery('.emailadmin_no_single').fadeOut();
+			// switch back to single selectbox
+			account_id.set_multiple(false);
+			this.et2.getWidgetById('button[multiple]').set_disabled(false);
+		}
+		// switched to multiple user
+		else
+		{
+			jQuery('.emailadmin_no_single').fadeIn();
+		}
+		if (_event && _event.stopPropagation) _event.stopPropagation();
+		return false;
+	},
+
+	/**
+	 * Callback if user changed account selction
+	 *
+	 * @param {object} _event event-object or information about event
+	 * @param {et2_baseWidget} _widget widget causing the event
+	 */
+	change_account: function(_event, _widget)
+	{
+		// todo check dirty and query user to a) save changes, b) discard changes, c) cancel selection
+		_widget.getInstanceManager().submit();
+	},
+
+	/**
+	 * Callback if user changes notification folders: unset use-default checkbox
+	 *
+	 * @param {object} _event
+	 * @param {et2_widget} _widget
+	 */
+	change_folders: function(_event, _widget)
+	{
+		var use_default = this.et2.getWidgetById('notify_use_default');
+		if (use_default) use_default.set_value(false);
+	},
+
+	/**
+	 * default onExecute for admin actions
+	 *
+	 * @param {object} _action
+	 * @param {object} _senders
+	 */
+	account_edit_action: function(_action, _senders)
+	{
+		if (_action.data.url)
+		{
+			this.egw.open_link(_action.data.url, _action.data.target || '_blank', _action.data.popup);
+		}
 	}
 });
