@@ -14,20 +14,7 @@
 namespace EGroupware\Api;
 
 // explicitly import old phpgwapi classes used:
-use mime_magic;
-use common;
-use config;
-use html;
-use egw_db;
-use translation;
 use HTTP_WebDAV_Server;
-use egw_exception_assertion_failed;
-use egw_exception_db;
-use egw_exception_wrong_parameter;
-use egw_exception_wrong_userinput;
-use egw_exception;
-use egw_time;
-use egw_cache;
 
 /**
  * Class containing static methods to use the new eGW virtual file system
@@ -126,7 +113,7 @@ class Vfs extends Vfs\StreamWrapper
 	/**
 	 * Reference to the global db object
 	 *
-	 * @var egw_db
+	 * @var Db
 	 */
 	static $db;
 
@@ -141,7 +128,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("Filename '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("Filename '$path' is not an absolute path!");
 		}
 		return fopen(self::PREFIX.$path,$mode);
 	}
@@ -156,7 +143,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("Directory '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("Directory '$path' is not an absolute path!");
 		}
 		return opendir(self::PREFIX.$path);
 	}
@@ -171,7 +158,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("Directory '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("Directory '$path' is not an absolute path!");
 		}
 		return dir(self::PREFIX.$path);
 	}
@@ -187,7 +174,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("Directory '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("Directory '$path' is not an absolute path!");
 		}
 		return scandir(self::PREFIX.$path,$sorting_order);
 	}
@@ -204,7 +191,10 @@ class Vfs extends Vfs\StreamWrapper
 		$old_props = self::file_exists($to) ? self::propfind($to,null) : array();
 		// copy properties (eg. file comment), if there are any and evtl. existing old properties
 		$props = self::propfind($from,null);
-
+		if(!$props)
+		{
+			$props = array();
+		}
 		foreach($old_props as $prop)
 		{
 			if (!self::find_prop($props,$prop))
@@ -250,7 +240,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("File '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("File '$path' is not an absolute path!");
 		}
 		if (($stat = self::url_stat($path,0,$try_create_home)))
 		{
@@ -270,7 +260,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($path[0] != '/')
 		{
-			throw new egw_exception_assertion_failed("File '$path' is not an absolute path!");
+			throw new Exception\AssertionFailed("File '$path' is not an absolute path!");
 		}
 		if (($stat = self::url_stat($path,STREAM_URL_STAT_LINK,$try_create_home)))
 		{
@@ -331,7 +321,7 @@ class Vfs extends Vfs\StreamWrapper
 
 		if (!isset($GLOBALS['egw_info']['server']['vfs_fstab']))	// happens eg. in setup
 		{
-			$api_config = config::read('phpgwapi');
+			$api_config = Config::read('phpgwapi');
 			if (isset($api_config['vfs_fstab']) && is_array($api_config['vfs_fstab']))
 			{
 				self::$fstab = $api_config['vfs_fstab'];
@@ -373,11 +363,14 @@ class Vfs extends Vfs\StreamWrapper
 		}
 		self::$fstab[$path] = $url;
 
-		uksort(self::$fstab,create_function('$a,$b','return strlen($a)-strlen($b);'));
+		uksort(self::$fstab, function($a, $b)
+		{
+			return strlen($a) - strlen($b);
+		});
 
 		if ($persitent_mount)
 		{
-			config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
+			Config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
 			$GLOBALS['egw_info']['server']['vfs_fstab'] = self::$fstab;
 			// invalidate session cache
 			if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
@@ -408,7 +401,7 @@ class Vfs extends Vfs\StreamWrapper
 		}
 		unset(self::$fstab[$path]);
 
-		config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
+		Config::save_value('vfs_fstab',self::$fstab,'phpgwapi');
 		$GLOBALS['egw_info']['server']['vfs_fstab'] = self::$fstab;
 		// invalidate session cache
 		if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
@@ -765,7 +758,7 @@ class Vfs extends Vfs\StreamWrapper
 	 *
 	 * @param string|array $urls url or array of url's
 	 * @param boolean $allow_urls =false allow to use url's, default no only pathes (to stay within the vfs)
-	 * @throws egw_exception_assertion_failed when trainig to remove /, /apps or /home
+	 * @throws Exception\AssertionFailed when trainig to remove /, /apps or /home
 	 * @return array
 	 */
 	static function remove($urls,$allow_urls=false)
@@ -776,7 +769,7 @@ class Vfs extends Vfs\StreamWrapper
 		{
 			if (preg_match('/^\/?(home|apps|)\/*$/',self::parse_url($url,PHP_URL_PATH)))
 			{
-				throw new egw_exception_assertion_failed(__METHOD__.'('.array2string($urls).") Cautiously rejecting to remove folder '$url'!");
+				throw new Exception\AssertionFailed(__METHOD__.'('.array2string($urls).") Cautiously rejecting to remove folder '$url'!");
 			}
 		}
 		return self::find($urls,array('depth'=>true,'url'=>$allow_urls,'hidden'=>true),array(__CLASS__,'_rm_rmdir'));
@@ -876,7 +869,7 @@ class Vfs extends Vfs\StreamWrapper
 		// throw exception if stat array is used insead of path, can be removed soon
 		if (is_array($path))
 		{
-			throw new egw_exception_wrong_parameter('path has to be string, use check_access($path,$check,$stat=null)!');
+			throw new Exception\WrongParameter('path has to be string, use check_access($path,$check,$stat=null)!');
 		}
 		// query stat array, if not given
 		if (is_null($stat))
@@ -987,7 +980,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		if ($session_only)
 		{
-			$session_eacls =& egw_cache::getSession(__CLASS__, self::SESSION_EACL);
+			$session_eacls =& Cache::getSession(__CLASS__, self::SESSION_EACL);
 			$session_eacls[] = array(
 				'path'   => $url[0] == '/' ? $url : self::parse_url($url, PHP_URL_PATH),
 				'owner'  => $owner ? $owner : self::$user,
@@ -1010,7 +1003,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		$eacls = self::_call_on_backend('get_eacl',array($path),true);	// true = fail silent (no PHP Warning)
 
-		$session_eacls =& egw_cache::getSession(__CLASS__, self::SESSION_EACL);
+		$session_eacls =& Cache::getSession(__CLASS__, self::SESSION_EACL);
 		if ($session_eacls)
 		{
 			// eacl is recursive, therefore we have to match all parent-dirs too
@@ -1098,7 +1091,7 @@ class Vfs extends Vfs\StreamWrapper
 			if (!preg_match($use='/^([ugoa]*)([+=-]+)([rwx]+)$/',$s,$matches))
 			{
 				$use = str_replace(array('/','^','$','(',')'),'',$use);
-				throw new egw_exception_wrong_userinput("$s is not an allowed mode, use $use !");
+				throw new Exception\WrongUserinput("$s is not an allowed mode, use $use !");
 			}
 			$base = (strpos($matches[3],'r') !== false ? self::READABLE : 0) |
 				(strpos($matches[3],'w') !== false ? self::WRITABLE : 0) |
@@ -1204,7 +1197,7 @@ class Vfs extends Vfs\StreamWrapper
 	 * Get the closest mime icon
 	 *
 	 * @param string $mime_type
-	 * @param boolean $et_image =true return $app/$icon string for etemplate (default) or html img tag if false
+	 * @param boolean $et_image =true return $app/$icon string for etemplate (default) or url for false
 	 * @param int $size =128
 	 * @return string
 	 */
@@ -1221,23 +1214,15 @@ class Vfs extends Vfs\StreamWrapper
 		$mime_full = strtolower(str_replace	('/','_',$mime_type));
 		list($mime_part) = explode('_',$mime_full);
 
-		if (!($img=common::image('etemplate',$icon='mime'.$size.'_'.$mime_full)) &&
+		if (!($img=Image::find('etemplate',$icon='mime'.$size.'_'.$mime_full)) &&
 			// check mime-alias-map before falling back to more generic icons
-			!(isset(mime_magic::$mime_alias_map[$mime_type]) &&
-				($img=common::image('etemplate',$icon='mime'.$size.'_'.str_replace('/','_',mime_magic::$mime_alias_map[$mime_full])))) &&
-			!($img=common::image('etemplate',$icon='mime'.$size.'_'.$mime_part)))
+			!(isset(MimeMagic::$mime_alias_map[$mime_type]) &&
+				($img=Image::find('etemplate',$icon='mime'.$size.'_'.str_replace('/','_',MimeMagic::$mime_alias_map[$mime_full])))) &&
+			!($img=Image::find('etemplate',$icon='mime'.$size.'_'.$mime_part)))
 		{
-			$img = common::image('etemplate',$icon='mime'.$size.'_unknown');
+			$img = Image::find('etemplate',$icon='mime'.$size.'_unknown');
 		}
-		if ($et_image === 'url')
-		{
-			return $img;
-		}
-		if ($et_image)
-		{
-			return 'etemplate/'.$icon;
-		}
-		return html::image('etemplate',$icon,mime_magic::mime2label($mime_type));
+		return $et_image ? 'etemplate/'.$icon : $img;
 	}
 
 	/**
@@ -1431,7 +1416,7 @@ class Vfs extends Vfs\StreamWrapper
 	 * @param array $_files List of files to include in the zip
 	 * @param string $name optional Zip file name.  If not provided, it will be determined automatically from the files
 	 *
-	 * @return undefined
+	 * @todo use https://github.com/maennchen/ZipStream-PHP to not assamble all files in memmory
 	 */
 	public static function download_zip(Array $_files, $name = false)
 	{
@@ -1443,7 +1428,7 @@ class Vfs extends Vfs\StreamWrapper
 		$zip = new \ZipArchive();
 		if (!$zip->open($zip_file, \ZipArchive::OVERWRITE))
 		{
-			throw new egw_exception("Cannot open zip file for writing.");
+			throw new Exception("Cannot open zip file for writing.");
 		}
 
 		// Find lowest common directory, to use relative paths
@@ -1526,7 +1511,7 @@ class Vfs extends Vfs\StreamWrapper
 
 			// Use safe names - replace unsafe chars, convert to ASCII (ZIP spec says CP437, but we'll try)
 			$path = explode('/',$relative);
-			$_name = translation::convert(translation::to_ascii(implode('/', str_replace($replace,'_',$path))),false,'ASCII');
+			$_name = Translation::convert(Translation::to_ascii(implode('/', str_replace($replace,'_',$path))),false,'ASCII');
 
 			// Don't go infinite with app entries
 			if(self::is_link($addfile))
@@ -1570,7 +1555,7 @@ class Vfs extends Vfs\StreamWrapper
 		}
 
 		// Set a comment to help tell them apart
-		$zip->setArchiveComment(lang('Created by %1', $GLOBALS['egw_info']['user']['account_lid']) . ' ' .egw_time::to());
+		$zip->setArchiveComment(lang('Created by %1', $GLOBALS['egw_info']['user']['account_lid']) . ' ' .DateTime::to());
 
 		// Record total for debug, not available after close()
 		$total_files = $zip->numFiles;
@@ -1635,7 +1620,7 @@ class Vfs extends Vfs\StreamWrapper
 	{
 		// we require write rights to lock/unlock a resource
 		if (!$path || $update && !$token || $check_writable &&
-			!(self::is_writable($path) || !self::file_exists($path) && self::is_writable(self::dirname($path))))
+			!(self::is_writable($path) || !self::file_exists($path) && ($dir=self::dirname($path)) && self::is_writable($dir)))
 		{
 			return false;
 		}
@@ -1655,8 +1640,8 @@ class Vfs extends Vfs\StreamWrapper
 			),__LINE__,__FILE__)->fetch())))
 			{
 				$owner = $row['lock_owner'];
-				$scope = egw_db::from_bool($row['lock_exclusive']) ? 'exclusive' : 'shared';
-				$type  = egw_db::from_bool($row['lock_write']) ? 'write' : 'read';
+				$scope = Db::from_bool($row['lock_exclusive']) ? 'exclusive' : 'shared';
+				$type  = Db::from_bool($row['lock_write']) ? 'write' : 'read';
 
 				self::$db->update(self::LOCK_TABLE,array(
 					'lock_expires' => $timeout,
@@ -1681,11 +1666,7 @@ class Vfs extends Vfs\StreamWrapper
 			}
 			if (!$token)
 			{
-				if (strpos(ini_get('include_path'), EGW_API_INC) === false)
-				{
-					ini_set('include_path', EGW_API_INC.PATH_SEPARATOR.ini_get('include_path'));
-				}
-				require_once('HTTP/WebDAV/Server.php');
+				require_once(__DIR__.'/WebDAV/Server.php');
 				$token = HTTP_WebDAV_Server::_new_locktoken();
 			}
 			try {
@@ -1701,7 +1682,7 @@ class Vfs extends Vfs\StreamWrapper
 				),false,__LINE__,__FILE__);
 				$ret = true;
 			}
-			catch(egw_exception_db $e) {
+			catch(Db\Exception $e) {
 				unset($e);
 				$ret = false;	// there's already a lock
 			}
@@ -1756,10 +1737,10 @@ class Vfs extends Vfs\StreamWrapper
 		// ToDo: shared locks can return multiple rows
 		if (($result = self::$db->select(self::LOCK_TABLE,'*',$where,__LINE__,__FILE__)->fetch()))
 		{
-			$result = egw_db::strip_array_keys($result,'lock_');
-			$result['type']  = egw_db::from_bool($result['write']) ? 'write' : 'read';
-			$result['scope'] = egw_db::from_bool($result['exclusive']) ? 'exclusive' : 'shared';
-			$result['depth'] = egw_db::from_bool($result['recursive']) ? 'infinite' : 0;
+			$result = Db::strip_array_keys($result,'lock_');
+			$result['type']  = Db::from_bool($result['write']) ? 'write' : 'read';
+			$result['scope'] = Db::from_bool($result['exclusive']) ? 'exclusive' : 'shared';
+			$result['depth'] = Db::from_bool($result['recursive']) ? 'infinite' : 0;
 		}
 		if ($result && $result['expires'] < time())	// lock is expired --> remove it
 		{
@@ -1790,7 +1771,7 @@ class Vfs extends Vfs\StreamWrapper
 			$extra[] = $extra_info;
 		}
 
-		if (($vfs_extra = $GLOBALS['egw']->hooks->process(array(
+		if (($vfs_extra = Hooks::process(array(
 			'location' => 'vfs_extra',
 			'path' => $path,
 			'content' => $content,
@@ -1906,7 +1887,7 @@ class Vfs extends Vfs\StreamWrapper
 
 		if ($mime_main == 'egw')
 		{
-			$image = common::image($mime_sub, 'navbar');
+			$image = Image::find($mime_sub, 'navbar');
 		}
 		else if ($file && $mime_main == 'image' && in_array($mime_sub, array('png','jpeg','jpg','gif','bmp')) &&
 		         (string)$GLOBALS['egw_info']['server']['link_list_thumbnail'] != '0' &&
@@ -1925,12 +1906,12 @@ class Vfs extends Vfs\StreamWrapper
 			{
 				$thparams['thsize'] = $thsize;
 			}
-			$image = $GLOBALS['egw']->link('/etemplate/thumbnail.php', $thparams);
+			$image = $GLOBALS['egw']->link('/api/thumbnail.php', $thparams);
 		}
 		else
 		{
 			list($app, $name) = explode("/", self::mime_icon($mime), 2);
-			$image = common::image($app, $name);
+			$image = Image::find($app, $name);
 		}
 
 		return $image;
@@ -2069,7 +2050,7 @@ class Vfs extends Vfs\StreamWrapper
 			if (self::LOG_LEVEL) error_log(__METHOD__."($tmp_name, $target, ".array2string($props).",$check_is_uploaded_file) returning FALSE !is_uploaded_file()");
 			return false;
 		}
-		if (!(self::is_writable($target) || self::is_writable(self::dirname($target))))
+		if (!(self::is_writable($target) || ($dir = self::dirname($target)) && self::is_writable($dir)))
 		{
 			if (self::LOG_LEVEL) error_log(__METHOD__."($tmp_name, $target, ".array2string($props).",$check_is_uploaded_file) returning FALSE !writable");
 			return false;
