@@ -7,23 +7,14 @@
  * @package api
  * @subpackage vfs
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2008-15 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @version $Id$
  */
 
 namespace EGroupware\Api\Vfs\Sqlfs;
 
 use EGroupware\Api\Vfs;
-
-// explicitly import old phpgwapi classes used:
-use egw_cache;
-use mime_magic;
-use config;
-use translation;
-use egw_exception_db;
-use egw_exception_wrong_parameter;
-use egw_exception_assertion_failed;
-
+use EGroupware\Api;
 
 /**
  * EGroupware API: VFS - new DB based VFS stream wrapper
@@ -43,7 +34,7 @@ use egw_exception_assertion_failed;
  *
  * @link http://www.php.net/manual/en/function.stream-wrapper-register.php
  */
-class StreamWrapper implements Vfs\StreamWrapperIface
+class StreamWrapper extends Api\Db\Pdo implements Vfs\StreamWrapperIface
 {
 	/**
 	 * Mime type of directories, the old vfs uses 'Directory', while eg. WebDAV uses 'httpd/unix-directory'
@@ -150,12 +141,6 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 	 * @var array $path => info-array pairs
 	 */
 	static protected $stat_cache = array();
-	/**
-	 * Reference to the PDO object we use
-	 *
-	 * @var \PDO
-	 */
-	static protected $pdo;
 	/**
 	 * Array with filenames of dir opened with dir_opendir
 	 *
@@ -186,7 +171,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 
 		self::$stat_cache = array();
 
-		egw_cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl = null);
+		Api\Cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl = null);
 	}
 
 	/**
@@ -364,7 +349,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 			$values = array(
 				'fs_size' => $this->stream_tell(),
 				// todo: analyse the file for the mime-type
-				'fs_mime' => mime_magic::filename2mime($this->opened_path),
+				'fs_mime' => Api\MimeMagic::filename2mime($this->opened_path),
 				'fs_id'   => $this->opened_fs_id,
 				'fs_modifier' => Vfs::$user,
 				'fs_modified' => self::_pdo_timestamp(time()),
@@ -1185,11 +1170,11 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 			// decrement subquery limit by 1 and try again, if not already smaller then 3
 			if ($max_subquery_depth < 3)
 			{
-				throw new egw_exception_db($e->getMessage());
+				throw new Api\Db\Exception($e->getMessage());
 			}
 			$GLOBALS['egw_info']['server']['max_subquery_depth'] = --$max_subquery_depth;
 			error_log(__METHOD__."() decremented max_subquery_depth to $max_subquery_depth");
-			config::save_value('max_subquery_depth', $max_subquery_depth, 'phpgwapi');
+			Api\Config::save_value('max_subquery_depth', $max_subquery_depth, 'phpgwapi');
 			if (method_exists($GLOBALS['egw'],'invalidate_session_cache')) $GLOBALS['egw']->invalidate_session_cache();
 			return self::url_stat($url, $flags, $eacl_access);
 		}
@@ -1204,7 +1189,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 	 *
 	 * @return string
 	 */
-	protected function _sql_readable()
+	protected static function _sql_readable()
 	{
 		static $sql_read_acl=null;
 
@@ -1377,7 +1362,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 	 */
 	static protected function _read_extended_acl()
 	{
-		if ((self::$extended_acl = egw_cache::getSession(self::EACL_APPNAME, 'extended_acl')))
+		if ((self::$extended_acl = Api\Cache::getSession(self::EACL_APPNAME, 'extended_acl')))
 		{
 			return;		// ext. ACL read from session.
 		}
@@ -1398,7 +1383,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 		uksort(self::$extended_acl, function($a,$b) {
 			return strlen($b)-strlen($a);
 		});
-		egw_cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl);
+		Api\Cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl);
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__.'() '.array2string(self::$extended_acl));
 	}
 
@@ -1464,7 +1449,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 		}
 		if ($ret)
 		{
-			egw_cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl);
+			Api\Cache::setSession(self::EACL_APPNAME, 'extended_acl', self::$extended_acl);
 		}
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($path,$rights,$owner,$fs_id)=".(int)$ret);
 		return $ret;
@@ -1478,7 +1463,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 	 * @param string $path
 	 * @return array|boolean array with array('path'=>$path,'owner'=>$owner,'rights'=>$rights) or false if $path not found
 	 */
-	function get_eacl($path)
+	static function get_eacl($path)
 	{
 		if (!($stat = static::url_stat($path, STREAM_URL_STAT_QUIET)))
 		{
@@ -1633,117 +1618,6 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 		return $stat;
 	}
 
-	public static $pdo_type;
-	/**
-	 * Case sensitive comparison operator, for mysql we use ' COLLATE utf8_bin ='
-	 *
-	 * @var string
-	 */
-	public static $case_sensitive_equal = '=';
-
-	/**
-	 * Reconnect to database
-	 */
-	static public function reconnect()
-	{
-		self::$pdo = self::_pdo();
-	}
-
-	/**
-	 * Create pdo object / connection, as long as pdo is not generally used in eGW
-	 *
-	 * @return \PDO
-	 */
-	static protected function _pdo()
-	{
-		$egw_db = isset($GLOBALS['egw_setup']) ? $GLOBALS['egw_setup']->db : $GLOBALS['egw']->db;
-
-		switch($egw_db->Type)
-		{
-			case 'mysqli':
-			case 'mysqlt':
-			case 'mysql':
-				self::$case_sensitive_equal = '= BINARY ';
-				self::$pdo_type = 'mysql';
-				break;
-			default:
-				self::$pdo_type = $egw_db->Type;
-				break;
-		}
-		// get host used be egw_db
-		$egw_db->connect();
-		$host = $egw_db->get_host();
-
-		$dsn = self::$pdo_type.':dbname='.$egw_db->Database.($host ? ';host='.$host.($egw_db->Port ? ';port='.$egw_db->Port : '') : '');
-		// check once if pdo extension and DB specific driver is loaded or can be loaded
-		static $pdo_available=null;
-		if (is_null($pdo_available))
-		{
-			foreach(array('pdo','pdo_'.self::$pdo_type) as $ext)
-			{
-				check_load_extension($ext,true);	// true = throw Exception
-			}
-			$pdo_available = true;
-		}
-		try {
-			self::$pdo = new \PDO($dsn,$egw_db->User,$egw_db->Password,array(
-				\PDO::ATTR_ERRMODE=>\PDO::ERRMODE_EXCEPTION,
-			));
-		}
-		catch(Exception $e)
-		{
-			unset($e);
-			// Exception reveals password, so we ignore the exception and connect again without pw, to get the right exception without pw
-			self::$pdo = new \PDO($dsn,$egw_db->User,'$egw_db->Password');
-		}
-		// set client charset of the connection
-		$charset = translation::charset();
-		switch(self::$pdo_type)
-		{
-			case 'mysql':
-				if (isset($egw_db->Link_ID->charset2mysql[$charset])) $charset = $egw_db->Link_ID->charset2mysql[$charset];
-				// fall throught
-			case 'pgsql':
-				$query = "SET NAMES '$charset'";
-				break;
-		}
-		if ($query)
-		{
-			self::$pdo->exec($query);
-		}
-		return self::$pdo;
-	}
-
-	/**
-	 * Just a little abstration 'til I know how to organise stuff like that with PDO
-	 *
-	 * @param mixed $time
-	 * @return string Y-m-d H:i:s
-	 */
-	static protected function _pdo_timestamp($time)
-	{
-		if (is_numeric($time))
-		{
-			$time = date('Y-m-d H:i:s',$time);
-		}
-		return $time;
-	}
-
-	/**
-	 * Just a little abstration 'til I know how to organise stuff like that with PDO
-	 *
-	 * @param boolean $val
-	 * @return string '1' or '0' for mysql, 'true' or 'false' for everyone else
-	 */
-	static protected function _pdo_boolean($val)
-	{
-		if (self::$pdo_type == 'mysql')
-		{
-			return $val ? '1' : '0';
-		}
-		return $val ? 'true' : 'false';
-	}
-
 	/**
 	 * Maximum value for a single hash element (should be 10^N): 10, 100 (default), 1000, ...
 	 *
@@ -1768,7 +1642,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 	{
 		if (!is_numeric($id))
 		{
-			throw new egw_exception_wrong_parameter(__METHOD__."(id=$id) id has to be an integer!");
+			throw new Api\Exception\WrongParameter(__METHOD__."(id=$id) id has to be an integer!");
 		}
 		if (!isset($GLOBALS['egw_info']['server']['files_dir']))
 		{
@@ -1782,7 +1656,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 		}
 		if (!$GLOBALS['egw_info']['server']['files_dir'])
 		{
-			throw  new egw_exception_assertion_failed("\$GLOBALS['egw_info']['server']['files_dir'] not set!");
+			throw  new Api\Exception\AssertionFailed("\$GLOBALS['egw_info']['server']['files_dir'] not set!");
 		}
 		$hash = array();
 		$n = $id;
@@ -1865,7 +1739,7 @@ class StreamWrapper implements Vfs\StreamWrapperIface
 		{
 			return false;
 		}
-		if (!Vfs::check_access($path,EGW_ACL_EDIT,$stat))
+		if (!Vfs::check_access($path,Api\Acl::EDIT,$stat))
 		{
 			return false;	// permission denied
 		}
