@@ -14,10 +14,7 @@
 namespace EGroupware\Api\Vfs;
 
 use EGroupware\Api\Vfs;
-
-// explicitly import old phpgwapi classes used:
-use mime_magic;
-use egw_exception_db;
+use EGroupware\Api;
 
 /**
  * eGroupWare API: VFS - stream wrapper interface
@@ -363,7 +360,7 @@ class StreamWrapper implements StreamWrapperIface
 
 		if (isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
 		{
-			$GLOBALS['egw']->hooks->process(array(
+			Api\Hooks::process(array(
 				'location' => str_replace('b','',$this->opened_stream_mode) == 'r' ? 'vfs_read' :
 					($this->opened_stream_is_new ? 'vfs_added' : 'vfs_modified'),
 				'path' => $this->opened_stream_path,
@@ -510,7 +507,7 @@ class StreamWrapper implements StreamWrapperIface
 		// call "vfs_unlink" hook only after successful unlink, with data from (not longer possible) stat call
 		if ($ok && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
 		{
-			$GLOBALS['egw']->hooks->process(array(
+			Api\Hooks::process(array(
 				'location' => 'vfs_unlink',
 				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
 				'url'  => $url,
@@ -563,7 +560,7 @@ class StreamWrapper implements StreamWrapperIface
 		// call "vfs_rename" hook
 		if ($ret && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
 		{
-			$GLOBALS['egw']->hooks->process(array(
+			Api\Hooks::process(array(
 				'location' => 'vfs_rename',
 				'from' => $path_from[0] == '/' ? $path_from : self::parse_url($path_from, PHP_URL_PATH),
 				'to' => $path_to[0] == '/' ? $path_to : self::parse_url($path_to, PHP_URL_PATH),
@@ -596,7 +593,7 @@ class StreamWrapper implements StreamWrapperIface
 		// call "vfs_mkdir" hook
 		if ($ret && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
 		{
-			$GLOBALS['egw']->hooks->process(array(
+			Api\Hooks::process(array(
 				'location' => 'vfs_mkdir',
 				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
 				'url' => $url,
@@ -634,7 +631,7 @@ class StreamWrapper implements StreamWrapperIface
 		// call "vfs_rmdir" hook, only after successful rmdir
 		if ($ok && isset($GLOBALS['egw']) && isset($GLOBALS['egw']->hooks))
 		{
-			$GLOBALS['egw']->hooks->process(array(
+			Api\Hooks::process(array(
 				'location' => 'vfs_rmdir',
 				'path' => $path[0] == '/' ? $path : self::parse_url($path, PHP_URL_PATH),
 				'url' => $url,
@@ -849,7 +846,7 @@ class StreamWrapper implements StreamWrapperIface
 		// using EGw's own mime magic (currently only checking the extension!)
 		if (!$mime)
 		{
-			$mime = mime_magic::filename2mime(self::parse_url($url,PHP_URL_PATH));
+			$mime = Api\MimeMagic::filename2mime(self::parse_url($url,PHP_URL_PATH));
 		}
 		//error_log(__METHOD__."($path,$recheck) mime=$mime");
 		return $mime;
@@ -977,7 +974,7 @@ class StreamWrapper implements StreamWrapperIface
 				}
 			}
 		}
-		catch (egw_exception_db $e) {
+		catch (Api\Db\Exception $e) {
 			// some long running operations, eg. merge-print, run into situation that DB closes our separate sqlfs connection
 			// we try now to reconnect Vfs\Sqlfs\StreamWrapper once
 			// it's done here in vfs_stream_wrapper as situation can happen in sqlfs, links, stylite.links or stylite.versioning
@@ -1001,7 +998,7 @@ class StreamWrapper implements StreamWrapperIface
 				'account_lid' => basename($path),
 				'account_name' => basename($path),
 			);
-			call_user_func(array('vfs_home_hooks',$hook_data['location']),$hook_data);
+			call_user_func(array(__NAMESPACE__.'\\Hooks',$hook_data['location']),$hook_data);
 			unset($hook_data);
 			$stat = self::url_stat($path,$flags,false);
 		}
@@ -1106,7 +1103,10 @@ class StreamWrapper implements StreamWrapperIface
 		self::$symlink_cache[$path] = $target;
 
 		// sort longest path first
-		uksort(self::$symlink_cache,create_function('$b,$a','return strlen($a)-strlen($b);'));
+		uksort(self::$symlink_cache, function($b, $a)
+		{
+			return strlen($a) - strlen($b);
+		});
 		if (self::LOG_LEVEL > 1) error_log(__METHOD__."($path,$target) cache now ".array2string(self::$symlink_cache));
 	}
 
