@@ -1,10 +1,12 @@
 <?php
-    /**
+/**
      * class.ico.php
      *
      * $Id$
      **/
 
+use EGroupware\Api;
+
     /**
      * Class Ico
      * Open ICO files and extract any size/depth to PNG format
