@@ -6,11 +6,15 @@
  * @package calendar
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @author Joerg Lehrke <jlehrke@noc.de>
- * @copyright (c) 2004-15 by RalfBecker-At-outdoor-training.de
+ * @copyright (c) 2004-16 by RalfBecker-At-outdoor-training.de
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Acl;
+
 if (!defined('ACL_TYPE_IDENTIFER'))	// used to mark ACL-values for the debug_message methode
 {
 	define('ACL_TYPE_IDENTIFER','***ACL***');
@@ -20,17 +24,6 @@ define('HOUR_s',60*60);
 define('DAY_s',24*HOUR_s);
 define('WEEK_s',7*DAY_s);
 
-/**
- * Gives read access to the calendar, but all events the user is not participating are private!
- * Used by addressbook.
- */
-define('EGW_ACL_READ_FOR_PARTICIPANTS',EGW_ACL_CUSTOM_1);
-define('EGW_ACL_FREEBUSY',EGW_ACL_CUSTOM_2);
-/**
- * Allows to invite an other user (if configured to be used!)
- */
-define('EGW_ACL_INVITE',EGW_ACL_CUSTOM_3);
-
 /**
  * Required (!) include, as we use the MCAL_* constants, BEFORE instanciating (and therefore autoloading) the class
  */
@@ -56,6 +49,20 @@ require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.calendar_so.inc.php');
  */
 class calendar_bo
 {
+	/**
+	 * Gives read access to the calendar, but all events the user is not participating are private!
+	 * Used by addressbook.
+	 */
+	const ACL_READ_FOR_PARTICIPANTS = Acl::CUSTOM1;
+	/**
+	 * Right to see free/busy data only
+	 */
+	const ACL_FREEBUSY = Acl::CUSTOM2;
+	/**
+	 * Allows to invite an other user (if configured to be used!)
+	 */
+	const ACL_INVITE = Acl::CUSTOM3;
+
 	/**
 	 * @var int $debug name of method to debug or level of debug-messages:
 	 *	False=Off as higher as more messages you get ;-)
@@ -177,26 +184,16 @@ class calendar_bo
 	 * @var array $cached_holidays holidays plus birthdays (gets cached in the session for performance reasons)
 	 */
 	var $cached_holidays;
-	/**
-	 * @var boholiday
-	 */
-	var $holidays;
 	/**
 	 * Instance of the socal class
 	 *
 	 * @var calendar_so
 	 */
 	var $so;
-	/**
-	 * Instance of the datetime class
-	 *
-	 * @var egw_datetime
-	 */
-	var $datetime;
 	/**
 	 * Instance of the categories class
 	 *
-	 * @var categories
+	 * @var Api\Categories
 	 */
 	var $categories;
 
@@ -207,12 +204,6 @@ class calendar_bo
 	 */
 	public $require_acl_invite = null;
 
-	/**
-	 * if the number of selected users for a view exeeds this number a view is consolidated (5 is set as default)
-	 * @var int
-	 */
-	public $calview_no_consolidate = 5;
-
 	/**
 	 * Warnings to show in regular UI
 	 *
@@ -228,22 +219,21 @@ class calendar_bo
 		if ($this->debug > 0) $this->debug_message('calendar_bo::bocal() started',True);
 
 		$this->so = new calendar_so();
-		$this->datetime = $GLOBALS['egw']->datetime;
 
 		$this->common_prefs =& $GLOBALS['egw_info']['user']['preferences']['common'];
 		$this->cal_prefs =& $GLOBALS['egw_info']['user']['preferences']['calendar'];
 
 		$this->now = time();
-		$this->now_su = egw_time::server2user($this->now,'ts');
+		$this->now_su = Api\DateTime::server2user($this->now,'ts');
 
 		$this->user = $GLOBALS['egw_info']['user']['account_id'];
 
 		$this->grants = $GLOBALS['egw']->acl->get_grants('calendar');
 
-		if (!is_array($this->resources = $GLOBALS['egw']->session->appsession('resources','calendar')))
+		if (!is_array($this->resources = Api\Cache::getSession('calendar', 'resources')))
 		{
 			$this->resources = array();
-			foreach($GLOBALS['egw']->hooks->process('calendar_resources') as $app => $data)
+			foreach(Api\Hooks::process('calendar_resources') as $app => $data)
 			{
 				if ($data && $data['type'])
 				{
@@ -257,19 +247,18 @@ class calendar_bo
 			);
 			$this->resources[''] = array(
 				'type' => '',
-				'app' => 'home-accounts',
+				'app' => 'api-accounts',
 			);
-			$GLOBALS['egw']->session->appsession('resources','calendar',$this->resources);
+			Api\Cache::setSession('calendar', 'resources', $this->resources);
 		}
-		//echo "registered resources="; _debug_array($this->resources);
+		//error_log(__METHOD__ . " registered resources=". array2string($this->resources));
 
-		$this->config = config::read('calendar');	// only used for horizont, regular calendar config is under phpgwapi
-		$this->calview_no_consolidate = ($GLOBALS['egw_info']['server']['calview_no_consolidate']?$GLOBALS['egw_info']['server']['calview_no_consolidate']:5);
+		$this->config = Api\Config::read('calendar');	// only used for horizont, regular calendar Api\Config is under phpgwapi
 		$this->require_acl_invite = $GLOBALS['egw_info']['server']['require_acl_invite'];
 
-		$this->categories = new categories($this->user,'calendar');
+		$this->categories = new Api\Categories($this->user,'calendar');
 
-		$this->customfields = config::get_customfields('calendar');
+		$this->customfields = Api\Storage\Customfields::get('calendar');
 
 		foreach($this->alarms as $secs => &$label)
 		{
@@ -324,7 +313,7 @@ class calendar_bo
 			$data[] = array(
 				'res_id' => $id,
 				'email' => $email,
-				'rights' => EGW_ACL_READ_FOR_PARTICIPANTS,
+				'rights' => self::ACL_READ_FOR_PARTICIPANTS,
 				'name' => $name,
 			);
 		}
@@ -344,11 +333,10 @@ class calendar_bo
 		foreach(array_keys($event['participants']) as $uid)
 		{
 			if (is_numeric($uid) && $GLOBALS['egw']->accounts->get_type($uid) == 'g' &&
-				($members = $GLOBALS['egw']->accounts->member($uid)))
+				($members = $GLOBALS['egw']->accounts->members($uid, true)))
 			{
 				foreach($members as $member)
 				{
-					$member = $member['account_id'];
 					if (!isset($event['participants'][$member]))
 					{
 						$event['participants'][$member] = 'G';
@@ -380,7 +368,7 @@ class calendar_bo
 		foreach($_users as $user)
 		{
 			$user = trim($user);
-			if ($ignore_acl || $this->check_perms(EGW_ACL_READ|EGW_ACL_READ_FOR_PARTICIPANTS|($use_freebusy?EGW_ACL_FREEBUSY:0),0,$user))
+			if ($ignore_acl || $this->check_perms(ACL::READ|self::ACL_READ_FOR_PARTICIPANTS|($use_freebusy?self::ACL_FREEBUSY:0),0,$user))
 			{
 				if ($user && !in_array($user,$users))	// already added?
 				{
@@ -399,30 +387,30 @@ class calendar_bo
 			{
 				if ($no_enum_groups) continue;
 
-				$members = $GLOBALS['egw']->accounts->member($user);
+				$members = $GLOBALS['egw']->accounts->members($user, true);
 				if (is_array($members))
 				{
 					foreach($members as $member)
 					{
 						// use only members which gave the user a read-grant
-						if (!in_array($member['account_id'],$users) &&
-							($ignore_acl || $this->check_perms(EGW_ACL_READ|($use_freebusy?EGW_ACL_FREEBUSY:0),0,$member['account_id'])))
+						if (!in_array($member, $users) &&
+							($ignore_acl || $this->check_perms(Acl::READ|($use_freebusy?self::ACL_FREEBUSY:0),0,$member)))
 						{
-							$users[] = $member['account_id'];
+							$users[] = $member;
 						}
 					}
 				}
 			}
 			else	// for users we have to include all the memberships, to get the group-events
 			{
-				$memberships = $GLOBALS['egw']->accounts->membership($user);
+				$memberships = $GLOBALS['egw']->accounts->memberships($user, true);
 				if (is_array($memberships))
 				{
 					foreach($memberships as $group)
 					{
-						if (!in_array($group['account_id'],$users))
+						if (!in_array($group,$users))
 						{
-							$users[] = $group['account_id'];
+							$users[] = $group;
 						}
 					}
 				}
@@ -451,7 +439,7 @@ class calendar_bo
 	 *		otherwise the original recuring event (with the first start- + enddate) is returned
 	 *  num_rows int number of entries to return, default or if 0, max_entries from the prefs
 	 *  order column-names plus optional DESC|ASC separted by comma
-	 *  ignore_acl if set and true no check_perms for a general EGW_ACL_READ grants is performed
+	 *  ignore_acl if set and true no check_perms for a general Acl::READ grants is performed
 	 *  enum_groups boolean if set and true, group-members will be added as participants with status 'G'
 	 *  cols string|array columns to select, if set an iterator will be returned
 	 *  append string to append to the query, eg. GROUP BY
@@ -492,7 +480,7 @@ class calendar_bo
 			$params['private_grants'] = array();
 			foreach($this->grants as $user => $rights)
 			{
-				if ($rights & EGW_ACL_PRIVATE) $params['private_grants'][] = $user;
+				if ($rights & Acl::PRIVAT) $params['private_grants'][] = $user;
 			}
 		}
 
@@ -556,7 +544,7 @@ class calendar_bo
 			}
 			else
 			{
-				$is_private = !$this->check_perms(EGW_ACL_READ,$event);
+				$is_private = !$this->check_perms(Acl::READ,$event);
 			}
 			if ($is_private || (!$event['public'] && $filter == 'hideprivate'))
 			{
@@ -648,7 +636,7 @@ class calendar_bo
 		// no method, fall back to link title
 		if (is_null($app_data))
 		{
-			$is_private = !egw_link::title($app,$id);
+			$is_private = !Link::title($app,$id);
 		}
 		// boolean value to make all events of $app public (false) or private (true)
 		elseif (is_bool($app_data))
@@ -666,7 +654,7 @@ class calendar_bo
 	/**
 	 * Clears all non-private info from a privat event
 	 *
-	 * That function only returns the infos allowed to be viewed by people without EGW_ACL_PRIVATE grants
+	 * That function only returns the infos allowed to be viewed by people without Acl::PRIVAT grants
 	 *
 	 * @param array &$event
 	 * @param array $allowed_participants ids of the allowed participants, eg. the ones the search is over or eg. the owner of the calendar
@@ -732,7 +720,7 @@ class calendar_bo
 		if ($new_horizont > time()+$maxdays*DAY_s)		// some user tries to "look" more then the maximum number of days in the future
 		{
 			if ($this->debug == 'check_move_horizont') $this->debug_message('calendar_bo::check_move_horizont(%1) horizont=%2 new horizont more then %3 days from now --> ignoring it',true,$new_horizont,(int)$this->config['horizont'],$maxdays);
-			$this->warnings['horizont'] = lang('Requested date %1 outside allowed range of %2 days: recurring events obmitted!', egw_time::to($new_horizont,true), $maxdays);
+			$this->warnings['horizont'] = lang('Requested date %1 outside allowed range of %2 days: recurring events obmitted!', Api\DateTime::to($new_horizont,true), $maxdays);
 			return;
 		}
 		if ($new_horizont < time()+31*DAY_s)
@@ -753,11 +741,11 @@ class calendar_bo
 					$this->debug_message('calendar_bo::check_move_horizont(%1): calling set_recurrences(%2,%3)',true,$new_horizont,$event,$old_horizont);
 				}
 				// insert everything behind max(cal_start), which can be less then $old_horizont because of bugs in the past
-				$this->set_recurrences($event,egw_time::server2user($recuring[$cal_id]+1));	// set_recurences operates in user-time!
+				$this->set_recurrences($event,Api\DateTime::server2user($recuring[$cal_id]+1));	// set_recurences operates in user-time!
 			}
 		}
 		// update the horizont
-		config::save_value('horizont',$this->config['horizont'],'calendar');
+		Api\Config::save_value('horizont',$this->config['horizont'],'calendar');
 
 		if ($this->debug == 'check_move_horizont') $this->debug_message('calendar_bo::check_move_horizont(%1) new horizont=%2, exiting',true,$new_horizont,(int)$this->config['horizont']);
 	}
@@ -798,16 +786,15 @@ class calendar_bo
 		$exceptions = array();
 		foreach((array)$event['recur_exception'] as $exception)
 		{
-			$exceptions[] = egw_time::to($exception, true);	// true = date
+			$exceptions[] = Api\DateTime::to($exception, true);	// true = date
 		}
-		//error_log(__METHOD__."(".array2string($event).", $start) exceptions=".array2string($exceptions));
 		foreach($events as $event)
 		{
-			$is_exception = in_array(egw_time::to($event['start'], true), $exceptions);
+			$is_exception = in_array(Api\DateTime::to($event['start'], true), $exceptions);
 			$start = $this->date2ts($event['start'],true);
 			if ($event['whole_day'])
 			{
-				$time = $this->so->startOfDay(new egw_time($event['end'], egw_time::$user_timezone));
+				$time = $this->so->startOfDay(new Api\DateTime($event['end'], Api\DateTime::$user_timezone));
 				$time->setTime(23, 59, 59);
 				$end = $this->date2ts($time,true);
 			}
@@ -815,7 +802,7 @@ class calendar_bo
 			{
 				$end = $this->date2ts($event['end'],true);
 			}
-			//error_log(__METHOD__."() start=".egw_time::to($start).", is_exception=".array2string($is_exception));
+			//error_log(__METHOD__."() start=".Api\DateTime::to($start).", is_exception=".array2string($is_exception));
 			$this->so->recurrence($event['id'], $start, $end, $event['participants'], $is_exception);
 		}
 	}
@@ -824,7 +811,7 @@ class calendar_bo
 	 * Convert data read from the db, eg. convert server to user-time
 	 *
 	 * Also make sure all timestamps comming from DB as string are converted to integer,
-	 * to avoid misinterpretation by egw_time as Ymd string.
+	 * to avoid misinterpretation by Api\DateTime as Ymd string.
 	 *
 	 * @param array &$events array of event-arrays (reference)
 	 * @param $date_format ='ts' date-formats: 'ts'=timestamp, 'server'=timestamp in server-time, 'array'=array or string with date-format
@@ -837,38 +824,38 @@ class calendar_bo
 			// convert timezone id of event to tzid (iCal id like 'Europe/Berlin')
 			if (empty($event['tzid']) && (!$event['tz_id'] || !($event['tzid'] = calendar_timezones::id2tz($event['tz_id']))))
 			{
-				$event['tzid'] = egw_time::$server_timezone->getName();
+				$event['tzid'] = Api\DateTime::$server_timezone->getName();
 			}
 			// database returns timestamps as string, convert them to integer
-			// to avoid misinterpretation by egw_time as Ymd string
+			// to avoid misinterpretation by Api\DateTime as Ymd string
 			// (this will fail on 32bit systems for times > 2038!)
-			$event['start'] = (int)$event['start'];	// this is for isWholeDay(), which also calls egw_time
+			$event['start'] = (int)$event['start'];	// this is for isWholeDay(), which also calls Api\DateTime
 			$event['end'] = (int)$event['end'];
 			$event['whole_day'] = self::isWholeDay($event);
 			if ($event['whole_day'] && $date_format != 'server')
 			{
 				// Adjust dates to user TZ
-				$stime =& $this->so->startOfDay(new egw_time((int)$event['start'], egw_time::$server_timezone), $event['tzid']);
-				$event['start'] = egw_time::to($stime, $date_format);
-				$time =& $this->so->startOfDay(new egw_time((int)$event['end'], egw_time::$server_timezone), $event['tzid']);
+				$stime =& $this->so->startOfDay(new Api\DateTime((int)$event['start'], Api\DateTime::$server_timezone), $event['tzid']);
+				$event['start'] = Api\DateTime::to($stime, $date_format);
+				$time =& $this->so->startOfDay(new Api\DateTime((int)$event['end'], Api\DateTime::$server_timezone), $event['tzid']);
 				$time->setTime(23, 59, 59);
-				$event['end'] = egw_time::to($time, $date_format);
+				$event['end'] = Api\DateTime::to($time, $date_format);
 				if (!empty($event['recurrence']))
 				{
-					$time =& $this->so->startOfDay(new egw_time((int)$event['recurrence'], egw_time::$server_timezone), $event['tzid']);
-					$event['recurrence'] = egw_time::to($time, $date_format);
+					$time =& $this->so->startOfDay(new Api\DateTime((int)$event['recurrence'], Api\DateTime::$server_timezone), $event['tzid']);
+					$event['recurrence'] = Api\DateTime::to($time, $date_format);
 				}
 				if (!empty($event['recur_enddate']))
 				{
-					$time =& $this->so->startOfDay(new egw_time((int)$event['recur_enddate'], egw_time::$server_timezone), $event['tzid']);
+					$time =& $this->so->startOfDay(new Api\DateTime((int)$event['recur_enddate'], Api\DateTime::$server_timezone), $event['tzid']);
 					$time->setTime(23, 59, 59);
-					$event['recur_enddate'] = egw_time::to($time, $date_format);
+					$event['recur_enddate'] = Api\DateTime::to($time, $date_format);
 				}
 				$timestamps = array('modified','created');
 			}
 			else
 			{
-				$timestamps = array('start','end','modified','created','recur_enddate','recurrence');
+				$timestamps = array('start','end','modified','created','recur_enddate','recurrence','recur_date');
 			}
 			// we convert here from the server-time timestamps to user-time and (optional) to a different date-format!
 			foreach ($timestamps as $ts)
@@ -886,8 +873,8 @@ class calendar_bo
 					if ($event['whole_day'] && $date_format != 'server')
 					{
 						// Adjust dates to user TZ
-						$time =& $this->so->startOfDay(new egw_time((int)$date, egw_time::$server_timezone), $event['tzid']);
-						$date = egw_time::to($time, $date_format);
+						$time =& $this->so->startOfDay(new Api\DateTime((int)$date, Api\DateTime::$server_timezone), $event['tzid']);
+						$date = Api\DateTime::to($time, $date_format);
 					}
 					else
 					{
@@ -917,7 +904,7 @@ class calendar_bo
 	{
 		if (empty($ts) || $date_format == 'server') return $ts;
 
-		return egw_time::server2user($ts,$date_format);
+		return Api\DateTime::server2user($ts,$date_format);
 	}
 
 	/**
@@ -927,7 +914,7 @@ class calendar_bo
 	 * @param mixed $date =null date to specify a single event of a series
 	 * @param boolean $ignore_acl should we ignore the acl, default False for a single id, true for multiple id's
 	 * @param string $date_format ='ts' date-formats: 'ts'=timestamp, 'server'=timestamp in servertime, 'array'=array, or string with date-format
-	 * @param array|int $clear_private_infos_users =null if not null, return events with EGW_ACL_FREEBUSY too,
+	 * @param array|int $clear_private_infos_users =null if not null, return events with self::ACL_FREEBUSY too,
 	 * 	but call clear_private_infos() with the given users
 	 * @return boolean|array event or array of id => event pairs, false if the acl-check went wrong, null if $ids not found
 	 */
@@ -939,7 +926,7 @@ class calendar_bo
 
 		$return = null;
 
-		$check = $clear_private_infos_users ? EGW_ACL_FREEBUSY : EGW_ACL_READ;
+		$check = $clear_private_infos_users ? self::ACL_FREEBUSY : Acl::READ;
 		if ($ignore_acl || is_array($ids) || ($return = $this->check_perms($check,$ids,0,$date_format,$date)))
 		{
 			if (is_array($ids) || !isset(self::$cached_event['id']) || self::$cached_event['id'] != $ids ||
@@ -970,7 +957,7 @@ class calendar_bo
 				$return = self::$cached_event;
 			}
 		}
-		if ($clear_private_infos_users && !is_array($ids) && !$this->check_perms(EGW_ACL_READ,$return))
+		if ($clear_private_infos_users && !is_array($ids) && !$this->check_perms(Acl::READ,$return))
 		{
 			$this->clear_private_infos($return, (array)$clear_private_infos_users);
 		}
@@ -1009,7 +996,7 @@ class calendar_bo
 		// if $end is before recur_enddate, use it instead
 		if (!$event['recur_enddate'] || $this->date2ts($event['recur_enddate']) > $this->date2ts($end))
 		{
-			//echo "<p>recur_enddate={$event['recur_enddate']}=".egw_time::to($event['recur_enddate'])." > end=$end=".egw_time::to($end)." --> using end instead of recur_enddate</p>\n";
+			//echo "<p>recur_enddate={$event['recur_enddate']}=".Api\DateTime::to($event['recur_enddate'])." > end=$end=".Api\DateTime::to($end)." --> using end instead of recur_enddate</p>\n";
 			// insert at least the event itself, if it's behind the horizont
 			$event['recur_enddate'] = $this->date2ts($end) < $this->date2ts($event['end']) ? $event['end'] : $end;
 		}
@@ -1100,7 +1087,7 @@ class calendar_bo
 	{
 		static $res_info_cache = array();
 
-		if (!is_scalar($uid)) throw new egw_exception_wrong_parameter(__METHOD__.'('.array2string($uid).') parameter must be scalar');
+		if (!is_scalar($uid)) throw new Api\Exception\WrongParameter(__METHOD__.'('.array2string($uid).') parameter must be scalar');
 
 		if (!isset($res_info_cache[$uid]))
 		{
@@ -1145,7 +1132,7 @@ class calendar_bo
 	 * Note: Participating in an event is considered as haveing read-access on that event,
 	 *	even if you have no general read-grant from that user.
 	 *
-	 * @param int $needed necessary ACL right: EGW_ACL_{READ|EDIT|DELETE}
+	 * @param int $needed necessary ACL right: Acl::{READ|EDIT|DELETE}
 	 * @param mixed $event event as array or the event-id or 0 for a general check
 	 * @param int $other uid to check (if event==0) or 0 to check against $this->user
 	 * @param string $date_format ='ts' date-format used for reading: 'ts'=timestamp, 'array'=array, 'string'=iso8601 string for xmlrpc
@@ -1194,9 +1181,9 @@ class calendar_bo
 		$grant = $grants[$owner];
 
 		// now any ACL rights (but invite rights!) implicate FREEBUSY rights (at least READ has to include FREEBUSY)
-		if ($grant & ~EGW_ACL_INVITE) $grant |= EGW_ACL_FREEBUSY;
+		if ($grant & ~self::ACL_INVITE) $grant |= self::ACL_FREEBUSY;
 
-		if (is_array($event) && ($needed == EGW_ACL_READ || $needed == EGW_ACL_FREEBUSY))
+		if (is_array($event) && ($needed == Acl::READ || $needed == self::ACL_FREEBUSY))
 		{
 			// Check if the $user is one of the participants or has a read-grant from one of them
 			// in that case he has an implicite READ grant for that event
@@ -1208,19 +1195,19 @@ class calendar_bo
 					if ($uid == $user || $uid < 0 && in_array($user, (array)$GLOBALS['egw']->accounts->members($uid,true)))
 					{
 						// if we are a participant, we have an implicite FREEBUSY, READ and PRIVAT grant
-						$grant |= EGW_ACL_FREEBUSY | EGW_ACL_READ | EGW_ACL_PRIVATE;
+						$grant |= self::ACL_FREEBUSY | Acl::READ | Acl::PRIVAT;
 						break;
 					}
-					elseif ($grants[$uid] & EGW_ACL_READ)
+					elseif ($grants[$uid] & Acl::READ)
 					{
 						// if we have a READ grant from a participant, we dont give an implicit privat grant too
-						$grant |= EGW_ACL_READ;
+						$grant |= Acl::READ;
 						// we cant break here, as we might be a participant too, and would miss the privat grant
 					}
 					elseif (!is_numeric($uid))
 					{
-						// if the owner only grants EGW_ACL_FREEBUSY we are not interested in the recources explicit rights
-						if ($grant == EGW_ACL_FREEBUSY) continue;
+						// if the owner only grants self::ACL_FREEBUSY we are not interested in the recources explicit rights
+						if ($grant == self::ACL_FREEBUSY) continue;
 						// if we have a resource as participant
 						$resource = $this->resource_info($uid);
 						$grant |= $resource['rights'];
@@ -1228,17 +1215,17 @@ class calendar_bo
 				}
 			}
 		}
-		if ($GLOBALS['egw']->accounts->get_type($owner) == 'g' && $needed == EGW_ACL_ADD)
+		if ($GLOBALS['egw']->accounts->get_type($owner) == 'g' && $needed == Acl::ADD)
 		{
 			$access = False;	// a group can't be the owner of an event
 		}
 		else
 		{
 			$access = $user == $owner || $grant & $needed
-				&& ($needed == EGW_ACL_FREEBUSY || !$private || $grant & EGW_ACL_PRIVATE);
+				&& ($needed == self::ACL_FREEBUSY || !$private || $grant & Acl::PRIVAT);
 		}
 		// do NOT allow users to purge deleted events, if we dont have 'userpurge' enabled
-		if ($access && $needed == EGW_ACL_DELETE && $event['deleted'] &&
+		if ($access && $needed == Acl::DELETE && $event['deleted'] &&
 			!$GLOBALS['egw_info']['user']['apps']['admin'] &&
 			$GLOBALS['egw_info']['server']['calendar_delete_history'] != 'userpurge')
 		{
@@ -1263,7 +1250,7 @@ class calendar_bo
 	 */
 	static function date2ts($date,$user2server=False)
 	{
-		return $user2server ? egw_time::user2server($date,'ts') : egw_time::to($date,'ts');
+		return $user2server ? Api\DateTime::user2server($date,'ts') : Api\DateTime::to($date,'ts');
 	}
 
 	/**
@@ -1275,7 +1262,7 @@ class calendar_bo
 	 */
 	static function date2array($date,$server2user=False)
 	{
-		return $server2user ? egw_time::server2user($date,'array') : egw_time::to($date,'array');
+		return $server2user ? Api\DateTime::server2user($date,'array') : Api\DateTime::to($date,'array');
 	}
 
 	/**
@@ -1288,7 +1275,7 @@ class calendar_bo
 	 */
 	static function date2string($date,$server2user=False,$format='Ymd')
 	{
-		return $server2user ? egw_time::server2user($date,$format) : egw_time::to($date,$format);
+		return $server2user ? Api\DateTime::server2user($date,$format) : Api\DateTime::to($date,$format);
 	}
 
 	/**
@@ -1300,7 +1287,7 @@ class calendar_bo
 	 */
 	static function format_date($date,$format='')
 	{
-		return egw_time::to($date,$format);
+		return Api\DateTime::to($date,$format);
 	}
 
 	/**
@@ -1326,12 +1313,12 @@ class calendar_bo
 	{
 		static $acl2string = array(
 			0               => 'ACL-UNKNOWN',
-			EGW_ACL_READ    => 'ACL_READ',
-			EGW_ACL_ADD     => 'ACL_ADD',
-			EGW_ACL_EDIT    => 'ACL_EDIT',
-			EGW_ACL_DELETE  => 'ACL_DELETE',
-			EGW_ACL_PRIVATE => 'ACL_PRIVATE',
-			EGW_ACL_FREEBUSY => 'ACL_FREEBUSY',
+			Acl::READ    => 'ACL_READ',
+			Acl::ADD     => 'ACL_ADD',
+			Acl::EDIT    => 'ACL_EDIT',
+			Acl::DELETE  => 'ACL_DELETE',
+			Acl::PRIVAT => 'ACL_PRIVATE',
+			self::ACL_FREEBUSY => 'ACL_FREEBUSY',
 		);
 		for($i = 2; $i < func_num_args(); ++$i)
 		{
@@ -1376,7 +1363,6 @@ class calendar_bo
 			}
 			$msg = str_replace('%'.($i-1),$param,$msg);
 		}
-		error_log($msg);
 		if ($backtrace) error_log(function_backtrace(1));
 	}
 
@@ -1488,11 +1474,11 @@ class calendar_bo
 		if ($end_m == 24*60-1) ++$duration;
 		$duration = floor($duration/60).lang('h').($duration%60 ? $duration%60 : '');
 
-		$timespan = $t = common::formattime(sprintf('%02d',$start_m/60),sprintf('%02d',$start_m%60));
+		$timespan = $t = Api\DateTime::to('20000101T'.sprintf('%02d',$start_m/60).sprintf('%02d',$start_m%60).'00', false);
 
 		if ($both)	// end-time too
 		{
-			$timespan .= ' - '.common::formattime(sprintf('%02d',$end_m/60),sprintf('%02d',$end_m%60));
+			$timespan .= ' - '.Api\DateTime::to('20000101T'.sprintf('%02d',$end_m/60).sprintf('%02d',$end_m%60).'00', false);
 			// dont double am/pm if they are the same in both times
 			if ($this->common_prefs['timeformat'] == 12 && substr($timespan,-2) == substr($t,-2))
 			{
@@ -1517,7 +1503,6 @@ class calendar_bo
 		static $id2email = array();
 
 		if ($use_type && $use_type != 'u') $id = $use_type.$id;
-		if($id === 0 || $id === '0') $id = $this->user;
 
 		if (!isset($id2lid[$id]))
 		{
@@ -1532,7 +1517,7 @@ class calendar_bo
 			}
 			else
 			{
-				$id2lid[$id] = common::grab_owner_name($id);
+				$id2lid[$id] = Api\Accounts::username($id);
 				$id2email[$id] = $GLOBALS['egw']->accounts->id2name($id,'account_email');
 			}
 		}
@@ -1565,19 +1550,19 @@ class calendar_bo
 				switch($status[0])
 				{
 					case 'A':	// accepted
-						$status = html::image('calendar','accepted',$lang_status);
+						$status = Api\Html::image('calendar','accepted',$lang_status);
 						break;
 					case 'R':	// rejected
-						$status = html::image('calendar','rejected',$lang_status);
+						$status = Api\Html::image('calendar','rejected',$lang_status);
 						break;
 					case 'T':	// tentative
-						$status = html::image('calendar','tentative',$lang_status);
+						$status = Api\Html::image('calendar','tentative',$lang_status);
 						break;
 					case 'U':	// no response = unknown
-						$status = html::image('calendar','needs-action',$lang_status);
+						$status = Api\Html::image('calendar','needs-action',$lang_status);
 						break;
 					case 'D':	// delegated
-						$status = html::image('calendar','forward',$lang_status);
+						$status = Api\Html::image('calendar','forward',$lang_status);
 						break;
 					case 'G':	// group invitation
 						// Todo: Image, seems not to be used
@@ -1589,7 +1574,7 @@ class calendar_bo
 			{
 				$status = '('.$lang_status.')';
 			}
-			$names[$id] = html::htmlspecialchars($this->participant_name($id)).($quantity > 1 ? ' ('.$quantity.')' : '').' '.$status;
+			$names[$id] = Api\Html::htmlspecialchars($this->participant_name($id)).($quantity > 1 ? ' ('.$quantity.')' : '').' '.$status;
 
 			// add role, if not a regular participant
 			if ($role != 'REQ-PARTICIPANT')
@@ -1634,7 +1619,7 @@ class calendar_bo
 
 			if (!isset($id2cat[$cat_id]))
 			{
-				$id2cat[$cat_id] = categories::read($cat_id);
+				$id2cat[$cat_id] = Api\Categories::read($cat_id);
 			}
 			$cat = $id2cat[$cat_id];
 
@@ -1657,7 +1642,7 @@ class calendar_bo
 	 */
 	private static function _list_cals_add($id,&$users,&$groups)
 	{
-		$name = common::grab_owner_name($id);
+		$name = Api\Accounts::username($id);
 		if (!($egw_name = $GLOBALS['egw']->accounts->id2name($id)))
 		{
 			return;	// do not return no longer existing accounts which eg. still mentioned in acl
@@ -1703,13 +1688,13 @@ class calendar_bo
 		{
 			self::_list_cals_add($id,$users,$groups);
 		}
-		if (($memberships = $GLOBALS['egw']->accounts->membership($user)))
+		if (($memberships = $GLOBALS['egw']->accounts->memberships($user, true)))
 		{
-			foreach($memberships as $group_info)
+			foreach($memberships as $group)
 			{
-				self::_list_cals_add($group_info['account_id'],$users,$groups);
+				self::_list_cals_add($group,$users,$groups);
 
-				if (($account_perms = $GLOBALS['egw']->acl->get_ids_for_location($group_info['account_id'],EGW_ACL_READ,'calendar')))
+				if (($account_perms = $GLOBALS['egw']->acl->get_ids_for_location($group,Acl::READ,'calendar')))
 				{
 					foreach($account_perms as $id)
 					{
@@ -1755,14 +1740,11 @@ class calendar_bo
 	 *
 	 * @param int $year =0 year, defaults to 0 = current year
 	 * @return array indexed with Ymd of array of holidays. A holiday is an array with the following fields:
-	 *	index: numerical unique id
-	 *	locale: string, 2-char short for the nation
 	 *	name: string
+	 *  title: optional string with description
 	 *	day: numerical day in month
 	 *	month: numerical month
 	 *	occurence: numerical year or 0 for every year
-	 *	dow: day of week, 0=sunday, .., 6= saturday
-	 *	observande_rule: boolean
 	 */
 	function read_holidays($year=0)
 	{
@@ -1770,21 +1752,19 @@ class calendar_bo
 
 		if (!$this->cached_holidays)	// try reading the holidays from the session
 		{
-			$this->cached_holidays = $GLOBALS['egw']->session->appsession('holidays','calendar');
+			$this->cached_holidays = Api\Cache::getSession('calendar', 'holidays');
 		}
 		if (!isset($this->cached_holidays[$year]))
 		{
-			if (!is_object($this->holidays))
-			{
-				$this->holidays = CreateObject('calendar.boholiday');
-			}
-			$this->holidays->prepare_read_holidays($year);
-			$this->cached_holidays[$year] = $this->holidays->read_holiday();
+			$this->cached_holidays[$year] = calendar_holidays::read(
+				!empty($GLOBALS['egw_info']['server']['ical_holiday_url']) ?
+				$GLOBALS['egw_info']['server']['ical_holiday_url'] :
+				$GLOBALS['egw_info']['user']['preferences']['common']['country'], $year);
 
 			// search for birthdays
 			if ($GLOBALS['egw_info']['server']['hide_birthdays'] != 'yes')
 			{
-				$contacts = new addressbook_bo();
+				$contacts = new Api\Contacts();
 				$filter = array(
 					'n_family' => "!''",
 					'bday' => "!''",
@@ -1824,7 +1804,7 @@ class calendar_bo
 				}
 			}
 			// store holidays and birthdays in the session
-			$this->cached_holidays = $GLOBALS['egw']->session->appsession('holidays','calendar',$this->cached_holidays);
+			Api\Cache::setSession('calendar', 'holidays', $this->cached_holidays);
 		}
 		if ((int) $this->debug >= 2 || $this->debug == 'read_holidays')
 		{
@@ -1839,7 +1819,7 @@ class calendar_bo
 	 * @param type $event
 	 * @return array array of selected calendar fields
 	 */
-	function get_link_options ($event = array())
+	public static function get_link_options ($event = array())
 	{
 		unset($event);	// not used, but required by function signature
 		$options = array (
@@ -1891,13 +1871,13 @@ class calendar_bo
 					case 'participants':
 						foreach (array_keys($event[$val]) as $key)
 						{
-							$extra_fields [$val] = accounts::id2name($key, 'account_fullname');
+							$extra_fields [$val] = Api\Accounts::id2name($key, 'account_fullname');
 						}
 						break;
 					case 'modifier':
 					case 'creator':
 					case 'owner':
-						$extra_fields [$val] = accounts::id2name($event[$val], 'account_fullname');
+						$extra_fields [$val] = Api\Accounts::id2name($event[$val], 'account_fullname');
 						break;
 					default:
 						$extra_fields [] = $event[$val];
@@ -1940,7 +1920,7 @@ class calendar_bo
 	 * Check access to the file store
 	 *
 	 * @param int $id id of entry
-	 * @param int $check EGW_ACL_READ for read and EGW_ACL_EDIT for write or delete access
+	 * @param int $check Acl::READ for read and Acl::EDIT for write or delete access
 	 * @param string $rel_path =null currently not used in calendar
 	 * @param int $user =null for which user to check, default current user
 	 * @return boolean true if access is granted or false otherwise
@@ -1959,19 +1939,15 @@ class calendar_bo
 	 */
 	function check_set_default_prefs()
 	{
-		if ($this->cal_prefs['interval'] && ($set = $GLOBALS['egw']->session->appsession('default_prefs_set','calendar')))
+		if ($this->cal_prefs['interval'] && ($set = Api\Cache::getSession('calendar', 'default_prefs_set')))
 		{
 			return;
 		}
-		$GLOBALS['egw']->session->appsession('default_prefs_set','calendar','set');
+		Api\Cache::setSession('calendar', 'default_prefs_set', 'set');
 
 		$default_prefs =& $GLOBALS['egw']->preferences->default['calendar'];
 		$forced_prefs  =& $GLOBALS['egw']->preferences->forced['calendar'];
 
-		if (!($planner_start_with_group = $GLOBALS['egw']->accounts->name2id('Default')))
-		{
-			$planner_start_with_group = '0';
-		}
 		$subject = lang('Calendar Event') . ' - $$action$$: $$startdate$$ $$title$$'."\n";
 		$values = array(
 			'notifyAdded'     => $subject . lang ('You have a meeting scheduled for %1','$$startdate$$'),
@@ -1980,7 +1956,6 @@ class calendar_bo
 			'notifyDisinvited'=> $subject . lang ('You have been disinvited from the meeting at %1','$$startdate$$'),
 			'notifyResponse'  => $subject . lang ('On %1 %2 %3 your meeting request for %4','$$date$$','$$fullname$$','$$action$$','$$startdate$$'),
 			'notifyAlarm'     => lang('Alarm for %1 at %2 in %3','$$title$$','$$startdate$$','$$location$$')."\n".lang ('Here is your requested alarm.'),
-			'planner_start_with_group' => $planner_start_with_group,
 			'interval'        => 30,
 		);
 		foreach($values as $var => $default)
@@ -2085,7 +2060,7 @@ class calendar_bo
 		$users = $this->resolve_users($user);
 		$ctag = $users ? $this->so->get_ctag($users, $filter == 'owner', $master_only) : 0;	// no rights, return 0 as ctag (otherwise we get SQL error!)
 
-		if ($this->debug > 1) error_log(__METHOD__. "($user, '$filter') = $ctag = ".date('Y-m-d H:i:s',$ctag)." took ".(microtime(true)-$startime)." secs");
+		if ($this->debug > 1) error_log(__METHOD__. "($user, '$filter', $master_only) = $ctag = ".date('Y-m-d H:i:s',$ctag)." took ".(microtime(true)-$startime)." secs");
 		return $ctag;
 	}
 
@@ -2104,7 +2079,7 @@ class calendar_bo
 		}
 
 		$content = array(
-			'info_cat'       => $GLOBALS['egw']->categories->check_list(EGW_ACL_READ, $calendar['category']),
+			'info_cat'       => $GLOBALS['egw']->categories->check_list(Acl::READ, $calendar['category']),
 			'info_priority'  => $calendar['priority'] ,
 			'info_public'    => $calendar['public'] != 'private',
 			'info_subject'   => $calendar['title'],
@@ -2120,9 +2095,9 @@ class calendar_bo
 		$content['link_app'][] = $calendar['info_link']['app'];
 		$content['link_id'][]  = $calendar['info_link']['id'];
 		// Copy claendar's links
-		foreach(egw_link::get_links('calendar',$calendar['id'],'','link_lastmod DESC',true) as $link)
+		foreach(Link::get_links('calendar',$calendar['id'],'','link_lastmod DESC',true) as $link)
 		{
-			if ($link['app'] != egw_link::VFS_APPNAME)
+			if ($link['app'] != Link::VFS_APPNAME)
 			{
 				$content['link_app'][] = $link['app'];
 				$content['link_id'][]  = $link['id'];
@@ -2133,7 +2108,7 @@ class calendar_bo
 			}
 		}
 		// Copy same custom fields
-		foreach(array_keys(config::get_customfields('infolog')) as $name)
+		foreach(array_keys(Api\Storage\Customfields::get('infolog')) as $name)
 		{
 			if ($this->customfields[$name]) $content['#'.$name] = $calendar['#'.$name];
 		}
@@ -2156,7 +2131,7 @@ class calendar_bo
 		{
 			$set['ts_start'] = $event['start'];
 			$set['ts_title'] = $this->link_title($event);
-			$set['start_time'] = egw_time::to($event['start'],'H:i');
+			$set['start_time'] = Api\DateTime::to($event['start'],'H:i');
 			$set['ts_description'] = $event['description'];
 			if ($this->isWholeDay($event)) $event['end']++;	// whole day events are 1sec short
 			$set['ts_duration']	= ($event['end'] - $event['start']) / 60;
@@ -2164,9 +2139,9 @@ class calendar_bo
 			$set['end_time'] = null;	// unset end-time
 			$set['cat_id'] = (int)$event['category'];
 
-			foreach(egw_link::get_links('calendar',$id,'','link_lastmod DESC',true) as $link)
+			foreach(Link::get_links('calendar',$id,'','link_lastmod DESC',true) as $link)
 			{
-				if ($link['app'] != 'timesheet' && $link['app'] != egw_link::VFS_APPNAME)
+				if ($link['app'] != 'timesheet' && $link['app'] != Link::VFS_APPNAME)
 				{
 					$set['link_app'][] = $link['app'];
 					$set['link_id'][]  = $link['id'];
