@@ -5,11 +5,16 @@
  * @link http://www.egroupware.org
  * @package calendar
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2004-14 by RalfBecker-At-outdoor-training.de
+ * @copyright (c) 2004-16 by RalfBecker-At-outdoor-training.de
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+
 /**
  * diverse static calendar hooks
  */
@@ -31,15 +36,19 @@ class calendar_hooks
 				'menuaction' => 'calendar.calendar_uiforms.edit',
 			),
 			'view_id'    => 'cal_id',
-			'view_popup' => '750x400',
-			'edit_popup' => '750x400',
-			'view_list'  => 'calendar.calendar_uilist.listview',
+			'view_popup' => '850x590',
+			'edit_popup' => '850x590',
+			'list'  => array(
+				'menuaction' => 'calendar.calendar_uiviews.index',
+				'view' => 'listview',
+				'ajax'=>'true'
+			),
 			'add'        => array(
 				'menuaction' => 'calendar.calendar_uiforms.edit',
 			),
 			'add_app'    => 'link_app',
 			'add_id'     => 'link_id',
-			'add_popup'  => '750x400',
+			'add_popup'  => '850x590',
 			'file_access' => 'calendar.calendar_bo.file_access',
 			'file_access_user' => true,	// file_access supports 4th parameter $user
 			'mime' => array(
@@ -47,7 +56,7 @@ class calendar_hooks
 					'menuaction' => 'calendar.calendar_uiforms.edit',
 					'mime_data' => 'ical_data',
 					'mime_url' => 'ical_url',
-					'mime_popup' => '750x400',
+					'mime_popup' => '850x590',
 					'mime_target' => '_blank'
 				),
 			),
@@ -75,12 +84,11 @@ class calendar_hooks
 	static function admin()
 	{
 		$file = Array(
-			'Site Configuration' => egw::link('/index.php','menuaction=admin.uiconfig.index&appname=calendar'),
-			'Custom fields' => egw::link('/index.php','menuaction=admin.customfields.index&appname=calendar'),
-			'Calendar Holiday Management' => egw::link('/index.php','menuaction=calendar.uiholiday.admin'),
-			'Global Categories' => egw::link('/index.php','menuaction=admin.admin_categories.index&appname=calendar'),
-			'Category ACL' => egw::link('/index.php','menuaction=calendar.calendar_uiforms.cat_acl'),
-			'Update timezones' => egw::link('/index.php','menuaction=calendar.calendar_timezones.update'),
+			'Site Configuration' => Egw::link('/index.php','menuaction=admin.admin_config.index&appname=calendar&ajax=true'),
+			'Custom fields' => Egw::link('/index.php','menuaction=admin.customfields.index&appname=calendar'),
+			'Global Categories' => Egw::link('/index.php','menuaction=admin.admin_categories.index&appname=calendar'),
+			'Category ACL' => Egw::link('/index.php','menuaction=calendar.calendar_uiforms.cat_acl'),
+			'Update timezones' => Egw::link('/index.php','menuaction=calendar.calendar_timezones.update'),
 		);
 		display_section('calendar','calendar',$file);
 	}
@@ -97,34 +105,17 @@ class calendar_hooks
 			$bo = new calendar_bo();
 			$bo->check_set_default_prefs();
 		}
-		$mainscreen = array(
-			'0'            => lang('None'),
-			'day'          => lang('Dayview'),
-			'day4'         => lang('Four days view'),
-			'1'            => lang('Weekview'),
-			'weekN'        => lang('Multiple week view'),
-			'month'        => lang('Monthview'),
-			'year'         => lang('yearview'),
-			'planner_cat'  => lang('Planner by category'),
-			'planner_user' => lang('Planner by user'),
-			'listview'     => lang('Listview'),
-		);
 		$yesno = array(
 			'1' => lang('Yes'),
 			'0' => lang('No'),
 		);
-		$grid_views = array(
-			'all' => lang('all'),
-			'day_week' => lang('Dayview').', '.lang('Four days view').' &amp; '.lang('Weekview'),
-			'day4' => lang('Dayview').' &amp; '.lang('Four days view'),
+		$list_views = array(
+			0 => lang('None'),
+			'weekN' => lang('Multiple week view'),
+			'week' => lang('Weekview'),
+			'day4' => lang('Four days view'),
 			'day' => lang('Dayview'),
 		);
-		/* Select list with number of day by week */
-		$week_view = array(
-			'5' => lang('Weekview without weekend'),
-			'7' => lang('Weekview with weekend'),
-		);
-
 		$updates = array(
 			'no'             => lang('Never'),
 			'add_cancel'     => lang('on invitation / cancelation only'),
@@ -163,16 +154,19 @@ class calendar_hooks
 			'Saturday' => lang('Saturday')
 		);
 
-		for ($i=0; $i < 24; ++$i)
+		if (!isset($hook_data['setup']))
 		{
-			$times[$i] = $GLOBALS['egw']->common->formattime($i,'00');
+			$times = Api\Etemplate\Widget\Select::typeOptions('select-hour', '');
 		}
-
-		for ($i = 2; $i <= 9; ++$i)
+		for ($i = 2; $i <= 4; ++$i)
 		{
 			$muliple_weeks[$i] = lang('%1 weeks',$i);
 		}
 
+		for ($i = 2; $i <= 9; $i++)
+		{
+			$consolidated[$i] = $i;
+		}
 		$intervals = array(
 			5	=> '5',
 			10	=> '10',
@@ -182,12 +176,14 @@ class calendar_hooks
 			45	=> '45',
 			60	=> '60'
 		);
+		$default_participants = array(
+			0 => lang('Just me'),
+			'selected' => lang('Selected users/groups')
+		);
 		$defaultresource_sel = array(
 			'resources_conflict'    => lang('resources with conflict detection'),
 			'resources_without_conflict'    => lang('resources except conflicting ones'),
-			'resources'     => lang('resources'),
-			'addressbook'   => lang('addressbook'),
-			'home-accounts' => lang('Accounts'),
+			'resources'     => lang('resources')
 		);
 		$reset_stati_on_shifts = array(
 			'no'		=> lang('Never'),
@@ -204,7 +200,7 @@ class calendar_hooks
 			$options = array('0' => lang('none'));
 			foreach($GLOBALS['egw']->accounts->search(array('type' => 'owngroups','app' => 'calendar')) as $group)
 			{
-				$options[$group['account_id']] = common::grab_owner_name($group['account_id']);
+				$options[$group['account_id']] = Api\Accounts::username($group['account_id']);
 			}
 			$freebusy_url = calendar_bo::freebusy_url($GLOBALS['egw_info']['user']['account_lid'],$GLOBALS['egw_info']['user']['preferences']['calendar']['freebusy_pw']);
 			$freebusy_url = '<a href="'.$freebusy_url.'" target="_blank">'.$freebusy_url.'</a>';
@@ -213,9 +209,9 @@ class calendar_hooks
 
 			// Timezone for file exports
 			$export_tzs = array('0' => 'Use Event TZ');
-			$export_tzs += egw_time::getTimezones();
+			$export_tzs += Api\DateTime::getTimezones();
 		}
-		$link_title_options = ExecMethod('calendar.calendar_bo.get_link_options');
+		$link_title_options = calendar_bo::get_link_options();
 		$settings = array(
 			'1.section' => array(
 				'type'  => 'section',
@@ -235,16 +231,6 @@ class calendar_hooks
 				'admin'  => False,
 				'default'=> '1',	// 1 = week
 			),*/
-			'days_in_weekview' => array(
-				'type'   => 'select',
-				'label'  => 'default week view',
-				'name'   => 'days_in_weekview',
-				'values' => $week_view,
-				'help'   => 'Do you want a weekview with or without weekend?',
-				'xmlrpc' => True,
-				'admin'  => False,
-				'default'=> '7',
-			),
 			'multiple_weeks' => array(
 				'type'   => 'select',
 				'label'  => 'Weeks in multiple week view',
@@ -295,20 +281,21 @@ class calendar_hooks
 				'admin'  => False,
 				'default'=> 30,
 			),
-			'display_holidays_event' => array(
-				'type'   => 'select',
-				'label'  => 'Display holidays or birthdays as events in dayview',
-				'name'   => 'display_holidays_event',
-				'values' => array(
-					'0'	 => lang('Display in header'), //Please note that these values are a binary mask
-					'1' => lang('Birthdays only'),
-					'2' => lang('Holidays only'),
-					'3' => lang('Both, holidays and birthdays')
-				),
-				'help'   => "When selected, birthdays and/or holidays will be displayed as events in your calendar. Please note that this option only changes the appereance inside of EGroupware, but does not change the information being sent via iCal or other calendar interfaces.",
-				'xmlrpc' => True,
-				'admin'  => False,
-				'default'=> '0',
+			'day_consolidate' => array(
+				'type'  => 'select',
+				'label' => 'Minimum number of users for showing day view as consolidated.',
+				'name'  => 'day_consolidate',
+				'values'=> $consolidated,
+				'help'  => 'How many seperate calendars to show before merging them together',
+				'default'=> 6
+			),
+			'week_consolidate' => array(
+				'type'  => 'select',
+				'label' => 'Minimum number of users for showing week view as consolidated.',
+				'name'  => 'week_consolidate',
+				'values'=> $consolidated,
+				'help'  => 'How many seperate calendars to show before merging them together',
+				'default'=> 4
 			),
 			'limit_des_lines' => array(
 				'type'   => 'input',
@@ -319,15 +306,6 @@ class calendar_hooks
 				'xmlrpc' => True,
 				'admin'  => False
 			),
-			'planner_start_with_group' => array(
-				'type'   => 'select',
-				'label'  => 'Preselected group for entering the planner',
-				'name'   => 'planner_start_with_group',
-				'values' => $options,
-				'help'   => 'This group that is preselected when you enter the planner. You can change it in the planner anytime you want.',
-				'xmlrpc' => True,
-				'admin'  => False,
-			),
 			'planner_show_empty_rows' => array(
 				'type'   => 'select',
 				'label'  => 'Show empty rows in Planner',
@@ -344,14 +322,14 @@ class calendar_hooks
 				'forced' => 'user',
 			),
 			'use_time_grid' => array(
-				'type'   => 'select',
-				'label'  => 'Views with fixed time intervals',
+				'type'   => 'multiselect',
+				'label'  => 'Views showing a list of events',
 				'name'   => 'use_time_grid',
-				'values' => $grid_views,
-				'help'   => 'For which views should calendar show distinct lines with a fixed time interval.',
+				'values' => $list_views,
+				'help'   => 'For which views should calendar just a list of events instead of distinct lines with a fixed time interval.',
 				'xmlrpc' => True,
 				'admin'  => False,
-				'forced' => 'all',
+				'default' => ['weekN'],
 			),
 			'link_title' => array(
 				'type'   => 'multiselect',
@@ -381,6 +359,16 @@ class calendar_hooks
 				'admin'  => False,
 				'default'=> 60,
 			),
+			'default_participant' => array(
+				'type'	=> 'select',
+				'label'	=> 'New event participants',
+				'name'	=> 'default_participant',
+				'values'=>	$default_participants,
+				'help'	=> 'Participants automatically added to new events',
+				'default'	=> 'selected',
+				'xmlrpc' => False,
+				'admin'  => False
+			),
 			'default-alarm' => array(
 				'type'   => 'date-duration',//'select',
 				'label'  => lang('Default alarm for regular events').' ('.lang('empty = no alarm').')',
@@ -419,7 +407,7 @@ class calendar_hooks
 				'help'		=> 'Default type of resources application selected in the calendar particpants research form.',
 				'xmlrpc'	=> True,
 				'admin'		=> False,
-				'forced'    => 'addressbook',
+				'default'	=> 'resources'
 			),
 			'default_private' => array(
 				'type'  => 'check',
@@ -579,7 +567,7 @@ class calendar_hooks
 				'name'   => 'default_document',
 				'help'   => lang('If you specify a document (full vfs path) here, %1 displays an extra document icon for each entry. That icon allows to download the specified document with the data inserted.',lang('calendar')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','calendar_title').' '.
-					lang('The following document-types are supported:'). implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:'). implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -591,7 +579,7 @@ class calendar_hooks
 				'name'   => 'document_dir',
 				'help'   => lang('If you specify a directory (full vfs path) here, %1 displays an action for each document. That action allows to download the specified document with the data inserted.',lang('calendar')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','calendar_title').' '.
-					lang('The following document-types are supported:'). implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:'). implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -774,7 +762,7 @@ END:VALARM';
 	/**
 	 * Sync default alarms from CalDAV to Calendar
 	 *
-	 * Gets called by groupdav::PROPPATCH() for 'default-alarm-vevent-date(time)' changes
+	 * Gets called by Api\CalDAV::PROPPATCH() for 'default-alarm-vevent-date(time)' changes
 	 */
 	public static function sync_default_alarms()
 	{
@@ -793,25 +781,25 @@ END:VALARM';
 	/**
 	 * ACL rights and labels used
 	 *
-	 * @param string|array string with location or array with parameters incl. "location", specially "owner" for selected acl owner
-	 * @return array acl::(READ|ADD|EDIT|DELETE|PRIVAT|CUSTOM(1|2|3)) => $label pairs
+	 * @param string|array string with location or array with parameters incl. "location", specially "owner" for selected Acl owner
+	 * @return array Acl::(READ|ADD|EDIT|DELETE|PRIVAT|CUSTOM(1|2|3)) => $label pairs
 	 */
 	public static function acl_rights($params)
 	{
 		$rights = array(
-			acl::CUSTOM2 => 'freebusy',
-			acl::CUSTOM3 => 'invite',
-			acl::READ    => 'read',
-			acl::ADD     => 'add',
-			acl::EDIT    => 'edit',
-			acl::DELETE  => 'delete',
-			acl::PRIVAT  => 'private',
+			Acl::CUSTOM2 => 'freebusy',
+			Acl::CUSTOM3 => 'invite',
+			Acl::READ    => 'read',
+			Acl::ADD     => 'add',
+			Acl::EDIT    => 'edit',
+			Acl::DELETE  => 'delete',
+			Acl::PRIVAT  => 'private',
 		);
 		$require_acl_invite = $GLOBALS['egw_info']['server']['require_acl_invite'];
 
 		if (!$require_acl_invite || $require_acl_invite == 'groups' && !($params['owner'] < 0))
 		{
-			unset($rights[acl::CUSTOM3]);
+			unset($rights[Acl::CUSTOM3]);
 		}
 		return $rights;
 	}
@@ -827,7 +815,7 @@ END:VALARM';
 		unset($data);	// not used, but in function signature for hooks
 		return true;
 	}
-	
+
 	/**
 	 * Mail integration hook to import mail message contents into a calendar entry
 	 *
@@ -835,9 +823,11 @@ END:VALARM';
 	 */
 	public static function mail_import($args)
 	{
+		unset($args);	// not used, but required by function signature
+
 		return array (
 			'menuaction' => 'calendar.calendar_uiforms.mail_import',
-			'popup' => egw_link::get_registry('calendar', 'edit_popup')
+			'popup' => Link::get_registry('calendar', 'edit_popup')
 		);
 	}
 }
@@ -848,11 +838,12 @@ function calendar_purge_old($config)
 	$id = 'calendar_purge';
 
 	// Cancel old purge
-	ExecMethod('phpgwapi.asyncservice.cancel_timer', $id);
+	$async = new Api\Asyncservice();
+	$async->cancel_timer($id);
 
 	if((float)$config > 0)
 	{
-		$result = ExecMethod2('phpgwapi.asyncservice.set_timer',
+		$result = $async->set_timer(
 			array('month' => '*', 'day' => 1),
 			$id,
 			'calendar.calendar_boupdate.purge',
@@ -863,4 +854,4 @@ function calendar_purge_old($config)
 			$GLOBALS['config_error'] = 'Unable to schedule purge';
 		}
 	}
-}
\ No newline at end of file
+}
