@@ -5,11 +5,18 @@
  * @link http://www.egroupware.org
  * @package calendar
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2005-13 by RalfBecker-At-outdoor-training.de
+ * @copyright (c) 2005-16 by RalfBecker-At-outdoor-training.de
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+use EGroupware\Api\Etemplate;
+
 /**
  * Class to generate the calendar listview and the search
  *
@@ -41,6 +48,9 @@ class calendar_uilist extends calendar_ui
 	var $date_filters = array(
 		'after'  => 'After current date',
 		'before' => 'Before current date',
+		'today'  => 'Today',
+		'week'   => 'Week',
+		'month'  => 'Month',
 		'all'	=> 'All events',
 		'custom' => 'Selected range',
 	);
@@ -48,16 +58,12 @@ class calendar_uilist extends calendar_ui
 	/**
 	 * Constructor
 	 *
-	 * @param array $set_states=null to manualy set / change one of the states, default NULL = use $_REQUEST
+	 * @param array $set_states =null to manualy set / change one of the states, default NULL = use $_REQUEST
 	 */
 	function __construct($set_states=null)
 	{
 		parent::__construct(true,$set_states);	// call the parent's constructor
 
-		$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps']['calendar']['title'].' - '.lang('Listview').
-			// for a single owner we add it's name to the app-header
-			(count(explode(',',$this->owner)) == 1 ? ': '.$this->bo->participant_name($this->owner) : '');
-
 		foreach($this->date_filters as $name => $label)
 		{
 			$this->date_filters[$name] = lang($label);
@@ -66,72 +72,52 @@ class calendar_uilist extends calendar_ui
 		$this->check_owners_access();
 	}
 
-	/**
-	 * Show the calendar on the home page
-	 *
-	 * @return string with content
-	 */
-	function &home()
-	{
-		// set the defaults for the home-page
-		$this->__construct(array(
-			'date'	   => $this->bo->date2string($this->bo->now_su),
-			'cat_id'	 => 0,
-			'filter'	 => 'default',
-			'owner'	  => $this->user,
-			'multiple'   => 0,
-			'view'	   => $this->bo->cal_prefs['mainscreen_showevents'],
-		));
-		egw_session::appsession('calendar_list','calendar','');	// in case there's already something set
-
-		return $this->listview(null,'',true);
-	}
-
 	/**
 	 * Show the listview
 	 */
-	function listview($content=null,$msg='',$home=false)
+	function listview($_content=null,$msg='',$home=false)
 	{
 		if ($_GET['msg']) $msg .= $_GET['msg'];
 		if ($this->group_warning) $msg .= $this->group_warning;
 
-		$etpl = new etemplate_new('calendar.list');
+		$etpl = new Etemplate('calendar.list');
 
 		// Handle merge from sidebox
 		if($_GET['merge'])
 		{
-			$content['nm']['action'] = 'document_'.$_GET['merge'];
-			$content['nm']['select_all'] = true;
+			$_content['nm']['action'] = 'document_'.$_GET['merge'];
+			$_content['nm']['select_all'] = true;
 		}
 
-		if (is_array($content))
+		if (is_array($_content))
 		{
 			// handle a single button like actions
 			foreach(array('delete','timesheet','document') as $button)
 			{
-				if ($content['nm']['rows'][$button])
+				if ($_content['nm']['rows'][$button])
 				{
-					list($id) = each($content['nm']['rows'][$button]);
-					$content['nm']['action'] = $button;
-					$content['nm']['selected'] = array($id);
+					list($id) = each($_content['nm']['rows'][$button]);
+					$_content['nm']['action'] = $button;
+					$_content['nm']['selected'] = array($id);
 				}
 			}
 			// Handle actions
-			if ($content['nm']['action'])
+			if ($_content['nm']['action'])
 			{
 				// Allow merge using the date range filter
-				if(strpos($content['nm']['action'],'document') !== false &&
-					!count($content['nm']['selected']) && !$content['nm']['select_all']) {
-					$content['nm']['selected'][] = $this->get_merge_range($content['nm']);
+				if(strpos($_content['nm']['action'],'document') !== false &&
+					!count($_content['nm']['selected']) && !$_content['nm']['select_all']) {
+					$_content['nm']['selected'][] = $this->get_merge_range($_content['nm']);
 				}
-				if (!count($content['nm']['selected']) && !$content['nm']['select_all'])
+				if (!count($_content['nm']['selected']) && !$_content['nm']['select_all'])
 				{
 					$msg = lang('You need to select some events first');
 				}
 				else
 				{
-					if ($this->action($content['nm']['action'],$content['nm']['selected'],$content['nm']['select_all'],
-						$success,$failed,$action_msg,'calendar_list',$msg, $content['nm']['checkboxes']['no_notifications']))
+					$success = $failed = $action_msg = null;
+					if ($this->action($_content['nm']['action'],$_content['nm']['selected'],$_content['nm']['select_all'],
+						$success,$failed,$action_msg,'calendar_list',$msg, $_content['nm']['checkboxes']['no_notifications']))
 					{
 						$msg .= lang('%1 event(s) %2',$success,$action_msg);
 					}
@@ -143,7 +129,7 @@ class calendar_uilist extends calendar_ui
 			}
 		}
 		$content = array(
-			'nm'  => egw_session::appsession('calendar_list','calendar'),
+			'nm'  => Api\Cache::getSession('calendar', 'calendar_list'),
 		);
 		if (!is_array($content['nm']))
 		{
@@ -157,10 +143,10 @@ class calendar_uilist extends calendar_ui
 				'sort'            => 'ASC',// IO direction of the sort: 'ASC' or 'DESC'
 				'default_cols'    => '!week,weekday,cal_title,cal_description,recure,cal_location,cal_owner,cat_id,pm_id',
 				'filter_onchange' => "app.calendar.filter_change",
-				'header_left'     => 'calendar.list.dates',
 				'row_id'          => 'row_id',	// set in get rows "$event[id]:$event[recur_date]"
 				'row_modified'    => 'modified',
-				'favorites'       => true
+				'favorites'       => true,
+				'placeholder_actions' => array('add')
 			);
 		}
 		$content['nm']['actions'] = $this->get_actions();
@@ -177,6 +163,7 @@ class calendar_uilist extends calendar_ui
 		if (isset($_REQUEST['json_data']) && ($json_data = json_decode($_REQUEST['json_data'], true)) &&
 			!empty($json_data['request']['parameters'][0]))
 		{
+			$params = null;
 			parse_str(substr($json_data['request']['parameters'][0], 10), $params);	// cut off "/index.php?"
 			if (isset($params['keywords']))	// new search => set filters so every match is shown
 			{
@@ -190,7 +177,7 @@ class calendar_uilist extends calendar_ui
 		$sel_options['filter'] = &$this->date_filters;
 
 		// Send categories for row styling - calendar uses no_cat, so they don't go automatically
-		$sel_options['category'] = array('' => lang('all')) + etemplate_widget_menupopup::typeOptions('select-cat', ',,calendar',$no_lang,false,$value['cat_id']);
+		$sel_options['category'] = array('' => lang('all')) + Etemplate\Widget\Select::typeOptions('select-cat', ',,calendar');
 		// Prevent double encoding - widget does this on its own, but we're just grabbing the options
 		foreach($sel_options['category'] as &$label)
 		{
@@ -214,9 +201,9 @@ class calendar_uilist extends calendar_ui
 
 		if($msg)
 		{
-			egw_framework::message($msg);
+			Framework::message($msg);
 		}
-		$html = $etpl->exec('calendar.calendar_uilist.listview',$content,$sel_options,$readonlys,array(),$home ? -1 : 0);
+		$html = $etpl->exec('calendar.calendar_uilist.listview',$content,$sel_options,array(),array(),$home ? -1 : 0);
 
 		// Not sure why this has to be echoed instead of appended, but that's what works.
 		//echo calendar_uiviews::edit_series();
@@ -251,46 +238,44 @@ class calendar_uilist extends calendar_ui
 	 * @internal
 	 * @param array &$params parameters
 	 * @param array &$rows returned rows/events
-	 * @param array &$readonlys eg. to disable buttons based on acl
+	 * @param array &$readonlys eg. to disable buttons based on Acl
 	 */
 	function get_rows(&$params,&$rows,&$readonlys)
 	{
+		unset($readonlys);	// not used;
 		//echo "uilist::get_rows() params="; _debug_array($params);
-		if (isset($_GET['listview_days']) && is_numeric($_GET['listview_days']))
-		{
-			$params['filter'] = 'fixed';
-		}
+		$this->filter = $params['filter'];
 		if ($params['filter'] == 'custom')
 		{
 			if (!$params['startdate'] && !$params['enddate'])
 			{
-				$params['filter'] = 'all';
+				$this->filter = 'all';
 			}
 			elseif (!$params['startdate'])
 			{
-				$params['filter'] = 'before';
+				$this->filter = 'before';
 				$this->manage_states(array('date' => $this->bo->date2string($params['enddate'])));
 			}
 			elseif (!$params['enddate'])
 			{
-				$params['filter'] = 'after';
+				$this->filter = 'after';
 				$this->manage_states(array('date' => $this->bo->date2string($params['startdate'])));
 			}
 		}
-		$old_params = egw_session::appsession('calendar_list','calendar');
+		$old_params = Api\Cache::getSession('calendar', 'calendar_list');
 		if (is_array($old_params))
 		{
 			if ($old_params['filter'] && $old_params['filter'] != $params['filter'])	// filter changed => order accordingly
 			{
 				$params['order'] = 'cal_start';
-				$params['sort'] = $params['filter'] == 'after' ? 'ASC' : 'DESC';
+				$params['sort'] = $params['filter'] == 'before' ? 'DESC' : 'ASC';
 			}
 			if ($old_params['search'] != $params['search'])
 			{
 				$this->adjust_for_search($params['search'],$params);
 			}
 		}
-		if (!$params['csv_export']) egw_session::appsession('calendar_list','calendar',$params);
+		if (!$params['csv_export']) Api\Cache::setSession('calendar', 'calendar_list', $params);
 
 		// do we need to query custom fields and which
 		// Check stored preference if selectcols isn't available (ie: first call)
@@ -308,70 +293,88 @@ class calendar_uilist extends calendar_ui
 			}
 		}
 		$search_params = array(
-			'cat_id'  => $this->cat_id ? explode(',',$this->cat_id) : 0,
+			'cat_id'  => $params['cat_id'] ? $params['cat_id'] : 0,
 			'filter'  => $this->filter,
 			'query'   => $params['search'],
 			'offset'  => (int) $params['start'],
 			'num_rows'=> $params['num_rows'],
-			'order'   => $params['order'] ? $params['order'].' '.$params['sort'] : 'cal_start',
+			'order'   => $params['order'] ? $params['order'].' '.$params['sort'] : 'cal_start ASC',
 			'cfs'	 => $params['csv_export'] ? array() : $cfs,
 		);
-		switch($params['filter'])
+		// Non-blocking events above blocking
+		$search_params['order'] .= ', cal_non_blocking DESC';
+
+		switch($this->filter)
 		{
 			case 'all':
 				break;
 			case 'before':
-				$search_params['end'] = $this->date;
-				$label = lang('Before %1',$this->bo->long_date($this->date));
+				$search_params['end'] = $params['date'] ? Api\DateTime::to($params['date'],'ts') : $this->date;
+				$label = lang('Before %1',$this->bo->long_date($search_params['end']));
 				break;
 			case 'custom':
-				$this->first = $search_params['start'] = $params['startdate'];
+				$this->first = $search_params['start'] = Api\DateTime::to($params['startdate'],'ts');
 				$this->last  = $search_params['end'] = strtotime('+1 day', $this->bo->date2ts($params['enddate']))-1;
 				$label = $this->bo->long_date($this->first,$this->last);
 				break;
-			case 'fixed':
-				if ($this->listview_days == 5 || $this->listview_days == 7)	// weekview
-				{
-					$this->first = $this->datetime->get_weekday_start($this->year,$this->month,$this->day);
-					$this->last = $this->bo->date2array($this->first);
-					$this->last['day'] += (int) $this->listview_days - 1;
-					$this->last['hour'] = 23; $this->last['minute'] = $this->last['sec'] = 59;
-					unset($this->last['raw']);
-					$this->last = $this->bo->date2ts($this->last);
-					$this->date_filters['fixed'] = $label = lang('Week').' '.adodb_date('W',$this->first).': '.$this->bo->long_date($this->first,$this->last);
-					$params['startdate'] = $search_params['start'] = $this->first;
-					$params['enddate'] = $search_params['end'] = $this->last;
-					break;
-				}
-				elseif ((string)$this->listview_days === '0')	// monthview
-				{
-					$this->first = $this->bo->date2array($this->date);
-					$this->first['day'] = 1;
-					unset($this->first['raw']);
-					$this->last = $this->first;
-					$this->last['month'] += 1;
-					$this->first = $this->bo->date2ts($this->first);
-					$this->last = $this->bo->date2ts($this->last);
-					$this->last--;
-					$this->date_filters['fixed'] = $label = lang(adodb_date('F',$this->bo->date2ts($this->date))).' '.$this->year;
-					$params['startdate'] = $search_params['start'] = $this->first;
-					$params['enddate'] = $search_params['end'] = $this->last;
-					break;
-				}
+			case 'today':
+				$today = new Api\DateTime();
+				$today->setTime(0, 0, 0);
+				$this->first = $search_params['start'] = $today->format('ts');
+				$today->setTime(23,59,59);
+				$this->last  = $search_params['end'] = $today->format('ts');
+				break;
+			case 'week':
+				$start = new Api\DateTime($params['date'] ? $params['date'] : $this->date);
+				$start->setWeekstart();
+				$this->first = $start->format('ts');
+				$this->last = $this->bo->date2array($this->first);
+				$this->last['day'] += ($params['weekend'] == 'true' ? 7 : 5) - 1;
+				$this->last['hour'] = 23; $this->last['minute'] = $this->last['sec'] = 59;
+				unset($this->last['raw']);
+				$this->last = $this->bo->date2ts($this->last);
+				$this->date_filters['week'] = $label = lang('Week').' '.adodb_date('W',$this->first).': '.$this->bo->long_date($this->first,$this->last);
+				$search_params['start'] = $this->first;
+				$search_params['end'] = $this->last;
+				$params['startdate'] = Api\DateTime::to($this->first, Api\DateTime::ET2);
+				$params['enddate'] = Api\DateTime::to($this->last, Api\DateTime::ET2);
+				break;
+
+			case 'month':
+				$this->first = $this->bo->date2array($params['date'] ? $params['date'] : $this->date);
+				$this->first['day'] = 1;
+				unset($this->first['raw']);
+				$this->last = $this->first;
+				$this->last['month'] += 1;
+				$this->date_filters['month'] = $label = lang(adodb_date('F',$this->bo->date2ts($params['date']))).' '.$this->first['year'];
+				$this->first = $this->bo->date2ts($this->first);
+				$this->last = $this->bo->date2ts($this->last);
+				$this->last--;
+				$search_params['start'] = $this->first;
+				$search_params['end'] = $this->last;
+				$params['startdate'] = Api\DateTime::to($this->first, Api\DateTime::ET2);
+				$params['enddate'] = Api\DateTime::to($this->last, Api\DateTime::ET2);
+				break;
+
 				// fall through to after given date
 			case 'after':
 			default:
+				$this->date = $params['startdate'] ? Api\DateTime::to($params['startdate'],'ts') : $this->date;
 				$label = lang('After %1',$this->bo->long_date($this->date));
 				$search_params['start'] = $this->date;
 				break;
 		}
-		if ((int) $params['col_filter']['participant'])
+		if($params['status_filter'])
 		{
-			$search_params['users'] = (int) $params['col_filter']['participant'];
+			$search_params['filter'] = $params['status_filter'];
 		}
-		elseif(empty($params['search']))	// active search displays entries from all users
+		if ($params['col_filter']['participant'])
 		{
-			$search_params['users'] = explode(',',$this->owner);
+			$search_params['users'] = is_array($params['col_filter']['participant']) ? $params['col_filter']['participant'] : array( $params['col_filter']['participant']);
+		}
+		elseif (!$params['col_filter'] || !$params['col_filter']['participant'])
+		{
+			$search_params['users'] = $params['owner'] ? $params['owner'] : explode(',',$this->owner);
 		}
 		if ($params['col_filter'])
 		{
@@ -385,51 +388,28 @@ class calendar_uilist extends calendar_ui
 			}
 		}
 		$rows = $js_integration_data = array();
-		if ($label)
+
+		// App header is mostly taken care of on the client side, but here we update
+		// it to match changing list filters
+		if($params['view'] && $params['view'] == 'listview')
 		{
-			$GLOBALS['egw_info']['flags']['app_header'] .= ': '.$label;
-			// Add it in as specific option, or it will be cleared
-			$rows['sel_options']['filter'] = $this->date_filters;
-			$rows['sel_options']['filter'][$params['filter']] = $label;
+			Api\Json\Response::get()->call('app.calendar.set_app_header',
+				(count($search_params['users']) == 1 ? $this->bo->participant_name($search_params['users'][0]).': ' : '') .
+				$label);
 		}
 		foreach((array) $this->bo->search($search_params, !empty($col_filter) ? $col_filter : null) as $event)
 		{
-			if (!$this->bo->check_perms(EGW_ACL_EDIT,$event))
-			{
-				$event['class'] .= 'rowNoEdit ';
-			}
 
-			// Delete disabled for other applications
-			if (!$this->bo->check_perms(EGW_ACL_DELETE,$event) || !is_numeric($event['id']))
-			{
-				$event['class'] .= 'rowNoDelete ';
-			}
-
-			// mark deleted events
-			if ($event['deleted'])
-			{
-				$event['class'] .= 'rowDeleted ';
-			}
-
-			$event['recure'] = $this->bo->recure2string($event);
 			if ($params['csv_export'])
 			{
 				$event['participants'] = implode(",\n",$this->bo->participants($event,true));
 			}
 			else
 			{
-				$event['parts'] = implode(",\n",$this->bo->participants($event,true));
-				$event['date'] = $this->bo->date2string($event['start']);
-			}
-			if (empty($event['description'])) $event['description'] = ' ';	// no description screws the titles horz. alignment
-			if (empty($event['location'])) $event['location'] = ' ';	// no location screws the owner horz. alignment
-
-			// respect category permissions
-			if(!empty($event['category']))
-			{
-				$event['category'] = $this->categories->check_list(EGW_ACL_READ, $event['category']);
+				$this->to_client($event);
 			}
 
+			$matches = null;
 			if(!(int)$event['id'] && preg_match('/^([a-z_-]+)([0-9]+)$/i',$event['id'],$matches))
 			{
 				$app = $matches[1];
@@ -437,7 +417,7 @@ class calendar_uilist extends calendar_ui
 				$icons = array();
 				if (($is_private = calendar_bo::integration_get_private($app,$app_id,$event)))
 				{
-					$icons[] = html::image('calendar','private');
+					$icons[] = Api\Html::image('calendar','private');
 				}
 				else
 				{
@@ -446,7 +426,7 @@ class calendar_uilist extends calendar_ui
 			}
 			else
 			{
-				$is_private = !$this->bo->check_perms(EGW_ACL_READ,$event);
+				$is_private = !$this->bo->check_perms(Acl::READ,$event);
 			}
 			if ($is_private)
 			{
@@ -471,32 +451,17 @@ class calendar_uilist extends calendar_ui
 				if (!isset($js_integration_data[$app]))
 				{
 					$js_integration_data[$app] = calendar_bo::integration_get_data($app,'edit_link');
-					if (!is_array($js_integration_data[$app]) || !isset($js_integration_data[$app]['edit']))
-					{
-						$js_integration_data[$app]['edit'] = egw_link::get_registry($app, 'edit');
-						$js_integration_data[$app]['edit_id'] = egw_link::get_registry($app, 'edit_id');
-						$js_integration_data[$app]['edit_popup'] = egw_link::get_registry($app, 'edit_popup');
-					}
 				}
 			}
 			elseif ($event['recur_type'] != MCAL_RECUR_NONE)
 			{
-				$event['edit_link'] = "edit_series({$event['id']}, {$event['start']});return false;";
-				$event['app_id'] .= ':'.$event['recur_date'];
+				$event['app_id'] .= ':'.Api\DateTime::to($event['recur_date'] ? $event['recur_date'] : $event['start'],'ts');
 			}
-			else
-			{
-				$view_link = egw::link('/index.php',array('menuaction'=>'calendar.calendar_uiforms.edit','cal_id'=>$event['id'],'date'=>$this->bo->date2string($event['start'])));
-				$event['edit_link'] = $this->popup($view_link).'; return false;';
-			}
-
-			// set id for grid
-			$event['row_id'] = $event['id'].($event['recur_type'] ? ':'.$event['recur_date'] : '');
 
 			// Format start and end with timezone
 			foreach(array('start','end') as $time)
 			{
-				$event[$time] = egw_time::to($event[$time],'Y-m-d\TH:i:s\Z');
+				$event[$time] = Api\DateTime::to($event[$time],'Y-m-d\TH:i:s\Z');
 			}
 
 			$rows[] = $event;
@@ -508,6 +473,38 @@ class calendar_uilist extends calendar_ui
 
 		$wv=0;
 		$dv=0;
+
+		// Add in some select options
+		$users = is_array($search_params['users']) ? $search_params['users'] : explode(',',$search_params['users']);
+
+		$this->bo->warnings['groupmembers'] = '';
+		if(($message = $this->check_owners_access($users)))
+		{
+			Api\Json\Response::get()->error($message);
+		}
+		else if($this->bo->warnings['groupmembers'])
+		{
+			Api\Json\Response::get()->error($this->bo->warnings['groupmembers']);
+		}
+		$rows['sel_options']['filter'] = $this->date_filters;
+		if($label)
+		{
+			$rows['sel_options']['filter'][$params['filter']] = $label;
+		}
+		foreach($users as $owner)
+		{
+			if(!is_int($owner) && $this->bo->resources[$owner[0]])
+			{
+				$app = $this->bo->resources[$owner[0]]['app'];
+				$_owner = substr($owner,1);
+				// Try link first
+				$title = Link::title($app, $_owner );
+				if($title)
+				{
+					$rows['sel_options']['owner'][$owner] = $title;
+				}
+			}
+		}
 		$params['options-selectcols']['week'] = lang('Week');
 		$params['options-selectcols']['weekday'] = lang('Weekday');
 		if ((substr($this->cal_prefs['nextmatch-calendar.list.rows'],0,4) == 'week' && strlen($this->cal_prefs['nextmatch-calendar.list.rows'])==4) || substr($this->cal_prefs['nextmatch-calendar.list.rows'],0,5) == 'week,')
@@ -564,9 +561,10 @@ class calendar_uilist extends calendar_ui
 		if ($use_all)
 		{
 			// get the whole selection
-			$query = is_array($session_name) ? $session_name : egw_session::appsession($session_name,'calendar');
+			$query = is_array($session_name) ? $session_name : Api\Cache::getSession('calendar', $session_name);
 			@set_time_limit(0);				// switch off the execution time limit, as for big selections it's too small
 			$query['num_rows'] = -1;		// all
+			$readonlys = null;
 			$this->get_rows($query,$checked,$readonlys,!in_array($action,array('ical','document')));	   // true = only return the id's
 			// Get rid of any extras (rows that aren't events)
 			if(in_array($action,array('ical','document')))
@@ -583,8 +581,9 @@ class calendar_uilist extends calendar_ui
 		// for calendar integration we have to fetch all rows and unset the not selected ones, as we can not filter by id
 		elseif($action == 'document')
 		{
-			$query = is_array($session_name) ? $session_name : egw_session::appsession($session_name,'calendar');
+			$query = is_array($session_name) ? $session_name : Api\Cache::getSession('calendar', $session_name);
 			@set_time_limit(0);				// switch off the execution time limit, as for big selections it's too small
+			$events = null;
 			$this->get_rows($query,$events,$readonlys);
 			foreach($events as $key => $event)
 			{
@@ -611,15 +610,16 @@ class calendar_uilist extends calendar_ui
 				}
 				$boical = new calendar_ical();
 				$ical =& $boical->exportVCal($ids, '2.0', 'PUBLISH');
-				html::content_header('event.ics', 'text/calendar', bytes($ical));
+				Api\Header\Content::type('event.ics', 'text/calendar', bytes($ical));
 				echo $ical;
-				common::egw_exit();
+				exit();
 
 			case 'document':
 				if (!$settings) $settings = $GLOBALS['egw_info']['user']['preferences']['calendar']['default_document'];
 				$document_merge = new calendar_merge();
 				$msg = $document_merge->download($settings, $checked, '', $GLOBALS['egw_info']['user']['preferences']['calendar']['document_dir']);
 				$failed = count($checked);
+				error_log($msg);
 				return false;
 		}
 
@@ -635,6 +635,7 @@ class calendar_uilist extends calendar_ui
 			{
 				$id = $id['id'];
 			}
+			$matches = null;
 			if(!(int)$id && preg_match('/^([a-z_-]+)([0-9]+)$/i',$id,$matches))
 			{
 				$app = $matches[1];
@@ -669,6 +670,11 @@ class calendar_uilist extends calendar_ui
 								}
 							}
 						}
+
+						if(Api\Json\Response::isJSONResponse())
+						{
+							Api\Json\Response::get()->call('egw.refresh','','calendar',$id,'delete');
+						}
 					}
 					else
 					{
@@ -682,13 +688,19 @@ class calendar_uilist extends calendar_ui
 						// unDelete the whole thing
 						$recur_date = 0;
 					}
-					if ($id && ($event = $this->bo->read($id, $recur_date)) && $this->bo->check_perms(EGW_ACL_EDIT,$id) &&
+					if ($id && ($event = $this->bo->read($id, $recur_date)) && $this->bo->check_perms(Acl::EDIT,$id) &&
 						is_array($event) && $event['deleted'])
 					{
 						$event['deleted'] = null;
 						if($this->bo->save($event))
 						{
 							$success++;
+
+							if(Api\Json\Response::isJSONResponse())
+							{
+								Api\Json\Response::get()->call('egw.dataStoreUID','calendar::'.$id,$this->to_client($this->bo->read($id,$recur_date)));
+								Api\Json\Response::get()->call('egw.refresh','','calendar',$id,'edit');
+							}
 							break;
 						}
 					}
@@ -699,6 +711,7 @@ class calendar_uilist extends calendar_ui
 					if($id && ($event = $this->bo->read($id, $recur_date)))
 					{
 						$old_status = $event['participants'][$GLOBALS['egw_info']['user']['account_id']];
+						$quantity = $role = null;
 						calendar_so::split_status($old_status, $quantity, $role);
 						if ($old_status != $status)
 						{
@@ -707,6 +720,10 @@ class calendar_uilist extends calendar_ui
 							if ($this->bo->set_status($event,$GLOBALS['egw_info']['user']['account_id'],$new_status,$recur_date,
 								false,true,$skip_notification))
 							{
+								if(Api\Json\Response::isJSONResponse())
+								{
+									Api\Json\Response::get()->call('egw.dataStoreUID','calendar::'.$id,$this->to_client($this->bo->read($id,$recur_date)));
+								}
 								$success++;
 								//$msg = lang('Status changed');
 							}
@@ -728,7 +745,7 @@ class calendar_uilist extends calendar_ui
 					}
 					elseif ($app)
 					{
-						$query = egw_session::appsession('calendar_list','calendar');
+						$query = Api\Cache::getSession('calendar', 'calendar_list');
 						$query['query'] = $app_id;
 						$query['search'] = $app_id;
 						$result = $this->bo->search($query);
@@ -768,14 +785,14 @@ class calendar_uilist extends calendar_ui
 					$err = $timesheet_bo->save($timesheet);
 
 					//get the project manager linked to the calnedar entry
-					$calApp_links = egw_link::get_links('calendar', $event['id']);
+					$calApp_links = Link::get_links('calendar', $event['id']);
 					foreach ($calApp_links as $l_app)
 					{
 						if ($l_app['app'] == 'projectmanager')
 						{
 							$prj_links = $l_app;
 							//Links timesheet to projectmanager
-							egw_link::link('timesheet', $timesheet_bo->data['ts_id'], 'projectmanager', $prj_links['id']);
+							Link::link('timesheet', $timesheet_bo->data['ts_id'], 'projectmanager', $prj_links['id']);
 
 						}
 					}
@@ -788,7 +805,7 @@ class calendar_uilist extends calendar_ui
 						if(!$recur_date || $app) {
 							// Create link
 							$link_id = $app ? $app_id : $id;
-							egw_link::link($app ? $app : 'calendar', $link_id, 'timesheet', $timesheet_bo->data['ts_id']);
+							Link::link($app ? $app : 'calendar', $link_id, 'timesheet', $timesheet_bo->data['ts_id']);
 						}
 					}
 					else
@@ -852,14 +869,15 @@ class calendar_uilist extends calendar_ui
 		$actions = array(
 			'add' => array(
 				'caption' => 'Add',
-				'egw_open' => 'add-calendar'
+				'egw_open' => 'add-calendar',
+				'hideOnMobile' => true
 			),
 			'open' => array(
 				'caption' => 'Open',
 				'default' => true,
 				'allowOnMultiple' => false,
 				'url' => 'menuaction=calendar.calendar_uiforms.edit&cal_id=$id',
-				'popup' => egw_link::get_registry('calendar', 'view_popup'),
+				'popup' => Link::get_registry('calendar', 'view_popup'),
 				'group' => $group=1,
 				'onExecute' => 'javaScript:app.calendar.cal_open',
 				'disableClass' => 'rowNoView',
@@ -869,7 +887,7 @@ class calendar_uilist extends calendar_ui
 				'group' => $group,
 				'disableClass' => 'rowNoView',
 				'url' => 'menuaction=calendar.calendar_uiforms.edit&cal_id=$id&action=copy',
-				'popup' => egw_link::get_registry('calendar', 'view_popup'),
+				'popup' => Link::get_registry('calendar', 'view_popup'),
 				'allowOnMultiple' => false,
 			),
 			'select_all' => array(
@@ -915,7 +933,7 @@ class calendar_uilist extends calendar_ui
 				'group' => $group,
 				'allowOnMultiple' => false,
 				'url' => 'menuaction=infolog.infolog_ui.edit&type=task&action=calendar&action_id=$id',
-				'popup' => egw_link::get_registry('infolog', 'add_popup'),
+				'popup' => Link::get_registry('infolog', 'add_popup'),
 			);
 		}
 		if ($GLOBALS['egw_info']['user']['apps']['timesheet'])
@@ -928,7 +946,7 @@ class calendar_uilist extends calendar_ui
 				'allowOnMultiple' => false,
 				'hideOnDisabled' => true,	// show only one timesheet action in context menu
 				'onExecute' => 'javaScript:app.calendar.cal_fix_app_id',
-				'popup' => egw_link::get_registry('timesheet', 'add_popup'),
+				'popup' => Link::get_registry('timesheet', 'add_popup'),
 			);
 			$actions['timesheet-add'] = array(	// automatic add for multiple events
 				'icon' => 'timesheet/navbar',
@@ -948,7 +966,7 @@ class calendar_uilist extends calendar_ui
 		);
 		$actions['documents'] = calendar_merge::document_action(
 			$this->bo->cal_prefs['document_dir'], ++$group, 'Insert in document', 'document_',
-			$this->bo->cal_prefs['default_document'],bo_merge::getExportLimit('calendar')
+			$this->bo->cal_prefs['default_document'],Api\Storage\Merge::getExportLimit('calendar')
 		);
 		++$group;
 		$actions['delete'] = array(
