@@ -10,21 +10,31 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Acl;
+use EGroupware\Api\Etemplate;
+
 /**
  * Calendar planner block for sitemgr
  */
 class module_calendar_planner extends Module
 {
 	/**
-	 * Default callendar CSS file
+	 * Default calendar CSS file
 	 */
 	const CALENDAR_CSS = '/calendar/templates/default/app.css';
 
+	const ETEMPLATE_CSS = '/api/templates/default/etemplate2.css';
+
 	/**
 	 * Constructor
 	 */
 	function __construct()
 	{
+		parent::__construct();
+
 		$this->arguments = array(
 			'sortby' => array(
 				'type' => 'select',
@@ -32,8 +42,7 @@ class module_calendar_planner extends Module
 				'options' => array(
 					0 => lang('Planner by category'),
 					'user' => lang('Planner by user'),
-					'month' => lang('Yearly Planner'),
-					'yearly' => lang('Yearly Planner').' ('.lang('initially year aligned').')',
+					'month' => lang('Yearly Planner')
 				),
 			),
 			'cat_id' => array(
@@ -84,19 +93,19 @@ class module_calendar_planner extends Module
 	 */
 	function get_user_interface()
 	{
-		$cats = new categories('','calendar');
+		$cats = new Api\Categories('','calendar');
 		foreach($cats->return_array('all',0,False,'','cat_name','',True) as $cat)
 		{
 			$this->arguments['cat_id']['options'][$cat['id']] = str_repeat('&nbsp; ',$cat['level']).$cat['name'];
 		}
-		if (count($cat_ids) > 5)
+		if (count($this->arguments['cat_id']['options']) > 5)
 		{
 			$this->arguments['cat_id']['multiple'] = 5;
 		}
 
 		if (!isset($GLOBALS['egw']->accounts))
 		{
-			$GLOBALS['egw']->accounts = new accounts();
+			$GLOBALS['egw']->accounts = new Api\Accounts();
 		}
 		$this->accounts =& $GLOBALS['egw']->accounts;
 		$search_params = array(
@@ -104,6 +113,7 @@ class module_calendar_planner extends Module
 			'app' => 'calendar',
 		);
 		$accounts = $this->accounts->search($search_params);
+		$calendar_bo = new calendar_bo();
 		$users = array();
 		$groups = array();
 		// sort users and groups separately.
@@ -113,12 +123,12 @@ class module_calendar_planner extends Module
 		{
 			$is_group = false;
 			$has_read_permissions = false;
-			$acl = new acl($entry['account_id']);
+			$acl = new Acl($entry['account_id']);
 			$acl->read_repository();
 			// get the rights for each account to check whether the anon user has read permissions.
 			$rights = $acl->get_rights($anon_user,'calendar');
 			// also add the anon user if it's his own calendar.
-			if (($rights & EGW_ACL_READ) || ($entry['account_id'] == $anon_user))
+			if ($calendar_bo->check_perms(Acl::READ|calendar_bo::ACL_READ_FOR_PARTICIPANTS|calendar_bo::ACL_FREEBUSY,0,$entry['account_id'],'ts',null,$anon_user) || ($entry['account_id'] == $anon_user))
 			{
 				$has_read_permissions = true;
 			}
@@ -129,7 +139,7 @@ class module_calendar_planner extends Module
 				foreach ($anon_groups as $parent_group)
 				{
 					$rights = $acl->get_rights($parent_group,'calendar');
-					if (($rights & EGW_ACL_READ) || ($entry['account_id'] == $parent_group))
+					if (($rights & Acl::READ) || ($entry['account_id'] == $parent_group))
 					{
 						$has_read_permissions = true;
 						break;
@@ -145,14 +155,14 @@ class module_calendar_planner extends Module
 				}
 				else
 				{
-					$users[$entry['account_id']] = $GLOBALS['egw']->common->display_fullname($entry['account_lid'],$entry['account_firstname'],$entry['account_lastname']);
+					$users[$entry['account_id']] = Api\Accounts::format_username($entry['account_lid'],$entry['account_firstname'],$entry['account_lastname']);
 				}
 			}
 		}
 		asort($groups);
 		asort($users);
 		// concat users and groups to the option array.
-		$this->arguments['owner']['options'] = $groups + $users;
+		$this->arguments['owner']['options'] = array_unique($groups + $users);
 		if (count($this->arguments['owner']['options']) > 10)
 		{
 			$this->arguments['owner']['multiple'] = 10;
@@ -162,19 +172,34 @@ class module_calendar_planner extends Module
 			$this->arguments['owner']['multiple'] = true;
 		}
 
-		$calendar_bo = new calendar_bo();
- 		foreach ($calendar_bo->resources as $resource)
+		$query = '';
+		$options = array('start' => 0, 'num_rows' => 50);
+
+		$acl = new Acl($anon_user);
+		$acl->read_repository();
+ 		foreach ($calendar_bo->resources as $type => $data)
 		{
-			if(!is_array($resource['cal_sidebox'])) continue;
-			$this->arguments['resources']['options'] = array_merge($this->arguments['resources']['options'],
-				ExecMethod($resource['cal_sidebox']['file'],array(
-					'menuaction' => $_GET['menuaction'],
-					'block_id' => $_GET['block_id'],
-					'return_array' => true,
-				)));
+			// Check anon user's permissions - must have at least run for the hook to be available
+			if($acl->check('run',EGW_ACL_READ, $data['app']) &&
+				$type != '' && $data['app'] && Link::get_registry($data['app'], 'query')
+			)
+			{
+				$_results = Link::query($data['app'], $query,$options);
+			}
+			if(!$_results) continue;
+			$_results = array_unique($_results);
+			foreach ($_results as $key => $value)
+			{
+				if($calendar_bo->check_perms(Acl::READ,0,$type.$key,'ts',null,$anon_user))
+				{
+					$this->arguments['resources']['options'][$type.$key] = $value;
+				}
+			}
 		}
+		$this->arguments['resources']['options'] = array_unique($this->arguments['resources']['options']);
 		$this->arguments['resources']['multiple'] = count($this->arguments['resources']['options']) ? 4 : 0;
 
+
 		return parent::get_user_interface();
 	}
 
@@ -186,10 +211,9 @@ class module_calendar_planner extends Module
 	 */
 	function get_content(&$arguments,$properties)
 	{
-		translation::add_app('calendar');
+		$GLOBALS['egw_info']['flags']['currentapp'] = 'calendar';
 
-		//_debug_array($arguments);
-		$arguments['view'] = 'planner';
+		//error_log(array2string($arguments));
 		if (empty($arguments['date']))
 		{
 			$arguments['date'] = date('Ymd');
@@ -200,7 +224,7 @@ class module_calendar_planner extends Module
 			$arguments['date'] = substr($arguments['date'],0,4).'0101';
 		}
 		if (isset($_GET['date'])) $arguments['date'] = $_GET['date'];
-		if (empty($arguments['cat_id'])) $arguments['cat_id'] = 0;
+		if (empty($arguments['cat_id'])) $arguments['cat_id'] = '';
 		if(isset($arguments['resources']) && in_array('r0', $arguments['resources']))
 		{
 			foreach($arguments['resources'] as $index => $value)
@@ -221,23 +245,107 @@ class module_calendar_planner extends Module
 
 		$html = '<style type="text/css">'."\n";
 		$html .= '@import url('.$GLOBALS['egw_info']['server']['webserver_url'].self::CALENDAR_CSS.");\n";
-		$html .= '</style>'."\n";
+		$html .= '@import url('.$GLOBALS['egw_info']['server']['webserver_url'].self::ETEMPLATE_CSS.");\n";
+		$html .= '@import url('.$GLOBALS['egw_info']['server']['webserver_url'].Api\Categories::css(Api\Categories::GLOBAL_APPNAME).");\n";
+		$html .= '@import url('.$GLOBALS['egw_info']['server']['webserver_url'].Api\Categories::css('calendar').");\n";
+		$html .= '.popupMainDiv #calendar-planner { position: static;}
+		#calendar-planner .calendar_plannerWidget, #calendar-planner div.calendar_plannerRows {
+    height: auto !important;
+}
+	</style>'."\n";
+		$html .= Api\Html::image('sitemgr', 'left', lang('Previous'), 'onclick=\'app.calendar.toolbar_action({id:"previous"});\'')
+		. Api\Html::image('sitemgr', 'right', lang('Next'), 'style="float: right;" onclick=\'app.calendar.toolbar_action({id:"next"});\'');
 
 		if (is_array($params['owner']))
 		{
-			$params['owner'] = implode(',', $params['owner']);
+			// Buffer, and add anything that gets cleared to the content
+			ob_start(function($buffer) use(&$html) {
+				$html .= $buffer;
+				return '';
+			});
+			Framework::$header_done = true;
+			$ui = new calendar_uiviews();
+			$ui->sortby = $arguments['sortby'];
+			$ui->owner = $params['owner'];
 
-			$uiviews = new calendar_uiviews($params);
-			$uiviews->allowEdit = false;	// switches off all edit popups
+			if (!$ui->planner_view || $ui->planner_view == 'month')	// planner monthview
+			{
+				if ($ui->day < 15)	// show one complete month
+				{
+					$ui->_week_align_month($ui->first,$ui->last);
+				}
+				else	// show 2 half month
+				{
+					$ui->_week_align_month($ui->first,$ui->last,15);
+				}
+			}
+			elseif ($ui->planner_view == 'week' || $ui->planner_view == 'weekN')	// weeekview
+			{
+				$start = new Api\DateTime($ui->date);
+				$start->setWeekstart();
+				$ui->first = $start->format('ts');
+				$ui->last = $ui->bo->date2array($this->first);
+				$ui->last['day'] += ($ui->planner_view == 'week' ? 7 : 7 * $ui->cal_prefs['multiple_weeks'])-1;
+				$ui->last['hour'] = 23; $ui->last['minute'] = $ui->last['sec'] = 59;
+				unset($ui->last['raw']);
+				$ui->last = $ui->bo->date2ts($ui->last);
+			}
+			else // dayview
+			{
+				$ui->first = $ui->bo->date2ts($ui->date);
+				$ui->last = $ui->bo->date2array($ui->first);
+				$ui->last['day'] += 0;
+				$ui->last['hour'] = 23; $ui->last['minute'] = $ui->last['sec'] = 59;
+				unset($ui->last['raw']);
+				$ui->last = $ui->bo->date2ts($ui->last);
+			}
 
-			// Initialize Tooltips
-			static $wz_tooltips;
-			if (!$wz_tooltips++) $html .= '<script language="JavaScript" type="text/javascript" src="'.$GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/wz_tooltip/wz_tooltip.js"></script>'."\n";
+			$search_params = $ui->search_params;
+			$search_params['daywise'] = false;
+			$search_params['start'] = $ui->first;
+			$search_params['end'] = $ui->last;
+			$search_params['owner'] = $ui->owner;
+			$search_params['enum_groups'] = $ui->sortby == 'user';
 
-			// replacing egw-urls with sitemgr ones, allows to use navigation links
-			$html .= str_replace($GLOBALS['egw_info']['server']['webserver_url'].'/index.php?',
-				$this->link().'&',
-				$uiviews->planner(true));
+			$content = array();
+			$sel_options = array();
+			$content['planner'] = $ui->bo->search($search_params);
+			foreach($content['planner'] as &$event)
+			{
+				$ui->to_client($event);
+			}
+
+			$tmpl = new Etemplate('calendar.planner');
+
+			$tmpl->setElementAttribute('planner','start_date', Api\DateTime::to($ui->first, Api\DateTime::ET2));
+			$tmpl->setElementAttribute('planner','end_date', Api\DateTime::to($ui->last, Api\DateTime::ET2));
+			$tmpl->setElementAttribute('planner','owner', $search_params['owner']);
+			$tmpl->setElementAttribute('planner','group_by', $ui->sortby);
+
+			// Make sure all used owners are there, faking
+			// calendar_owner_etemplate_widget::beforeSendToClient() since the
+			// rest of the calendar app is probably missing.
+			foreach($search_params['owner'] as $owner)
+			{
+				$sel_options['owner'][] = Array(
+					'id' => $owner,
+					'value' => $owner,
+					'label' => calendar_owner_etemplate_widget::get_owner_label($owner)
+				);
+			}
+			$tmpl->exec(__METHOD__, $content,$sel_options, array('__ALL__' => true),array(),2);
+			$html .= ob_get_contents();
+			$html .= '<script>'
+			. '	window.egw_LAB.wait(function() {jQuery(function() {'
+			. 'app.calendar.set_state(' . json_encode(array(
+					'owner' => $search_params['owner'],
+					'sortby' => $ui->sortby,
+					'filter' => $arguments['filter']
+				)).');'
+			. '});});'
+			. '</script>';
+
+			ob_end_clean();
 		}
 		else
 		{
