@@ -19,10 +19,6 @@ find ${@-.} -name '*.php' -exec php -l {} \; 2>&1 | \
 	grep -v 'vendor/pear-pear.php.net/PEAR/PEAR/Autoloader.php' | \
 	# exclude composer conditional included autoload_static.php, as it requires PHP 5.6+
 	grep -v 'vendor/composer/autoload_static.php' | \
-	# used only for deprecated SyncML
-	grep -v 'phpgwapi/inc/horde/Horde/String.php' | \
 	# phpFreeChat does not work with PHP7
 	grep -v 'phpfreechat/phpfreechat/' | \
-	# unused zpush ics backend
-	grep -v 'activesync/backend/ics.php' | \
 	perl -pe 'END { exit $status } $status=1 if /^(PHP Fatal|(PHP )?Parse error)/;'  > /dev/null
