@@ -19,28 +19,28 @@ date_default_timezone_set('Europe/Berlin');	// to get ride of 5.3 warnings
 $verbose = 0;
 $config = array(
 	'packagename' => 'egroupware-epl',
-	'version' => '14.3',        // '14.3'
+	'version' => '16.1',        // '14.3'
 	'packaging' => date('Ymd'), // '20160520'
-	'branch'  => '14.2',        // checked out branch
+	'branch'  => 'master',        // checked out branch
 	'tag' => '$version.$packaging',	// name of tag
 	'checkoutdir' => realpath(__DIR__.'/../..'),
-	'egw_buildroot' => '/tmp/build_root/epl_14.2_buildroot',
-	'sourcedir' => '/home/download/stylite-epl/egroupware-epl-14.2',
+	'egw_buildroot' => '/tmp/build_root/epl_16.1_buildroot',
+	'sourcedir' => '/home/download/stylite-epl/egroupware-epl-16.1',
 	/* svn-config currently not used, as we use .mrconfig to define modules and urls
 	'svntag' => 'tags/$version.$packaging',
 	'svnbase' => 'svn+ssh://svn@dev.egroupware.org/egroupware',
 	'stylitebase' => 'svn+ssh://stylite@svn.stylite.de/stylite',
-	'svnbranch' => 'branches/14.2',         //'trunk', // 'branches/1.6' or 'tags/1.6.001'
+	'svnbranch' => 'branches/16.1',         //'trunk', // 'branches/1.6' or 'tags/1.6.001'
 	'svnalias' => 'aliases/default-ssh',    // default alias
 	'extra' => array('$stylitebase/$svnbranch/stylite', '$stylitebase/$svnbranch/esyncpro', '$stylitebase/trunk/archive'),//, '$stylitebase/$svnbranch/groups'), //,'svn+ssh://stylite@svn.stylite.de/stylite/trunk/eventmgr'),
 	*/
-	'extra' => array('stylite', 'esyncpro', 'archive'),	// create an extra archive for given apps
+	'extra' => array('stylite', 'esyncpro', 'archive',	// create an extra archive for given apps
 		// these apps are placed in egroupware-epl-contrib archive
-		//'contrib' => array('phpgwapi', 'etemplate', 'jdots', 'phpbrain', 'wiki', 'sambaadmin', 'sitemgr', 'phpfreechat')),
+		'contrib' => array('phpgwapi', 'etemplate', 'jdots', 'phpbrain', 'wiki', 'sambaadmin', 'sitemgr', 'phpfreechat')),
 	'aliasdir' => 'egroupware',             // directory created by the alias
 	'types' => array('tar.bz2','tar.gz','zip','all.tar.bz2'),
 	// add given extra-apps or (uncompressed!) archives to above all.tar.bz2 archive
-	'all-add' => array(/*'contrib',*/ '/home/stylite/epl-trunk/phpfreechat_data_public.tar'),
+	'all-add' => array('contrib', '/home/stylite/epl-trunk/phpfreechat_data_public.tar'),
 	// diverse binaries we need
 	'svn' => trim(`which svn`),
 	'tar' => trim(`which tar`),
@@ -58,13 +58,15 @@ $config = array(
 	'composer' => ($composer=trim(`which composer.phar`)) ? $composer.' install --ignore-platform-reqs' : '',
 	'after-checkout' => 'rm -rf */source */templates/*/source',
 	'packager' => 'build@stylite.de',
-	'obs' => '/home/stylite/obs/stylite-epl',
+	'obs' => '/home/stylite/obs/stylite-epl-trunk',
 	'obs_package_alias' => '',	// name used in obs package, if different from packagename
 	'changelog' => false,   // eg. '* 1. Zeile\n* 2. Zeile' for debian.changes
 	'changelog_packager' => 'Ralf Becker <rb@stylite.de>',
 	'editchangelog' => '* ',
 	//'sfuser' => 'ralfbecker',
 	//'release' => '$sfuser,egroupware@frs.sourceforge.net:/home/frs/project/e/eg/egroupware/eGroupware-$version/eGroupware-$version.$packaging/',
+	// what gets uploaded with upload
+	'upload' => '$sourcedir/*egroupware-epl{,-contrib}-$version.$packaging*',
 	'copychangelog' => '$sourcedir/README', //'$sfuser,egroupware@frs.sourceforge.net:/home/frs/project/e/eg/egroupware/README',
 	'skip' => array(),
 	'run' => array('checkout','editchangelog','tag','copy','virusscan','create','sign','obs','copychangelog'),
@@ -382,11 +384,28 @@ function do_release()
 		'body' => $config['changelog'],
 	);
 	$response = github_api("/repos/EGroupware/egroupware/releases", $data);
-	$upload_url = preg_replace('/{\?[^}]+}$/', '', $response['upload_url']);	// remove {?name,label} template
+	$config['upload_url'] = preg_replace('/{\?[^}]+}$/', '', $response['upload_url']);	// remove {?name,label} template
 
-	$archives = $config['sourcedir'].'/*egroupware-epl-'.$config['version'].'.'.$config['packaging'].'*';
+	do_upload();
+}
 
-	foreach(glob($archives) as $path)
+/**
+ * Upload archives
+ */
+function do_upload()
+{
+	global $config,$verbose;
+
+	if (empty($config['upload_url']))
+	{
+		$response = github_api("/repos/EGroupware/egroupware/releases", array(), 'GET');
+		$config['upload_url'] = preg_replace('/{\?[^}]+}$/', '', $response[0]['upload_url']);	// remove {?name,label} template
+	}
+
+	$archives = config_translate('upload');
+	echo "Uploading $archives to $config[upload_url]\n";
+
+	foreach(glob($archives, GLOB_BRACE) as $path)
 	{
 		$label = null;
 		if (substr($path, -4) == '.zip')
@@ -410,8 +429,9 @@ function do_release()
 		{
 			continue;
 		}
+		if ($verbose) echo "Uploading $path as $content_type\n";
 		$name = basename($path);
-		github_api($upload_url, array(
+		github_api($config['upload_url'], array(
 			'name' => $name,
 			'label' => isset($label) ? $label : $name,
 		), 'FILE', $path, $content_type);
