@@ -125,14 +125,6 @@ function set_distro_defaults($distro=null)
 				$config['start_db'] = '/etc/init.d/mysql';
 				$config['start_webserver'] = '/etc/init.d/apache2';
 			}
-			// enable mcrypt
-			if (file_exists('/usr/sbin/php5enmod'))
-			{
-				$config['php5enmod'] = '/usr/sbin/php5enmod';
-				// Ubuntu only needs "-s ALL" and Debian gives an error, because it does not support it
-				if (!file_exists('/etc/php5/conf.d/')) $config['php5enmod'] .= ' -s ALL';
-				$config['php5enmod'] .= ' mcrypt';
-			}
 			$config['autostart_db'] = '/usr/sbin/update-rc.d mysql defaults';
 			$config['autostart_webserver'] = '/usr/sbin/update-rc.d apache2 defaults';
 			$config['webserver_user'] = 'www-data';
@@ -658,17 +650,17 @@ function set_univention_defaults()
 			$domain = array_shift($domains);
 			// set "use auth with session credentials",tls,"not user editable","further identities"
 			$config['smtpserver'] = "$mailserver,465,,,yes,tls,no,yes";
-			$config['smtp'] = ',emailadmin_smtp_univention';
+			$config['smtp'] = ',Smtp\\Univention';
 			$config['mailserver'] = "$mailserver,993,$domain,email,tls";
 			if (_ucr_get('mail/dovecot') == 'yes')
 			{
-				$config['imap'] = /*'cyrus,'._ucr_secret('cyrus')*/','.',emailadmin_imap_dovecot';
+				$config['imap'] = /*'cyrus,'._ucr_secret('cyrus')*/','.',Imap\\Dovecot';
 				// default with sieve port to 4190, as config is only available on host mailserver app is installed
 				if (!($sieve_port = _ucr_get('mail/dovecot/sieve/port'))) $sieve_port = 4190;
 			}
 			else
 			{
-				$config['imap'] = /*'cyrus,'._ucr_secret('cyrus')*/','.',emailadmin_imap_cyrus';
+				$config['imap'] = /*'cyrus,'._ucr_secret('cyrus')*/','.',Imap\\Cyrus';
 				// default with sieve port to 4190, as config is only available on host mailserver app is installed
 				if (!($sieve_port = _ucr_get('mail/cyrus/sieve/port'))) $sieve_port = 4190;
 			}
@@ -730,7 +722,7 @@ function _ucr_secret($name)
  */
 function check_fix_php_apc_ini()
 {
-	if (extension_loaded('apc') || extension_loaded('apcu'))
+	if (extension_loaded('apc'))
 	{
 		$shm_size = ini_get('apc.shm_size');
 		$shm_segments = ini_get('apc.shm_segments');
@@ -747,7 +739,7 @@ function check_fix_php_apc_ini()
 			phpinfo();
 			$phpinfo = ob_get_clean();
 			$matches = null;
-			if (preg_match('#(/[a-z0-9./-]+apcu?.ini)(,| |$)#mi', $phpinfo, $matches) &&
+			if (preg_match('#(/[a-z0-5./-]+apcu?.ini)(,| |$)#mi', $phpinfo, $matches) &&
 				file_exists($path = $matches[1]) && ($apc_ini = file_get_contents($path)))
 			{
 				$new_shm_size = 128 / $shm_segments;
