@@ -521,7 +521,7 @@ class editor
 			// check if application of template has a app.js file --> load it
 			if (file_exists(EGW_SERVER_ROOT.'/'.$app.'/js/app.js'))
 			{
-				$GLOBALS['egw']->js->validate_file('.','app',$app,false);
+				egw_framework::validate_file('.','app',$app,false);
 			}
 			$editor->data[$editor->rows]['A']['obj'] = &$this->etemplate;
 			$vals = $content['vals'];
@@ -1595,6 +1595,9 @@ class editor
 
 		if (isset($this->extensions['**loaded**'][$app])) return '';	// already loaded
 
+		// load eT2 widgets first, as eg. customfield_widget depends on eT2 Widget\Transformer
+		EGroupware\Api\Etemplate\Widget::scanForWidgets();
+
 		$labels = array();
 		$dir = @opendir(EGW_SERVER_ROOT.'/'.$app.'/inc');
 		while ($dir && ($file = readdir($dir)))
