@@ -77,6 +77,11 @@
  */
 class nextmatch_widget
 {
+	/**
+	 * Path where the icons are stored (relative to webserver_url)
+	 */
+	const ICON_PATH = '/api/images';
+
 	/**
 	 * Prefix for custom field names
 	 *
@@ -810,9 +815,9 @@ class nextmatch_widget
 					'no_lang' => true,
 				);
 				// add category icon
-				if ($cat['data']['icon'] && file_exists(EGW_SERVER_ROOT.'/phpgwapi/images/'.basename($cat['data']['icon'])))
+				if ($cat['data']['icon'] && file_exists(EGW_SERVER_ROOT.self::ICON_PATH.'/'.basename($cat['data']['icon'])))
 				{
-					$cat_actions[$cat['id']]['iconUrl'] = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/images/'.$cat['data']['icon'];
+					$cat_actions[$cat['id']]['iconUrl'] = $GLOBALS['egw_info']['server']['webserver_url'].self::ICON_PATH.'/'.$cat['data']['icon'];
 				}
 			}
 		}
@@ -849,9 +854,9 @@ class nextmatch_widget
 					'prefix' => $prefix,
 				);
 				// add category icon
-				if ($cat['data']['icon'] && file_exists(EGW_SERVER_ROOT.'/phpgwapi/images/'.basename($cat['data']['icon'])))
+				if ($cat['data']['icon'] && file_exists(EGW_SERVER_ROOT.self::ICON_PATH.'/'.basename($cat['data']['icon'])))
 				{
-					$cat_actions[$cat['id']]['iconUrl'] = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/images/'.$cat['data']['icon'];
+					$cat_actions[$cat['id']]['iconUrl'] = $GLOBALS['egw_info']['server']['webserver_url'].self::ICON_PATH.'/'.$cat['data']['icon'];
 				}
 				unset($cats[$key]);
 			}
@@ -882,9 +887,6 @@ class nextmatch_widget
 	 */
 	public static function init_egw_actions(array $actions=null, $action_links=null, $template_name='', $prefix='egw_')
 	{
-		// Load some JS files needed for the egw_action framework
-		egw_framework::includeCSS('/phpgwapi/js/egw_action/test/skins/dhtmlxmenu_egw.css');
-
 		egw_framework::validate_file('dhtmlxtree','dhtmlxMenu/codebase/dhtmlxcommon');
 		egw_framework::validate_file('dhtmlxtree','dhtmlxMenu/codebase/dhtmlxmenu');
 		egw_framework::validate_file('egw_action','egw_action');
@@ -895,8 +897,6 @@ class nextmatch_widget
 		egw_framework::validate_file('egw_action','egw_keymanager');
 		egw_framework::validate_file('.', 'nextmatch_action', 'etemplate');
 
-		//egw_framework::validate_file('dhtmlxtree','dhtmlxMenu/codebase/ext/dhtmlxmenu_ext');
-
 		if (!is_array($action_links)) $action_links = array();
 
 		$app = $GLOBALS['egw_info']['flags']['currentapp'];
@@ -905,7 +905,7 @@ class nextmatch_widget
 
 		return '
 <script type="text/javascript">
-	egw_LAB.wait(function() {$j(document).ready(function() {
+	egw_LAB.wait(function() {jQuery(document).ready(function() {
 		// Initialize the action manager and add some actions to it
 		var actionManager = egw_getActionManager("'.$app.'");
 		var objectManager = egw_getObjectManager("'.$app.'");
@@ -924,7 +924,7 @@ class nextmatch_widget
 
 		// Create a new action object for each table row
 		var divObj = document.getElementById("'.$template_name.'");
-		$j("table.egwGridView_grid>tbody>tr", divObj).each(function(index, elem)
+		jQuery("table.egwGridView_grid>tbody>tr", divObj).each(function(index, elem)
 		{
 			// Create a new action object
 			if (elem.id) {
