@@ -76,7 +76,7 @@ app.classes.filemanager = AppJS.extend(
 		{
 			this.path_widget[et2.DOMContainer.id] = path_widget;
 			// Bind to removal to remove from list
-			$j(et2.DOMContainer).on('clear', function(e) {
+			jQuery(et2.DOMContainer).on('clear', function(e) {
 				if (app.filemanager && app.filemanager.path_widget) delete app.filemanager.path_widget[e.target.id];
 			});
 		}
@@ -629,7 +629,7 @@ app.classes.filemanager = AppJS.extend(
 			}
 
 			// Multiple file download for those that support it
-			a = $j(a)
+			a = jQuery(a)
 				.prop('href', url)
 				.prop('download', data ? data.data.name : "")
 				.appendTo(this.et2.getDOMNode());
@@ -720,7 +720,7 @@ app.classes.filemanager = AppJS.extend(
 			// Toggle button icon to the other view
 			button_widget.set_image("list_"+(view == nm.controller.VIEW_ROW ? nm.controller.VIEW_TILE : nm.controller.VIEW_ROW));
 
-			button_widget.set_label(view == nm.controller.VIEW_ROW ? this.egw.lang("Tile view") : this.egw.lang('List view'));
+			button_widget.set_statustext(view == nm.controller.VIEW_ROW ? this.egw.lang("Tile view") : this.egw.lang('List view'));
 		}
 
 		nm.set_view(view);
@@ -737,7 +737,7 @@ app.classes.filemanager = AppJS.extend(
 		{
 			template.loading.done(function() {
 				nm.applyFilters({view: view});
-			})
+			});
 		}
 	},
 
@@ -853,7 +853,7 @@ app.classes.filemanager = AppJS.extend(
 		widget.options.onFinish = function() {
 			widget.options.onFinish = old_onfinish;
 			widget.options.onFinishOne = old_onfinishone;
-		}
+		};
 		// This triggers the upload
 		widget.set_value(files);
 
@@ -889,14 +889,7 @@ app.classes.filemanager = AppJS.extend(
 					var widget = etemplate2.getById(id).widgetContainer.getWidgetById(ids[i]);
 					if (widget)
 					{
-						if (widget._type == 'button' || widget._type == 'buttononly')
-						{
-							widget.set_readonly(_ro);
-						}
-						else
-						{
-							widget.set_disabled(_ro);
-						}
+						widget.set_readonly(_ro);
 					}
 				}
 			}
