@@ -9,12 +9,10 @@
  * @version $Id$
  */
 
-"use strict";
-
 /*egw:uses
-        jquery.jquery;
-        jquery.jquery-ui;
-	/phpgwapi/js/jquery/gridster/jquery.gridster.js;
+	/vendor/bower-asset/jquery/dist/jquery.js;
+	/vendor/bower-asset/jquery-ui/jquery-ui.js;
+	/vendor/npm-asset/gridster/dist/jquery.gridster.js;
 */
 
 /**
@@ -27,7 +25,7 @@
  * @see http://gridster.net
  * @augments AppJS
  */
-app.classes.home = AppJS.extend(
+app.classes.home = (function(){ "use strict"; return AppJS.extend(
 {
 	/**
 	 * AppJS requires overwriting this with the actual application name
@@ -98,7 +96,7 @@ app.classes.home = AppJS.extend(
 		{
 			// call parent
 			this._super.apply(this, arguments);
-			
+
 			this.et2.set_id('home.index');
 			this.et2.set_actions(this.et2.getArrayMgr('modifications').getEntry('home.index')['actions']);
 
@@ -108,7 +106,7 @@ app.classes.home = AppJS.extend(
 			this._do_ordering();
 
 			// Accept drops of favorites, which aren't part of action system
-			$j(this.et2.getDOMNode().parentNode).droppable({
+			jQuery(this.et2.getDOMNode().parentNode).droppable({
 				hoverClass: 'drop-hover',
 				accept: function(draggable) {
 					// Check for direct support for that application
@@ -157,19 +155,21 @@ app.classes.home = AppJS.extend(
 			// Check for existing etemplate, this one loaded over it
 			// NOTE: Moving them around like this can cause problems with event handlers
 			var existing = etemplate2.getById(et2.uniqueId);
-			if(portlet && existing && existing.etemplate_exec_id != et2.etemplate_exec_id)
+			if(portlet && existing)
 			{
 				for(var i = 0; i < portlet._children.length; i++)
 				{
-					if(portlet._children[i]._inst) portlet._children[i]._inst.clear();
+					if(typeof portlet._children[i]._init == 'undefined')
+					{
+						portlet.removeChild(portlet._children[i])
+					}
 				}
-				portlet._children = [];
 			}
 			// It's in the right place for original load, but move it into portlet
-			var misplaced = $j(etemplate2.getById('home-index').DOMContainer).siblings('#'+et2.DOMContainer.id);
+			var misplaced = jQuery(etemplate2.getById('home-index').DOMContainer).siblings('#'+et2.DOMContainer.id);
 			if(portlet)
 			{
-				portlet.content = $j(et2.DOMContainer).appendTo(portlet.content);
+				portlet.content = jQuery(et2.DOMContainer).appendTo(portlet.content);
 				portlet.addChild(et2.widgetContainer);
 				et2.resize();
 			}
@@ -185,7 +185,7 @@ app.classes.home = AppJS.extend(
 		// Special handling to deal with legacy (non-et2) calendar links
 		if(name == 'home.legacy')
 		{
-			$j('.calendar_calDayColHeader a, .calendar_plannerDayScale a, .calendar_plannerWeekScale a, .calendar_plannerMonthScale a, .calendar_calGridHeader a', et2.DOMContainer)
+			jQuery('.calendar_calDayColHeader a, .calendar_plannerDayScale a, .calendar_plannerWeekScale a, .calendar_plannerMonthScale a, .calendar_calGridHeader a', et2.DOMContainer)
 				.on('click', function(e) {
 					egw.link_handler(this.href,'calendar');
 					return false;
@@ -255,7 +255,7 @@ app.classes.home = AppJS.extend(
 		// Try to put it about where the menu was opened
 		if(action.menu_context)
 		{
-			var $portlet_container = $j(this.portlet_container.getDOMNode());
+			var $portlet_container = jQuery(this.portlet_container.getDOMNode());
 			attrs.row = Math.max(1,Math.round((action.menu_context.posy - $portlet_container.offset().top )/ this.GRID)+1);
 			attrs.col = Math.max(1,Math.round((action.menu_context.posx - $portlet_container.offset().left) / this.GRID)+1);
 		}
@@ -273,7 +273,7 @@ app.classes.home = AppJS.extend(
 		portlet._process_edit(et2_dialog.OK_BUTTON, attrs);
 
 		// Set up sorting/grid of new portlet
-		var $portlet_container = $j(this.portlet_container.getDOMNode());
+		var $portlet_container = jQuery(this.portlet_container.getDOMNode());
 		$portlet_container.data("gridster").add_widget(
 			portlet.getDOMNode(),
 			this.DEFAULT.WIDTH, this.DEFAULT.HEIGHT,
@@ -295,7 +295,7 @@ app.classes.home = AppJS.extend(
 			return this.add(action);
 		}
 
-		var $portlet_container = $j(this.portlet_container.getDOMNode());
+		var $portlet_container = jQuery(this.portlet_container.getDOMNode());
 
 		// Basic portlet attributes
 		var attrs = {
@@ -348,10 +348,10 @@ app.classes.home = AppJS.extend(
 
 	/**
 	 * Set the current selection as default for other users
-	 * 
+	 *
 	 * Only works (and available) for admins, this shows a dialog to select
 	 * the group, and then sets the default for that group.
-	 * 
+	 *
 	 * @param {egwAction} action
 	 * @param {egwActionObject[]} selected
 	 */
@@ -385,7 +385,7 @@ app.classes.home = AppJS.extend(
 		{
 			// Disable action for feedback
 			action.set_enabled(false);
-			
+
 			// Pass them to server
 			egw.json('home_ui::ajax_set_default', ['delete', portlet_ids, group]).sendRequest(true);
 			return;
@@ -407,7 +407,7 @@ app.classes.home = AppJS.extend(
 
 	/**
 	 * Allow a refresh from anywhere by triggering an update with no changes
-	 * 
+	 *
 	 * @param {string} id
 	 */
 	refresh: function(id) {
@@ -473,7 +473,7 @@ app.classes.home = AppJS.extend(
 	 * Set up the drag / drop / re-order of portlets
 	 */
 	_do_ordering: function() {
-		var $portlet_container = $j(this.portlet_container.getDOMNode());
+		var $portlet_container = jQuery(this.portlet_container.getDOMNode());
 		$portlet_container
 			.addClass("home ui-helper-clearfix")
 			.disableSelection()
@@ -512,8 +512,8 @@ app.classes.home = AppJS.extend(
 						var changed = this.serialize_changed();
 
 						// Reset changed, or they keep accumulating
-						this.$changed = $j([]);
-						
+						this.$changed = jQuery([]);
+
 						for (var key in changed)
 						{
 							if(!changed[key].id) continue;
@@ -539,7 +539,7 @@ app.classes.home = AppJS.extend(
 			e.stopPropagation();
 		});
 		// Bind window resize to re-layout gridster
-		$j(window).one("resize."+this.et2._inst.uniqueId, function() {
+		jQuery(window).one("resize."+this.et2._inst.uniqueId, function() {
 			// Note this doesn't change the positions, just makes them invalid
 			$portlet_container.data('gridster').recalculate_faux_grid();
 		});
@@ -710,15 +710,15 @@ app.classes.home = AppJS.extend(
 		}
 
 		// Aim to match the size
-		var portlet_dom = $j('[id$='+id+'][data-sizex]',this.portlet_container.getDOMNode());
+		var portlet_dom = jQuery('[id$='+id+'][data-sizex]',this.portlet_container.getDOMNode());
 		var width = portlet_dom.attr('data-sizex') * this.GRID;
 		var height = portlet_dom.attr('data-sizey') * this.GRID;
-		
+
 		// CKEditor is impossible to use below a certain size
 		// Add 35px for the toolbar, 35px for the buttons
 		var window_width = Math.max(580, width+20);
 		var window_height = Math.max(350, height+70);
-		
+
 		// Open popup, but add 70 to the height for the toolbar
 		egw.open_link(egw.link('/index.php',{
 			menuaction: 'home.home_note_portlet.edit',
@@ -746,38 +746,8 @@ app.classes.home = AppJS.extend(
 		nm.div.toggleClass('header_hidden');
 		nm.set_hide_header(nm.div.hasClass('header_hidden'));
 		nm.resize();
-	},
-	
-	/**
-	 * Function to set video iframe base on selected tutorial from
-	 * tutorials box
-	 * 
-	 * @param {type} url
-	 */
-	tutorial_videoOnClick: function (_url)
-	{
-		var frame = etemplate2.getByApplication('home')[0].widgetContainer.getWidgetById('src');
-		if (frame)
-		{
-			frame.set_value(_url);
-		}
-	},
-	
-	/**
-	 * Function calls on discard checkbox and will set
-	 * the egw_tutorial_noautoload preference
-	 * 
-	 * @param {type} egw
-	 * @param {type} widget
-	 */
-	tutorial_autoloadDiscard: function (egw, widget)
-	{
-		if (widget)
-		{
-			this.egw.set_preference('common', 'egw_tutorial_noautoload', widget.get_value());
-		}
 	}
-});
+})}).call(this);
 
 /// Base class code
 
@@ -785,7 +755,7 @@ app.classes.home = AppJS.extend(
  * Base class for portlet specific javascript
  *
  * Should this maybe extend et2_portlet?  It would complicate instantiation.
- * 
+ *
  * @type @exp;Class@call;extend
  */
 app.classes.home.home_portlet = Class.extend({
@@ -812,9 +782,49 @@ app.classes.home.home_portlet = Class.extend({
 });
 
 app.classes.home.home_link_portlet = app.classes.home.home_portlet.extend({
+	init: function(portlet) {
+		// call parent
+		this._super.apply(this, arguments);
+
+		// Check for tooltip
+		if(this.portlet)
+		{
+			var content = jQuery('.tooltip',this.portlet.content);
+			if(content.length && content.children().length)
+			{
+				//Check if the tooltip is already initialized
+				this.portlet.content.tooltip({
+					items: this.portlet.content,
+					content: content.html(),
+					tooltipClass: 'portlet_' + this.portlet.id,
+					show: {effect: 'slideDown', delay:500},
+					hide: {effect: 'slideUp', delay: 500},
+					position: {my: "left top", at:"left bottom", collision: "flipfit"},
+					open: jQuery.proxy(function(event, ui) {
+						// Calendar specific formatting
+						if(ui.tooltip.has('.calendar_calEventTooltip').length)
+						{
+							ui.tooltip.removeClass("ui-tooltip");
+							ui.tooltip.addClass("calendar_uitooltip");
+						}
+					},this),
+					close: function(event,ui) {
+						ui.tooltip.hover(
+							function() {
+								jQuery(this).stop(true).fadeTo(100,1);
+							},
+							function() {
+								jQuery(this).slideUp("400",function() {jQuery(this).remove();});
+							}
+						);
+					}
+				});
+			}
+		}
+	},
 	observer: function(_msg, _app, _id, _type)
 	{
-		if(this.portlet)
+		if(this.portlet && this.portlet.settings)
 		{
 			var value = this.portlet.settings.entry || {};
 			if(value.app && value.app == _app && value.id && value.id == _id)
@@ -843,7 +853,38 @@ app.classes.home.home_list_portlet = app.classes.home.home_portlet.extend({
 		}
 	}
 });
+app.classes.home.home_weather_portlet = app.classes.home.home_portlet.extend({
+	init: function(portlet) {
+		// call parent
+		this._super.apply(this, arguments);
+
+		// Use location API
+		if(!this.portlet.options.settings && 'geolocation' in navigator)
+		{
+			navigator.geolocation.getCurrentPosition(function(position) {
+				if(portlet && portlet.options && portlet.options.settings &&
+					portlet.options.settings.position && portlet.options.settings.position == position.coords.latitude + ',' + position.coords.longitude)
+				{
+					return;
+				}
+				portlet._process_edit(et2_dialog.OK_BUTTON, {position: position.coords.latitude + ',' + position.coords.longitude});
+			});
+		}
+	}
+});
 app.classes.home.home_favorite_portlet = app.classes.home.home_portlet.extend({
+	init: function(portlet) {
+		// call parent
+		this._super.apply(this, arguments);
+
+		// Somehow favorite got lost, or is not set
+		if(portlet.options && portlet.options.settings && typeof portlet.options.settings !== 'undefined' &&
+			!portlet.options.settings.favorite
+		)
+		{
+			portlet.edit_settings();
+		}
+	},
 	observer: function(_msg, _app, _id, _type, _msg_type, _targetapp)
 	{
 		if(this.portlet.class.indexOf(_app) == 0 || this.portlet.class == 'home_favorite_portlet')
@@ -857,7 +898,7 @@ app.classes.home.home_favorite_portlet = app.classes.home.home_portlet.extend({
 /**
  * An example illustrating extending the base code for a application specific code.
  * See also the calendar app, which needs custom handlers
- * 
+ *
  * @type @exp;app@pro;classes@pro;home@pro;home_favorite_portlet@call;extend
  * Note we put it in home, but this code should go in addressbook/js/addressbook_favorite_portlet.js
  *
