@@ -10,6 +10,10 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Etemplate;
+
 /**
  * userinterface for exports
  *
@@ -22,7 +26,6 @@ class importexport_export_ui {
 		'download' 	=>	true,
 	);
 
-	private $js;
 	private $user;
 
 	/**
@@ -33,12 +36,10 @@ class importexport_export_ui {
 	private $export_plugins;
 
 	public function __construct() {
-		$this->js = $GLOBALS['egw']->js = is_object($GLOBALS['egw']->js) ? $GLOBALS['egw']->js : CreateObject('phpgwapi.javascript');
-		$this->js->validate_file('.','export_dialog','importexport');
-		$this->js->validate_file('.','importexport','importexport');
+		Framework::includeJS('.','export_dialog','importexport');
+		Framework::includeJS('.','importexport','importexport');
 		$this->user = $GLOBALS['egw_info']['user']['user_id'];
 		$this->export_plugins = importexport_helper_functions::get_plugins('all','export');
-		$GLOBALS['egw_info']['flags']['include_xajax'] = true;
 
 	}
 
@@ -48,7 +49,7 @@ class importexport_export_ui {
 		$readonlys = array();
 		$preserv = array();
 
-		$et = new etemplate_new(self::_appname. '.export_dialog');
+		$et = new Etemplate(self::_appname. '.export_dialog');
 		$_appname = $_content['appname'] ? $_content['appname'] : $_GET['appname'];
 		$_definition = $_content['definition'] ? $_content['definition'] : $_GET['definition'];
 		$_plugin = $_content['plugin'] ? $_content['plugin'] : $_GET['plugin'];
@@ -58,8 +59,8 @@ class importexport_export_ui {
 		if($_GET['selection'] || $_content['selection_passed']) $content['selection_passed'] = $preserv['selection_passed'] = true;
 
 		// Check global setting
-		if(!bo_merge::is_export_limit_excepted()) {
-			$export_limit = bo_merge::getExportLimit($_appname);
+		if(!Api\Storage\Merge::is_export_limit_excepted()) {
+			$export_limit = Api\Storage\Merge::getExportLimit($_appname);
 			if($export_limit == 'no') {
 				die(lang('Admin disabled exporting'));
 			}
@@ -123,7 +124,6 @@ class importexport_export_ui {
 					$sel_options['plugin'] = $plugins;
 */
 			}
-			//$this->js->set_onload("set_style_by_class('tr','select_definition','display','none');");
 		}
 		else {
 			$readonlys['plugin'] = true;
@@ -183,7 +183,7 @@ class importexport_export_ui {
 		if($definition && is_array($definition->plugin_options) && $definition->plugin_options['selection'] && !$content['selection_passed']) {
 			$_selection = $definition->plugin_options['selection'];
 		}
-		
+
 		if ($_selection && ($content['old_definition'] == $content['definition'] || $content['selection_passed'])) {
 			$readonlys[$tabs]['selection_tab'] = true;
 			$content['selection'] = $_selection;
@@ -211,7 +211,6 @@ class importexport_export_ui {
 			$content['filter']['fields'] = importexport_helper_functions::get_filter_fields($_appname, $selected_plugin);
 			if(!$content['filter']['fields'])
 			{
-				$this->js->set_onload("\$j('input[value=\"filter\"]').parent().hide();");
 				$content['no_filter'] = true;
 			}
 			else
@@ -233,13 +232,7 @@ class importexport_export_ui {
 			$content['selection'] = 'search';
 		}
 
-		// Disable / hide definition filter if not selected
-		if($content['selection'] != 'filter')
-		{
-			$this->js->set_onload("
-				\$j('div.filters').hide();
-			");
-		}
+
 		unset ($plugin_object);
 		$apps = importexport_helper_functions::get_apps('export');
 		//error_log(__METHOD__.__LINE__.array2string($apps));
@@ -255,7 +248,7 @@ class importexport_export_ui {
 		if($_content['preview'] || $_content['export'])
 		{
 			//error_log(__LINE__.__FILE__.'$_content: '.print_r($_content,true));
-			$response = egw_json_response::get();
+			$response = Api\Json\Response::get();
 
 			if ($_content['definition'] == 'expert') {
 				$definition = new importexport_definition();
@@ -297,19 +290,18 @@ class importexport_export_ui {
 					}
 					if(is_array($value) && array_key_exists('from', $value) && $value['from'])
 					{
-						$filter[$key]['from'] = egw_time::to($value['from'],'ts');
+						$filter[$key]['from'] = Api\DateTime::to($value['from'],'ts');
 					}
 					// If user selects an end date, they most likely want entries including that date
 					if(is_array($value) && array_key_exists('to',$value) && $value['to'] )
 					{
 						// Adjust time to 23:59:59
-						$filter[$key]['to'] = new egw_time($value['to']);
+						$filter[$key]['to'] = new Api\DateTime($value['to']);
 						$filter[$key]['to']->setTime(23,59,59);
 						$filter[$key]['to'] = $filter[$key]['to']->format('ts');
 					}
 				}
 			}
-			error_log(array2string($filter));
 
 			unset($_content['filter']);
 			$definition->filter = $filter;
@@ -327,7 +319,7 @@ class importexport_export_ui {
 			$tmpfname = tempnam($GLOBALS['egw_info']['server']['temp_dir'],'export');
 			$file = fopen($tmpfname, "w+");
 			if (! $charset = $definition->plugin_options['charset']) {
-				$charset = $GLOBALS['egw']->translation->charset();
+				$charset = Api\Translation::charset();
 			}
 			if($charset == 'user')
 			{
@@ -349,7 +341,7 @@ class importexport_export_ui {
 			}
 
 			// Store charset to use in header
-			egw_cache::setSession('importexport', $tmpfname, $charset, 100);
+			Api\Cache::setSession('importexport', $tmpfname, $charset, 100);
 
 			if($_content['export'] == 'pressed') {
 				fclose($file);
@@ -368,7 +360,7 @@ class importexport_export_ui {
 					$link_query['filename'] = $plugin_filename;
 				}
 				$response->redirect( $GLOBALS['egw']->link('/index.php',$link_query),true);
-				egw_framework::window_close();
+				Framework::window_close();
 				return;
 			}
 			elseif($_content['preview'] == 'pressed') {
@@ -389,13 +381,13 @@ class importexport_export_ui {
 				unlink($tmpfname);
 
 				// Convert back to system charset for display
-				$preview = $GLOBALS['egw']->translation->convert( $preview,
+				$preview = Api\Translation::convert( $preview,
 					$charset,
-					$GLOBALS['egw']->translation->charset()
+					Api\Translation::charset()
 				);
 
 				$preview = "<div class='header'>".lang('Preview') . "<span class='count'>".(int)$record_count."</span></div>".$preview;
-				
+
 				$et->setElementAttribute('preview-box', 'value', nl2br($preview));
 				return;
 			}
@@ -409,41 +401,9 @@ class importexport_export_ui {
 		return $et->exec(self::_appname. '.importexport_export_ui.export_dialog',$content,$sel_options,$readonlys,$preserv,2);
 	}
 
-	public function ajax_get_definitions($_appname, xajaxResponse &$response = null) {
-		if(is_null($response)) {
-			$response = new xajaxResponse();
-		} else {
-			$no_return = true;
-		}
-		if (!$_appname) {
-			$response->jquery('tr.select_definition','hide');
-			return $no_return ? '' : $response->getXML();
-		}
-
-		$definitions = new importexport_definitions_bo(array(
-			'type' => 'export',
-			'application' => $_appname
-		));
-		foreach ((array)$definitions->get_definitions() as $identifier) {
-			try {
-				$definition = new importexport_definition($identifier);
-			} catch (Exception $e) {
-				// Permission error
-				continue;
-			}
-				if ($title = $definition->get_title()) {
-					if (!$selected_plugin) $selected_plugin = $title;
-					$response->addScript("selectbox_add_option('exec[definition]','$title', '$value',".($selected_plugin == $title ? 'true' : 'false').");");
-				}
-				unset($definition);
-		}
-		unset($definitions);
-		$response->addScript("selectbox_add_option('exec[definition]','" . lang('Expert options') . "', 'expert',".($selected_plugin == $title ? 'true' : 'false').");");
-	}
-
 	public function ajax_get_definition_description($_definition) {
 
-		$_response = egw_json_response::get();
+		$_response = Api\Json\Response::get();
 		$description = '';
 		if ($_definition)
 		{
@@ -457,14 +417,14 @@ class importexport_export_ui {
 	}
 
 	public function ajax_get_plugin_description($_plugin) {
-		$_respone = egw_json_response::get();
+		$_respone = Api\Json\Response::get();
 
 		$plugin_object = new $_plugin;
 		if (is_a($plugin_object, 'importexport_iface_export_plugin')) {
 			$description = $plugin_object->get_description();
 		}
 		$_response->addAssign('importexport-export_dialog_plugin_description','innerHTML',$description);
-		
+
 		unset ($plugin_object);
 	}
 
@@ -488,9 +448,9 @@ class importexport_export_ui {
 		$file = fopen($tmpfname,'rb');
 
 		// Get charset
-		$charset = egw_cache::getSession('importexport', $tmpfname);
+		$charset = Api\Cache::getSession('importexport', $tmpfname);
 
-		html::content_header($nicefname.'.'.$_GET['_suffix'],
+		Api\Header\Content::type($nicefname.'.'.$_GET['_suffix'],
 			($_GET['_type'] ? $_GET['_type'] : 'application/text') . ($charset ? '; charset='.$charset : ''),
 			filesize($tmpfname));
 		fpassthru($file);
@@ -498,6 +458,6 @@ class importexport_export_ui {
 		unlink($tmpfname);
 
 		// Try to avoid any extra finishing output
-		common::egw_exit();
+		exit();
 	}
 } // end class uiexport
