@@ -2,7 +2,7 @@
 /**
  * EGroupware index page
  *
- * Starts all applications using $_GET[menuaction]
+ * Starts all Egw\Applications using $_GET[menuaction]
  *
  * @link http://www.egroupware.org
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
@@ -10,6 +10,10 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Egw;
+
 // support of Mac or iPhone trying to autodetect CalDAV or CardDAV support
 // if EGroupware is not installed in the docroot, you need either this code in the index.php there,
 // or an uncoditional redirect to this file or copy groupdav.htaccess to your docroot as .htaccess
@@ -34,23 +38,34 @@ if(isset($_GET['hasupdates']) && $_GET['hasupdates'] == 'yes')
 /*
 	This is the menuaction driver for the multi-layered design
 */
-if(isset($_GET['menuaction']) && preg_match('/^[A-Za-z0-9_]+\.[A-Za-z0-9_]+\.[A-Za-z0-9_]+$/',$_GET['menuaction']))
+if(isset($_GET['menuaction']) && preg_match('/^[A-Za-z0-9_]+\.[A-Za-z0-9_\\\\]+\.[A-Za-z0-9_]+$/',$_GET['menuaction']))
 {
 	list($app,$class,$method) = explode('.',$_GET['menuaction']);
-	if(! $app || ! $class || ! $method)
+
+	// check if autoloadable class belongs to given app
+	if (substr($class, 0, 11) == 'EGroupware\\')
+	{
+		list(,$app_from_class) = explode('\\', strtolower($class));
+	}
+	elseif(strpos($class, '_') !== false)
+	{
+		list($app_from_class) = explode('_', $class);
+	}
+	if(!$app || !$class || !$method || isset($app_from_class) &&
+		isset($GLOBALS['egw_info']['apps'][$app_from_class]) && $app_from_class != $app)
 	{
 		$invalid_data = True;
 	}
 }
 else
 {
-	$app = 'home';
+	$app = 'api';
 	$invalid_data = True;
 }
 //error_log(__METHOD__."$app,$class,$method");
 if($app == 'phpgwapi')
 {
-	$app = 'home';
+	$app = 'api';
 	$api_requested = True;
 }
 
@@ -62,21 +77,18 @@ $GLOBALS['egw_info'] = array(
 	)
 );
 include('./header.inc.php');
-// check if users are supposed to change their password every x sdays, then check if password is of old age or the devil-admin reset the users password
-// and forced the user to change his password on next login.
-auth::check_password_age($app,$class,$method);
 
 // user changed timezone
 if (isset($_GET['tz']))
 {
-	egw_time::setUserPrefs($_GET['tz']);	// throws exception, if tz is invalid
+	Api\DateTime::setUserPrefs($_GET['tz']);	// throws exception, if tz is invalid
 
 	$GLOBALS['egw']->preferences->add('common','tz',$_GET['tz']);
 	$GLOBALS['egw']->preferences->save_repository();
 
-	if (($referer = common::get_referer()))
+	if (($referer = Api\Header\Referer::get()))
 	{
-		egw::redirect_link($referer);
+		Egw::redirect_link($referer);
 	}
 }
 
@@ -97,7 +109,7 @@ if(@file_exists($tpl_info))
 }
 
 
-if($app == 'home' && !$class && !$api_requested && !($windowed && $_GET['cd'] == 'yes' && !html::$ua_mobile))
+if($app == 'api' && !$class && !$api_requested && !($windowed && $_GET['cd'] == 'yes' && !Api\Header\UserAgent::mobile()) && $GLOBALS['egw_info']['user']['preferences']['common']['template_set'] == 'idots')
 {
 	if ($GLOBALS['egw_info']['server']['force_default_app'] && $GLOBALS['egw_info']['server']['force_default_app'] != 'user_choice')
 	{
@@ -105,11 +117,11 @@ if($app == 'home' && !$class && !$api_requested && !($windowed && $_GET['cd'] ==
 	}
 	if($GLOBALS['egw_info']['user']['preferences']['common']['default_app'] && !$hasupdates)
 	{
-		egw::redirect(egw_framework::index($GLOBALS['egw_info']['user']['preferences']['common']['default_app']),$GLOBALS['egw_info']['user']['preferences']['common']['default_app']);
+		Egw::redirect(Framework::index($GLOBALS['egw_info']['user']['preferences']['common']['default_app']),$GLOBALS['egw_info']['user']['preferences']['common']['default_app']);
 	}
 	else
 	{
-		egw::redirect_link('/home/index.php?cd=yes');
+		Egw::redirect_link('/home/index.php?cd=yes');
 	}
 }
 
@@ -120,8 +132,8 @@ if($windowed && $_GET['cd'] == 'yes')
 		'nonavbar'   => False,
 		'currentapp' => 'eGroupWare'
 	);
-	common::egw_header();
-	common::egw_footer();
+	echo $GLOBALS['egw']->framework->header();
+	echo $GLOBALS['egw']->framework->footer();
 }
 else
 {
@@ -130,7 +142,14 @@ else
 		$app = 'phpgwapi';
 	}
 
-	$obj = CreateObject($app.'.'.$class);
+	if (class_exists($class))
+	{
+		$obj = new $class;
+	}
+	else
+	{
+		$obj = CreateObject($app.'.'.$class);
+	}
 	if((is_array($obj->public_functions) && $obj->public_functions[$method]) && !$invalid_data)
 	{
 		$obj->$method();
@@ -177,6 +196,6 @@ else
 
 	if(!isset($GLOBALS['egw_info']['nofooter']))
 	{
-		common::egw_footer();
+		echo $GLOBALS['egw']->framework->footer();
 	}
 }
