@@ -1,23 +1,26 @@
 <?php
 /**
- * EGroupware: GroupDAV access: infolog handler
+ * EGroupware: CalDAV/CardDAV/GroupDAV access: InfoLog handler
  *
  * @link http://www.egroupware.org
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package infolog
- * @subpackage groupdav
+ * @subpackage caldav
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2007-15 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Acl;
+
 /**
- * EGroupware: GroupDAV access: infolog handler
+ * EGroupware: CalDAV access: infolog handler
  *
- * Permanent error_log() calls should use $this->groupdav->log($str) instead, to be send to PHP error_log()
+ * Permanent error_log() calls should use $this->caldav->log($str) instead, to be send to PHP error_log()
  * and our request-log (prefixed with "### " after request and response, like exceptions).
  */
-class infolog_groupdav extends groupdav_handler
+class infolog_groupdav extends Api\CalDAV\Handler
 {
 	/**
 	 * bo class of the application
@@ -49,7 +52,7 @@ class infolog_groupdav extends groupdav_handler
 	/**
 	 * Are we using info_id, info_uid or caldav_name for the path/url
 	 *
-	 * Get's set in constructor to 'caldav_name' and groupdav_handler::$path_extension = ''!
+	 * Get's set in constructor to 'caldav_name' and self::$path_extension = ''!
 	 */
 	static $path_attr = 'info_id';
 
@@ -57,11 +60,11 @@ class infolog_groupdav extends groupdav_handler
 	 * Constructor
 	 *
 	 * @param string $app 'calendar', 'addressbook' or 'infolog'
-	 * @param groupdav $groupdav calling class
+	 * @param Api\CalDAV $caldav calling class
 	 */
-	function __construct($app, groupdav $groupdav)
+	function __construct($app, Api\CalDAV $caldav)
 	{
-		parent::__construct($app, $groupdav);
+		parent::__construct($app, $caldav);
 
 		$this->bo = new infolog_bo();
 		$this->vCalendar = new Horde_Icalendar;
@@ -70,7 +73,7 @@ class infolog_groupdav extends groupdav_handler
 		if (version_compare($GLOBALS['egw_info']['apps']['calendar']['version'], '1.9.002', '>='))
 		{
 			self::$path_attr = 'caldav_name';
-			groupdav_handler::$path_extension = '';
+			self::$path_extension = '';
 		}
 	}
 
@@ -91,7 +94,7 @@ class infolog_groupdav extends groupdav_handler
 			if (!is_array($info)) $info = $this->bo->read($info);
 			$name = $info[self::$path_attr];
 		}
-		return $name.groupdav_handler::$path_extension;
+		return $name.self::$path_extension;
 	}
 
 	/**
@@ -146,6 +149,7 @@ class infolog_groupdav extends groupdav_handler
 		$filter = $this->get_infolog_filter($path, $user);
 
 		// process REPORT filters or multiget href's
+		$nresults = null;
 		if (($id || $options['root']['name'] != 'propfind') && !$this->_report_filters($options, $filter, $id, $nresults))
 		{
 			// return empty collection, as iCal under iOS 5 had problems with returning "404 Not found" status
@@ -165,7 +169,7 @@ class infolog_groupdav extends groupdav_handler
 
 		// check if we have to return the full calendar data or just the etag's
 		if (!($filter['calendar_data'] = $options['props'] == 'all' &&
-			$options['root']['ns'] == groupdav::CALDAV) && is_array($options['props']))
+			$options['root']['ns'] == Api\CalDAV::CALDAV) && is_array($options['props']))
 		{
 			foreach($options['props'] as $prop)
 			{
@@ -207,7 +211,7 @@ class infolog_groupdav extends groupdav_handler
 		else
 		{
 			// return iterator, calling ourself to return result in chunks
-			$files['files'] = new groupdav_propfind_iterator($this,$path,$filter,$files['files']);
+			$files['files'] = new Api\CalDAV\PropfindIterator($this,$path,$filter,$files['files']);
 		}
 		return true;
 	}
@@ -217,7 +221,7 @@ class infolog_groupdav extends groupdav_handler
 	 *
 	 * @param string $path
 	 * @param array $filter
-	 * @param array|boolean $start=false false=return all or array(start,num)
+	 * @param array|boolean $start =false false=return all or array(start,num)
 	 * @return array with "files" array with values for keys path and props
 	 */
 	function &propfind_callback($path,array $filter,$start=false)
@@ -234,6 +238,7 @@ class infolog_groupdav extends groupdav_handler
 
 		$order = 'info_datemodified';
 		$sort = 'DESC';
+		$matches = null;
 		if (preg_match('/^([a-z0-9_]+)( DESC| ASC)?$/i', $filter['order'], $matches))
 		{
 			$order = $matches[1];
@@ -293,7 +298,7 @@ class infolog_groupdav extends groupdav_handler
 				{
 					$content = $handler->exportVTODO($task, '2.0', null);	// no METHOD:PUBLISH for CalDAV
 					$props['getcontentlength'] = bytes($content);
-					$props[] = HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'calendar-data',$content);
+					$props[] = Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'calendar-data',$content);
 				}
 				$files[] = $this->add_resource($path, $task, $props);
 			}
@@ -315,7 +320,7 @@ class infolog_groupdav extends groupdav_handler
 			// hack to support limit with sync-collection report: tasks are returned in modified ASC order (oldest first)
 			// if limit is smaller then full result, return modified-1 as sync-token, so client requests next chunk incl. modified
 			// (which might contain further entries with identical modification time)
-			if ($start[0] == 0 && $start[1] != groupdav_propfind_iterator::CHUNK_SIZE && $this->bo->total > $start[1])
+			if ($start[0] == 0 && $start[1] != Api\CalDAV\PropfindIterator::CHUNK_SIZE && $this->bo->total > $start[1])
 			{
 				--$this->sync_collection_token;
 			}
@@ -337,8 +342,6 @@ class infolog_groupdav extends groupdav_handler
 	{
 		if ($options['filters'])
 		{
-			$cal_filters_in = $cal_filters;	// remember filter, to be able to reset standard open-filter, if client sets own filters
-
 			foreach($options['filters'] as $filter)
 			{
 				switch($filter['name'])
@@ -414,11 +417,11 @@ class infolog_groupdav extends groupdav_handler
 				case 'sync-level':
 					if ($option['data'] != '1')
 					{
-						$this->groupdav->log(__METHOD__."(...) only sync-level {$option['data']} requested, but only 1 supported! options[other]=".array2string($options['other']));
+						$this->caldav->log(__METHOD__."(...) only sync-level {$option['data']} requested, but only 1 supported! options[other]=".array2string($options['other']));
 					}
 					break;
 				default:
-					$this->groupdav->log(__METHOD__."(...) unknown xml tag '{$option['name']}': options[other]=".array2string($options['other']));
+					$this->caldav->log(__METHOD__."(...) unknown xml tag '{$option['name']}': options[other]=".array2string($options['other']));
 					break;
 			}
 		}
@@ -429,8 +432,8 @@ class infolog_groupdav extends groupdav_handler
 			$ids = array();
 			if ($id)
 			{
-				$cal_filters[self::$path_attr] = groupdav_handler::$path_extension ?
-					basename($id,groupdav_handler::$path_extension) : $id;
+				$cal_filters[self::$path_attr] = self::$path_extension ?
+					basename($id,self::$path_extension) : $id;
 			}
 			else	// fetch all given url's
 			{
@@ -441,8 +444,8 @@ class infolog_groupdav extends groupdav_handler
 						$parts = explode('/',$option['data']);
 						if (($id = basename(urldecode(array_pop($parts)))))
 						{
-							$cal_filters[self::$path_attr][] = groupdav_handler::$path_extension ?
-								basename($id,groupdav_handler::$path_extension) : $id;
+							$cal_filters[self::$path_attr][] = self::$path_extension ?
+								basename($id,self::$path_extension) : $id;
 						}
 					}
 				}
@@ -474,7 +477,7 @@ class infolog_groupdav extends groupdav_handler
 		}
 		elseif (empty($attrs['start']))
 		{
-			$this->groupdav->log(__METHOD__.'('.array2string($attrs).') minimum one of start or end is required!');
+			$this->caldav->log(__METHOD__.'('.array2string($attrs).') minimum one of start or end is required!');
 			return '1';	// to not give sql error, but simply not filter out anything
 		}
 		// we dont need to care for DURATION line in rfc4791#section-9.9, as we always put that in DUE/info_enddate
@@ -508,7 +511,7 @@ class infolog_groupdav extends groupdav_handler
  			"NOT info_datecompleted > 0". (isset($end) ? " AND info_created < $end" : '').
 		')';
 		$sql = '('.implode(' OR ', $to_or).')';
-		if ($this->debug > 1) error_log(__FILE__ . __METHOD__.'('.array2string($attrs).") time-range={$filter['attrs']['start']}-{$filter['attrs']['end']} --> $sql");
+		if ($this->debug > 1) error_log(__FILE__ . __METHOD__.'('.array2string($attrs).") time-range=$attrs[start]-$attrs[end] --> $sql");
 		return $sql;
 	}
 
@@ -517,11 +520,13 @@ class infolog_groupdav extends groupdav_handler
 	 *
 	 * @param array &$options
 	 * @param int $id
-	 * @param int $user=null account_id
+	 * @param int $user =null account_id
 	 * @return mixed boolean true on success, false on failure or string with http status (eg. '404 Not Found')
 	 */
 	function get(&$options,$id,$user=null)
 	{
+		unset($user);	// not used, but required by function signature
+
 		if (!is_array($task = $this->_common_get_put_delete('GET',$options,$id)))
 		{
 			return $task;
@@ -539,12 +544,14 @@ class infolog_groupdav extends groupdav_handler
 	 *
 	 * @param array &$options
 	 * @param int $id
-	 * @param int $user=null account_id of owner, default null
-	 * @param string $prefix=null user prefix from path (eg. /ralf from /ralf/addressbook)
+	 * @param int $user =null account_id of owner, default null
+	 * @param string $prefix =null user prefix from path (eg. /ralf from /ralf/addressbook)
 	 * @return mixed boolean true on success, false on failure or string with http status (eg. '404 Not Found')
 	 */
 	function put(&$options,$id,$user=null,$prefix=null)
 	{
+		unset($prefix);	// not used, but required by function signature
+
 		if ($this->debug) error_log(__METHOD__."($id, $user)".print_r($options,true));
 
 		$oldTask = $this->_common_get_put_delete('PUT',$options,$id);
@@ -584,9 +591,9 @@ class infolog_groupdav extends groupdav_handler
 
 		// send evtl. necessary respose headers: Location, etag, ...
 		// but only for new entries, as X-INFOLOG-STATUS get's not updated on client, if we confirm with an etag
-		if ($retval !== true && (!$path_attr_is_name ||
+		if ($retval !== true)
 			// POST with add-member query parameter
-			$_SERVER['REQUEST_METHOD'] == 'POST' && isset($_GET['add-member'])))
+			//$_SERVER['REQUEST_METHOD'] == 'POST' && isset($_GET['add-member'])))
 		{
 			$this->put_response_headers($infoId, $options['path'], $retval, self::$path_attr == 'caldav_name');
 		}
@@ -609,7 +616,7 @@ class infolog_groupdav extends groupdav_handler
 	 * Callback for infolog_ical::importVTODO to implement infolog-cat-action
 	 *
 	 * @param array $task
-	 * @param array $oldTask=null
+	 * @param array $oldTask =null
 	 * @return array modified task data
 	 */
 	public function cat_action(array $task, $oldTask=null)
@@ -617,7 +624,7 @@ class infolog_groupdav extends groupdav_handler
 		$action = $GLOBALS['egw_info']['user']['preferences']['groupdav']['infolog-cat-action'];
 
 		//error_log(__METHOD__.'('.array2string($task).', '.array2string($oldTask).") action=$action");
-		if ($task['info_cat'] && ($new_cat = categories::id2name($task['info_cat'])) &&
+		if ($task['info_cat'] && ($new_cat = Api\Categories::id2name($task['info_cat'])) &&
 			strpos($new_cat, '@') !== false)
 		{
 			$new_user = $GLOBALS['egw']->accounts->name2id($new_cat, 'account_email');
@@ -627,17 +634,19 @@ class infolog_groupdav extends groupdav_handler
 		if ($new_user)
 		{
 			// make sure category is global, as otherwise it will not be transmitted to other users
-			if (!categories::is_global($task['info_cat']))
+			if (!Api\Categories::is_global($task['info_cat']))
 			{
-				$cat_obj = new categories(categories::GLOBAL_ACCOUNT, 'infolog');
-				$cat = categories::read($task['info_cat']);
-				$cat['owner'] = categories::GLOBAL_ACCOUNT;
-				$cat['access'] = 'public';
-				$cat_obj->edit($cat);
+				$cat_obj = new Api\Categories(Api\Categories::GLOBAL_ACCOUNT, 'infolog');
+				if (($cat = Api\Categories::read($task['info_cat'])))
+				{
+					$cat['owner'] = Api\Categories::GLOBAL_ACCOUNT;
+					$cat['access'] = 'public';
+					$cat_obj->edit($cat);
+				}
 			}
 			// if replace, remove user of old category from responsible
 			if ($action == 'replace' && $oldTask && $oldTask['info_cat'] &&
-				($old_cat = categories::id2name($oldTask['info_cat'])) && strpos($old_cat, '@') !== false &&
+				($old_cat = Api\Categories::id2name($oldTask['info_cat'])) && strpos($old_cat, '@') !== false &&
 				($old_user = $GLOBALS['egw']->accounts->name2id($old_cat, 'account_email')) &&
 				($key = array_search($old_user, (array)$task['info_responsible'])) !== false)
 			{
@@ -716,7 +725,7 @@ class infolog_groupdav extends groupdav_handler
 	/**
 	 * Check if user has the neccessary rights on a task / infolog entry
 	 *
-	 * @param int $acl EGW_ACL_READ, EGW_ACL_EDIT or EGW_ACL_DELETE
+	 * @param int $acl Acl::READ, Acl::EDIT or Acl::DELETE
 	 * @param array|int $task task-array or id
 	 * @return boolean null if entry does not exist, false if no access, true if access permitted
 	 */
@@ -726,7 +735,7 @@ class infolog_groupdav extends groupdav_handler
 
 		$access = $this->bo->check_access($task,$acl);
 
-		if (!$access && $acl == EGW_ACL_EDIT && $this->bo->is_responsible($task))
+		if (!$access && $acl == Acl::EDIT && $this->bo->is_responsible($task))
 		{
 			$access = true;	// access limited to $this->bo->responsible_edit fields (handled in infolog_bo::write())
 		}
@@ -768,43 +777,45 @@ class infolog_groupdav extends groupdav_handler
 	/**
 	 * Add extra properties for calendar collections
 	 *
-	 * @param array $props=array() regular props by the groupdav handler
+	 * @param array $props =array() regular props by the Api\CalDAV handler
 	 * @param string $displayname
-	 * @param string $base_uri=null base url of handler
-	 * @param int $user=null account_id of owner of collection
+	 * @param string $base_uri =null base url of handler
+	 * @param int $user =null account_id of owner of collection
 	 * @return array
 	 */
-	public function extra_properties(array $props=array(), $displayname, $base_uri=null,$user=null)
+	public function extra_properties(array $props, $displayname, $base_uri=null,$user=null)
 	{
+		unset($base_uri);	// not used, but required by function signature
+
 		// calendar description
-		$displayname = translation::convert(lang('Tasks of'),translation::charset(),'utf-8').' '.$displayname;
-		$props['calendar-description'] = HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'calendar-description',$displayname);
+		$displayname = Api\Translation::convert(lang('Tasks of'),Api\Translation::charset(),'utf-8').' '.$displayname;
+		$props['calendar-description'] = Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'calendar-description',$displayname);
 		// supported components, currently only VEVENT
-		$props['supported-calendar-component-set'] = HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'supported-calendar-component-set',array(
-			HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'comp',array('name' => 'VCALENDAR')),
-			HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'comp',array('name' => 'VTODO')),
+		$props['supported-calendar-component-set'] = Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'supported-calendar-component-set',array(
+			Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'comp',array('name' => 'VCALENDAR')),
+			Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'comp',array('name' => 'VTODO')),
 		));
 		// supported reports
 		$props['supported-report-set'] = array(
-			'calendar-query' => HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'calendar-query',''))))),
-			'calendar-multiget' => HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'calendar-multiget',''))))),
+			'calendar-query' => Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'calendar-query',''))))),
+			'calendar-multiget' => Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'calendar-multiget',''))))),
 		);
 		// only advertice rfc 6578 sync-collection report, if "delete-prevention" is switched on (deleted entries get marked deleted but not actualy deleted
-		$config = config::read('infolog');
+		$config = Api\Config::read('infolog');
 		if ($config['history'])
 		{
-			$props['supported-report-set']['sync-collection'] = HTTP_WebDAV_Server::mkprop('supported-report',array(
-				HTTP_WebDAV_Server::mkprop('report',array(
-					HTTP_WebDAV_Server::mkprop('sync-collection','')))));
+			$props['supported-report-set']['sync-collection'] = Api\CalDAV::mkprop('supported-report',array(
+				Api\CalDAV::mkprop('report',array(
+					Api\CalDAV::mkprop('sync-collection','')))));
 		}
 		// get timezone of calendar
-		if ($this->groupdav->prop_requested('calendar-timezone'))
+		if ($this->caldav->prop_requested('calendar-timezone'))
 		{
-			$props['calendar-timezone'] = HTTP_WebDAV_Server::mkprop(groupdav::CALDAV,'calendar-timezone',
+			$props['calendar-timezone'] = Api\CalDAV::mkprop(Api\CalDAV::CALDAV,'calendar-timezone',
 				calendar_timezones::user_timezone($user));
 		}
 		return $props;
@@ -834,7 +845,7 @@ class infolog_groupdav extends groupdav_handler
 	{
 		if (!isset($hook_data['setup']))
 		{
-			translation::add_app('infolog');
+			Api\Translation::add_app('infolog');
 			$infolog = new infolog_bo();
 			$types = $infolog->enums['type'];
 		}
