@@ -11,6 +11,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Acl;
+
 /**
  * InfoLog: Create and parse iCal's
  */
@@ -178,8 +181,8 @@ class infolog_ical extends infolog_bo
 			$taskData['info_cat'] = $cats[0];
 		}
 
-		$taskData = translation::convert($taskData,
-			translation::charset(), $charset);
+		$taskData = Api\Translation::convert($taskData,
+			Api\Translation::charset(), $charset);
 
 		if ($this->log)
 		{
@@ -199,8 +202,8 @@ class infolog_ical extends infolog_bo
 			// check if we have vtimezone component data for tzid of event, if not default to user timezone (default to server tz)
 			if (!calendar_timezones::add_vtimezone($vcal, $tzid))
 			{
-				error_log(__METHOD__."() unknown TZID='$tzid', defaulting to user timezone '".egw_time::$user_timezone->getName()."'!");
-				calendar_timezones::add_vtimezone($vcal, egw_time::$user_timezone->getName());
+				error_log(__METHOD__."() unknown TZID='$tzid', defaulting to user timezone '".Api\DateTime::$user_timezone->getName()."'!");
+				calendar_timezones::add_vtimezone($vcal, Api\DateTime::$user_timezone->getName());
 				$tzid = null;
 			}
 			if (!isset(self::$tz_cache[$tzid]))
@@ -312,7 +315,8 @@ class infolog_ical extends infolog_bo
 			$vevent->setAttribute($field, $value, $options);
 		}
 
-		if ($taskData['info_startdate'])
+		// only export startdate < duedate, as some clients (eg. CalDAV Sync for Android) have problems with that
+		if ($taskData['info_startdate'] && (empty($taskData['info_enddate']) || $taskData['info_startdate'] <= $taskData['info_enddate']))
 		{
 			self::setDateOrTime($vevent, 'DTSTART', $taskData['info_startdate'], $tzid);
 		}
@@ -326,10 +330,8 @@ class infolog_ical extends infolog_bo
 		}
 
 		$vevent->setAttribute('DTSTAMP',time());
-		$vevent->setAttribute('CREATED', $taskData['info_created'] ? $taskData['info_created'] :
-			$GLOBALS['egw']->contenthistory->getTSforAction('infolog_task',$taskData['info_id'],'add'));
-		$vevent->setAttribute('LAST-MODIFIED', $taskData['info_datemodified'] ? $taskData['info_datemodified'] :
-			$GLOBALS['egw']->contenthistory->getTSforAction('infolog_task',$taskData['info_id'],'modify'));
+		$vevent->setAttribute('CREATED', $taskData['info_created']);
+		$vevent->setAttribute('LAST-MODIFIED', $taskData['info_datemodified']);
 		$vevent->setAttribute('CLASS',$taskData['info_access'] == 'public' ? 'PUBLIC' : 'PRIVATE');
 		$vevent->setAttribute('STATUS',$this->status2vtodo($taskData['info_status']));
 		// we try to preserv the original infolog status as X-INFOLOG-STATUS, so we can restore it, if the user does not modify STATUS
@@ -358,7 +360,7 @@ class infolog_ical extends infolog_bo
 			}
 			else
 			{
-				$url = 'urn:uuid:'.common::generate_uid('accounts', $taskData['info_owner']);
+				$url = 'urn:uuid:'.Api\CalDAV::generate_uid('accounts', $taskData['info_owner']);
 			}
 			$vevent->setAttribute('ORGANIZER',$url,array(
 				'CN'		=>	$GLOBALS['egw']->accounts->id2name($taskData['info_owner'],'account_fullname'),
@@ -372,7 +374,7 @@ class infolog_ical extends infolog_bo
 				}
 				else
 				{
-					$url = 'urn:uuid:'.common::generate_uid('accounts', $responsible);
+					$url = 'urn:uuid:'.Api\CalDAV::generate_uid('accounts', $responsible);
 				}
 				if ($responsible > 0)
 				{
@@ -457,22 +459,22 @@ class infolog_ical extends infolog_bo
 		}
 		elseif(is_null($tzid))
 		{
-			$tz = egw_time::$user_timezone;
+			$tz = Api\DateTime::$user_timezone;
 		}
 		else
 		{
-			$tz = egw_time::$server_timezone;
+			$tz = Api\DateTime::$server_timezone;
 		}
 		if (!is_a($time,'DateTime'))
 		{
-			$time = new egw_time($time,egw_time::$server_timezone);
+			$time = new Api\DateTime($time,Api\DateTime::$server_timezone);
 		}
 		$time->setTimezone($tz);
 
 		// check for date --> export it as such
 		if ($time->format('Hi') == '0000')
 		{
-			$arr = egw_time::to($time, 'array');
+			$arr = Api\DateTime::to($time, 'array');
 			$value = array(
 				'year'  => $arr['year'],
 				'month' => $arr['month'],
@@ -493,7 +495,7 @@ class infolog_ical extends infolog_bo
 			}
 			else
 			{
-				$value = egw_time::to($time, 'ts');
+				$value = Api\DateTime::to($time, 'ts');
 			}
 		}
 		//error_log(__METHOD__."(, '$attr', ".array2string($time_in).', '.array2string($tzid).') tz='.$tz->getName().', value='.array2string($value).(is_int($value)?date('Y-m-d H:i:s',$value):''));
@@ -542,7 +544,7 @@ class infolog_ical extends infolog_bo
 		// setting owner or responsible for new tasks based on folder
 		if (!is_null($user) && $_taskID == -1)
 		{
-			if ($this->check_access($taskData, EGW_ACL_ADD))
+			if ($this->check_access($taskData, Acl::ADD))
 			{
 				$taskData['info_owner'] = $user;
 			}
@@ -632,7 +634,7 @@ class infolog_ical extends infolog_bo
 	 */
 	protected static function date2ts($date)
 	{
-		return is_scalar($date) ? $date : egw_time::to($date, 'ts');
+		return is_scalar($date) ? $date : Api\DateTime::to($date, 'ts');
 	}
 
 	/**
@@ -656,7 +658,7 @@ class infolog_ical extends infolog_bo
 		$vcal = new Horde_Icalendar;
 		if ($charset && $charset != 'utf-8')
 		{
-			$_vcalData = translation::convert($_vcalData, $charset, 'utf-8');
+			$_vcalData = Api\Translation::convert($_vcalData, $charset, 'utf-8');
 		}
 		if (!($vcal->parsevCalendar($_vcalData, 'VCALENDAR')))
 		{
@@ -849,14 +851,14 @@ class infolog_ical extends infolog_bo
 						break;
 
 					case 'ATTENDEE':
-						if (($uid = groupdav_principals::url2uid($attribute['value'])) && is_numeric($uid))
+						if (($uid = Api\CalDAV\Principals::url2uid($attribute['value'])) && is_numeric($uid))
 						{
 							$taskData['info_responsible'][] = $uid;
 						}
 						break;
 
 					case 'ORGANIZER':
-						if (($uid = groupdav_principals::url2uid($attribute['value'])) && is_numeric($uid))
+						if (($uid = Api\CalDAV\Principals::url2uid($attribute['value'])) && is_numeric($uid))
 						{
 							$taskData['info_owner'] = $uid;
 						}
@@ -922,8 +924,8 @@ class infolog_ical extends infolog_bo
 	{
 		if(!($note = $this->read($_noteID, true, 'server'))) return false;
 
-		$note = translation::convert($note,
-			translation::charset(), $charset);
+		$note = Api\Translation::convert($note,
+			Api\Translation::charset(), $charset);
 
 		switch	($_type)
 		{
@@ -935,8 +937,8 @@ class infolog_ical extends infolog_bo
 				if (!empty($note['info_cat']))
 				{
 					$cats = $this->get_categories(array($note['info_cat']));
-					$note['info_cat'] = translation::convert($cats[0],
-						translation::charset(), $charset);
+					$note['info_cat'] = Api\Translation::convert($cats[0],
+						Api\Translation::charset(), $charset);
 				}
 				$vnote = new Horde_Icalendar_Vnote();
 				$vnote->setAttribute('PRODID','-//EGroupware//NONSGML EGroupware InfoLog '.$GLOBALS['egw_info']['apps']['infolog']['version'].'//'.
@@ -1084,7 +1086,7 @@ class infolog_ical extends infolog_bo
 			case 'text/plain':
 				$note = array();
 				$note['info_type'] = 'note';
-				$txt = str_replace("\r\n", "\n", translation::convert($_data, $charset));
+				$txt = str_replace("\r\n", "\n", Api\Translation::convert($_data, $charset));
 
 				$match = null;
 				if (preg_match('/([^\n]+)\n\n(.*)/ms', $txt, $match))
@@ -1102,7 +1104,7 @@ class infolog_ical extends infolog_bo
 				$vnote = new Horde_Icalendar;
 				if ($charset && $charset != 'utf-8')
 				{
-					$_data = translation::convert($_data, $charset, 'utf-8');
+					$_data = Api\Translation::convert($_data, $charset, 'utf-8');
 				}
 				if (!$vnote->parsevCalendar($_data, 'VCALENDAR'))	return false;
 
@@ -1208,13 +1210,13 @@ class infolog_ical extends infolog_bo
 			error_log(__FILE__.'['.__LINE__.'] '.__METHOD__.
 				'(' . $this->productManufacturer .
 				', '. $this->productName .', ' .
-				($this->tzid ? $this->tzid : egw_time::$user_timezone->getName()) .
+				($this->tzid ? $this->tzid : Api\DateTime::$user_timezone->getName()) .
 				")\n" , 3, $this->logfile);
 		}
 
 		//Horde::logMessage('setSupportedFields(' . $this->productManufacturer . ', '
 		//	. $this->productName .', ' .
-		//	($this->tzid ? $this->tzid : egw_time::$user_timezone->getName()) .')',
+		//	($this->tzid ? $this->tzid : Api\DateTime::$user_timezone->getName()) .')',
 		//	__FILE__, __LINE__, PEAR_LOG_DEBUG);
 	}
 }
