@@ -60,11 +60,44 @@ app.classes.infolog = AppJS.extend(
 				var filter2 = nm.getWidgetById('filter2');
 				this.show_details(filter2.value == 'all',nm.getDOMNode(nm));
 				// Remove the rule added by show_details() if the template is removed
-				$j(_et2.DOMContainer).on('clear', function() {egw.css('#infolog-index_nm .et2_box.infoDes');});
+				jQuery(_et2.DOMContainer).on('clear', function() {egw.css('#infolog-index_nm .et2_box.infoDes');});
+
+				// Enable decrypt on hover
+				if(this.egw.user('apps').stylite)
+				{
+					this._get_stylite(function() {this.mailvelopeAvailable(function() {app.stylite.decrypt_hover(nm);});});
+				}
 				break;
 			case 'infolog.edit.print':
-				// Trigger print command if the infolog oppend for printing porpuse
-				this.infolog_print_preview_onload();
+				if (this.et2.getArrayMgr('content').data.info_des.indexOf(this.begin_pgp_message) != -1)
+				{
+					this.mailvelopeAvailable(this.printEncrypt);
+				}
+				else
+				{
+					// Trigger print command if the infolog oppend for printing purpose
+					this.infolog_print_preview_onload();
+				}
+				break;
+			case 'infolog.edit':
+				if (this.et2.getArrayMgr('content').data.info_des &&
+					this.et2.getArrayMgr('content').data.info_des.indexOf(this.begin_pgp_message) != -1)
+				{
+					this._get_stylite(jQuery.proxy(function() {this.mailvelopeAvailable(jQuery.proxy(function() {
+						this.toggleEncrypt();
+
+						// Decrypt history on hover
+						var history = this.et2.getWidgetById('history');
+						app.stylite.decrypt_hover(history,'span');
+						jQuery(history.getDOMNode(history))
+							.tooltip('option','position',{my:'top left', at: 'top left', of: history.getDOMNode(history)});
+
+					},this));},this));
+					// This disables the diff in history
+					var history = this.et2.getArrayMgr('content').getEntry('history');
+					history['status-widgets'].De = 'description';
+				}
+				break;
 		}
 	},
 
@@ -107,22 +140,6 @@ app.classes.infolog = AppJS.extend(
 		{
 			this.et2._inst.refresh(_msg, _app, _id, _type);
 		}
-		// Refresh handler for infologs integrated in calendar
-		if (_app == 'infolog' && _id && _type != 'delete')
-		{
-			var info_type = egw.dataGetUIDdata(_app+"::"+_id)?egw.dataGetUIDdata(_app+"::"+_id).data.info_type:false;
-			var cal_show = egw.preference('cal_show','infolog')||false;
-
-			if (info_type && cal_show)
-			{
-				var rex = RegExp(info_type,'gi');
-				if (cal_show.match(rex))
-				{
-					//Trigger refresh the whole calendar if the changed infolog entry is integrated one
-					if (typeof app['calendar'] != 'undefined') app.calendar.egw.window.location.reload();
-				}
-			}
-		}
 	},
 
 	/**
@@ -137,14 +154,13 @@ app.classes.infolog = AppJS.extend(
 	{
 		// call parent
 		var state = this._super.apply(this, arguments);
-
 		var nm = {};
 
 		// Get index etemplate
 		var et2 = etemplate2.getById('infolog-index');
 		if(et2)
 		{
-			var content = this.et2.getArrayMgr('content');
+			var content = et2.widgetContainer.getArrayMgr('content');
 			nm = content && content.data && content.data.nm ? content.data.nm: {};
 		}
 
@@ -198,6 +214,7 @@ app.classes.infolog = AppJS.extend(
 					if (filter && dates)
 					{
 						dates.set_disabled(false);
+						jQuery(this.et2.getWidgetById('startdate').getDOMNode()).find('input').focus();
 					}
 					break;
 				default:
@@ -239,7 +256,7 @@ app.classes.infolog = AppJS.extend(
 
 			// Load new preferences
 			var colData = nm.columns.slice();
-			for(var i = 0; i < nm.columns.length; i++) colData[i].disabled=false;
+			for(var i = 0; i < nm.columns.length; i++) colData[i].visible=false;
 
 			nm.set_columns(egw.preference(nm.options.settings.columnselection_pref,'infolog').split(','));
 			nm._applyUserPreferences(nm.columns, colData);
@@ -248,9 +265,9 @@ app.classes.infolog = AppJS.extend(
 			for(var i = 0; i < colData.length; i++)
 			{
 				nm.dataview.getColumnMgr().columns[i].set_width(colData[i].width);
-				nm.dataview.getColumnMgr().columns[i].set_visibility(!colData[i].disabled);
+				nm.dataview.getColumnMgr().columns[i].set_visibility(colData[i].visible);
 			}
-			nm.dataview.getColumnMgr().updated = true;			
+			nm.dataview.getColumnMgr().updated = true;
 			// Update page
 			nm.dataview.updateColumns();
 		}
@@ -266,6 +283,11 @@ app.classes.infolog = AppJS.extend(
 	{
 		// Show / hide descriptions
         egw.css((dom_node && dom_node.id ? "#"+dom_node.id+' ' : '') + ".et2_box.infoDes","display:" + (show ? "block;" : "none;"));
+		if (egwIsMobile())
+		{
+			var $select = jQuery('.infoDetails');
+			(show)? $select.each(function(i,e){jQuery(e).hide();}): $select.each(function(i,e){jQuery(e).show();});
+		}
 	},
 
 	confirm_delete_2: function (_action, _senders)
@@ -276,7 +298,7 @@ app.classes.infolog = AppJS.extend(
 		{
 			for(var i = 0; i < _senders.length; i++)
 			{
-				if ($j(_senders[i].iface.node).hasClass('infolog_rowHasSubs'))
+				if (jQuery(_senders[i].iface.node).hasClass('infolog_rowHasSubs'))
 				{
 					children = true;
 					break;
@@ -291,7 +313,7 @@ app.classes.infolog = AppJS.extend(
 
 			}
 		};
-		var confirmDeleteDialog = et2_dialog.show_dialog(callbackDeleteDialog, this.egw.lang("Do you really want to DELETE this Rule"),this.egw.lang("Delete"), {},et2_dialog.BUTTONS_YES_NO_CANCEL, et2_dialog.WARNING_MESSAGE);
+		et2_dialog.show_dialog(callbackDeleteDialog, this.egw.lang("Do you really want to DELETE this Rule"),this.egw.lang("Delete"), {},et2_dialog.BUTTONS_YES_NO_CANCEL, et2_dialog.WARNING_MESSAGE);
 	},
 
 	/**
@@ -309,7 +331,7 @@ app.classes.infolog = AppJS.extend(
 		{
 			for(var i = 0; i < _senders.length; i++)
 			{
-				if ($j(_senders[i].iface.getDOMNode()).hasClass('infolog_rowHasSubs'))
+				if (jQuery(_senders[i].iface.getDOMNode()).hasClass('infolog_rowHasSubs'))
 				{
 					children = true;
 					break;
@@ -400,7 +422,7 @@ app.classes.infolog = AppJS.extend(
 				if (completed != (status.value == 'done' || status.value == 'billed') ||
 					(status.value == 'not-started') != (percent.value == 0))
 				{
-					status.value = percent.value == 0 ? ($j('[value="not-started"]',status).length ? 'not-started':'ongoing') : (percent.value == 100 ? 'done' : 'ongoing');
+					status.value = percent.value == 0 ? (jQuery('[value="not-started"]',status).length ? 'not-started':'ongoing') : (percent.value == 100 ? 'done' : 'ongoing');
 				}
 				break;
 
@@ -512,11 +534,11 @@ app.classes.infolog = AppJS.extend(
 	},
 
 	/**
-	 * Wrapper so add -> New actions in the context menu can pass current 
+	 * Wrapper so add -> New actions in the context menu can pass current
 	 * filter values into new edit dialog
-	 * 
+	 *
 	 * @see add_with_extras
-	 * 
+	 *
 	 * @param {egwAction} action
 	 * @param {egwActionObject[]} selected
 	 */
@@ -570,7 +592,7 @@ app.classes.infolog = AppJS.extend(
 			}
 		}
 		var extras = {
-			type: _type || nm_value.filter || "",
+			type: _type || nm_value.col_filter.info_type || "task",
 			cat_id: nm_value.cat_id || "",
 			action: nm_value.action || _action || "",
 			// egw_link can handle arrays, but server is expecting CSV
@@ -633,5 +655,215 @@ app.classes.infolog = AppJS.extend(
 	submit_if_not_empty: function(_node, _widget)
 	{
 		if (_widget.get_value()) this.et2._inst.submit();
+	},
+
+	/**
+	 * Insert text at the cursor position (or end) of a text field
+	 *
+	 * @param {et2_inputWidget|string} widget Either a widget object or it's ID
+	 * @param {string} text [text=timestamp username] Text to insert
+	 */
+	insert_text: function(widget, text)
+	{
+		if(typeof widget == 'string')
+		{
+			et2 = etemplate2.getById('infolog-edit');
+			if(et2)
+			{
+				widget = et2.widgetContainer.getWidgetById(widget);
+			}
+		}
+		if(!widget || !widget.input)
+		{
+			return;
+		}
+
+		if(!text)
+		{
+			var now = new Date();
+			text = date(egw.preference('dateformat') + ' ' + (egw.preference("timeformat") === "12" ? "h:ia" : "H:i")+' ',now);
+
+			// Get properly formatted user name
+			var user = parseInt(egw.user('account_id'));
+			var accounts = egw.accounts('accounts');
+			for(var j = 0; j < accounts.length; j++)
+			{
+				if(accounts[j].value === user)
+				{
+					text += accounts[j].label;
+					break;
+				}
+			}
+			text += ': ';
+		}
+
+		var input = widget.input[0];
+		var scrollPos = input.scrollTop;
+		var browser = ((input.selectionStart || input.selectionStart == "0") ?
+			"standards" : (document.selection ? "ie" : false ) );
+
+		var pos = 0;
+
+		// Find cursor or selection
+		if (browser == "ie")
+		{
+			input.focus();
+			var range = document.selection.createRange();
+			range.moveStart ("character", -input.value.length);
+			pos = range.text.length;
+		}
+		else if (browser == "standards")
+		{
+			pos = input.selectionStart;
+		};
+
+		// Insert the text
+		var front = (input.value).substring(0, pos);
+		var back = (input.value).substring(pos, input.value.length);
+		input.value = front+text+back;
+
+		// Clean up a little
+		pos = pos + text.length;
+		if (browser == "ie") {
+			input.focus();
+			var range = document.selection.createRange();
+			range.moveStart ("character", -input.value.length);
+			range.moveStart ("character", pos);
+			range.moveEnd ("character", 0);
+			range.select();
+		}
+		else if (browser == "standards") {
+			input.selectionStart = pos;
+			input.selectionEnd = pos;
+			input.focus();
+		}
+		input.scrollTop = scrollPos;
+	},
+
+	/**
+	 * Toggle encryption
+	 *
+	 * @param {jQuery.Event} _event
+	 * @param {et2_button} _widget
+	 * @param {DOMNode} _node
+	 */
+	toggleEncrypt: function(_event, _widget, _node)
+	{
+		if (!this.egw.user('apps').stylite)
+		{
+			this.egw.message(this.egw.lang('InfoLog encryption requires EPL Subscription')+': <a href="http://www.egroupware.org/EPL">www.egroupware.org/EPL</a>');
+			return;
+		}
+		this._get_stylite(function() {app.stylite.toggleEncrypt.call(app.stylite,_event,_widget,_node);});
+	},
+
+	/**
+	 * Make sure stylite javascript is loaded, and call the given callback when it is
+	 *
+	 * @param {function} callback
+	 * @param {object} attrs
+	 *
+	 */
+	_get_stylite: function(callback,attrs)
+	{
+		// use app object from etemplate2, which might be private and not just window.app
+		var app = this.et2.getInstanceManager().app_obj;
+
+		if (!app.stylite)
+		{
+			var self = this;
+			egw_LAB.script('stylite/js/infolog-encryption.js?'+this.et2.getArrayMgr('content').data.encryption_ts).wait(function()
+			{
+				app.stylite = new app.classes.stylite;
+				app.stylite.et2 = self.et2;
+				if(callback)
+				{
+					callback.apply(app.stylite,attrs);
+				}
+			});
+		}
+		else
+		{
+			app.stylite.et2 = this.et2;
+			callback.apply(app.stylite,attrs);
+		}
+	},
+
+	/**
+	 * OnChange callback for responsible
+	 *
+	 * @param {jQuery.Event} _event
+	 * @param {et2_widget} _widget
+	 */
+	onchangeResponsible: function(_event, _widget)
+	{
+		if (app.stylite && app.stylite.onchangeResponsible)
+		{
+			app.stylite.onchangeResponsible.call(app.stylite, _event, _widget);
+		}
+	},
+
+	/**
+	 * Action handler for context menu change responsible action
+	 *
+	 * We populate the dialog with the current value.
+	 *
+	 * @param {egwAction} _action
+	 * @param {egwActionObject[]} _selected
+	 */
+	change_responsible: function(_action, _selected)
+	{
+		var et2 = _selected[0].manager.data.nextmatch.getInstanceManager();
+		var responsible = et2.widgetContainer.getWidgetById('responsible');
+		if(responsible)
+		{
+			responsible.set_value([]);
+			et2.widgetContainer.getWidgetById('responsible_action[title]').set_value('');
+			et2.widgetContainer.getWidgetById('responsible_action[title]').set_class('');
+			et2.widgetContainer.getWidgetById('responsible_action[ok]').set_disabled(_selected.length !== 1);
+			et2.widgetContainer.getWidgetById('responsible_action[add]').set_disabled(_selected.length === 1)
+			et2.widgetContainer.getWidgetById('responsible_action[delete]').set_disabled(_selected.length === 1)
+		}
+
+		if(_selected.length === 1)
+		{
+			var data = egw.dataGetUIDdata(_selected[0].id);
+
+			if(responsible && data && data.data)
+			{
+				et2.widgetContainer.getWidgetById('responsible_action[title]').set_value(data.data.info_subject);
+				et2.widgetContainer.getWidgetById('responsible_action[title]').set_class(data.data.sub_class)
+				responsible.set_value(data.data.info_responsible);
+			}
+		}
+		
+		nm_open_popup(_action, _selected);
+	},
+
+	/**
+	 * Handle encrypted info_desc for print purpose
+	 * and triggers print action after decryption
+	 *
+	 * @param {Keyring} _keyring Mailvelope keyring to use
+	 */
+	printEncrypt: function (_keyring)
+	{
+		//this.mailvelopeAvailable(this.toggleEncrypt);
+		var info_desc = this.et2.getWidgetById('info_des');
+
+		var self = this;
+		mailvelope.createDisplayContainer('#infolog-edit-print_info_des', info_desc.value, _keyring).then(function(_container)
+		{
+			var $info_des_dom = jQuery(self.et2.getWidgetById('info_des').getDOMNode());
+//			$info_des_dom.children('iframe').height($info_des_dom.height());
+			$info_des_dom.children('span').hide();
+			//Trigger print action
+			self.infolog_print_preview();
+		},
+		function(_err)
+		{
+			self.egw.message(_err, 'error');
+		});
 	}
+
 });
