@@ -10,6 +10,10 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Json;
+
 /**
  * callback if the session-check fails, redirects to login.php, if no valid basic auth credentials given
  *
@@ -20,16 +24,15 @@ function login_redirect(&$anon_account)
 {
 	// allow to make json calls via basic auth
 	if (!empty($_SERVER['PHP_AUTH_USER']) && !empty($_SERVER['PHP_AUTH_PW']) &&
-		($session_id = egw_digest_auth::autocreate_session_callback($anon_account)))
+		($session_id = Api\Header\Authenticate::autocreate_session_callback($anon_account)))
 	{
 		return $session_id;
 	}
-	unset($anon_account);
-	egw_json_request::isJSONRequest(true);	// because egw_json_request::parseRequest() is not (yet) called
-	$response = egw_json_response::get();
+	Json\Request::isJSONRequest(true);	// because Api\Json\Request::parseRequest() is not (yet) called
+	$response = Json\Response::get();
 	$response->redirect($GLOBALS['egw_info']['server']['webserver_url'].'/login.php?cd=10', true);
 
-	common::egw_exit();
+	exit();
 }
 
 /**
@@ -44,7 +47,7 @@ function ajax_exception_handler($e)
 	// handle redirects without logging
 	if (is_a($e, 'egw_exception_redirect'))
 	{
-		egw::redirect($e->url, $e->app);
+		Egw::redirect($e->url, $e->app);
 	}
 	// logging all exceptions to the error_log
 	$message = null;
@@ -52,7 +55,7 @@ function ajax_exception_handler($e)
 	{
 		_egw_log_exception($e,$message);
 	}
-	$response = egw_json_response::get();
+	$response = Json\Response::get();
 	$message .= ($message ? "\n\n" : '').$e->getMessage();
 
 	// only show trace (incl. function arguments) if explicitly enabled, eg. on a development system
@@ -62,10 +65,6 @@ function ajax_exception_handler($e)
 	}
 	$response->alert($message);
 
-	if (is_object($GLOBALS['egw']))
-	{
-		common::egw_exit();
-	}
 	exit;
 }
 
@@ -77,7 +76,15 @@ if (isset($_GET['menuaction']))
 	if (strpos($_GET['menuaction'],'::') !== false && strpos($_GET['menuaction'],'.') === false)	// static method name app_something::method
 	{
 		@list($className,$functionName,$handler) = explode('::',$_GET['menuaction']);
-		list($appName) = explode('_',$className);
+
+		if (substr($className, 0, 11) == 'EGroupware\\')
+		{
+			list(,$appName) = explode('\\', strtolower($className));
+		}
+		else
+		{
+			list($appName) = explode('_',$className);
+		}
 	}
 	else
 	{
@@ -94,24 +101,24 @@ if (isset($_GET['menuaction']))
 			'no_exception_handler' => true,	// we already installed our own
 			// only log ajax requests which represent former GET requests or submits
 			// cuts down updates to egw_access_log table
-			'no_dla_update' => !preg_match('/(\.etemplate_new\.ajax_process_content\.etemplate|\.jdots_framework\.ajax_exec\.template)$/', $_GET['menuaction']),
+			'no_dla_update' => !preg_match('/(Etemplate::ajax_process_content|\.jdots_framework\.ajax_exec\.template)$/', $_GET['menuaction']),
 		)
 	);
 	include_once('./header.inc.php');
 
 
 	//Create a new json handler
-	$json = new egw_json_request();
+	$json = new Json\Request();
 
 	//Check whether the request data is set
 	if (isset($GLOBALS['egw_unset_vars']['_POST[json_data]']))
 	{
 		$json->isJSONRequest(true);	// otherwise exception is not send back to client, as we have not yet called parseRequest()
-		throw new egw_exception_assertion_failed("JSON Data contains script tags. Aborting...");
+		throw new Json\Exception\ScriptTags("JSON Data contains script tags. Aborting...");
 	}
 	$json->parseRequest($_GET['menuaction'], $_REQUEST['json_data']);
-	egw_json_response::get();
-	common::egw_exit();
+	Json\Response::get();
+	exit();
 }
 
-throw new Exception($_SERVER['PHP_SELF'] . ' Invalid AJAX JSON Request');
+throw new Json\Exception($_SERVER['PHP_SELF'] . ' Invalid AJAX JSON Request');
