@@ -5,11 +5,16 @@
  * @link http://www.egroupware.org
  * @package mail
  * @author Hadi Nategh [hn@stylite.de]
- * @copyright (c) 2013 by Stylite AG <info-AT-stylite.de>
+ * @copyright (c) 2013-16 by Stylite AG <info-AT-stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Etemplate;
+use EGroupware\Api\Mail;
+
 class mail_acl
 {
 	/**
@@ -36,17 +41,10 @@ class mail_acl
 		'custom'	=> array('label'=>'custom','title'=>'User defined combination of rights for the ACL'),
 	);
 
-	/**
-	 * instance of mail_bo
-	 *
-	 * @var mail_bo
-	 */
-	var $mail_bo;
-
 	/**
 	 * imap object instanciated in constructor for account to edit
 	 *
-	 * @var emailadmin_imap
+	 * @var Mail\Imap
 	 */
 	var $imap;
 
@@ -65,13 +63,13 @@ class mail_acl
 	 */
 	function edit(array $content=null ,$msg='')
 	{
-		$tmpl = new etemplate_new('mail.acl');
+		$tmpl = new Etemplate('mail.acl');
 		if (!is_array($content))
 		{
 			$acc_id = $_GET['acc_id']?$_GET['acc_id']:$GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID'];
 			if (isset($_GET['account_id']) && !isset($GLOBALS['egw_info']['user']['apps']['admin']))
 			{
-				egw_framework::window_close(lang('Permission denied'));
+				Framework::window_close(lang('Permission denied'));
 			}
 			$account_id = $_GET['account_id'];
 		}
@@ -80,7 +78,7 @@ class mail_acl
 			$acc_id = $content['acc_id'];
 			$account_id = $content['account_id'];
 		}
-		$account = emailadmin_account::read($acc_id, $account_id);
+		$account = Mail\Account::read($acc_id, $account_id);
 		$this->imap = $account->imapServer(isset($account_id) ? (int)$account_id : false);
 
 		$mailbox = $_GET['mailbox']? base64_decode($_GET['mailbox']): $content['mailbox'][0];
@@ -179,14 +177,14 @@ class mail_acl
 						$msg .= "\n".lang("Error: Could not save ACL").' '.lang("reason!");
 					}
 					//Send message
-					egw_framework::message($msg);
+					Framework::message($msg);
 					if ($button == "apply") break;
 
 				//Fall through
 				case 'cancel':
-					egw_framework::window_close();
-					common::egw_exit();
-					break;
+					Framework::window_close();
+					exit;
+
 				case 'delete':
 					$aclRvmCnt = $this->remove_acl($content, $msg);
 					if (is_array($aclRvmCnt))
@@ -197,7 +195,7 @@ class mail_acl
 					{
 						error_log(__METHOD__.__LINE__. "()" . "The remove_acl suppose to return an array back, something is wrong there");
 					}
-					egw_framework::message($msg);
+					Framework::message($msg);
 			}
 		}
 		$readonlys = $sel_options = array();
@@ -243,15 +241,15 @@ class mail_acl
 	/**
 	 * Autocomplete for folder taglist
 	 *
-	 * @throws egw_exception_no_permission_admin
+	 * @throws Api\Exception\NoPermission\Admin
 	 */
 	public static function ajax_folders()
 	{
 		if (!empty($_GET['account_id']) && !$GLOBALS['egw_info']['user']['apps']['admin'])
 		{
-			throw new egw_exception_no_permission_admin;
+			throw new Api\Exception\NoPermission\Admin;
 		}
-		$account = emailadmin_account::read($_GET['acc_id'], $_GET['account_id']);
+		$account = Mail\Account::read($_GET['acc_id'], $_GET['account_id']);
 		$imap = $account->imapServer(!empty($_GET['account_id']) ? (int)$_GET['account_id'] : false);
 		$mailbox = $imap->isAdminConnection ? $imap->getUserMailboxString($imap->isAdminConnection) : 'INBOX';
 
@@ -267,12 +265,12 @@ class mail_acl
 			}
 		}
 		// switch regular JSON response handling off
-		egw_json_request::isJSONRequest(false);
+		Api\Json\Request::isJSONRequest(false);
 
 		header('Content-Type: application/json; charset=utf-8');
 		echo json_encode($folders);
 
-		common::egw_exit();
+		exit;
 	}
 
 	/**
@@ -441,10 +439,10 @@ class mail_acl
 	 * Get subfolders of a mailbox
 	 *
 	 * @param string $mailbox structural folder name
-	 * @param emailadmin_imap $imap
+	 * @param Mail\Imap $imap
 	 * @return Array an array including all subfolders of given mailbox| returns an empty array in case of no subfolders
 	 */
-	protected static function getSubfolders($mailbox, emailadmin_imap $imap)
+	protected static function getSubfolders($mailbox, Mail\Imap $imap)
 	{
 		$delimiter = $imap->getDelimiter();
 		$nameSpace = $imap->getNameSpace();
