@@ -5,18 +5,18 @@
  * @link http://www.egroupware.org
  * @package mail
  * @author Stylite AG [info@stylite.de]
- * @copyright (c) 2013-2014 by Stylite AG <info-AT-stylite.de>
+ * @copyright (c) 2013-2016 by Stylite AG <info-AT-stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api\Mail;
+
 /**
  * Mail worker class
  *  -provides backend functionality for all classes in Mail
  *  -provides classes that may be used by other apps too
  *
- * @link https://github.com/horde/horde/blob/master/imp/lib/Contents.php
+ * @deprecated use Api\Mail
  */
-class mail_bo extends emailadmin_imapbase
-{
-}
+class mail_bo extends Mail {}
