@@ -5,11 +5,15 @@
  * @link http://www.egroupware.org
  * @package mail
  * @author Stylite AG [info@stylite.de]
- * @copyright (c) 2013 by Stylite AG <info-AT-stylite.de>
+ * @copyright (c) 2013-16 by Stylite AG <info-AT-stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Mail;
+
 /**
  * Class containing admin, preferences and sidebox-menus and other hooks
  */
@@ -24,11 +28,11 @@ class mail_hooks
 	{
 		$actions = array();
 
-		$account = emailadmin_account::read($data['acc_id'], $data['account_id']);
-		if (emailadmin_account::is_multiple($account) && $account['acc_imap_admin_username'] ||
+		$account = Mail\Account::read($data['acc_id'], $data['account_id']);
+		if (Mail\Account::is_multiple($account) && $account['acc_imap_admin_username'] ||
 			$account['acc_imap_type'] == 'managementserver_imap')
 		{
-			translation::add_app('mail');
+			Api\Translation::add_app('mail');
 
 			if (true /* ToDo check ACL available */ || $account['acc_imap_type'] == 'managementserver_imap')
 			{
@@ -37,7 +41,7 @@ class mail_hooks
 					'caption' => 'Folder ACL',
 					'icon' => 'lock',
 					'popup' => '750x420',
-					'url' => egw::link('/index.php', array(
+					'url' => Egw::link('/index.php', array(
 						'menuaction' => 'mail.mail_acl.edit',
 						'acc_id' => $data['acc_id'],
 						'account_id' => $data['account_id'],
@@ -52,7 +56,7 @@ class mail_hooks
 					'caption' => 'Vacation notice',
 					'icon' => 'mail/navbar',
 					'popup' => '750x420',
-					'url' => egw::link('/index.php', array(
+					'url' => Egw::link('/index.php', array(
 						'menuaction' => 'mail.mail_sieve.editVacation',
 						'acc_id' => $data['acc_id'],
 						'account_id' => $data['account_id'],
@@ -67,11 +71,13 @@ class mail_hooks
 	/**
      * Hook called by link-class to include mail in the appregistry of the linkage
      *
-     * @param array/string $location location and other parameters (not used)
+     * @param array|string $location location and other parameters (not used)
      * @return array with method-names
      */
     static function search_link($location)
     {
+		unset($location);	// not used, but required by function signature
+
         return array(
 			'view'  => array(
 				'menuaction' => 'mail.mail_ui.displayMessage',
@@ -119,60 +125,23 @@ class mail_hooks
 			$profileID = 0;
 			if (isset($GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID']))
 				$profileID = (int)$GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID'];
-
-			$mailConfig = config::read('mail');
 		}
 
-		$connectionTimeout = array(
-			'0' => lang('use default timeout (20 seconds)'),
-			'10' => '10', // timeout used in SIEVE
-			'20' => '20',
-			'30' => '30',
-			'40' => '40',
-			'50' => '50',
-			'60' => '60',
-			'70' => '70',
-			'80' => '80',
-			'90' => '90',
-		);
-
 		$no_yes = array(
 			'0' => lang('no'),
 			'1' => lang('yes')
 		);
 		$no_yes_copy = array_merge($no_yes,array('2'=>lang('yes, offer copy option')));
 
- 		$prefAllowManageFolders = $no_yes;
-
 		$forwardOptions = array(
 			'asmail' => lang('forward as attachment'),
 			'inline' => lang('forward inline'),
 		);
-		$sortOrder = array(
-			'0' => lang('date(newest first)'),
-			'1' => lang('date(oldest first)'),
-			'3' => lang('from(A->Z)'),
-			'2' => lang('from(Z->A)'),
-			'5' => lang('subject(A->Z)'),
-			'4' => lang('subject(Z->A)'),
-			'7' => lang('size(0->...)'),
-			'6' => lang('size(...->0)')
-		);
-
 		$trustServersUnseenOptions = array_merge(
 			$no_yes,
 			array('2' => lang('yes') . ' - ' . lang('but check shared folders'))
 		);
 
-		$selectOptions = array_merge(
-			$no_yes,
-			array('2' => lang('yes') . ' - ' . lang('small view'))
- 		);
-		$newWindowOptions = array(
-			'1' => lang('only one window'),
-			'2' => lang('allways a new window'),
-		);
-
 		$deleteOptions = array(
 			'move_to_trash'		=> lang('move to trash'),
 			'mark_as_deleted'	=> lang('mark as deleted'),
@@ -205,46 +174,10 @@ class mail_hooks
 			'only_if_no_text'	=> lang('display only when no plain text is available'),
 			'always_display'	=> lang('always show html emails'),
 		);
-		$toggle = false;
-		if ($GLOBALS['egw_info']['user']['preferences']['common']['select_mode'] == 'EGW_SELECTMODE_TOGGLE') $toggle=true;
-		$rowOrderStyle = array(
-			'mail'	=> lang('mail'),
-			'outlook'	=> 'Outlook',
-			'mail_wCB' => lang('mail').' '.($toggle?lang('(select mails by clicking on the line, like a checkbox)'):lang('(with checkbox enforced)')),
-			'outlook_wCB'	=> 'Outlook'.' '.($toggle?lang('(select mails by clicking on the line, like a checkbox)'):lang('(with checkbox enforced)')),
-		);
 
 		// otherwise we get warnings during setup
 		if (!is_array($folderList)) $folderList = array();
 
-		$trashOptions = array_merge(
-			array(
-				'none' => lang("Don't use Trash")
-			),
-			$folderList
-		);
-
-		$sentOptions = array_merge(
-			array(
-				'none' => lang("Don't use Sent")
-			),
-			$folderList
-		);
-
-		$draftOptions = array_merge(
-			array(
-				'none' => lang("Don't use draft folder")
-			),
-			$folderList
-		);
-
-		$templateOptions = array_merge(
-		    array(
-		        'none' => lang("Don't use template folder")
-		    ),
-		    $folderList
-		);
-
 		// modify folderlist, add a none entry, to be able to force the regarding settings, if no folders apply
 		$folderList['none'] = lang('no folders');
 
@@ -431,6 +364,8 @@ class mail_hooks
 	 */
 	static function admin($hook_data)
 	{
+		unset($hook_data);	// not used, but required by function signature
+
 		unset($GLOBALS['egw_info']['user']['preferences']['common']['auto_hide_sidebox']);
 		// Only Modify the $file and $title variables.....
 		$title = $appname = 'mail';
@@ -439,7 +374,7 @@ class mail_hooks
 			$profileID = (int)$GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID'];
 
 		$file = Array(
-			'Site Configuration' => egw::link('/index.php',array('menuaction'=>'admin.uiconfig.index','appname'=>'mail')),
+			'Site Configuration' => Egw::link('/index.php',array('menuaction'=>'admin.uiconfig.index','appname'=>'mail')),
 		);
 		display_section($appname,$title,$file);
 	}
@@ -451,6 +386,8 @@ class mail_hooks
 	 */
 	static function sidebox_menu($hook_data)
 	{
+		unset($hook_data);	// not used, but required by function signature
+
 		//error_log(__METHOD__);
 		// always show the side bar
 		unset($GLOBALS['egw_info']['user']['preferences']['common']['auto_hide_sidebox']);
@@ -463,18 +400,18 @@ class mail_hooks
 			$profileID = (int)$GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID'];
 		try
 		{
-			$mail_bo = mail_bo::getInstance(true,$profileID);
+			$mail_bo = Mail::getInstance(true,$profileID);
 			$profileID = $GLOBALS['egw_info']['user']['preferences']['mail']['ActiveProfileID'] = $mail_bo->profileID;
 		} catch (Exception $e) {
 			//error_log(__METHOD__."()" . $e->getMessage());
-			$profileID = emailadmin_account::get_default_acc_id();
+			$profileID = Mail\Account::get_default_acc_id();
 		}
 
 		$preferences =& $mail_bo->mailPreferences;
 		$serverCounter = $sieveEnabledServerCounter = 0;
 		// account select box
 		$selectedID = $profileID;
-		$allAccountData = emailadmin_account::search($only_current_user=true, $just_name=false, $order_by=null);
+		$allAccountData = Mail\Account::search($only_current_user=true, $just_name=false, $order_by=null);
 		if ($allAccountData) {
 			$rememberFirst=$selectedFound=null;
 			foreach ($allAccountData as $tmpkey => $icServers)
@@ -504,13 +441,13 @@ class mail_hooks
 			'link'=>false,
 			'icon' => false
 		);
-		
+
 		$linkData = array(
 			'menuaction' => 'mail.mail_ui.importMessage',
 		);
 
 		$file += array(
-			'import message' => "javascript:egw_openWindowCentered2('".egw::link('/index.php', $linkData,false)."','importMessageDialog',600,100,'no','$appname');",
+			'import message' => "javascript:egw_openWindowCentered2('".Egw::link('/index.php', $linkData,false)."','importMessageDialog',600,100,'no','$appname');",
 		);
 
 
@@ -519,20 +456,22 @@ class mail_hooks
 		{
 			$file += array(
 				'create new account' => "javascript:egw_openWindowCentered2('" .
-					egw::link('/index.php', array('menuaction' => 'mail.mail_wizard.add'), '').
+					Egw::link('/index.php', array('menuaction' => 'mail.mail_wizard.add'), '').
 					"','_blank',640,480,'yes')",
 			);
 		}
 		// display them all
 		display_sidebox($appname,$menu_title,$file);
 
-		if ($GLOBALS['egw_info']['user']['apps']['admin'])
+		if ($GLOBALS['egw_info']['user']['apps']['admin'] && !Api\Header\UserAgent::mobile())
 		{
 			$file = Array(
-				'Site Configuration' => egw::link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
+				'Site Configuration' => Egw::link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
 			);
 			display_sidebox($appname,lang('Admin'),$file);
 		}
+		Api\Hooks::pgp_encryption_menu('mail');
+
 	}
 
 	/**
@@ -543,22 +482,22 @@ class mail_hooks
 	static function notification_check_mailbox()
 	{
 		// should not run more often then every 3 minutes;
-		$lastRun = egw_cache::getCache(egw_cache::INSTANCE,'email','mailNotifyLastRun'.trim($GLOBALS['egw_info']['user']['account_id']),null,array(),$expiration=60*60*24*2);
+		$lastRun = Api\Cache::getCache(Api\Cache::INSTANCE,'email','mailNotifyLastRun'.trim($GLOBALS['egw_info']['user']['account_id']),null,array(),$expiration=60*60*24*2);
 		$currentTime = time();
 		if (!empty($lastRun) && $lastRun>$currentTime-3*60)
 		{
 			//error_log(__METHOD__.__LINE__." Job should not run too often; we limit this to once every 3 Minutes :". ($currentTime-$lastRun). " Seconds to go!");
 			return true;
 		}
-		$accountsToSearchObj = emailadmin_account::search($only_current_user=true, $just_name=true);
+		$accountsToSearchObj = Mail\Account::search(true, true);
 
 		foreach($accountsToSearchObj as $acc_id => $identity_name)
 		{
 			//error_log(__METHOD__.__LINE__.' '.$acc_id.':'.$identity_name);
-			$folders2notify[$acc_id] = emailadmin_notifications::read($acc_id);// read all, even those set for acc_id 0 (folders for all acounts?)
+				$folders2notify[$acc_id] = Mail\Notifications::read($acc_id);// read all, even those set for acc_id 0 (folders for all acounts?)
 			$accountsToSearchArray[$acc_id] = str_replace(array('<','>'),array('[',']'),$identity_name);
 		}
-		$notified_mail_uidsCache = egw_cache::getCache(egw_cache::INSTANCE,'email','notified_mail_uids'.trim($GLOBALS['egw_info']['user']['account_id']),null,array(),$expiration=60*60*24*2);
+		$notified_mail_uidsCache = Api\Cache::getCache(Api\Cache::INSTANCE,'email','notified_mail_uids'.trim($GLOBALS['egw_info']['user']['account_id']),null,array(),$expiration=60*60*24*2);
 		//error_log(__METHOD__.__LINE__.array2string($notified_mail_uidsCache));
 		if (!is_array($folders2notify)) return true;
 		foreach ($folders2notify as $nFKey =>$notifyfolders)
@@ -575,7 +514,7 @@ class mail_hooks
 				//error_log(__METHOD__.__LINE__.' (user: '.$currentRecipient->account_lid.') Active Profile:'.$activeProfile);
 				try
 				{
-					$bomail = mail_bo::getInstance(false, $activeProfile,false);
+					$bomail = Mail::getInstance(false, $activeProfile,false);
 				} catch (Exception $e)
 				{
 					error_log(__METHOD__.__LINE__.' (user: '.$currentRecipient->account_lid.') notification for Profile:'.$activeProfile.' failed.'.$e->getMessage());
@@ -609,8 +548,7 @@ class mail_hooks
 						$notified_mail_uidsCache[$activeProfile][$notify_folder] = array();
 					}
 					$folder_status[$notify_folder] = $bomail->getFolderStatus($notify_folder);
-					$cutoffdate = time();
-					$cutoffdate = $cutoffdate - (60*60*24*14); // last 14 days
+					$cutoffdate = time() - (60*60*24*14); // last 14 days
 					$_filter = array('status'=>array('UNSEEN','UNDELETED'),'type'=>"SINCE",'string'=> date("d-M-Y", $cutoffdate));
 					//error_log(__METHOD__.__LINE__.' (user: '.$currentRecipient->account_lid.') Mailbox:'.$notify_folder.' filter:'.array2string($_filter));
 					// $_folderName, $_startMessage, $_numberOfMessages, $_sort, $_reverse, $_filter, $_thisUIDOnly=null, $_cacheResult=true
@@ -642,7 +580,7 @@ class mail_hooks
 							'mail_uid'				=> $recent_message['uid'],
 							'mail_folder' 			=> $recent_message['folder_display_name'],
 							'mail_folder_base64' 	=> $recent_message['folder_base64'],
-							'mail_subject'			=> mail_bo::adaptSubjectForImport($recent_message['subject']),
+							'mail_subject'			=> Mail::adaptSubjectForImport($recent_message['subject']),
 							'mail_from'				=> !empty($recent_message['sender_name']) ? $recent_message['sender_name'] : $recent_message['sender_address'],
 							'mail_received'			=> $recent_message['date'],
 						);
@@ -663,37 +601,17 @@ class mail_hooks
 					$notification->set_skip_backends(array('email'));
 					$notification->send();
 				}
-				egw_cache::setCache(egw_cache::INSTANCE,'email','notified_mail_uids'.trim($GLOBALS['egw_info']['user']['account_id']),$notified_mail_uidsCache, $expiration=60*60*24*2);
+				Api\Cache::setCache(Api\Cache::INSTANCE,'email','notified_mail_uids'.trim($GLOBALS['egw_info']['user']['account_id']),$notified_mail_uidsCache, $expiration=60*60*24*2);
 			} catch (Exception $e) {
 				// fail silently per server, if possible
 				error_log(__METHOD__.__LINE__.' Notification on new messages for Profile '.$activeProfile.' ('.$accountsToSearchArray[$activeProfile].') failed:'.$e->getMessage());
 			}
 		}
-		egw_cache::setCache(egw_cache::INSTANCE,'email','mailNotifyLastRun'.trim($GLOBALS['egw_info']['user']['account_id']),time(), $expiration=60*60*24*2);
+		Api\Cache::setCache(Api\Cache::INSTANCE,'email','mailNotifyLastRun'.trim($GLOBALS['egw_info']['user']['account_id']),time(), $expiration=60*60*24*2);
 		//error_log(__METHOD__.__LINE__.array2string($notified_mail_uidsCache));
 		return true;
 	}
 
-	/**
-	 * Hook returning options for deny_* groups
-	 *
-	 * @param string $name function name
-	 * @param array $arguments
-	 * @return string html
-	 */
-	public static function __callStatic($name, $arguments)
-	{
-		if (substr($name, 0, 5) != 'deny_')
-		{
-			if ($name == 'edit_user') return;	// to ease upgrade, as hook is removed
-			throw new egw_exception_wrong_parameter("No method $name!");
-		}
-		$accountsel = new uiaccountsel();
-
-		return '<input type="hidden" value="" name="newsettings['.$name.']" />'.
-			$accountsel->selection('newsettings['.$name.']', 'deny_prefs', $arguments[0][$name], 'groups', 4);
-	}
-
 	/**
 	 * Check if current user has access to a specific feature
 	 *
@@ -710,7 +628,7 @@ class mail_hooks
 		{
 			return true;	// allways give admins or emailadmins all rights, even if they are in a denied group
 		}
-		if (!isset($config)) $config = (array)config::read('mail');
+		if (!isset($config)) $config = (array)Api\Config::read('mail');
 		//error_log(__METHOD__.__LINE__.' '.$feature.':'.array2string($config['deny_'.$feature]));
 		if (!empty($config['deny_'.$feature]))
 		{
