@@ -5,11 +5,16 @@
  * @link http://www.egroupware.org
  * @package mail
  * @author Hadi Nategh [hn@stylite.de]
- * @copyright (c) 2013 by Hadi Nategh <hn-AT-stylite.de>
+ * @copyright (c) 2013-16 by Hadi Nategh <hn-AT-stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Etemplate;
+use EGroupware\Api\Mail;
+
 class mail_sieve
 {
 	var $public_functions = array(
@@ -38,7 +43,7 @@ class mail_sieve
 	/**
 	 * account object
 	 *
-	 * @var emailadmin_account
+	 * @var Mail\Account
 	 */
 	var $account;
 
@@ -61,16 +66,16 @@ class mail_sieve
 	 */
 	function __construct()
 	{
-		$this->displayCharset = translation::charset();
+		$this->displayCharset = Api\Translation::charset();
 		$this->mail_admin = isset($GLOBALS['egw_info']['user']['apps']['emailadmin']);
-		$this->mailConfig = config::read('mail');
+		$this->mailConfig = Api\Config::read('mail');
 
-		$acc_id = isset($_GET['acc_id']) ? (int)$_GET['acc_id'] : egw_cache::getSession(__CLASS__, 'acc_id');
+		$acc_id = isset($_GET['acc_id']) ? (int)$_GET['acc_id'] : Api\Cache::getSession(__CLASS__, 'acc_id');
 		if ($acc_id > 0)
 		{
-			$this->account = emailadmin_account::read($acc_id);
-			$identity = emailadmin_account::read_identity($this->account->ident_id,true);
-			$this->currentIdentity = mail_bo::generateIdentityString($identity,false);
+			$this->account = Mail\Account::read($acc_id);
+			$identity = Mail\Account::read_identity($this->account->ident_id,true);
+			$this->currentIdentity = Mail::generateIdentityString($identity,false);
 		}
 
 		$this->restoreSessionData();
@@ -86,10 +91,10 @@ class mail_sieve
 	{
 		if (!is_array($content))
 		{
-			egw_cache::setSession(__CLASS__, 'acc_id', $this->account->acc_id);
+			Api\Cache::setSession(__CLASS__, 'acc_id', $this->account->acc_id);
 		}
-		//Instantiate an etemplate_new object
-		$tmpl = new etemplate_new('mail.sieve.index');
+		//Instantiate an eTemplate object
+		$tmpl = new Etemplate('mail.sieve.index');
 
 		if ($msg)
 		{
@@ -102,7 +107,7 @@ class mail_sieve
 			$content['rg']= $this->get_rows();
 
 			// Set content-menu actions
-			$tmpl->set_cell_attribute('rg', 'actions',$this->get_actions());
+			$tmpl->setElementAttribute('rg', 'actions',$this->get_actions());
 
 			$sel_options = array(
 				'status' => array(
@@ -128,8 +133,8 @@ class mail_sieve
 	 */
 	function editEmailNotification($content=null, $msg='')
 	{
-		//Instantiate an etemplate_new object, representing sieve.emailNotification
-		$eNotitmpl = new etemplate_new('mail.sieve.emailNotification');
+		//Instantiate an eTemplate object, representing sieve.emailNotification
+		$eNotitmpl = new Etemplate('mail.sieve.emailNotification');
 
 		if ($this->account->acc_sieve_enabled)
 		{
@@ -183,15 +188,15 @@ class mail_sieve
 							$msg .= lang('email notification update failed! You need to set an email address!');
 							break;
 						}
-						egw_framework::refresh_opener($msg, 'mail');
+						Framework::refresh_opener($msg, 'mail');
 						if ($button === 'apply')
 						{
 							break;
 						}
 
 					case 'cancel':
-						egw_framework::window_close();
-						common::egw_exit();
+						Framework::window_close();
+						exit;
 				}
 				$this->saveSessionData();
 			}
@@ -223,8 +228,8 @@ class mail_sieve
 	 */
 	function edit ($content=null)
 	{
-		//Instantiate an etemplate_new object, representing sieve.edit template
-		$etmpl = new etemplate_new('mail.sieve.edit');
+		//Instantiate an eTemplate object, representing sieve.edit template
+		$etmpl = new Etemplate('mail.sieve.edit');
 		$etmpl->setElementAttribute('action_folder_text','autocomplete_params', array('noPrefixId'=> true));
 		if (!is_array($content))
 		{
@@ -233,6 +238,7 @@ class mail_sieve
 
 				$rules = $this->rulesByID;
 				$content= $rules;
+				$content ['ruleID'] = $_GET['ruleID'];
 				switch ($rules['action'])
 				{
 					case 'folder':
@@ -268,7 +274,7 @@ class mail_sieve
 			list($button) = @each($content['button']);
 
 			//$ruleID is calculated by priority from the selected rule and is an unique ID
-			$ruleID = ($this->rulesByID['priority'] -1) / 2;
+			$content['ruleID'] = $ruleID = ($this->rulesByID['priority'] -1) / 2;
             $error = 0;
 			switch ($button)
 			{
@@ -330,7 +336,7 @@ class mail_sieve
 						$msg .= "\n".lang("Error: Could not save rule").' '.lang("No action defined!");
 						$error++;
 					}
-					egw_framework::refresh_opener($msg, 'mail', 'sieve');
+					Framework::refresh_opener($msg, 'mail', 'sieve');
 					if ($button == "apply")
 					{
 						break;
@@ -353,11 +359,11 @@ class mail_sieve
 						$this->rules = array_values($this->rules);
 						$this->updateScript();
 					}
-					egw_framework::refresh_opener($msg, 'mail', 'sieve');
+					Framework::refresh_opener($msg, 'mail', 'sieve');
 
 				case 'cancel':
-					egw_framework::window_close();
-					common::egw_exit();
+					Framework::window_close();
+					exit;
 			}
 		}
 		$sel_options = array(//array_merge($sel_options,array(
@@ -373,7 +379,7 @@ class mail_sieve
 				0 => 'raw',
 				1 => 'text',
 			),
-			'ctype' => emailadmin_script::$btransform_ctype_array,
+			'ctype' => Mail\Script::$btransform_ctype_array,
 
 		);
 
@@ -394,20 +400,16 @@ class mail_sieve
 	{
 		if(!(empty($this->mailConfig['prefpreventnotificationformailviaemail']) || $this->mailConfig['prefpreventnotificationformailviaemail'] == 0))
 		{
-			throw new egw_exception_no_permission();
+			throw new Api\Exception\NoPermission();
 		}
 
-		if(PEAR::isError($error = $this->account->imapServer()->retrieveRules()) )
-		{
-			$rules    = array();
-			$emailNotification = array();
-		}
-		else
-		{
-			$rules    = $this->account->imapServer()->getRules();
+		try {
 			$emailNotification = $this->account->imapServer()->getEmailNotification();
 		}
-
+		catch(Exception $e) {
+			unset($e);
+			$emailNotification = array();
+		}
 		return $emailNotification;
 	}
 
@@ -422,7 +424,7 @@ class mail_sieve
 	{
 		if(!(empty($this->mailConfig['prefpreventabsentnotice']) || $this->mailConfig['prefpreventabsentnotice'] == 0))
 		{
-			throw new egw_exception_no_permission();
+			throw new Api\Exception\NoPermission();
 		}
 		try {
 			if ($this->is_admin_vac)
@@ -439,11 +441,11 @@ class mail_sieve
 		}
 		catch(Exception $e)
 		{
-			egw_framework::window_close(lang($e->getMessage()));
+			Framework::window_close(lang($e->getMessage()));
 		}
 		if (is_null($accountID)) $accountID = $GLOBALS['egw_info']['user']['account_id'];
 
-		$accAllIdentities = $this->account->smtpServer()->getAccountEmailAddress(accounts::id2name($accountID));
+		$accAllIdentities = $this->account->smtpServer()->getAccountEmailAddress(Api\Accounts::id2name($accountID));
 		$allAliases = array($this->account->ident_email);
 		foreach ($accAllIdentities as &$arrVal)
 		{
@@ -467,8 +469,8 @@ class mail_sieve
 	 */
 	function editVacation($content=null, $msg='')
 	{
-		//Instantiate an etemplate_new object, representing the sieve.vacation template
-		$vtmpl = new etemplate_new('mail.sieve.vacation');
+		//Instantiate an eTemplate object, representing the sieve.vacation template
+		$vtmpl = new Etemplate('mail.sieve.vacation');
 		$vacation = array();
 
 		if (isset($_GET['account_id'])) $account_id = $preserv['account_id'] = $_GET['account_id'];
@@ -480,11 +482,11 @@ class mail_sieve
 		}
 		if(isset($account_id) && $this->mail_admin)
 		{
-			foreach(emailadmin_account::search($account_id, false, null, false, 0, false) as $account)
+			foreach(Mail\Account::search($account_id, false, null, false, 0, false) as $account)
 			{
 				try {
 					// check if account is valid for multiple users, has admin credentials and sieve enabled
-					if (emailadmin_account::is_multiple($account) &&
+					if (Mail\Account::is_multiple($account) &&
 						($icServer = $account->imapServer(true)) &&	// check on icServer object, so plugins can overwrite
 						$icServer->acc_imap_admin_username && $icServer->acc_sieve_enabled)
 					{
@@ -512,12 +514,12 @@ class mail_sieve
 		}
 		elseif(!is_array($content) && isset($_GET['acc_id']))
 		{
-			$this->account = emailadmin_account::read($_GET['acc_id']);
+			$this->account = Mail\Account::read($_GET['acc_id']);
 			$preserv['acc_id'] = $this->account->acc_id;
 		}
 		elseif ($content['acc_id'])
 		{
-			$this->account = emailadmin_account::read($content['acc_id']);
+			$this->account = Mail\Account::read($content['acc_id']);
 			$preserv['acc_id'] = $content['acc_id'];
 		}
 
@@ -558,7 +560,7 @@ class mail_sieve
 					if (strlen(trim($content['text']))==0)
 					{
 						$content['msg'] = $msg = lang('error').': '.lang('No vacation notice text provided. Please enter a message.');
-						egw_framework::refresh_opener($msg, 'mail');
+						Framework::refresh_opener($msg, 'mail');
 					}
 					//Set default value for days new entry
 					if (empty($content['days']))
@@ -582,7 +584,7 @@ class mail_sieve
 								// store text as default
 								if ($content['set_as_default'] == 1 && $content['text'])
 								{
-									config::save_value('default_vacation_text', $content['text'], 'mail');
+									Api\Config::save_value('default_vacation_text', $content['text'], 'mail');
 								}
 							}
 							if (isset($content['status']))
@@ -640,18 +642,17 @@ class mail_sieve
 										//Reset vacationNotice cache which is used in mail_ui get_rows
 										if (isset($account_id) && $this->mail_admin)
 										{
-											$account_lid = accounts::id2name($account_id,'account_lid');
-											$cachedVacations = array($icServer->acc_id => $newVacation) + (array)egw_cache::getCache(egw_cache::INSTANCE, 'email', 'vacationNotice'.$account_lid);
+											$account_lid = Api\Accounts::id2name($account_id,'account_lid');
+											$cachedVacations = array($icServer->acc_id => $newVacation) + (array)Api\Cache::getCache(Api\Cache::INSTANCE, 'email', 'vacationNotice'.$account_lid);
 											//error_log(__METHOD__.__LINE__.' Setting Cache for '.$account_lid.':'.array2string($cachedVacations));
-											egw_cache::setCache(egw_cache::INSTANCE,'email', 'vacationNotice'.$account_lid, $cachedVacations);
+											Api\Cache::setCache(Api\Cache::INSTANCE,'email', 'vacationNotice'.$account_lid, $cachedVacations);
 										}
 										else
 										{
-											$cachedVacations = array($icServer->acc_id => $newVacation) + (array)egw_cache::getCache(egw_cache::INSTANCE, 'email', 'vacationNotice'.$GLOBALS['egw_info']['user']['account_lid']);
+											$cachedVacations = array($icServer->acc_id => $newVacation) + (array)Api\Cache::getCache(Api\Cache::INSTANCE, 'email', 'vacationNotice'.$GLOBALS['egw_info']['user']['account_lid']);
 											//error_log(__METHOD__.__LINE__.' Setting Cache for own ('.$GLOBALS['egw_info']['user']['account_lid'].'):'.array2string($cachedVacations));
-											egw_cache::setCache(egw_cache::INSTANCE,'email', 'vacationNotice'.$GLOBALS['egw_info']['user']['account_lid'], $cachedVacations);
+											Api\Cache::setCache(Api\Cache::INSTANCE,'email', 'vacationNotice'.$GLOBALS['egw_info']['user']['account_lid'], $cachedVacations);
 										}
-
 										$msg = lang('Vacation notice sucessfully updated.');
 									}
 								}
@@ -660,9 +661,9 @@ class mail_sieve
 									$msg .= implode("\n",$this->errorStack);
 								}
 								// refresh vacationNotice on index
-								$response = egw_json_response::get();
+								$response = Api\Json\Response::get();
 								$response->call('app.mail.mail_callRefreshVacationNotice',$icServer->ImapServerId);
-								egw_framework::refresh_opener($msg, 'mail');
+								Framework::refresh_opener($msg, 'mail');
 								if ($button === 'apply' || $icServer->error !=="")
 								{
 									break;
@@ -670,7 +671,7 @@ class mail_sieve
 							}
 
 						case 'cancel':
-							egw_framework::window_close();
+							Framework::window_close();
 					}
 				}
 
@@ -720,7 +721,7 @@ class mail_sieve
 	static function strip_rfc882_addresses($_addresses)
 	{
 		$addresses = array();
-		foreach(emailadmin_imapbase::parseAddressList($_addresses) as $addr)
+		foreach(Mail::parseAddressList($_addresses) as $addr)
 		{
 			if ($addr->valid)
 			{
@@ -741,10 +742,10 @@ class mail_sieve
 	{
 		if (!($_vacation['acc_id'] > 0))
 		{
-			throw new egw_exception_wrong_parameter('No acc_id given!');
+			throw new Api\Exception\WrongParameter('No acc_id given!');
 		}
 		// setting up an async job to enable/disable the vacation message
-		$async = new asyncservice();
+		$async = new Api\Asyncservice();
 		if (empty($_vacation['account_id'])) $_vacation['account_id'] = $GLOBALS['egw_info']['user']['account_id'];
 		$async_id = !empty($_vacation['id']) ? $_vacation['id'] : 'mail-vacation-'.$_vacation['account_id'];
 		$async->delete($async_id);
@@ -773,13 +774,13 @@ class mail_sieve
 	 * Callback for the async job to enable/disable the vacation message
 	 *
 	 * @param array $_vacation
-	 * @throws egw_exception_not_found if mail account is not found
+	 * @throws Api\Exception\NotFound if mail account is not found
 	 */
 	static function async_vacation(array $_vacation)
 	{
 		//error_log(__METHOD__.'('.array2string($_vacation).')');
 
-		$account = emailadmin_account::read($_vacation['acc_id'], $_vacation['account_id']);
+		$account = Mail\Account::read($_vacation['acc_id'], $_vacation['account_id']);
 		$icServer = $account->imapServer($_vacation['account_id']);
 
 		//error_log(__METHOD__.'() imap username='.$icServer->acc_imap_username);
@@ -790,7 +791,7 @@ class mail_sieve
 			self::setAsyncJob($_vacation);
 		}
 		// if mail account no longer exists --> remove async job
-		catch (egw_exception_not_found $e)
+		catch (Api\Exception\NotFound $e)
 		{
 			$_vacation['status'] = 'off';
 			self::setAsyncJob($_vacation);
@@ -901,7 +902,7 @@ class mail_sieve
 		$this->saveSessionData();
 
 		//Calling to referesh after move action
-		$response = egw_json_response::get();
+		$response = Api\Json\Response::get();
 		$response->call('app.mail.sieve_refresh');
 	}
 
@@ -947,7 +948,7 @@ class mail_sieve
 		ob_start();
 		$result = $this->updateScript();
 
-		$response = egw_json_response::get();
+		$response = Api\Json\Response::get();
 
 		if($result)
 		{
@@ -1058,7 +1059,7 @@ class mail_sieve
 			{
 				$newruletext .= ", ";
 			}
-			$btransform_ctype = emailadmin_script::$btransform_ctype_array[$rule['ctype']];
+			$btransform_ctype = Mail\Script::$btransform_ctype_array[$rule['ctype']];
 			$ctype_subtype = "";
 			if ($rule['field_ctype_val'])
 			{
@@ -1066,7 +1067,7 @@ class mail_sieve
 			}
 			$complete .= " body :content " . " \"" . $btransform_ctype . $ctype_subtype . $rule['field_ctype_val'] . "\"" . " :contains \"\"";
 			$started = 1;
-			//error_log(__CLASS__."::".__METHOD__.array2string(emailadmin_script::$btransform_ctype_array));
+			//error_log(__CLASS__."::".__METHOD__.array2string(Mail\Script::$btransform_ctype_array));
 		}
 		if (!$rule['unconditional'])
 		{
@@ -1171,19 +1172,19 @@ class mail_sieve
 	 */
 	function getRules($ruleID = null)
 	{
-		if(PEAR::isError($error = $this->account->imapServer()->retrieveRules()) )
-		{
-			error_log(__METHOD__.__LINE__.$error->message);
-			$this->rules	= array();
-			$this->rulesByID = array();
-			$this->vacation	= array();
-		}
-		else
-		{
+		try {
+			$this->account->imapServer()->retrieveRules();
 			$this->rules	= $this->account->imapServer()->getRules();
 			$this->rulesByID = $this->rules[$ruleID];
 			$this->vacation	= $this->account->imapServer()->getVacation();
 		}
+		catch(Exception $e) {
+			error_log(__METHOD__.__LINE__.$e->getMessage().': '.$e->details);
+			$this->rules	= array();
+			$this->rulesByID = array();
+			$this->vacation	= array();
+			return false;
+		}
 		return true;
 	}
 
