@@ -9,12 +9,15 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+
 /**
- * Wizard to create mail accounts
+ * Wizard to create mail Api\Accounts
  *
- * Extends emailadmin_wizard to allow non-admins to use it.
+ * Extends admin_mail to allow non-admins to use it.
  */
-class mail_wizard extends emailadmin_wizard
+class mail_wizard extends admin_mail
 {
 	/**
 	 * Prefix for callback names
@@ -29,11 +32,11 @@ class mail_wizard extends emailadmin_wizard
 		parent::__construct();
 
 		// need emailadmin's app.css file
-		egw_framework::includeCSS('emailadmin','app');
+		Framework::includeCSS('admin','app');
 
 		// and translations
-		translation::add_app('emailadmin');
+		Api\Translation::add_app('admin');
 
-		egw_framework::validate_file('/emailadmin/js/app.js');
+		Framework::includeJS('/admin/js/app.js');
 	}
 }
\ No newline at end of file
