@@ -6,14 +6,14 @@
  * @package mail
  * @subpackage setup
  * @author Stylite AG [info@stylite.de]
- * @copyright (c) 2013-14 by Stylite AG <info-AT-stylite.de>
+ * @copyright (c) 2013-16 by Stylite AG <info-AT-stylite.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
 $setup_info['mail']['name']      	= 'mail';
 $setup_info['mail']['title']     	= 'mail';
-$setup_info['mail']['version']     	= '14.1';
+$setup_info['mail']['version']     	= '16.1';
 $setup_info['mail']['app_order'] 	= 2;
 $setup_info['mail']['enable']    	= 1;
 $setup_info['mail']['index']    	= 'mail.mail_ui.index&ajax=true';
@@ -32,24 +32,16 @@ $setup_info['mail']['hooks']['search_link'] = 'mail_hooks::search_link';
 $setup_info['mail']['hooks']['admin'] = 'mail_hooks::admin';
 $setup_info['mail']['hooks']['settings'] = 'mail_hooks::settings';
 $setup_info['mail']['hooks']['sidebox_menu'] = 'mail_hooks::sidebox_menu';
-$setup_info['mail']['hooks']['session_creation'] = 'mail_bo::resetConnectionErrorCache';
-$setup_info['mail']['hooks']['verify_settings'] = 'mail_bo::forcePrefReload';
-$setup_info['mail']['hooks']['clear_cache'] = 'mail_bo::unsetCachedObjects';
+$setup_info['mail']['hooks']['session_creation'] = 'EGroupware\\Api\\Mail::resetConnectionErrorCache';
+$setup_info['mail']['hooks']['verify_settings'] = 'EGroupware\\Api\\Mail::forcePrefReload';
+$setup_info['mail']['hooks']['clear_cache'] = 'EGroupware\\Api\\Mail::unsetCachedObjects';
 $setup_info['mail']['hooks']['check_notify'] = 'mail_hooks::notification_check_mailbox';
 $setup_info['mail']['hooks']['emailadmin_edit'] = 'mail_hooks::emailadmin_edit';
 
 /* Dependencies for this app to work */
 $setup_info['mail']['depends'][] = array(
-	'appname'  => 'phpgwapi',
-	'versions' => Array('14.1')
-);
-$setup_info['mail']['depends'][] = array(
-	'appname'  => 'etemplate',
-	'versions' => Array('14.1')
-);
-$setup_info['mail']['depends'][] = array(
-	'appname'  => 'emailadmin',
-	'versions' => Array('14.1')
+	'appname'  => 'api',
+	'versions' => Array('16.1')
 );
 // installation checks for mail
 $setup_info['mail']['check_install'] = array(
