@@ -11,6 +11,8 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 // give Admins group rights for news_admin
 $admingroup = $GLOBALS['egw_setup']->add_account('Admins','Admin','Group',False,False);
 $GLOBALS['egw_setup']->add_acl('news_admin','run',$admingroup);
@@ -25,7 +27,7 @@ $GLOBALS['egw_setup']->add_acl('news_admin','run',$anonymous);
 $GLOBALS['egw_setup']->add_acl('phpgwapi','anonymous',$anonymous);
 
 // Create news category "news" writable be Admins group and readable by every user (not anonymous)
-$global_cat_owner = categories::GLOBAL_ACCOUNT;
+$global_cat_owner = Api\Categories::GLOBAL_ACCOUNT;
 $oProc->query("INSERT INTO {$GLOBALS['egw_setup']->cats_table} (cat_parent,cat_owner,cat_access,cat_appname,cat_name,cat_description,last_mod)
 	VALUES (0,$global_cat_owner,'public','news_admin','News','Category for news',".time().")");
 $cat_id = $oProc->m_odb->get_last_insert_id($GLOBALS['egw_setup']->cats_table,'cat_id');
@@ -55,5 +57,5 @@ foreach(array(
 	$GLOBALS['egw_setup']->add_acl('news_admin','L'.$egw_cat_id,$user,$rights);
 }
 // add import job
-$async = new asyncservice();
+$async = new Api\Asyncservice();
 $async->set_timer(array('hour' => '*'),'news_admin-import','news_admin.news_admin_import.async_import',null);
