@@ -1,6 +1,7 @@
 <?php
 /**
- * eGroupWare - Notifications
+ * EGroupware - Notifications
+ *
  * serves the hook "after_navbar" to create the notificationwindow
  *
  * @abstract notificatonwindow is an empty and non displayed 1px div which gets rezised
@@ -12,17 +13,19 @@
  * @author Cornelius Weiss <nelius@cwtech.de>
  * @version $Id$
  */
+
+use EGroupware\Api;
 if ($GLOBALS['egw_info']['user']['apps']['notifications'])
 {
-	$notification_config = config::read('notifications');
-	translation::add_app('notifications');
+	$notification_config = Api\Config::read('notifications');
+	Api\Translation::add_app('notifications');
 	$popup_poll_interval = empty($notification_config['popup_poll_interval']) ? 60 : $notification_config['popup_poll_interval'];
 	echo '<script src="'. $GLOBALS['egw_info']['server']['webserver_url']. '/notifications/js/notificationajaxpopup.js?'.
 		filemtime(EGW_SERVER_ROOT.'/notifications/js/notificationajaxpopup.js'). '" type="text/javascript" id="notifications_script_id" data-poll-interval="'.$popup_poll_interval.'"></script>';
 	echo '
 		<div id="egwpopup" style="display: none; z-index: 999;">
 			<div id="egwpopup_header">'.lang('Notification'). '<span style="float:right;">'.
-				html::submit_button('egwpopup_close_button', 'X', '', true, 'id="egwpopup_close_button"', 'close.button') .
+				Api\Html::submit_button('egwpopup_close_button', 'X', '', true, 'id="egwpopup_close_button"', 'close.button') .
 			'</span></div>
 			<div id="egwpopup_message"></div>
 			<div id="egwpopup_footer">
