@@ -6,7 +6,7 @@
  * @package notifications
  * @link http://www.egroupware.org
  * @author Cornelius Weiss <nelius@cwtech.de>
- * @version $Id: tables_current.inc.php 42756 2013-06-12 16:57:44Z ralfbecker $
+ * @version $Id$
  */
 
 $phpgw_baseline = array(
@@ -14,9 +14,9 @@ $phpgw_baseline = array(
 		'fd' => array(
 			'notify_id' => array('type' => 'auto','nullable' => False,'comment' => 'primary key'),
 			'account_id' => array('type' => 'int','meta' => 'user','precision' => '20','nullable' => False,'comment' => 'user to notify'),
-			'notify_message' => array('type' => 'text','comment' => 'notification message'),
+			'notify_message' => array('type' => 'varchar','precision' => '16384','comment' => 'notification message'),
 			'notify_created' => array('type' => 'timestamp','meta' => 'timestamp','default' => 'current_timestamp','comment' => 'creation time of notification'),
-			'notify_type' => array('type' => 'varchar','precision' => '32','comment' => 'notification type')
+			'notify_type' => array('type' => 'ascii','precision' => '32','comment' => 'notification type')
 		),
 		'pk' => array('notify_id'),
 		'fk' => array(),
