@@ -1874,7 +1874,7 @@ class uikb extends bokb
 			$num_main_cat ++;
 			$categories_str .= "<tr><td valign=top>";
 			if ($cat['icon'])
-					$categories_str .= "<img src='" . $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/images/' . $cat['icon'] . "'>";
+					$categories_str .= "<img src='" . $GLOBALS['egw_info']['server']['webserver_url'] . '/api/images/' . $cat['icon'] . "'>";
 			$categories_str .= "</td><td><a href='".$this->link('menuaction=phpbrain.uikb.index&cat='.$cat['id'])
 									."'><b>".$cat['name']."</b></a><br><div style='padding-left:10px'>";
 			$has_subcats = False;
