@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupWare API: Commononly used (static) functions
+ * EGroupware API: Commononly used (static) functions
  *
  * This file written by Dan Kuykendall <seek3r@phpgroupware.org>
  * and Joseph Engo <jengo@phpgroupware.org>
@@ -16,8 +16,12 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
- * common class containing commonly used static functions
+ * Commononly used (static) functions
+ *
+ * @deprecated use Api\* alternatives mentioned in individual methods
  */
 class common
 {
@@ -29,43 +33,14 @@ class common
 	 *
 	 * This method uses the language and nationalty set in the users common prefs.
 	 *
-	 * @param $category=LC_ALL category to set, see setlocal function
-	 * @param $charset=null default system charset
+	 * @param $category =LC_ALL category to set, see setlocal function
+	 * @param $charset =null default system charset
 	 * @return string the local (or best estimate) set
+	 * @deprecated use Api\Preferences::setlocal($category,$charset)
 	 */
-	static function setlocale($category=LC_ALL,$charset=null)
+	static function setlocale($category=LC_ALL, $charset=null)
 	{
-		$lang = $GLOBALS['egw_info']['user']['preferences']['common']['lang'];
-		$country = $GLOBALS['egw_info']['user']['preferences']['common']['country'];
-
-		if (strlen($lang) == 2)
-		{
-			$country_from_lang = strtoupper($lang);
-		}
-		else
-		{
-			list($lang,$lang2) = explode('-',$lang);
-			$country_from_lang = strtoupper($lang2);
-		}
-		if (is_null($charset)) $charset = translation::charset();
-
-		foreach(array(
-			$lang.'_'.$country,
-			$lang.'_'.$country_from_lang,
-			$lang,
-			'en_US',
-			'C',
-		) as $local)
-		{
-			if (($ret = setlocale($category,$local.'@'.$charset)) ||
-				($ret = setlocale($category,$local)))
-			{
-				//error_log(__METHOD__."($category,$charset) lang=$lang, country=$country, country_from_lang=$country_from_lang: returning '$ret'");
-				return $ret;
-			}
-		}
-		error_log(__METHOD__."($category,$charset) lang=$lang, country=$country, country_from_lang=$country_from_lang: Could not set local!");
-		return false;	// should not happen, as the 'C' local should at least be available everywhere
+		return Api\Preferences::setlocale($category, $charset);
 	}
 
 	/**
@@ -74,6 +49,7 @@ class common
 	 * This function checks for major version only.
 	 * @param $str1
 	 * @param $str2
+	 * @deprecated not used anymore
 	 */
 	static function cmp_version($str1,$str2,$debug=False)
 	{
@@ -106,6 +82,7 @@ class common
 	 * This function checks all fields. cmp_version() checks release version only.
 	 * @param $str1
 	 * @param $str2
+	 * @deprecated not used anymore
 	 */
 	static function cmp_version_long($str1,$str2,$debug=False)
 	{
@@ -138,28 +115,25 @@ class common
 	}
 
 	/**
-	* generate a unique id, which can be used for syncronisation
-	*
-	* @param string $_appName the appname
-	* @param string $_eventID the id of the content
-	* @return string the unique id
-	*/
+	 * generate a unique id, which can be used for syncronisation
+	 *
+	 * @param string $_appName the appname
+	 * @param string $_eventID the id of the content
+	 * @deprecated use Api\CalDAV::generate_uid($_appName, $_eventID)
+	 * @return string the unique id
+	 */
 	static function generate_uid($_appName, $_eventID)
 	{
-		if(empty($_appName) || empty($_eventID)) return false;
-
-		// not used: $suffix = $GLOBALS['egw_info']['server']['hostname'] ? $GLOBALS['egw_info']['server']['hostname'] : 'local';
-		$prefix = $_appName.'-'.$_eventID.'-'.$GLOBALS['egw_info']['server']['install_id'];
-
-		return $prefix;
+		return Api\CalDAV::generate_uid($_appName, $_eventID);
 	}
 
 	/**
-	* get the local content id from a global UID
-	*
-	* @param sting $_globalUid the global UID
-	* @return int local egw content id
-	*/
+	 * get the local content id from a global UID
+	 *
+	 * @param sting $_globalUid the global UID
+	 * @deprecated dont use, as only EGroupware interal uids are reversable
+	 * @return int local egw content id
+	 */
 	static function get_egwId($_globalUid)
 	{
 		if(empty($_globalUid)) return false;
@@ -175,6 +149,7 @@ class common
 	 * return an array of installed languages
 	 *
 	 * @return $installedLanguages; an array containing the installed languages
+	 * @deprecated not used anymore
 	 */
 	static function getInstalledLanguages()
 	{
@@ -193,6 +168,7 @@ class common
 	 * Uses HTTP_ACCEPT_LANGUAGE (from the browser) and getInstalledLanguages to find out which languages are installed
 	 *
 	 * @return string
+	 * @deprecated not used anymore
 	 */
 	static function getPreferredLanguage()
 	{
@@ -230,36 +206,35 @@ class common
 	 * It's actually a PHP-Bug, that we have to escape space.
 	 * For all other Characters, refer to RFC2254.
 	 *
-	 * @deprecated use ldap::quote()
+	 * @deprecated use Api\Ldap::quote()
 	 * @param $string either a string to be escaped, or an array of values to be escaped
 	 * @return string
 	 */
 	static function ldap_addslashes($string='')
 	{
-		return ldap::quote($string);
+		return Api\Ldap::quote($string);
 	}
 
 	/**
 	 * connect to the ldap server and return a handle
 	 *
-	 * @deprecated use ldap::ldapConnect()
-	 * @param $host ldap host
-	 * @param $dn ldap_root_dn
-	 * @param $passwd ldap_root_pw
+	 * @deprecated use Api\Ldap::factory(true, $host, $dn, $passwd)
+	 * @param string $host ='' ldap host
+	 * @param string $dn ='' ldap_root_dn
+	 * @param string $passwd ='' ldap_root_pw
 	 * @return resource
 	 */
 	static function ldapConnect($host='', $dn='', $passwd='')
 	{
 		// use Lars new ldap class
-		return $GLOBALS['egw']->ldap->ldapConnect($host,$dn,$passwd);
+		return Api\Ldap::factory(true, $host, $dn, $passwd);
 	}
 
 	/**
 	 * function to stop running an app
 	 *
-	 * used to stop running an app in the middle of execution <br>
-	 * There may need to be some cleanup before hand
 	 * @param $call_footer boolean value to if true then call footer else exit
+	 * @deprecated use $GLOBALS['egw']->framework->footer(), if necessary, and exit
 	 */
 	static function egw_exit($call_footer = False)
 	{
@@ -279,25 +254,16 @@ class common
 	 * return a random string of size $size
 	 *
 	 * @param $size int-size of random string to return
+	 * @deprecated use Api\Auth::randomstring($size)
 	 */
 	static function randomstring($size)
 	{
-		static $random_char = array(
-			'0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f',
-			'g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v',
-			'w','x','y','z','A','B','C','D','E','F','G','H','I','J','K','L',
-			'M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'
-		);
-
-		$s = '';
-		for ($i=0; $i < $size; $i++)
-		{
-			$s .= $random_char[mt_rand(0,count($random_char)-1)];
-		}
-		return $s;
+		return Api\Auth::randomstring($size);
 	}
 
-	// Look at the note towards the top of this file (jengo)
+	/**
+	 * @deprecated just use forward slashes supported by PHP on all OS
+	 */
 	static function filesystem_separator()
 	{
 		return filesystem_separator();
@@ -307,6 +273,7 @@ class common
 	 * This is used for reporting errors in a nice format.
 	 *
 	 * @param $error - array of errors
+	 * @deprecated not used anymore
 	 */
 	static function error_list($errors,$text='Error')
 	{
@@ -327,80 +294,27 @@ class common
 	/**
 	 * return the fullname of a user
 	 *
-	 * @param $lid='' account loginid
-	 * @param $firstname='' firstname
-	 * @param $lastname='' lastname
-	 * @param $accountid=0 id, to check if it's a user or group, otherwise the lid will be used
+	 * @param $lid ='' account loginid
+	 * @param $firstname ='' firstname
+	 * @param $lastname ='' lastname
+	 * @param $accountid =0 id, to check if it's a user or group, otherwise the lid will be used
+	 * @deprecated use Api\Accounts::format_username()
 	 */
 	static function display_fullname($lid = '', $firstname = '', $lastname = '',$accountid=0)
 	{
-		if (! $lid && ! $firstname && ! $lastname)
-		{
-			$lid       = $GLOBALS['egw_info']['user']['account_lid'];
-			$firstname = $GLOBALS['egw_info']['user']['account_firstname'];
-			$lastname  = $GLOBALS['egw_info']['user']['account_lastname'];
-		}
-		$is_group = $GLOBALS['egw']->accounts->get_type($accountid ? $accountid : $lid) == 'g';
-
-		if (empty($firstname)) $firstname = $lid;
-		if (empty($lastname) || $is_group)
-		{
-			$lastname  = $is_group ? lang('Group') : lang('User');
-		}
-		$display = $GLOBALS['egw_info']['user']['preferences']['common']['account_display'];
-
-		if ($firstname && $lastname)
-		{
-			$delimiter = $is_group ? ' ' : ', ';
-		}
-		else
-		{
-			$delimiter = '';
-		}
-
-		$name = '';
-		switch($display)
-		{
-			case 'firstname':
-				$name = $firstname . ' ' . $lastname;
-				break;
-			case 'lastname':
-				$name = $lastname . $delimiter . $firstname;
-				break;
-			case 'username':
-				$name = $lid;
-				break;
-			case 'firstall':
-				$name = $firstname . ' ' . $lastname . ' ['.$lid.']';
-				break;
-			case 'lastall':
-				$name = $lastname . $delimiter . $firstname . ' ['.$lid.']';
-				break;
-			case 'allfirst':
-				$name = '['.$lid.'] ' . $firstname . ' ' . $lastname;
-				break;
-			case 'all':
-				/* fall through */
-			default:
-				$name = '['.$lid.'] ' . $lastname . $delimiter . $firstname;
-		}
-		return $name;
+		return Api\Accounts::format_username($lid, $firstname, $lastname, $accountid);
 	}
 
 	/**
-	 * grab the owner name
+	 * Return formatted username for a given account_id
 	 *
-	 * @param $id account id
+	 * @param string $accountid =null account id
 	 * @return string full name of user or "#$accountid" if user not found
+	 * @deprecated use Api\Accounts::username($accountid)
 	 */
-	static function grab_owner_name($accountid = '')
+	static function grab_owner_name($accountid=null)
 	{
-		$lid = $fname = $lname = null;
-		if (!$GLOBALS['egw']->accounts->get_account_name($accountid,$lid,$fname,$lname))
-		{
-			return '#'.$accountid;
-		}
-		return self::display_fullname($lid,$fname,$lname,$accountid);
+		return Api\Accounts::username($accountid);
 	}
 
 	/**
@@ -414,6 +328,7 @@ class common
 	 * 		 * 		 * 	 page in a new browser window.
 	 * @param mixed $selected the tab whos key is $selected will be displayed as current tab
 	 * @param $fontsize optional
+	 * @deprecated not used anymore
 	 * @return string return html that displays the tabs
 	 */
 	static function create_tabs($tabs, $selected, $fontsize = '')
@@ -574,54 +489,11 @@ class common
 	 *
 	 * @param $appname appication name optional can be derived from $GLOBALS['egw_info']['flags']['currentapp'];
 	 * @return string|boolean dir or false if no dir is found
+	 * @deprecated use Api\Framework\Template::get_dir($appname)
 	 */
 	static function get_tpl_dir($appname = '')
 	{
-		if (!$appname)
-		{
-			$appname = $GLOBALS['egw_info']['flags']['currentapp'];
-		}
-		if ($appname == 'logout' || $appname == 'login')
-		{
-			$appname = 'phpgwapi';
-		}
-
-		if (!isset($GLOBALS['egw_info']['server']['template_set']) && isset($GLOBALS['egw_info']['user']['preferences']['common']['template_set']))
-		{
-			$GLOBALS['egw_info']['server']['template_set'] = $GLOBALS['egw_info']['user']['preferences']['common']['template_set'];
-		}
-
-		// Setting this for display of template choices in user preferences
-		if ($GLOBALS['egw_info']['server']['template_set'] == 'user_choice')
-		{
-			$GLOBALS['egw_info']['server']['usrtplchoice'] = 'user_choice';
-		}
-
-		if (($GLOBALS['egw_info']['server']['template_set'] == 'user_choice' ||
-			!isset($GLOBALS['egw_info']['server']['template_set'])) &&
-			isset($GLOBALS['egw_info']['user']['preferences']['common']['template_set']))
-		{
-			$GLOBALS['egw_info']['server']['template_set'] = $GLOBALS['egw_info']['user']['preferences']['common']['template_set'];
-		}
-		if (!file_exists(EGW_SERVER_ROOT.'/phpgwapi/templates/'.basename($GLOBALS['egw_info']['server']['template_set']).'/class.'.
-			$GLOBALS['egw_info']['server']['template_set'].'_framework.inc.php') &&
-			!file_exists(EGW_SERVER_ROOT.'/'.basename($GLOBALS['egw_info']['server']['template_set']).'/inc/class.'.
-			$GLOBALS['egw_info']['server']['template_set'].'_framework.inc.php'))
-		{
-			$GLOBALS['egw_info']['server']['template_set'] = 'idots';
-		}
-		$tpldir         = EGW_SERVER_ROOT . '/' . $appname . '/templates/' . $GLOBALS['egw_info']['server']['template_set'];
-		$tpldir_default = EGW_SERVER_ROOT . '/' . $appname . '/templates/default';
-
-		if (@is_dir($tpldir))
-		{
-			return $tpldir;
-		}
-		elseif (@is_dir($tpldir_default))
-		{
-			return $tpldir_default;
-		}
-		return False;
+		return Api\Framework\Template::get_dir($appname);
 	}
 
 	/**
@@ -732,93 +604,43 @@ class common
 	}
 
 	/**
-	 * @deprecated use image($app,$image) they are identical now
+	 * @deprecated use Api\Image::find($app,$image) they are identical now
 	 */
 	static function find_image($app,$image)
 	{
-		return self::image($app,$image);
+		return Api\Image::find($app,$image);
 	}
 
 	/**
 	 * Searches an image of a given type, if not found also without extension
 	 *
-	 * @param string $appname
+	 * @param string $app
 	 * @param string|array $image one or more image-name in order of precedence
-	 * @param string $extension='' extension to $image, makes sense only with an array
-	 * @param boolean $svg=false should svg images be returned or not:
+	 * @param string $extension ='' extension to $image, makes sense only with an array
+	 * @param boolean $svg =false should svg images be returned or not:
 	 *	true: always return svg, false: never return svg (current default), null: browser dependent, see svg_usable()
 	 * @return string url of image or null if not found
+	 * @deprecated not used in newer template
 	 */
 	static function image_on($app,$image,$extension='_on',$svg=false)
 	{
-		return ($img = self::image($app,$image,$extension,$svg)) ? $img : self::image($app,$image,'',$svg);
+		return ($img = Api\Image::find($app,$image,$extension,$svg)) ? $img : Api\Image::find($app,$image,'',$svg);
 	}
 
 	/**
 	 * Searches a appname, template and maybe language and type-specific image
 	 *
-	 * @param string $appname
+	 * @param string $app
 	 * @param string|array $image one or more image-name in order of precedence
-	 * @param string $extension='' extension to $image, makes sense only with an array
-	 * @param boolean $svg=false should svg images be returned or not:
+	 * @param string $extension ='' extension to $image, makes sense only with an array
+	 * @param boolean $_svg =false should svg images be returned or not:
 	 *	true: always return svg, false: never return svg (current default), null: browser dependent, see svg_usable()
 	 * @return string url of image or null if not found
+	 * @deprecated use Api\Image::find($app,$image,$extension='',$_svg=false)
 	 */
-	static function image($app,$image,$extension='',$svg=false)
+	static function image($app,$image,$extension='',$_svg=false)
 	{
-		static $image_map_no_svg = null, $image_map_svg = null;
-		if (is_null($svg)) $svg = self::svg_usable ();
-		if ($svg)
-		{
-			$image_map =& $image_map_svg;
-		}
-		else
-		{
-			$image_map =& $image_map_no_svg;
-		}
-		if (is_null($image_map)) $image_map = self::image_map(null, $svg);
-
-		// array of images in descending precedence
-		if (is_array($image))
-		{
-			foreach($image as $img)
-			{
-				if (($url = self::image($app, $img, $extension)))
-				{
-					return $url;
-				}
-			}
-			//error_log(__METHOD__."('$app', ".array2string($image).", '$extension') NONE found!");
-			return null;
-		}
-
-		$webserver_url = $GLOBALS['egw_info']['server']['webserver_url'];
-
-		// instance specific images have highest precedence
-		if (isset($image_map['vfs'][$image.$extension]))
-		{
-			return $webserver_url.$image_map['vfs'][$image.$extension];
-		}
-		// then app specific ones
-		if(isset($image_map[$app][$image.$extension]))
-		{
-			return $webserver_url.$image_map[$app][$image.$extension];
-		}
-		// then api
-		if(isset($image_map['phpgwapi'][$image.$extension]))
-		{
-			return $webserver_url.$image_map['phpgwapi'][$image.$extension];
-		}
-
-		// if image not found, check if it has an extension and try withoug
-		if (strpos($image, '.') !== false)
-		{
-			$name = null;
-			self::get_extension($image, $name);
-			return self::image($app, $name, $extension);
-		}
-		//error_log(__METHOD__."('$app', '$image', '$extension') image NOT found!");
-		return null;
+		return Api\Image::find($app, $image, $extension, $_svg);
 	}
 
 	/**
@@ -827,10 +649,11 @@ class common
 	 * All non IE and IE 9+
 	 *
 	 * @return boolean
+	 * @deprecated use Api\Image::svg_usable()
 	 */
 	static function svg_usable()
 	{
-		return html::$user_agent !== 'msie' || html::$ua_version >= 9;
+		return Api\Image::svg_usable();
 	}
 
 	/**
@@ -841,131 +664,24 @@ class common
 	 *
 	 * VFS image directory is treated like an application named 'vfs'.
 	 *
-	 * @param string $template_set=null 'default', 'idots', 'jerryr', default is template-set from user prefs
-	 * @param boolean $svg=null prefer svg images, default for all browsers but IE<9
+	 * @param string $template_set =null 'default', 'idots', 'jerryr', default is template-set from user prefs
+	 * @param boolean $svg =null prefer svg images, default for all browsers but IE<9
 	 * @return array of application => image-name => full path
+	 * @deprecated use Api\Image::map($template_set=null, $svg=null)
 	 */
 	static function image_map($template_set=null, $svg=null)
 	{
-		if (is_null($template_set))
-		{
-			$template_set = $GLOBALS['egw_info']['server']['template_set'];
-		}
-		if (is_null($svg))
-		{
-			$svg = self::svg_usable();
-		}
-		$cache_name = 'image_map_'.$template_set.($svg ? '_svg' : '');
-		if (($map = egw_cache::getInstance(__CLASS__, $cache_name)))
-		{
-			return $map;
-		}
-		//$starttime = microtime(true);
-
-		// priority: : PNG->JPG->GIF
-		$img_types = array('png','jpg','gif','ico');
-
-		// if we want svg, prepend it to img-types
-		if ($svg) array_unshift ($img_types, 'svg');
-
-		$map = array();
-		foreach(scandir(EGW_SERVER_ROOT) as $app)
-		{
-			if ($app[0] == '.' || !is_dir(EGW_SERVER_ROOT.'/'.$app) || !file_exists(EGW_SERVER_ROOT.'/'.$app.'/templates')) continue;
-
-			$app_map =& $map[$app];
-			if (true) $app_map = array();
-			$imagedirs = array();
-			if ($app == 'phpgwapi')
-			{
-				$imagedirs[] = $GLOBALS['egw']->framework->template_dir.'/images';
-			}
-			else
-			{
-				$imagedirs[] = '/'.$app.'/templates/'.$template_set.'/images';
-			}
-			if ($template_set != 'idots') $imagedirs[] = '/'.$app.'/templates/idots/images';
-			$imagedirs[] = '/'.$app.'/templates/default/images';
-
-			foreach($imagedirs as $imagedir)
-			{
-				if (!file_exists($dir = EGW_SERVER_ROOT.$imagedir) || !is_readable($dir)) continue;
-
-				foreach(scandir($dir) as $img)
-				{
-					if ($img[0] == '.') continue;
-
-					$subdir = null;
-					foreach(is_dir($dir.'/'.$img) ? scandir($dir.'/'.($subdir=$img)) : (array) $img as $img)
-					{
-						$name = null;
-						if (!in_array($ext = self::get_extension($img, $name), $img_types) || empty($name)) continue;
-
-						if (isset($subdir)) $name = $subdir.'/'.$name;
-
-						if (!isset($app_map[$name]) || array_search($ext, $img_types) < array_search(self::get_extension($app_map[$name]), $img_types))
-						{
-							$app_map[$name] = $imagedir.'/'.$name.'.'.$ext;
-						}
-					}
-				}
-			}
-		}
-		$app_map =& $map['vfs'];
-		if (true) $app_map = array();
-		if (($dir = $GLOBALS['egw_info']['server']['vfs_image_dir']) && egw_vfs::file_exists($dir) && egw_vfs::is_readable($dir))
-		{
-			foreach(egw_vfs::find($dir) as $img)
-			{
-				if (!in_array($ext = self::get_extension($img, $name), $img_types) || empty($name)) continue;
-
-				if (!isset($app_map[$name]) || array_search($ext, $img_types) < array_search(self::get_extension($app_map[$name]), $img_types))
-				{
-					$app_map[$name] = egw_vfs::download_url($img);
-				}
-			}
-		}
-		else if ($dir)
-		{
-			return $map;
-		}
-		//error_log(__METHOD__."('$template_set') took ".(microtime(true)-$starttime).' secs');
-		egw_cache::setInstance(__CLASS__, $cache_name, $map, 86400);	// cache for one day
-		//echo "<p>template_set=".array2string($template_set)."</p>\n"; _debug_array($map);
-		return $map;
+		return Api\Image::map($template_set, $svg);
 	}
 
 	/**
 	 * Delete image map cache for ALL template sets
+	 *
+	 * @deprecated use Api\Image::invalidate()
 	 */
 	public static function delete_image_map()
 	{
-		$templates = array('idots', 'jerryr', 'jdots', 'pixelegg');
-		if (($template_set = $GLOBALS['egw_info']['user']['preferences']['common']['template_set']) && !in_array($template_set, $templates))
-		{
-			$templates[] = $template_set;
-		}
-		//error_log(__METHOD__."() for templates ".array2string($templates));
-		foreach($templates as $template_set)
-		{
-			egw_cache::unsetInstance(__CLASS__, 'image_map_'.$template_set);
-			egw_cache::unsetInstance(__CLASS__, 'image_map_'.$template_set.'_svg');
-		}
-	}
-
-	/**
-	 * Get extension (and optional basename without extension) of a given path
-	 *
-	 * @param string $path
-	 * @param string &$name on return basename without extension
-	 * @return string extension without dot, eg. 'php'
-	 */
-	public static function get_extension($path, &$name=null)
-	{
-		$parts = explode('.', basename($path));
-		$ext = array_pop($parts);
-		$name = implode('.', $parts);
-		return $ext;
+		return Api\Image::invalidate();
 	}
 
 	/**
@@ -1052,6 +768,9 @@ class common
 		return egw_framework::_get_body_attribs();
 	}
 
+	/**
+	 * @deprecated not used anymore
+	 */
 	static function hex2bin($data)
 	{
 		$len = strlen($data);
@@ -1061,6 +780,7 @@ class common
 	/**
 	 * encrypt data passed to the function
 	 *
+	 * @deprecated not used anymore
 	 * @param $data data (string?) to be encrypted
 	 */
 	static function encrypt($data)
@@ -1071,6 +791,7 @@ class common
 	/**
 	 * decrypt $data
 	 *
+	 * @deprecated not used anymore
 	 * @param $data data to be decrypted
 	 */
 	static function decrypt($data)
@@ -1119,10 +840,10 @@ class common
 	/**
 	 * return a formatted timestamp or current time
 	 *
-	 * @param int $t=0 timestamp, default current time
-	 * @param string $format='' timeformat, default '' = read from the user prefernces
-	 * @param boolean $adjust_to_usertime=true should datetime::tz_offset be added to $t or not, default true
-	 * @deprecated use egw_time::to($time, $format) egw_time::server2user($time, $format)
+	 * @param int $t =0 timestamp, default current time
+	 * @param string $format ='' timeformat, default '' = read from the user prefernces
+	 * @param boolean $adjust_to_usertime =true should datetime::tz_offset be added to $t or not, default true
+	 * @deprecated use Api\DateTime::to($time, $format) Api\DateTime::server2user($time, $format)
 	 * @return string the formated date/time
 	 */
 	static function show_date($t = 0, $format = '', $adjust_to_usertime=true)
@@ -1139,8 +860,9 @@ class common
 	 *
 	 * @param string $yearstr year
 	 * @param string $monthstr month
-	 * @param string $day day
-	 * @param boolean $add_seperator=false add the separator specifed in the prefs or not, default no
+	 * @param string $daystr day
+	 * @param boolean $add_seperator =false add the separator specifed in the prefs or not, default no
+	 * @deprecated use Api\DateTime->format()
 	 * @return string
 	 */
 	static function dateformatorder($yearstr,$monthstr,$daystr,$add_seperator = False)
@@ -1165,7 +887,8 @@ class common
 	 *
 	 * @param int $hour hour
 	 * @param int $min minutes
-	 * @param int/string $sec='' defaults to ''
+	 * @param int|string $sec ='' defaults to ''
+	 * @deprecated use Api\DateTime->format()
 	 * @return string formated time
 	 */
 	static function formattime($hour,$min,$sec='')
@@ -1211,18 +934,11 @@ class common
 	 *
 	 * @param string $str
 	 * @return string
+	 * @deprecated use Api\Translation::to_ascii
 	 */
 	public static function transliterate($str)
 	{
-		static $extra = array(
-			'&szlig;' => 'ss',
-			' ' => '',
-		);
-		$entities = htmlentities($str, ENT_QUOTES,translation::charset());
-		$extra_replaced = str_replace(array_keys($extra),array_values($extra),$entities);
-		$umlauts = preg_replace('/&([aAuUoO])uml;/','\\1e',$extra_replaced);	// replace german umlauts with the letter plus one 'e'
-		$accents = preg_replace('/&([a-zA-Z])(grave|acute|circ|ring|cedil|tilde|slash|uml);/','\\1',$umlauts);	// remove all types of acents
-		return preg_replace('/&([a-zA-Z]+|#[0-9]+|);/','',$accents);	// remove all other entities
+		return Api\Translation::to_ascii($str);
 	}
 
 	/**
@@ -1235,37 +951,11 @@ class common
 	 * @param string $account account-name (lid)
 	 * @param string $domain =null domain-name or null to use eGW's default domain $GLOBALS['egw_info']['server']['mail_suffix]
 	 * @return string with email address
+	 * @deprecated use Api\Accounts::email($first, $last, $account, $domain)
 	 */
 	static function email_address($first,$last,$account,$domain=null)
 	{
-		//echo "<p align=right>common::email_address('$first','$last','$account')";
-		foreach (array('first','last','account') as $name)
-		{
-			$$name = self::transliterate($$name);
-		}
-		//echo " --> ('$first', '$last', '$account')";
-		if (!$first && !$last)	// fallback to the account-name, if real names contain only special chars
-		{
-			$first = '';
-			$last = $account;
-		}
-		if (!$first || !$last)
-		{
-			$dot = $underscore = '';
-		}
-		else
-		{
-			$dot = '.';
-			$underscore = '_';
-		}
-		if (!$domain) $domain = $GLOBALS['egw_info']['server']['mail_suffix'];
-
-		$email = str_replace(array('first','last','initial','account','dot','underscore','-'),
-			array($first,$last,substr($first,0,1),$account,$dot,$underscore,''),
-			$GLOBALS['egw_info']['server']['email_address_format'] ? $GLOBALS['egw_info']['server']['email_address_format'] : 'first-dot-last').
-			($domain ? '@'.$domain : '');
-		//echo " = '$email'</p>\n";
-		return $email;
+		return Api\Accounts::email($first, $last, $account, $domain);
 	}
 
 	/**
@@ -1366,6 +1056,7 @@ class common
 	 * @param $error error
 	 * @param $line line
 	 * @param $file file
+	 * @deprecated not used anymore
 	 */
 	static function phpgw_error($error,$line = '', $file = '')
 	{
@@ -1386,6 +1077,7 @@ class common
 	 * create phpcode from array
 	 *
 	 * @param $array - array
+	 * @deprecated not used anymore
 	 */
 	static function create_phpcode_from_array($array)
 	{
@@ -1435,6 +1127,7 @@ class common
 	 * return the full phpgw_info array for debugging
 	 *
 	 * @param array - array
+	 * @deprecated not used anymore
 	 */
 	static function debug_list_array_contents($array)
 	{
@@ -1478,6 +1171,7 @@ class common
 	/**
 	 * return a list of functionsin the API
 	 *
+	 * @deprecated not used anymore
 	 */
 	static function debug_list_core_functions()
 	{
@@ -1494,87 +1188,41 @@ class common
 	 * Return a value for the next id an app/class may need to insert values into LDAP
 	 *
 	 * @param string $appname app-name
-	 * @param int $min=0 if != 0 minimum id
-	 * @param int $max=0 if != 0 maximum id allowed, if it would be exceeded we return false
-	 * @return int/boolean the next id or false if $max given and exceeded
+	 * @param int $min =0 if != 0 minimum id
+	 * @param int $max =0 if != 0 maximum id allowed, if it would be exceeded we return false
+	 * @deprecated use Api\Accounts\Ldap::next_id($appname, $min, $max)
+	 * @return int|boolean the next id or false if $max given and exceeded
 	 */
 	static function next_id($appname,$min=0,$max=0)
 	{
-		if (!$appname)
-		{
-			return -1;
-		}
-
-		$id = (int) $GLOBALS['egw']->db->select(self::NEXTID_TABLE,'id',array('appname' => $appname),__LINE__,__FILE__)->fetchColumn();
-
-		if ($max && $id >= $max)
-		{
-			return False;
-		}
-		++$id;
-
-		if($id < $min) $id = $min;
-
-		$GLOBALS['egw']->db->insert(self::NEXTID_TABLE,array('id' => $id),array('appname' => $appname),__LINE__,__FILE__);
-
-		return (int)$id;
+		return Api\Accounts\Ldap::next_id($appname, $min, $max);
 	}
 
 	/**
 	 * Return a value for the last id entered, which an app may need to check values for LDAP
 	 *
 	 * @param string $appname app-name
-	 * @param int $min=0 if != 0 minimum id
-	 * @param int $max=0 if != 0 maximum id allowed, if it would be exceeded we return false
-	 * @return int current id in the next_id table for a particular app/class or -1 for no app and false if $max is exceeded.
+	 * @param int $min =0 if != 0 minimum id
+	 * @param int $max =0 if != 0 maximum id allowed, if it would be exceeded we return false
+	 * @deprecated use Api\Accounts\Ldap::last_id($appname, $min, $max)
+	 * @return int|boolean current id in the next_id table for a particular app/class or -1 for no app and false if $max is exceeded.
 	 */
 	static function last_id($appname,$min=0,$max=0)
 	{
-		if (!$appname)
-		{
-			return -1;
-		}
-
-		$id = (int)$GLOBALS['egw']->db->select(self::NEXTID_TABLE,'id',array('appname' => $appname),__LINE__,__FILE__)->fetchColumn();
-
-		if (!$id || $id < $min)
-		{
-			return self::next_id($appname,$min,$max);
-		}
-		if ($max && $id > $max)
-		{
-			return False;
-		}
-		return $id;
+		return Api\Accounts\Ldap::last_id($appname, $min, $max);
 	}
 
 	/**
-	 * gets an eGW conformat referer from $_SERVER['HTTP_REFERER'], suitable for direct use in the link function
+	 * gets an eGW conformant referer from $_SERVER['HTTP_REFERER'], suitable for direct use in the link function
 	 *
-	 * @param string $default='' default to use if referer is not set by webserver or not determinable
-	 * @param string $referer='' referer string to use, default ('') use $_SERVER['HTTP_REFERER']
+	 * @param string $default ='' default to use if referer is not set by webserver or not determinable
+	 * @param string $referer ='' referer string to use, default ('') use $_SERVER['HTTP_REFERER']
 	 * @return string
-	 * @todo get "real" referer for jDots template
+	 * @deprecated use Api\Header\Referer::get
 	 */
 	static function get_referer($default='',$referer='')
 	{
-		// HTTP_REFERER seems NOT to get urldecoded
-		if (!$referer) $referer = urldecode($_SERVER['HTTP_REFERER']);
-
-		$webserver_url = $GLOBALS['egw_info']['server']['webserver_url'];
-		if (empty($webserver_url) || $webserver_url{0} == '/')	// url is just a path
-		{
-			$referer = preg_replace('/^https?:\/\/[^\/]+/','',$referer);	// removing the domain part
-		}
-		if (strlen($webserver_url) > 1)
-		{
-			list(,$referer) = explode($webserver_url,$referer,2);
-		}
-		$referer = str_replace('/etemplate/process_exec.php','/index.php',$referer);
-
-		if (empty($referer) || strpos($referer,'cd=yes') !== false) $referer = $default;
-
-		return $referer;
+		return Api\Header\Referer::get($default, $referer);
 	}
 
 	// some depricated functions for the migration
