@@ -49,7 +49,7 @@ class jscalendar
 		}
 		else
 		{
-			$args['app'] = 'home'; // home can be granted to anyone.
+			$args['app'] = 'api';
 		}
 		if ($do_header)
 		{
@@ -136,7 +136,7 @@ class jscalendar
 		Calendar.setup({
 			inputField  : "'.$name.'",'.(!$useicon ? '' : '
 			button      : "'.$name.'-trigger"').',
-			onUpdate    : function(){var input = document.getElementById("'.$name.'"); $j(input).change(); }
+			onUpdate    : function(){var input = document.getElementById("'.$name.'"); jQuery(input).change(); }
 		})
 	});
 </script>
