@@ -102,13 +102,15 @@ class idots_framework extends egw_framework
 
 		// the instanciation of the template has to be here and not in the constructor,
 		// as the old Template class has problems if restored from the session (php-restore)
-		$this->tpl = new Template(EGW_TEMPLATE_DIR,'keep');
+		$this->tpl = new Template(EGW_SERVER_ROOT.'/api/templates/default', 'keep');
 		$this->tpl->set_file(array('_head' => 'head.tpl'));
 		$this->tpl->set_block('_head','head');
+		// now that head.tpl is loaded, switch to idots template dir
+		$this->tpl->set_root(EGW_TEMPLATE_DIR);
 
 		if (html::$ua_mobile)
 		{
-			self::$css_include_files[] = '/phpgwapi/templates/idots/mobile.css';
+			self::includeCSS('/phpgwapi/templates/idots/mobile.css');
 			$extra['mobile'] = true;
 		}
 
@@ -366,8 +368,8 @@ class idots_framework extends egw_framework
 		foreach($apps as $app => $app_data)
 		{
 			if ($app != 'preferences' && $app != 'about' && $app != 'logout' && $app != 'manual' &&
-				($app != 'home' || $GLOBALS['egw_info']['user']['preferences']['common']['start_and_logout_icons'] != 'no') ||
-				html::$ua_mobile && in_array($app,array('preferences','logout','home')))
+				($app != 'api' || $GLOBALS['egw_info']['user']['preferences']['common']['start_and_logout_icons'] != 'no') ||
+				html::$ua_mobile && in_array($app,array('preferences','logout','api')))
 			{
 				$this->tpl->set_var($app_data);
 
