@@ -13,7 +13,7 @@
  * @todo extend Stylite template preferences instead of this copy (simple include fails)
  */
 $apps = $no_navbar_apps = array();
-if (!$hook_data['setup'])	// does not work on setup time
+if (!$hook_data['setup'] && !isset($GLOBALS['egw_setup']))	// does not work on setup time
 {
 	foreach(ExecMethod('pixelegg.pixelegg_framework.navbar_apps') as $app => $data)
 	{
@@ -104,6 +104,24 @@ $GLOBALS['settings'] = array(
 		'xmlrpc' => True,
 		'admin'  => False,
 	),
+	'sidebox_custom_color' => array(
+		'type' => 'color',
+		'label' => 'Custom sidebar menu active color, defaults to above color darkened',
+		'no_lang' => true,
+		'name' => 'sidebox_custom_color',
+		'help' => lang('Use eg. %1 or %2','#FF0000','orange'),
+		'xmlrpc' => True,
+		'admin'  => False,
+	),
+	'loginbox_custom_color' => array(
+		'type' => 'color',
+		'label' => 'Custom login box color, defaults to above color darkened',
+		'no_lang' => true,
+		'name' => 'loginbox_custom_color',
+		'help' => lang('Use eg. %1 or %2','#FF0000','orange'),
+		'xmlrpc' => True,
+		'admin'  => False,
+	),
 	'navbar_format' => false,	// not used in JDots (defined in common prefs)
 	'default_app' => false,		// not used in JDots, as we can have multiple tabs open ...
 );
