@@ -11,7 +11,7 @@
 
 $setup_info['preferences']['name']      = 'preferences';
 $setup_info['preferences']['title']     = 'Preferences';
-$setup_info['preferences']['version']   = '14.1';
+$setup_info['preferences']['version']   = '16.1';
 $setup_info['preferences']['app_order'] = 1;
 $setup_info['preferences']['tables']    = '';
 $setup_info['preferences']['enable']    = 2;
@@ -33,10 +33,6 @@ $setup_info['preferences']['hooks']['deny_cats']     = 'preferences_hooks::deny_
 
 /* Dependencies for this app to work */
 $setup_info['preferences']['depends'][] = array(
-	'appname' => 'phpgwapi',
-	'versions' => Array('14.1')
-);
-$setup_info['preferences']['depends'][] = array(
-	'appname' => 'etemplate',
-	'versions' => Array('14.1')
+	'appname' => 'api',
+	'versions' => Array('16.1')
 );
