@@ -10,9 +10,13 @@
  * @version $Id$
  */
 
-define('EGW_ACL_BUDGET',EGW_ACL_CUSTOM_1);
-define('EGW_ACL_EDIT_BUDGET',EGW_ACL_CUSTOM_2);
-define('EGW_ACL_ADD_TIMESHEET', EGW_ACL_CUSTOM_3);
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Acl;
+
+define('EGW_ACL_BUDGET',Acl::CUSTOM1);
+define('EGW_ACL_EDIT_BUDGET',Acl::CUSTOM2);
+define('EGW_ACL_ADD_TIMESHEET', Acl::CUSTOM3);
 
 /**
  * General business object of the projectmanager
@@ -23,7 +27,7 @@ define('EGW_ACL_ADD_TIMESHEET', EGW_ACL_CUSTOM_3);
 class projectmanager_bo extends projectmanager_so
 {
 	/**
-	 * Debuglevel: 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. so_sql, or string with function-name to debug
+	 * Debuglevel: 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. Api\Storage\Base, or string with function-name to debug
 	 *
 	 * @var int|string
 	 */
@@ -306,11 +310,11 @@ class projectmanager_bo extends projectmanager_so
 			$extra = array();
 			if ($old && $this->link_title($new) !== ($old_title=$this->link_title($old)))
 			{
-				$extra[egw_link::OLD_LINK_TITLE] = $old_title;
+				$extra[Link::OLD_LINK_TITLE] = $old_title;
 			}
 			// notify the link-class about the update, as other apps may be subscribt to it
-			//error_log(__METHOD__."() calling egw_link::notify_update('projectmanager', {$this->data['pm_id']}, ".array2string($this->data+$extra).")");
-			egw_link::notify_update('projectmanager',$this->data['pm_id'],$this->data+$extra);
+			//error_log(__METHOD__."() calling Link::notify_update('projectmanager', {$this->data['pm_id']}, ".array2string($this->data+$extra).")");
+			Link::notify_update('projectmanager',$this->data['pm_id'],$this->data+$extra);
 		}
 		//$changed[] = array();
 		if (isset($old)) foreach($old as $name => $value)
@@ -365,7 +369,7 @@ class projectmanager_bo extends projectmanager_so
 
 			// the following is not really necessary, as it's already one in projectmanager_elements_bo::delete
 			// delete all links to project $pm_id
-			egw_link::unlink(0,'projectmanager',$pm_id);
+			Link::unlink(0,'projectmanager',$pm_id);
 
 			$this->instanciate('constraints,milestones,pricelist,roles');
 
@@ -388,7 +392,7 @@ class projectmanager_bo extends projectmanager_so
 	 * changes the data from the db-format to your work-format
 	 *
 	 * reimplemented to adjust the timezone of the timestamps (adding $this->tz_offset_s to get user-time)
-	 * Please note, we do NOT call the method of the parent or so_sql !!!
+	 * Please note, we do NOT call the method of the parent or Api\Storage\Base !!!
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 * @return array with changed data
@@ -411,7 +415,7 @@ class projectmanager_bo extends projectmanager_so
 	 * changes the data from your work-format to the db-format
 	 *
 	 * reimplemented to adjust the timezone of the timestamps (subtraction $this->tz_offset_s to get server-time)
-	 * Please note, we do NOT call the method of the parent or so_sql !!!
+	 * Please note, we do NOT call the method of the parent or Api\Storage\Base !!!
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 * @return array with changed data
@@ -432,7 +436,7 @@ class projectmanager_bo extends projectmanager_so
 	}
 
 	/**
-	 * generate a project-ID / generted by config format
+	 * generate a project-ID / generated by Api\Config format
 	 *
 	 * @param boolean $set_data=true set generated number in $this->data, default true
 	 * @param string $parent='' pm_number of parent
@@ -550,9 +554,9 @@ class projectmanager_bo extends projectmanager_so
 	/**
 	 * checks if the given user has enough rights for a certain operation
 	 *
-	 * Rights are given via owner grants or role based acl
+	 * Rights are given via owner grants or role based Acl
 	 *
-	 * @param int $required EGW_ACL_READ, EGW_ACL_WRITE, EGW_ACL_ADD, EGW_ACL_ADD_TIMESHEET, EGW_ACL_DELETE, EGW_ACL_BUDGET, EGW_ACL_EDIT_BUDGET
+	 * @param int $required Acl::READ, Acl::EDIT, Acl::ADD, EGW_ACL_ADD_TIMESHEET, Acl::DELETE, EGW_ACL_BUDGET, EGW_ACL_EDIT_BUDGET
 	 * @param array|int $data=null project or project-id to use, default the project in $this->data
 	 * @param boolean $no_cache=false should a cached value be used, if availible, or not
 	 * @param int $user=null for which user to check, default current user
@@ -577,7 +581,7 @@ class projectmanager_bo extends projectmanager_so
 
 		if (!$pm_id)	// new entry, everything allowed, but delete
 		{
-			return $required != EGW_ACL_DELETE;
+			return $required != Acl::DELETE;
 		}
 		if (!isset($rights) || $no_cache)	// check if we have a cache entry for $pm_id
 		{
@@ -596,7 +600,7 @@ class projectmanager_bo extends projectmanager_so
 			{
 				$data =& $this->data;
 			}
-			// rights come from owner grants or role based acl
+			// rights come from owner grants or role based Acl
 			$memberships = $GLOBALS['egw']->accounts->memberships($this->user);
 			$member_from_groups = array_intersect_key((array)$data['pm_members'], $memberships);
 			$grants_from_groups = 0;
@@ -614,15 +618,15 @@ class projectmanager_bo extends projectmanager_so
 			// anonymous access implies read rights for everyone
 			if (is_array($data) && $data['pm_access'] === 'anonym')
 			{
-				$rights |= EGW_ACL_READ;
+				$rights |= Acl::READ;
 			}
 		}
 		// private project need either a private grant or a role ACL
-		if (is_array($data) && $data['pm_access'] === 'private' && !($rights & EGW_ACL_PRIVATE) && !$data['pm_members'][$user]['role_acl'])
+		if (is_array($data) && $data['pm_access'] === 'private' && !($rights & Acl::PRIVAT) && !$data['pm_members'][$user]['role_acl'])
 		{
 			$access = false;
 		}
-		elseif ($required & EGW_ACL_READ)       // read-rights are implied by all other rights, but EGW_ACL_ADD_TIMESHEET
+		elseif ($required & Acl::READ)       // read-rights are implied by all other rights, but EGW_ACL_ADD_TIMESHEET
 		{
 			$access = (boolean) ($rights & ~EGW_ACL_ADD_TIMESHEET);
 		}
@@ -640,7 +644,7 @@ class projectmanager_bo extends projectmanager_so
 	/**
 	 * Read a project
 	 *
-	 * reimplemented to add an acl check
+	 * reimplemented to add an Acl check
 	 *
 	 * @param array $keys
 	 * @return array|boolean array with project, null if project not found or false if no perms to view it
@@ -651,7 +655,7 @@ class projectmanager_bo extends projectmanager_so
 		{
 			return null;
 		}
-		if (!$this->check_acl(EGW_ACL_READ))
+		if (!$this->check_acl(Acl::READ))
 		{
 			return false;
 		}
@@ -671,9 +675,7 @@ class projectmanager_bo extends projectmanager_so
 		if (!is_array($entry))
 		{
 			$pm_id = $entry;
-			$backup = $this->data;
 			$entry = $this->read( $entry );
-			$this->data = $backup;
 
 			// Even though ADD_TIMESHEET means no read, we let them
 			// see the title
@@ -707,7 +709,7 @@ class projectmanager_bo extends projectmanager_so
 				$titles[$project['pm_id']] = $this->link_title($project);
 			}
 		}
-		// we assume all not returned projects are not readable by the user, as we notify egw_link about all deletes
+		// we assume all not returned projects are not readable by the user, as we notify Link about all deletes
 		foreach($ids as $id)
 		{
 			if (!isset($titles[$id]))
@@ -751,9 +753,9 @@ class projectmanager_bo extends projectmanager_so
 	 *  - file read rights = project read rights
 	 *  - file write or delete rights = project edit rights
 	 *
-	 * @ToDo Implement own acl rights for file access
+	 * @ToDo Implement own Acl rights for file access
 	 * @param int $id pm_id of project
-	 * @param int $check EGW_ACL_READ for read and EGW_ACL_EDIT for write or delete access
+	 * @param int $check Acl::READ for read and Acl::EDIT for write or delete access
 	 * @param string $rel_path path relative to project directory (currently not used)
 	 * @param int $user=null for which user to check, default current user
 	 * @return boolean true if access is granted or false otherwise
@@ -778,16 +780,16 @@ class projectmanager_bo extends projectmanager_so
 		static $ancestors_cache = array();	// some caching
 
 		if (!$pm_id && !($pm_id = $this->pm_id)) return false;
-
+		
 		if (!isset($ancestors_cache[$pm_id]))
 		{
 			$ancestors_cache[$pm_id] = array();
 
 			// read all projectmanager entries attached to this one
-			foreach(egw_link::get_links('projectmanager',$pm_id,'projectmanager') as $link_id => $data)
+			foreach(Link::get_links('projectmanager',$pm_id,'projectmanager') as $link_id => $data)
 			{
 				// we need to read the complete link, to know if the entry is a child (link_id1 == pm_id)
-				$link = egw_link::get_link($link_id);
+				$link = Link::get_link($link_id);
 				if ($link['link_id1'] == $pm_id)
 				{
 					continue;	// we are the parent in this link ==> ignore it
@@ -826,10 +828,10 @@ class projectmanager_bo extends projectmanager_so
 			$children_cache[$pm_id] = array();
 
 			// read all projectmanager entries attached to this one
-			foreach(egw_link::get_links('projectmanager',$pm_id,'projectmanager') as $link_id => $data)
+			foreach(Link::get_links('projectmanager',$pm_id,'projectmanager') as $link_id => $data)
 			{
 				// we need to read the complete link, to know if the entry is a child (link_id1 == pm_id)
-				$link = egw_link::get_link($link_id);
+				$link = Link::get_link($link_id);
 				if ($link['link_id1'] != $pm_id)
 				{
 					continue;	// we are NOT the parent in this link ==> ignore it
@@ -925,7 +927,7 @@ class projectmanager_bo extends projectmanager_so
 	{
 		if ($this->logfile && ($f = @fopen($this->logfile,'a+')))
 		{
-			fwrite($f,date('Y-m-d H:i:s: ').common::grab_owner_name($GLOBALS['egw_info']['user']['account_id'])."\n");
+			fwrite($f,date('Y-m-d H:i:s: ').Api\Accounts::username($GLOBALS['egw_info']['user']['account_id'])."\n");
 			fwrite($f,$msg."\n\n");
 			fclose($f);
 		}
@@ -976,7 +978,7 @@ class projectmanager_bo extends projectmanager_so
 			}
 			else
 			{
-				$prefs = new preferences($uid);
+				$prefs = new Api\Preferences($uid);
 				$prefs->read_repository();
 				$user_prefs =& $prefs->data['projectmanager'];
 				unset($prefs);
@@ -1093,7 +1095,7 @@ class projectmanager_bo extends projectmanager_so
 
 			$data_backup = $this->data;
 		}
-		if (!$this->read((int) $source) || !$this->check_acl(EGW_ACL_READ))
+		if (!$this->read((int) $source) || !$this->check_acl(Acl::READ))
 		{
 			if ((int) $this->debug >= 1 || $this->debug == 'copy') $this->debug_message("projectmanager_bo::copy($source,$only_stage) returning false (not found or no perms), data=".print_r($this->data,true));
 			return false;
