@@ -10,13 +10,18 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+
 /**
  * Elements business object of the projectmanager
  */
 class projectmanager_elements_bo extends projectmanager_elements_so
 {
 	/**
-	 * Debuglevel: 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. so_sql, or string with function-name to debug
+	 * Debuglevel: 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. Api\Storage\Base, or string with function-name to debug
 	 *
 	 * @var int/string
 	 */
@@ -162,7 +167,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 				// for projectmanager we need to check the direction of the link
 				if ($data['target_app'] == 'projectmanager')
 				{
-					$link = egw_link::get_link($data['link_id']);
+					$link = Link::get_link($data['link_id']);
 					if ($link['link_id2'] == $data['id'])
 					{
 						//error_log(__METHOD__."() --> ignoring notification to child");
@@ -208,10 +213,10 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 *
 	 * @param string $app appname
 	 * @param string $id id of $app as used by the link-class and the datasource
-	 * @param int $pe_id=0 element- / link-id or 0 to only read and return the entry, but not save it!
-	 * @param int $pm_id=null project-id, default $this->pm_id
-	 * @param boolean $update_project=true update the data in the project if necessary
-	 * @param array $extra_keys=null key=>value pairs with element extra data to merge on update
+	 * @param int $pe_id =0 element- / link-id or 0 to only read and return the entry, but not save it!
+	 * @param int $pm_id =null project-id, default $this->pm_id
+	 * @param boolean $update_project =true update the data in the project if necessary
+	 * @param array $extra_keys =null key=>value pairs with element extra data to merge on update
 	 * @return array/boolean the updated project-element or false on error (eg. no read access)
 	 */
 	function &update($app,$id,$pe_id=0,$pm_id=null,$update_project=true,$extra_keys=null)
@@ -232,9 +237,12 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		}
 		$this->init();
 		$need_save_anyway = false;
+		$datasource =& $this->datasource($app);
+
 		// check if entry already exists and set basic values if not
 		if (!$pe_id || ($need_save_anyway = !$this->read(array('pm_id'=>$pm_id,'pe_id'=>$pe_id))))
 		{
+			$this->data = $datasource->read($id);
 			$this->data['pm_id'] = $pm_id;
 			$this->data['pe_id'] = $pe_id;
 			$this->data['pe_overwrite'] = 0;		// none set so far
@@ -245,7 +253,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 				$this->data['pe_status']= 'new';
 			}
 			// if user linking has no ADD rights, the entry is set to ignored
-			if (!$this->check_acl(EGW_ACL_ADD,array('pm_id'=>$pm_id)) && !
+			if (!$this->check_acl(Acl::ADD,array('pm_id'=>$pm_id)) && !
 				($this->check_acl(EGW_ACL_ADD_TIMESHEET, array('pm_id'=>$pm_id)) && $app == 'timesheet')
 			)
 			{
@@ -256,7 +264,6 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		{
 			$this->data_merge($extra_keys);
 		}
-		$datasource =& $this->datasource($app);
 		$this->updated = 0;
 
 		// mask out not overwritable parts like title and details
@@ -271,7 +278,8 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		foreach($data as $name => $value)
 		{
 			if (isset($datasource->name2id[$name]) && !($this->data['pe_overwrite'] & $datasource->name2id[$name]) &&
-				$this->data[$name] != $value)
+				// treat new entries / $need_save_anyway as changed
+				($need_save_anyway || $this->data[$name] != $value))
 			{
 				//if ((int) $pe_id) error_log(__METHOD__."($app,$id,$pe_id,$pm_id) $name ({$datasource->name2id[$name]}) updated, pe_overwrite={$this->data['pe_overwrite']}: '{$this->data[$name]}' != '$value'");
 				$this->data[$name] = $value;
@@ -297,7 +305,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 */
 	function update_cat($pe_ids, $cat_id)
 	{
-		if (!$this->check_acl(EGW_ACL_EDIT, array(
+		if (!$this->check_acl(Acl::EDIT, array(
 			'pm_id' => $this->pm_id,
 			'pe_id' => $pe_ids,
 		)))
@@ -369,7 +377,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 *	- Adding, editing and deleting of elements require the ADD right of the project (deleting requires the element to exist pe_id!=0)
 	 *	- reading or editing of budgets require the concerned rights of the project
 	 *
-	 * @param int $required EGW_ACL_READ, EGW_ACL_WRITE, EGW_ACL_ADD, EGW_ACL_DELETE, EGW_ACL_BUDGET or EGW_ACL_EDIT_BUDGET
+	 * @param int $required Acl::READ, ACL::EDIT, Acl::ADD, Acl::DELETE, EGW_ACL_BUDGET or EGW_ACL_EDIT_BUDGET
 	 * @param array/int $data=null project-element or pe_id to use, default the project-element in $this->data
 	 * @return boolean true if the rights are ok, false if not
 	 */
@@ -378,7 +386,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		$pe_id = is_array($data) ? $data['pe_id'] : ($data ? $data : $this->data['pe_id']);
 		$pm_id = is_array($data) ? $data['pm_id'] : ($data ? 0 : $this->data['pm_id']);
 
-		if (!$pe_id && (!$pm_id || $required == EGW_ACL_DELETE))
+		if (!$pe_id && (!$pm_id || $required == Acl::DELETE))
 		{
 			return false;
 		}
@@ -392,9 +400,9 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 
 			$pm_id = $data['pm_id'];
 		}
-		if ($required == EGW_ACL_EDIT ||$required ==  EGW_ACL_DELETE)
+		if ($required == Acl::EDIT ||$required ==  Acl::DELETE)
 		{
-			$required = EGW_ACL_ADD;	// edit or delete of elements is handled by the ADD right of the project
+			$required = Acl::ADD;	// edit or delete of elements is handled by the ADD right of the project
 		}
 		return $this->project->check_acl($required,$pm_id);
 	}
@@ -432,7 +440,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 * changes the data from the db-format to your work-format
 	 *
 	 * reimplemented to adjust the timezone of the timestamps (adding $this->tz_offset_s to get user-time)
-	 * Please note, we do NOT call the method of the parent or so_sql !!!
+	 * Please note, we do NOT call the method of the parent or Api\Storage\Base !!!
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 * @return array with changed data
@@ -458,7 +466,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 * changes the data from your work-format to the db-format
 	 *
 	 * reimplemented to adjust the timezone of the timestamps (subtraction $this->tz_offset_s to get server-time)
-	 * Please note, we do NOT call the method of the parent or so_sql !!!
+	 * Please note, we do NOT call the method of the parent or Api\Storage\Base !!!
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 * @return array with changed data
@@ -508,7 +516,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		{
 			unset($keys['update_remark']);
 			unset($this->data['update_remark']);
-			egw_link::update_remark($this->data['pe_id'],$this->data['pe_remark']);
+			Link::update_remark($this->data['pe_id'],$this->data['pe_remark']);
 		}
 		if ($keys) $this->data_merge($keys);
 
@@ -570,7 +578,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		if ($pe_id)
 		{
 			// delete one link
-			egw_link::unlink($pe_id);
+			Link::unlink($pe_id);
 			// update the project
 			$this->project->update($pm_id);
 
@@ -579,7 +587,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		elseif ($pm_id)
 		{
 			// delete all links to project $pm_id
-			egw_link::unlink(0,'projectmanager',$pm_id);
+			Link::unlink(0,'projectmanager',$pm_id);
 		}
 		return $ret;
 	}
@@ -614,7 +622,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	function &titles($keys=array())
 	{
 		$titles = array();
-		
+
 		// Support link titles, which just provides IDs
 		if(!$keys['pe_id'] && !$keys['pm_id'] && !$keys['ms_id'] && count($keys))
 		{
@@ -626,7 +634,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		}
 		return $titles;
 	}
-	
+
 	/**
 	 * query projectmanager elements for entries matching $pattern
 	 *
@@ -705,7 +713,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 			{
 				if ((int) $this->debug >= 3 || $this->debug == 'copytree') $this->debug_message("linking $element[pe_app]:$element[pe_app_id] $element[pe_title]");
 				$app_id = $element['pe_app_id'];
-				$link_id = egw_link::link('projectmanager',$this->pm_id,$element['pe_app'],$app_id,$element['pe_remark'],0,0,1);
+				$link_id = Link::link('projectmanager',$this->pm_id,$element['pe_app'],$app_id,$element['pe_remark'],0,0,1);
 			}
 			if ((int) $this->debug >= 3 || $this->debug == 'copytree') $this->debug_message("calling update($element[pe_app],$app_id,$link_id,$this->pm_id,false);");
 
@@ -796,7 +804,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 	 * @param string $op defaults to 'AND', can be set to 'OR' too, then criteria's are OR'ed together
 	 * @param int/boolean $start if != false, return only maxmatch rows begining with start
 	 * @param array $filter if set (!=null) col-data pairs, to be and-ed (!) into the query without wildcards
-	 * @param string/boolean $join=true default join with links-table or string as in so_sql
+	 * @param string/boolean $join=true default join with links-table or string as in Api\Storage\Base
 	 * @return array of matching rows (the row is an array of the cols) or False
 	 */
 	function search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join=true)
@@ -808,7 +816,7 @@ class projectmanager_elements_bo extends projectmanager_elements_so
 		if ($filter['cumulate'])
 		{
 			$cumulate = array();
-			foreach((array)$GLOBALS['egw']->hooks->process(array(
+			foreach((array)Api\Hooks::process(array(
 				'location' => 'pm_cumulate',
 				'pm_id' => $filter['pm_id'],
 			)) as $app => $data)
