@@ -12,10 +12,14 @@
  * @version $Id: class.projectmanager_merge.inc.php 30377 2010-09-27 19:35:10Z jaytraxx $
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+
 /**
  * Projectmanager - document merge object
  */
-class projectmanager_merge extends bo_merge
+class projectmanager_merge extends Api\Storage\Merge
 {
 	/**
 	 * Functions that can be called via menuaction
@@ -26,42 +30,42 @@ class projectmanager_merge extends bo_merge
 		'download_by_request'	=> true,
 		'show_replacements'		=> true,
 	);
-	
+
 	/**
 	 * Id of current project
 	 *
 	 * @var int
 	 */
 	var $pm_id = null;
-	
+
 	/**
 	 * Instance of the projectmanager_bo class
 	 *
 	 * @var projectmanager_bo
 	 */
 	var $projectmanager_bo;
-	
+
 	/**
 	 * Instance of the projectmanager_elements_bo class
 	 *
 	 * @var projectmanager_elements_bo
 	 */
 	var $projectmanager_elements_bo;
-	
+
 	/**
 	 * Instance of the projectmanager_eroles_bo class
 	 *
 	 * @var projectmanager_eroles_bo
 	 */
 	var $projectmanager_eroles_bo;
-	
+
 	/**
 	 * List of projectmanager fields which can be used for merging
 	 *
 	 * @var array
 	 */
 	var $projectmanager_fields = array();
-	
+
 	/**
 	 * Translate list for merged projectmanager fields
 	 *
@@ -69,21 +73,21 @@ class projectmanager_merge extends bo_merge
 	 */
 	var $pm_fields_translate = array();
 
-	
+
 	/**
 	 * List of projectmanager element fields which can be used for merging
 	 *
 	 * @var array
 	 */
 	var $projectmanager_element_fields = array();
-	
+
 	/**
 	 * Translate list for merged element fields
 	 *
 	 * @var array
 	 */
 	var $pe_fields_translate = array();
-	
+
 	/**
 	 * Element roles - array with keys pe_id, app, app_id and erole_id
 	 *
@@ -100,7 +104,7 @@ class projectmanager_merge extends bo_merge
 	function __construct($pm_id=null)
 	{
 		parent::__construct();
-		
+
 		if(isset($pm_id) && $pm_id > 0)
 		{
 			$this->change_project($pm_id);
@@ -108,7 +112,7 @@ class projectmanager_merge extends bo_merge
 		$this->projectmanager_bo = new projectmanager_bo($pm_id);
 		$this->table_plugins['elements'] = 'table_elements';
 		$this->table_plugins['eroles'] = 'table_eroles';
-		
+
 		$this->projectmanager_fields = array(
 			'pm_id'					=> lang('Project ID'),
 			'pm_number'				=> lang('Project number'),
@@ -134,7 +138,7 @@ class projectmanager_merge extends bo_merge
 			'pm_planned_budget'		=> lang('Planned budget'),
 			'pm_accounting_type'	=> lang('Accounting type'),
 			'user_timezone_read'	=> lang('Timezone'),
-			
+
 			'all_roles'		=> lang('All roles'),
 		);
 		$this->role_so = new projectmanager_roles_so();
@@ -150,12 +154,12 @@ class projectmanager_merge extends bo_merge
 		// Handle dates as dates in spreadsheets
 		$this->date_fields = projectmanager_egw_record_project::$types['date-time'];
 
-		
+
 		$this->pm_fields_translate = array(
 			'cat_id'				=> 'pm_cat_id',
 			'user_timezone_read'	=> 'pm_user_timezone',
 		);
-		
+
 		$this->projectmanager_element_fields = array(
 			'pe_id'					=> lang('Element ID'),
 			'pe_title'				=> lang('Title'),
@@ -207,7 +211,7 @@ class projectmanager_merge extends bo_merge
 		$this->pm_id = $id;
 		if($id) {
 			$this->projectmanager_eroles_bo = new projectmanager_eroles_bo($id);
-			$this->projectmanager_elements_bo = new projectmanager_elements_bo($id);	
+			$this->projectmanager_elements_bo = new projectmanager_elements_bo($id);
 		}
 		$this->projectmanager_bo = new projectmanager_bo($id);
 	}
@@ -222,7 +226,7 @@ class projectmanager_merge extends bo_merge
 	protected function get_replacements($id,&$content=null)
 	{
 		$replacements = array();
-	
+
 		// first replacement is always the contacts (if valid)
 		// If this special case is no longer needed, it can be removed & contacts handled as
 		// any other element
@@ -233,18 +237,18 @@ class projectmanager_merge extends bo_merge
 				$replacements += $this->contact_replacements($contact_id);
 			}
 		}
-		
+
 		// replace project content
 		if ($id > 0 && $this->pm_id != $id)
 		{
 			$this->change_project($id);
 		}
-		
+
 		$replacements += $this->projectmanager_replacements($this->pm_id, '', $content);
-		
+
 		// further replacements are made by eroles (if given)
 		if(!empty($this->eroles) && is_array($this->eroles))
-		{			
+		{
 			foreach($this->eroles as $erole)
 			{
 				$erole_title = $this->projectmanager_eroles_bo->id2title($erole['erole_id']);
@@ -261,7 +265,7 @@ class projectmanager_merge extends bo_merge
 		}
 		return empty($replacements) ? false : $replacements;
 	}
-	
+
 	/**
 	 * Get element replacements
 	 *
@@ -324,7 +328,7 @@ class projectmanager_merge extends bo_merge
 		return empty($replacements) ? false : $replacements;
 	}
 
-	
+
 	/**
 	 * Return replacements for a project
 	 *
@@ -344,22 +348,22 @@ class projectmanager_merge extends bo_merge
 		// Convert to human friendly values
 		$types = projectmanager_egw_record_project::$types;
 		$selects = array();
-		if($content && strpos($content, '$$#') !== 0)
+		if($content && strpos($content, '$$#') !== FALSE)
 		{
 			$this->cf_link_to_expand($record->get_record_array(), $content, $replacements);
 		}
 
 		importexport_export_csv::convert($record, $types, 'projectmanager', $selects);
 		$project = $record->get_record_array();
-		
+
 		// Set any missing custom fields, or the marker will stay
-		$custom = config::get_customfields('projectmanager');
+		$custom = Api\Storage\Customfields::get('projectmanager');
 		foreach($custom as $name => $field)
 		{
 			$this->projectmanager_fields['#'.$name] = $field['label'];
 			if(!$project['#'.$name]) $project['#'.$name] = '';
 		}
-		
+
 		// Add in roles
 		$roles = $this->role_so->query_list();
 
@@ -368,7 +372,7 @@ class projectmanager_merge extends bo_merge
 		$all_roles = array('Coordinator' => array());
 		$all_roles += array_fill_keys($roles, array());
 		foreach((Array)$project['pm_members'] as $account_id => $info) {
-			$all_roles[$info['role_title']][] = common::grab_owner_name($info['member_uid']);
+			$all_roles[$info['role_title']][] = Api\Accounts::username($info['member_uid']);
 		}
 		foreach($all_roles as $name => $users) {
 			$project[$name] = implode(', ', $users);
@@ -390,7 +394,7 @@ class projectmanager_merge extends bo_merge
 		foreach(array_keys($project) as $name)
 		{
 			if(!isset($this->projectmanager_fields[$name])) continue; // not a supported field
-			
+
 			$value = $project[$name];
 			switch($name)
 			{
@@ -399,10 +403,10 @@ class projectmanager_merge extends bo_merge
 				case 'pm_real_start': case 'pm_real_end':
 				case 'pe_planned_start_total': case 'pe_planned_end_total':
 				case 'pe_real_start_total': case 'pe_real_end_total':
-					if($value) $value = egw_time::to($value);
+					if($value) $value = Api\DateTime::to($value);
 					break;
 				case 'pm_creator': case 'pm_modifier':
-					$value = common::grab_owner_name($value);
+					$value = Api\Accounts::username($value);
 					break;
 				case 'cat_id':
 					if ($value)
@@ -438,7 +442,7 @@ class projectmanager_merge extends bo_merge
 
 		return $replacements;
 	}
-	
+
 	/**
 	 * Return replacements for a given project element
 	 *
@@ -447,10 +451,10 @@ class projectmanager_merge extends bo_merge
 	 * @return array
 	 */
 	public function projectmanager_element_replacements($pe_id,$prefix='', $content = '')
-	{	
+	{
 		$replacements = array();
 		if(!is_object($this->projectmanager_elements_bo)) return $replacements;
-		
+
 		// Filter selected elements
 		if($this->elements && !in_array($pe_id, $this->elements)) return $replacements;
 
@@ -458,17 +462,17 @@ class projectmanager_merge extends bo_merge
 		foreach(array_keys($element) as $name)
 		{
 			if(!isset($this->projectmanager_element_fields[$name])) continue; // not a supported field
-			
+
 			$value = !is_array($element[$name]) ? strip_tags($element[$name]) : $element[$name];
 			switch($name)
 			{
 				case 'pe_planned_start': case 'pe_planned_end':
 				case 'pe_real_start': case 'pe_real_end':
 				case 'pe_synced': case 'pe_modified':
-					if($value) $value = egw_time::to($value);
+					if($value) $value = Api\DateTime::to($value);
 					break;
 				case 'pe_modifier':
-					$value = common::grab_owner_name($value);
+					$value = Api\Accounts::username($value);
 					break;
 				case 'cat_id':
 					if ($value)
@@ -490,7 +494,7 @@ class projectmanager_merge extends bo_merge
 					$names = array();
 					foreach($value as $id => $user_id)
 					{
-						$names[] = common::grab_owner_name($user_id);
+						$names[] = Api\Accounts::username($user_id);
 					}
 					$value = implode(', ', $names);
 					break;
@@ -501,15 +505,15 @@ class projectmanager_merge extends bo_merge
 			}
 			$replacements['$$'.($prefix ? $prefix.'/':'').$name.'$$'] = $value;
 		}
-		
+
 		// Element links
 		if(strpos($content, ($prefix ? $prefix.'/':'').'links') !== false)
 		{
-			$replacements['$$'.($prefix ? $prefix.'/':'').'links$$'] = $this->get_links($element['pe_app'], $element['pe_app_id'], '!'.egw_link::VFS_APPNAME);
+			$replacements['$$'.($prefix ? $prefix.'/':'').'links$$'] = $this->get_links($element['pe_app'], $element['pe_app_id'], '!'.Link::VFS_APPNAME);
 		}
 		if(strpos($content, ($prefix ? $prefix.'/':'').'attachments') !== false)
 		{
-			$replacements['$$'.($prefix ? $prefix.'/':'').'attachments$$'] = $this->get_links($element['pe_app'], $element['pe_app_id'], egw_link::VFS_APPNAME);
+			$replacements['$$'.($prefix ? $prefix.'/':'').'attachments$$'] = $this->get_links($element['pe_app'], $element['pe_app_id'], Link::VFS_APPNAME);
 		}
 		if(strpos($content, ($prefix ? $prefix.'/':'').'links_attachments') !== false)
 		{
@@ -519,7 +523,7 @@ class projectmanager_merge extends bo_merge
 		return $replacements;
 	}
 
-	
+
 	/**
 	 * Set element roles for merging
 	 *
@@ -529,23 +533,23 @@ class projectmanager_merge extends bo_merge
 	public function set_eroles($eroles)
 	{
 		if(empty($eroles)) return false;
-		
+
 		$this->eroles = $eroles;
 		return true;
 	}
 
 	/**
-	 * Generate table with replacements for the preferences
+	 * Generate table with replacements for the Api\Preferences
 	 *
 	 */
 	public function show_replacements()
 	{
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('Projectmanager').' - '.lang('Replacements for inserting project data into documents');
 		$GLOBALS['egw_info']['flags']['nonavbar'] = false;
-		common::egw_header();
+		echo $GLOBALS['egw']->framework->header();
 
 		echo "<table width='90%' align='center'>\n";
-		
+
 		// Projectmanager
 		$n = 0;
 		echo '<tr><td colspan="4"><h3><a name="pm_fields">'.lang('Projectmanager fields:')."</a></h3></td></tr>";
@@ -563,7 +567,7 @@ class projectmanager_merge extends bo_merge
 
 		// Custom fields
 		echo '<tr><td colspan="4"><h3>'.lang('Custom fields').":</h3></td></tr>";
-		$custom = config::get_customfields('projectmanager');
+		$custom = Api\Storage\Customfields::get('projectmanager');
 		foreach($custom as $name => $field)
 		{
 			echo '<tr><td>{{#'.$name.'}}</td><td colspan="3">'.$field['label']."</td></tr>\n";
@@ -586,7 +590,7 @@ class projectmanager_merge extends bo_merge
 			if ($n&1) echo "</tr>\n";
 			$n++;
 		}
-		
+
 		// Element roles
 		if(!($this->projectmanager_bo->config['enable_eroles']))
 		{
@@ -605,9 +609,9 @@ class projectmanager_merge extends bo_merge
 				.'<ul>'
 				.'<li><a href="#pe_fields">'.lang('Projectmanager element fields').'</a></li>';
 				foreach(array(
-					'Addressbook fields' 	=> egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements'),
-					'Calendar fields'		=> egw::link('/index.php','menuaction=calendar.calendar_merge.show_replacements'),
-					'Infolog fields'		=> egw::link('/index.php','menuaction=infolog.infolog_merge.show_replacements'),
+					'Addressbook fields' 	=> Egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements'),
+					'Calendar fields'		=> Egw::link('/index.php','menuaction=calendar.calendar_merge.show_replacements'),
+					'Infolog fields'		=> Egw::link('/index.php','menuaction=infolog.infolog_merge.show_replacements'),
 				) as $placeholder => $link)
 				{
 					echo '<li><a href="'.$link.'" target="_blank">'.lang($placeholder).'</a></li>';
@@ -619,7 +623,7 @@ class projectmanager_merge extends bo_merge
 				.'{{erole/myrole/pe_title}}<br />{{erole/myrole/n_fn}}<br />{{erole/myrole/info_subject}}'
 				.'</td>';
 		echo "</tr>\n";
-		
+
 		// Table plugins
 		echo '<tr><td colspan="4">'
 				.'<h3>'.lang('Table plugins:').'</h3>'
@@ -655,9 +659,9 @@ class projectmanager_merge extends bo_merge
 				.'<ul>'
 				.'<li><a href="#pe_fields">'.lang('Projectmanager element fields').'</a></li>';
 				foreach(array(
-					'Addressbook fields' 	=> egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements'),
-					'Calendar fields'		=> egw::link('/index.php','menuaction=calendar.calendar_merge.show_replacements'),
-					'Infolog fields'		=> egw::link('/index.php','menuaction=infolog.infolog_merge.show_replacements'),
+					'Addressbook fields' 	=> Egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements'),
+					'Calendar fields'		=> Egw::link('/index.php','menuaction=calendar.calendar_merge.show_replacements'),
+					'Infolog fields'		=> Egw::link('/index.php','menuaction=infolog.infolog_merge.show_replacements'),
 				) as $placeholder => $link)
 				{
 					echo '<li><a href="'.$link.'" target="_blank">'.lang($placeholder).'</a></li>';
@@ -669,9 +673,9 @@ class projectmanager_merge extends bo_merge
 				.'<tr><td>{{erole/myrole/pe_title}}</td><td>{{erole/myrole/info_subject}} {{endtable}}</td></tr></table>'
 				.'</td>'
 				.'</tr>'."\n";
-		
+
 		// Serial letter
-		$link = egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements');
+		$link = Egw::link('/index.php','menuaction=addressbook.addressbook_merge.show_replacements');
 		echo '<tr><td colspan="4">'
 				.'<h3>'.lang('Contact fields for serial letters').'</h3>'
 				.lang('Addressbook elements of a project can be used to define individual serial letter recipients. Available fields are').':'
@@ -705,9 +709,9 @@ class projectmanager_merge extends bo_merge
 		}
 
 		echo "</table>\n";
-		common::egw_footer();
+		echo $GLOBALS['egw']->framework->footer();
 	}
-	
+
 	/**
 	 * Table plugin for project elements
 	 *
@@ -720,7 +724,7 @@ class projectmanager_merge extends bo_merge
 	public function table_elements($plugin,$id,$n,$repeat)
 	{
 		if(!isset($this->pm_id) && !$id) return false;
-		
+
 		static $elements;
 		if($id && $id != $this->pm_id) {
 			$this->change_project($id);
@@ -740,7 +744,7 @@ class projectmanager_merge extends bo_merge
 			else
 			{
 				$limit = array(0,-1);
-				if($this->export_limit && !bo_merge::is_export_limit_excepted()) {
+				if($this->export_limit && !Api\Storage\Merge::is_export_limit_excepted()) {
 					$limit = array(0,(int)$this->export_limit);
 					// Need to do this to give an error
 					$count = count($this->projectmanager_elements_bo->search($query));
@@ -751,10 +755,10 @@ class projectmanager_merge extends bo_merge
 				}
 			}
 			if($count && count($elements) < $count) {
-				throw new egw_exception(lang('No rights to export more then %1 entries!',(int)$this->export_limit));
+				throw new Api\Exception(lang('No rights to export more then %1 entries!',(int)$this->export_limit));
 			}
 		}
-	
+
 		$element =& $elements[$n];
 		$replacement = false;
 		if(isset($element))
@@ -774,18 +778,18 @@ class projectmanager_merge extends bo_merge
 	 * @return array
 	 */
 	public function table_eroles($plugin,$id,$n,$repeat)
-	{	
+	{
 		if(!($this->projectmanager_bo->config['enable_eroles'])) return false; // eroles are disabled
-		
+
 		static $erole_id;
 		static $erole_title;
 		static $elements;
-		
+
 		if (!$n)	// first row inits environment
 		{
 			// get erole_id from repeated line
 			preg_match_all('/\\$\\$erole\\/([A-Za-z0-9_]+)\\//s',$repeat,$matches);
-			
+
 			if(!is_array($matches[1]))
 			{
 				return false; // no erole found
@@ -799,11 +803,11 @@ class projectmanager_merge extends bo_merge
 			{
 				return false; // erole_id cannot be determined
 			}
-			
+
 			// get elements assigned to erole
 			$elements = $this->projectmanager_eroles_bo->get_elements($erole_id);
 		}
-		
+
 		$element =& $elements[$n];
 		$replacement = false;
 		if(isset($element))
@@ -817,5 +821,5 @@ class projectmanager_merge extends bo_merge
 		}
 
 		return $replacement;
-	}	
+	}
 }
