@@ -9,6 +9,11 @@
  * @version $Id$
  */
 
+/*egw:uses
+	/etemplate/js/etemplate2.js;
+	/projectmanager/js/et2_widget_gantt.js;
+*/
+
 /**
  * UI for projectmanager
  *
@@ -92,18 +97,18 @@ app.classes.projectmanager = AppJS.extend(
 			this._bind_sidebox(view.sidemenu, function() {app.projectmanager.show(view.name);return false;});
 
 			// If one template disappears, we want to release it
-			$j(et2.DOMContainer).one('clear',function() {
+			jQuery(et2.DOMContainer).one('clear',function() {
 				if(app.projectmanager && app.projectmanager.sidebox)
 				{
 					app.projectmanager.sidebox.off('.projectmanager');
 				}
 				view.etemplate = null;
-			})
+			});
 
 			// Start hidden, except for project list
-			if($j(et2.DOMContainer).siblings('.et2_container').length && !et2.widgetContainer.getArrayMgr('content').getEntry('project_tree'))
+			if(jQuery(et2.DOMContainer).siblings('.et2_container').length && !et2.widgetContainer.getArrayMgr('content').getEntry('project_tree'))
 			{
-				$j(et2.DOMContainer).hide();
+				jQuery(et2.DOMContainer).hide();
 			}
 
 			if(view.name == 'list')
@@ -117,7 +122,8 @@ app.classes.projectmanager = AppJS.extend(
 					return false;
 				});
 				// First load, framework could not use our link handler since it wasn't loaded
-				if(!app.projectmanager.linkHandler(egw_getFramework().getApplicationByName('projectmanager').browser.currentLocation))
+				var fw = egw_getFramework();
+				if(fw && !app.projectmanager.linkHandler(fw.getApplicationByName('projectmanager').browser.currentLocation))
 				{
 					this.show('list');
 				}
@@ -160,7 +166,7 @@ app.classes.projectmanager = AppJS.extend(
 		current_project = parseInt(current_project) || '';
 
 		// Store preference
-		if(this.egw.preference('current_project','projectmanger') != current_project)
+		if(this.egw.preference('current_project','projectmanager') != current_project)
 		{
 			this.egw.set_preference('projectmanager', 'current_project', current_project);
 		}
@@ -173,7 +179,7 @@ app.classes.projectmanager = AppJS.extend(
 			{
 				case 'elements':
 					et2.getWidgetById('nm').applyFilters({col_filter:{'pm_id': current_project}});
-					et2.getWidgetById('link_add').options.value.to_id = current_project;
+					if (et2.getWidgetById('link_add')) et2.getWidgetById('link_add').options.value.to_id = current_project;
 					break;
 				case 'gantt':
 					var gantt = et2.getWidgetById('gantt');
@@ -187,7 +193,7 @@ app.classes.projectmanager = AppJS.extend(
 					// Support multiple projects
 					if(!project_id || !project_id.map)
 					{
-						project_id = [current_project]
+						project_id = [current_project];
 					}
 					project_id = project_id.map(function(id) {return typeof id == 'string' && id.indexOf('projectmanager::') == 0 ? id : 'projectmanager::'+id;});
 
@@ -246,7 +252,7 @@ app.classes.projectmanager = AppJS.extend(
 		}
 
 		// Show selected sub-template
-		$j(this.views[what].etemplate.DOMContainer).show();
+		jQuery(this.views[what].etemplate.DOMContainer).show();
 
 		// Set header
 		this.egw.app_header(this.egw.lang(this.views[what].sidemenu),'projectmanager');
@@ -256,7 +262,7 @@ app.classes.projectmanager = AppJS.extend(
 		{
 			if(what != view && this.views[view].etemplate)
 			{
-				$j(this.views[view].etemplate.DOMContainer).hide();
+				jQuery(this.views[view].etemplate.DOMContainer).hide();
 			}
 		}
 	},
@@ -363,7 +369,7 @@ app.classes.projectmanager = AppJS.extend(
 		var state = {};
 
 		// Try and find a nextmatch widget, and set its filters
-		var et2 = this.views[this.view].etemplate
+		var et2 = this.views[this.view].etemplate;
 		if(et2)
 		{
 			if(this.view == 'gantt')
@@ -390,7 +396,7 @@ app.classes.projectmanager = AppJS.extend(
 			{
 				et2.widgetContainer.iterateOver(function(_widget) {
 					state = _widget.getValue();
-					
+
 					// These aren't considered for state
 					delete state.link_add;
 					delete state.link_addapp;
@@ -452,7 +458,7 @@ app.classes.projectmanager = AppJS.extend(
 				var itemId = _id != 'undefined'?_app+"::"+_id:0;
 				if (tree && itemId)
 				{
-					var node = tree.getNode(itemId);						
+					var node = tree.getNode(itemId);
 					// Not in tree.  Either parent node not expanded, or a new project
 					if(_type != 'delete' && node == null && typeof _links.projectmanager != 'undefined' && _links.projectmanager.length > 0)
 					{
@@ -483,7 +489,7 @@ app.classes.projectmanager = AppJS.extend(
 				// Fall through to try the element list too
 			default:
 				var appList = egw.link_app_list('query');
-				var nm = this.views.elements.etemplate ? this.views.elements.etemplate.widgetContainer.getWidgetById('nm') : null
+				var nm = this.views.elements.etemplate ? this.views.elements.etemplate.widgetContainer.getWidgetById('nm') : null;
 
 				if (typeof appList[_app] != 'undefined')
 				{
@@ -506,14 +512,14 @@ app.classes.projectmanager = AppJS.extend(
 		switch (this.view)
 		{
 			case 'list':
-				var nm = this.views.list.etemplate ? this.views.list.etemplate.widgetContainer.getWidgetById('nm') : null
+				var nm = this.views.list.etemplate ? this.views.list.etemplate.widgetContainer.getWidgetById('nm') : null;
 				if(nm)
 				{
 					nm.refresh(_id,_type);
 				}
 				return false;
 			case 'elements':
-				var nm = this.views.elements.etemplate ? this.views.elements.etemplate.widgetContainer.getWidgetById('nm') : null
+				var nm = this.views.elements.etemplate ? this.views.elements.etemplate.widgetContainer.getWidgetById('nm') : null;
 				if(nm)
 				{
 					nm.refresh(_id,_type);
@@ -662,14 +668,14 @@ app.classes.projectmanager = AppJS.extend(
 	 */
 	toggleDiv: function(event, widget, target)
 	{
-		var element = $j(target).closest('div').parent('div').find('table.egwLinkMoreOptions');
-		if($j(element).css('display') == 'none')
+		var element = jQuery(target).closest('div').parent('div').find('table.egwLinkMoreOptions');
+		if(jQuery(element).css('display') == 'none')
 		{
-			$j(element).fadeIn('medium');
+			jQuery(element).fadeIn('medium');
 		}
 		else
 		{
-			$j(element).fadeOut('medium');
+			jQuery(element).fadeOut('medium');
 		}
 	},
 
@@ -876,11 +882,15 @@ app.classes.projectmanager = AppJS.extend(
 
 	/**
 	 * Is the selected entry ignored?
+	 *
+	 * @param {egwAction} action
+	 * @param {egwActionObject[]} selected
+	 * @returns {Boolean}
 	 */
 	is_ignored: function(action, selected)
 	{
 		var ignored = false;
-		
+
 		for(var i = 0; i < selected.length; i++)
 		{
 			var data = egw.dataGetUIDdata(selected[i].id);
@@ -980,11 +990,11 @@ app.classes.projectmanager = AppJS.extend(
 	_bind_sidebox: function(label, click)
 	{
 		if(!app.projectmanager.sidebox) return false;
-		var sidebox = $j('a:contains("' +app.projectmanager.egw.lang(label)+'")',app.projectmanager.sidebox.parentsUntil('#egw_fw_sidemenu,#tdSidebox').last());
+		var sidebox = jQuery('a:contains("' +app.projectmanager.egw.lang(label)+'")',app.projectmanager.sidebox.parentsUntil('#egw_fw_sidemenu,#tdSidebox').last());
 		sidebox.off('click.projectmanager');
 		sidebox.on('click.projectmanager', click);
 	},
-	
+
 	/**
 	 * Get title in order to set it as document title
 	 * @returns {string}
