@@ -12,7 +12,7 @@
 /* Basic information about this app */
 $setup_info['registration']['name']      = 'registration';
 $setup_info['registration']['title']     = 'Registration';
-$setup_info['registration']['version']   = '14.1';
+$setup_info['registration']['version']   = '16.1';
 $setup_info['registration']['app_order'] = '40';
 $setup_info['registration']['enable']    = 2;
 $setup_info['registration']['license']   = 'GPL';
@@ -26,7 +26,7 @@ $setup_info['registration']['hooks']['search_link'] = 'registration_hooks::searc
 
 /* Dependencies for this app to work */
 $setup_info['registration']['depends'][] = array(
-	'appname'  => 'phpgwapi',
-	'versions' => Array('1.9','14.1')
+	'appname'  => 'api',
+	'versions' => Array('16.1')
 );
 
