@@ -10,6 +10,11 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+use EGroupware\Api\Vfs;
 
 /**
  * General business object for resources
@@ -18,6 +23,11 @@
  */
 class resources_bo
 {
+	/**
+	 * Path where the icons are stored (relative to webserver_url)
+	 */
+	const ICON_PATH = '/api/images';
+
 	const DELETED = 'deleted';
 	const PICTURE_NAME = '.picture.jpg';
 	var $resource_icons = '/resources/templates/default/images/resource_icons/';
@@ -29,13 +39,13 @@ class resources_bo
 	 */
 	var $so;
 	/**
-	 * Instance of resources acl class
+	 * Instance of resources Acl class
 	 *
-	 * @var bo_acl
+	 * @var resources_acl_bo
 	 */
 	var $acl;
 	/**
-	 * Instance of categories class for resources
+	 * Instance of Api\Categories class for resources
 	 */
 	var $cats;
 
@@ -69,18 +79,18 @@ class resources_bo
 	/**
 	 * Constructor
 	 *
-	 * @param int $user=null account_id of user to use for acl, default current user
+	 * @param int $user=null account_id of user to use for Acl, default current user
 	 */
 	function __construct($user=null)
 	{
 		$this->so = new resources_so();
-		$this->acl = CreateObject('resources.bo_acl', $user);
+		$this->acl = new resources_acl_bo($user);
 		$this->cats = $this->acl->egw_cats;
 
 		$this->cal_right_transform = array(
-			EGW_ACL_CALREAD 	=> EGW_ACL_READ,
-			EGW_ACL_DIRECT_BOOKING 	=> EGW_ACL_READ | EGW_ACL_ADD | EGW_ACL_EDIT | EGW_ACL_DELETE,
-			EGW_ACL_CAT_ADMIN 	=> EGW_ACL_READ | EGW_ACL_ADD | EGW_ACL_EDIT | EGW_ACL_DELETE,
+			resources_acl_bo::CAL_READ	=> Acl::READ,
+			resources_acl_bo::DIRECT_BOOKING 	=> Acl::READ | Acl::ADD | Acl::EDIT | Acl::DELETE,
+			resources_acl_bo::CAT_ADMIN 	=> Acl::READ | Acl::ADD | Acl::EDIT | Acl::DELETE,
 		);
 	}
 
@@ -93,11 +103,11 @@ class resources_bo
 	{
 		if(!$query['csv_export'])
 		{
-			$GLOBALS['egw']->session->appsession('session_data','resources_index_nm',$query);
+			Api\Cache::setSession('resources', 'index_nm', $query);
 		}
 		if ($query['store_state'])	// request to store state in session and filter in prefs?
 		{
-			egw_cache::setSession('resources',$query['store_state'],$query);
+			Api\Cache::setSession('resources',$query['store_state'],$query);
 			//echo "<p>".__METHOD__."() query[filter]=$query[filter], prefs[resources][filter]={$GLOBALS['egw_info']['user']['preferences']['resources']['filter']}</p>\n";
 			if ($query['filter'] != $GLOBALS['egw_info']['user']['preferences']['resources']['filter'])
 			{
@@ -147,7 +157,7 @@ class resources_bo
 
 		if ($query['filter'])
 		{
-			if (($children = $this->acl->get_cats(EGW_ACL_READ,$query['filter'])))
+			if (($children = $this->acl->get_cats(Acl::READ,$query['filter'])))
 			{
 				$filter['cat_id'] = array_keys($children);
 				$filter['cat_id'][] = $query['filter'];
@@ -157,7 +167,7 @@ class resources_bo
 				$filter['cat_id'] = $query['filter'];
 			}
 		}
-		elseif (($readcats = $this->acl->get_cats(EGW_ACL_READ)))
+		elseif (($readcats = $this->acl->get_cats(Acl::READ)))
 		{
 			$filter['cat_id'] = array_keys($readcats);
 		}
@@ -189,10 +199,10 @@ class resources_bo
 			return $nr;
 		}
 
-		$config = config::read('resources');
+		$config = Api\Config::read('resources');
 		foreach($rows as $num => &$resource)
 		{
-			if (!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_EDIT))
+			if (!$this->acl->is_permitted($resource['cat_id'],Acl::EDIT))
 			{
 				$readonlys["edit[$resource[res_id]]"] = true;
 			}
@@ -200,14 +210,14 @@ class resources_bo
 			{
 				$resource['class'] .= 'deleted ';
 			}
-			if (!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_DELETE) ||
+			if (!$this->acl->is_permitted($resource['cat_id'],Acl::DELETE) ||
 				($resource['deleted'] && !$GLOBALS['egw_info']['user']['apps']['admin'] && $config['history'] == 'history')
 			)
 			{
 				$readonlys["delete[$resource[res_id]]"] = true;
 				$resource['class'] .= 'no_delete ';
 			}
-			if ((!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_ADD)) ||
+			if ((!$this->acl->is_permitted($resource['cat_id'],Acl::ADD)) ||
 				// Allow new accessory action when viewing accessories of a certain resource
 				$query['filter2'] <= 0 && $resource['accessory_of'] != -1)
 			{
@@ -221,7 +231,7 @@ class resources_bo
 				$resource['class'] .= 'no_book ';
 				$resource['class'] .= 'no_view_calendar ';
 			}
-			if(!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_CALREAD))
+			if(!$this->acl->is_permitted($resource['cat_id'],resources_acl_bo::CAL_READ))
 			{
 				$readonlys["calendar[$resource[res_id]]"] = true;
 				$resource['class'] .= 'no_view_calendar ';
@@ -266,7 +276,7 @@ class resources_bo
 			$rows[$num]['admin'] = $this->acl->get_cat_admin($resource['cat_id']);
 		}
 
-		if(!config::get_customfields('resources'))
+		if(!Api\Storage\Customfields::get('resources'))
 		{
 			$rows['no_customfields'] = true;
 		}
@@ -286,7 +296,7 @@ class resources_bo
 		{
 			return null;	// not found
 		}
-		if (!$this->acl->is_permitted($data['cat_id'],EGW_ACL_READ))
+		if (!$this->acl->is_permitted($data['cat_id'],Acl::READ))
 		{
 			return false;	// permission denied
 		}
@@ -302,7 +312,7 @@ class resources_bo
 	 */
 	function save($resource)
 	{
-		if(!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_EDIT))
+		if(!$this->acl->is_permitted($resource['cat_id'],Acl::EDIT))
 		{
 			return lang('You are not permitted to edit this resource!');
 		}
@@ -311,13 +321,13 @@ class resources_bo
 		if(!$resource['res_id'])
 		{
 			$resource['res_owner'] = $GLOBALS['egw_info']['user']['account_id'];
-			$resource['res_created'] = egw_time::server2user(time(),'ts');
+			$resource['res_created'] = Api\DateTime::server2user(time(),'ts');
 			$resource['res_id'] = $this->so->save($resource);
 		}
 		else
 		{
 			$resource['res_modifier'] = $GLOBALS['egw_info']['user']['account_id'];
-			$resource['res_modified'] = egw_time::server2user(time(),'ts');
+			$resource['res_modified'] = Api\DateTime::server2user(time(),'ts');
 			$old = $this->read($resource['res_id']);
 		}
 
@@ -360,7 +370,7 @@ class resources_bo
 		// Check for restore of deleted, restore held links
                 if($old && $old['deleted'] && !$resource['deleted'])
                 {
-                        egw_link::restore('resources', $resource['res_id']);
+                        Link::restore('resources', $resource['res_id']);
                 }
 
 		// delete old pictures
@@ -370,31 +380,33 @@ class resources_bo
 		}
 
 		// Update link title
-		egw_link::notify_update('resources',$resource['res_id'], $resource);
+		Link::notify_update('resources',$resource['res_id'], $resource);
 		// save links
 		if(is_array($resource['link_to']['to_id']))
 		{
-			egw_link::link('resources',$resource['res_id'],$resource['link_to']['to_id']);
+			Link::link('resources',$resource['res_id'],$resource['link_to']['to_id']);
 		}
 		if($resource['accessory_of'] != $old['accessory_of'])
 		{
-			egw_link::unlink(0,'resources',$resource['res_id'],'','resources',$old['accessory_of']);
+			Link::unlink(0,'resources',$resource['res_id'],'','resources',$old['accessory_of']);
 
 			// Check for resource changing to accessory - move its accessories to resource
-			if($old['accessory_of'] == -1 && $accessories = $this->get_acc_list($resource['res_id']))
+			if($old['accessory_of'] == -1 && ($accessories = $this->get_acc_list($resource['res_id'])))
 			{
 				foreach($accessories as $accessory => $name)
 				{
-					egw_link::unlink(0,'resources',$accessory,'','resources',$resource['res_id']);
-					$acc = $this->read($accessory);
-					$acc['accessory_of'] = -1;
-					$this->so->save($acc);
+					Link::unlink(0,'resources',$accessory,'','resources',$resource['res_id']);
+					if (($acc = $this->read($accessory)))
+					{
+						$acc['accessory_of'] = -1;
+						$this->so->save($acc);
+					}
 				}
 			}
 		}
 		if($resource['accessory_of'] != -1)
 		{
-			egw_link::link('resources',$resource['res_id'],'resources',$resource['accessory_of']);
+			Link::link('resources',$resource['res_id'],'resources',$resource['accessory_of']);
 		}
 
 		if(!empty($resource['res_id']) && $this->so->get_value("cat_id",$resource['res_id']) != $resource['cat_id'] && $resource['accessory_of'] == -1)
@@ -402,10 +414,12 @@ class resources_bo
 			$accessories = $this->get_acc_list($resource['res_id']);
 			foreach($accessories as $accessory => $name)
 			{
-				$acc = $this->so->read($accessory);
-				$acc['cat_id'] = $resource['cat_id'];
-				$this->so->data = $acc;
-				$this->so->save();
+				if (($acc = $this->so->read($accessory)))
+				{
+					$acc['cat_id'] = $resource['cat_id'];
+					$this->so->data = $acc;
+					$this->so->save();
+				}
 			}
 		}
 
@@ -429,32 +443,35 @@ class resources_bo
 	 *
 	 * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
 	 * @param int $res_id id of resource
+	 * @return string|false string with error or false on success
 	 */
 	function delete($res_id)
 	{
-		if(!$this->acl->is_permitted($this->so->get_value('cat_id',$res_id),EGW_ACL_DELETE))
+		if(!$this->acl->is_permitted($this->so->get_value('cat_id',$res_id),Acl::DELETE))
 		{
 			return lang('You are not permitted to delete this resource!');
 		}
 
 		// check if we only mark resources as deleted, or really delete them
-		$old = $this->read($res_id);
-		$config = config::read('resources');
-		if ($config['history'] != '' && $old['deleted'] == null)
+		$config = Api\Config::read('resources');
+		if (!($old = $this->read($res_id)))
+		{
+			// error is returned at end of function
+		}
+		elseif ($config['history'] != '' && $old['deleted'] == null)
 		{
 			$old['deleted'] = time();
 			$this->save($old);
-			egw_link::unlink(0,'resources',$res_id,'','','',true);
+			Link::unlink(0,'resources',$res_id,'','','',true);
 			$accessories = $this->get_acc_list($res_id);
 			foreach($accessories as $acc_id => $name)
 			{
 				// Don't purge already deleted accessories
-				$acc = $this->read($acc_id);
-				if(!$acc['deleted'])
+				if (($acc = $this->read($acc_id)) && !$acc['deleted'])
 				{
 					$acc['deleted'] = time();
 					$this->save($acc);
-					egw_link::unlink(0,'resources',$acc_id,'','','',true);
+					Link::unlink(0,'resources',$acc_id,'','','',true);
 				}
 			}
 			return false;
@@ -464,15 +481,14 @@ class resources_bo
 			$accessories = $this->get_acc_list($res_id, true);
 			foreach($accessories as $acc_id => $name)
 			{
-				if($this->delete($acc_id))
+				if($this->delete($acc_id) && ($acc = $this->read($acc_id)))
 				{
-					$acc = $this->read($acc_id);
 					$acc['accessory_of'] = -1;
 					$this->save($acc);
 				}
 			};
 			$this->remove_picture($res_id);
-	 		egw_link::unlink(0,'resources',$res_id);
+	 		Link::unlink(0,'resources',$res_id);
 	 		// delete the resource from the calendar
 	 		ExecMethod('calendar.calendar_so.deleteaccount','r'.$res_id);
 	 		return false;
@@ -533,7 +549,7 @@ class resources_bo
 			$resource['responsible'] = $this->acl->get_cat_admin($resource['cat_id']);
 
 			// preseed the cache
-			egw_link::set_cache('resources',$resource['res_id'],$t=$this->link_title($resource));
+			Link::set_cache('resources',$resource['res_id'],$t=$this->link_title($resource));
 		}
 		return $data;
 	}
@@ -550,7 +566,7 @@ class resources_bo
 		{
 			return false;
 		}
-		return $this->acl->is_permitted($data['cat_id'],EGW_ACL_DIRECT_BOOKING) ? A : U;
+		return $this->acl->is_permitted($data['cat_id'],resources_acl_bo::DIRECT_BOOKING) ? A : U;
 	}
 
 	/**
@@ -577,13 +593,13 @@ class resources_bo
 		$only_keys = 'res_id,name,short_description,bookable,useable';
 
 		// If no read access to any category, just stop
-		if(!$this->acl->get_cats(EGW_ACL_READ))
+		if(!$this->acl->get_cats(Acl::READ))
 		{
 			$options['total'] = 0;
 			return array();
 		}
 		$filter = array(
-			'cat_id' => array_flip((array)$this->acl->get_cats(EGW_ACL_READ)),
+			'cat_id' => array_flip((array)$this->acl->get_cats(Acl::READ)),
 			//'accessory_of' => '-1'
 			'deleted' => null
 		);
@@ -598,7 +614,7 @@ class resources_bo
 		$data = $this->so->search($criteria,$only_keys,$order_by='name',$extra_cols='',$wildcard='%',$empty,$op='OR',$limit,$filter);
 		// maybe we need to check disponibility of the searched resources in the calendar if $pattern ['exec'] contains some extra args
 		$show_conflict=False;
-		if ($options['exec'])
+		if ($options['exec'] && $GLOBALS['egw_info']['preferences']['calendar']['defaultresource_sel'] !== 'resources')
 		{
 			// we'll use a cache for resources info taken from database
 			static $res_info_cache = array();
@@ -608,14 +624,13 @@ class resources_bo
 				//get a calendar objet for reservations
 				if ( (!isset($this->bocal)) || !(is_object($this->bocal)))
 				{
-					require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.calendar_bo.inc.php');
-					$this->bocal =& CreateObject('calendar.calendar_bo');
+					$this->bocal = new calendar_bo();
 				}
-				$start = new egw_time($cal_info['start']);
+				$start = new Api\DateTime($cal_info['start']);
 				$startarr= getdate($start->format('ts'));
-				if (isset($cal_info['whole_day'])) {
+				if (isset($cal_info['whole_day']) && $cal_info['whole_day']) {
 					$startarr['hour'] = $startarr['minute'] = 0;
-					$start = new egw_time($startarr);
+					$start = new Api\DateTime($startarr);
 					$end = $start->format('ts') + 86399;
 				} else {
 					$start = $start->format('ts');
@@ -664,10 +679,10 @@ class resources_bo
 									$res_info_cache[$resource_id]['useable'] = 1;
 								}
 								// now decrement this quantity useable
-								// TODO : decrement with real event quantity, not 1
-								// but this quantity is not given by calendar search, we should re-use a cal object
-								// to load specific cal infos, like quantity... lot of requests
-								$res_info_cache[$resource_id]['useable']--;
+								$quantity = 1;
+								$this->bocal->so->split_status($part_detail,$quantity);
+
+								$res_info_cache[$resource_id]['useable']-=$quantity;
 							}
 						}
 					}
@@ -675,7 +690,7 @@ class resources_bo
 			}
 		}
 		if (isset($res_info_cache)) {
-			$show_conflict= (isset($options['exec']['show_conflict'])&& ($options['exec']['show_conflict']=='0'))? False:True;
+			$show_conflict= $GLOBALS['egw_info']['user']['preferences']['calendar']['defaultresource_sel'] === 'resources_conflict';
 			// if we have this array indexed on resource id it means non-bookable resource are removed and we are working for calendar
 			// so we'll loop on this one and not $data
 			foreach($res_info_cache as $id => $resource) {
@@ -718,7 +733,7 @@ class resources_bo
 		{
 			if (!($resource  = $this->read(array('res_id' => $resource)))) return $resource;
 		}
-		elseif (!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_READ))
+		elseif (!$this->acl->is_permitted($resource['cat_id'],Acl::READ))
 		{
 			return false;
 		}
@@ -749,7 +764,7 @@ class resources_bo
 				$titles[$resource['res_id']] = $this->link_title($resource);
 			}
 		}
-		// we assume all not returned contacts are not readable for the user (as we report all deleted contacts to egw_link)
+		// we assume all not returned contacts are not readable for the user (as we report all deleted contacts to Link)
 		foreach($ids as $id)
 		{
 			if (!isset($titles[$id]))
@@ -791,7 +806,7 @@ class resources_bo
 		imagejpeg($src_img,$tmp_name);
 		imagedestroy($src_img);
 
-		egw_link::attach_file('resources',$resouce_id,array(
+		Link::attach_file('resources',$resouce_id,array(
 			'tmp_name' => $tmp_name,
 			'name'     => self::PICTURE_NAME,
 			'type'     => 'image/jpeg',
@@ -812,25 +827,24 @@ class resources_bo
 		switch($resource['picture_src'])
 		{
 			case 'own_src':
-				$picture = egw_link::vfs_path('resources',$resource['res_id'],self::PICTURE_NAME,true);	// vfs path
+				$picture = Link::vfs_path('resources',$resource['res_id'],self::PICTURE_NAME,true);	// vfs path
 				if ($fullsize)
 				{
-					$picture = egw::link(egw_vfs::download_url($picture));
+					$picture = Egw::link(Vfs::download_url($picture));
 				}
 				else
 				{
-					$picture = egw::link('/etemplate/thumbnail.php', array(
+					$picture = Egw::link('/api/thumbnail.php', array(
 						'path' => $picture
-					));
+					),false);
 				}
 				break;
 
 			case 'cat_src':
-				list($picture) = $this->cats->return_single($resource['cat_id']);
-				$picture = unserialize($picture['data']);
+				$picture = Api\Categories::id2name($resource['cat_id'], 'data');
 				if($picture['icon'])
 				{
-					$picture = !$fullsize?$GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/images/'.$picture['icon']:'/phpgwapi/images/'.$picture['icon'];
+					$picture = !$fullsize?$GLOBALS['egw_info']['server']['webserver_url'].self::ICON_PATH.'/'.$picture['icon']:self::ICON_PATH.'/'.$picture['icon'];
 					break;
 				}
 				// fall through
@@ -852,7 +866,7 @@ class resources_bo
 	 */
 	function remove_picture($res_id)
 	{
-		if (($arr = egw_link::delete_attached('resources',$res_id,self::PICTURE_NAME)) && is_array($arr))
+		if (($arr = Link::delete_attached('resources',$res_id,self::PICTURE_NAME)) && is_array($arr))
 		{
 			return array_shift($arr);	// $arr = array($path => (bool)$ok);
 		}
