@@ -10,6 +10,12 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Acl;
+use EGroupware\Api\Etemplate;
+
 /**
  * General userinterface object for resources
  *
@@ -31,7 +37,7 @@ class resources_ui
 	function __construct()
 	{
 // 		print_r($GLOBALS['egw_info']); die();
-		$this->tmpl	= new etemplate_new('resources.show');
+		$this->tmpl	= new Etemplate('resources.show');
 		$this->bo	= new resources_bo();
 // 		$this->calui	= CreateObject('resources.ui_calviews');
 	}
@@ -49,7 +55,7 @@ class resources_ui
 		{
 			$sessiondata = $content['nm'];
 			unset($sessiondata['rows']);
-			$GLOBALS['egw']->session->appsession('session_data','resources_index_nm',$sessiondata);
+			Api\Cache::setSession('resources', 'index_nm', $sessiondata);
 
 			if (isset($content['btn_delete_selected']))
 			{
@@ -72,7 +78,7 @@ class resources_ui
 				if(isset($row['view_acc']))
 				{
 					$sessiondata['filter2'] = array_search('pressed',$row['view_acc']);
-					$GLOBALS['egw']->session->appsession('session_data','resources_index_nm',$sessiondata);
+					Api\Cache::setSession('resources', 'index_nm', $sessiondata);
 					return $this->index();
 				}
 			}
@@ -105,11 +111,8 @@ class resources_ui
 		$content = array();
 		$content['msg'] = $msg ? $msg : $_GET['msg'];
 
-		$content['nm']['header_row']	= 'resources.show.nm_right';
 		$content['nm']['get_rows']		= 'resources.resources_bo.get_rows';
 		$content['nm']['no_filter'] 	= False;
-		$content['nm']['filter_label']	= lang('Category');
-		$content['nm']['filter2_label']	= 'Display';
 		$content['nm']['filter_no_lang'] = true;
 		$content['nm']['no_cat']	= true;
 		$content['nm']['bottom_too']	= true;
@@ -119,19 +122,19 @@ class resources_ui
 		$content['nm']['row_id']	= 'res_id';
 		$content['nm']['favorites'] = true;
 
-		$nm_session_data = $GLOBALS['egw']->session->appsession('session_data','resources_index_nm');
+		$nm_session_data = Api\Cache::getSession('resources', 'index_nm');
 		if($nm_session_data)
 		{
 			$content['nm'] = $nm_session_data;
 		}
-		$content['nm']['options-filter']= array(''=>lang('all categories'))+(array)$this->bo->acl->get_cats(EGW_ACL_READ);
+		$content['nm']['options-filter']= array(''=>lang('all categories'))+(array)$this->bo->acl->get_cats(Acl::READ);
 		$content['nm']['options-filter2'] = resources_bo::$filter_options;
 		if(!$content['nm']['filter2'])
 		{
 			$content['nm']['filter2'] = key(resources_bo::$filter_options);
 		}
 
-		$config = config::read('resources');
+		$config = Api\Config::read('resources');
 		if($config['history'])
 		{
 			$content['nm']['options-filter2'][resources_bo::DELETED] = lang('Deleted');
@@ -145,17 +148,18 @@ class resources_ui
 			$content['nm']['filter2'] = (int)$_GET['view_accs_of'];
 		}
 		$content['nm']['actions']	= $this->get_actions();
+		$content['nm']['placeholder_actions'] = array('add');
 
 		// check if user is permitted to add resources
 		// If they can't read any categories, they won't be able to save it
-		if(!$this->bo->acl->get_cats(EGW_ACL_ADD) || !$this->bo->acl->get_cats(EGW_ACL_READ))
+		if(!$this->bo->acl->get_cats(Acl::ADD) || !$this->bo->acl->get_cats(Acl::READ))
 		{
 			$no_button['add'] = $no_button['nm']['add'] = true;
 		}
 		$no_button['back'] = true;
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('resources');
 
-		egw_framework::validate_file('.','resources','resources');
+		Framework::includeJS('.','resources','resources');
 
 		if($content['nm']['filter2'] > 0)
 		{
@@ -171,7 +175,7 @@ class resources_ui
 
 		$options = array();
 
-		$GLOBALS['egw']->session->appsession('session_data','resources_index_nm',$content['nm']);
+		Api\Cache::setSession('resources', 'index_nm', $content['nm']);
 		$this->tmpl->read('resources.show');
 		return $this->tmpl->exec('resources.resources_ui.index',$content,$sel_options,$no_button,$preserv);
 	}
@@ -189,15 +193,18 @@ class resources_ui
 				'caption' => 'open',
 				'allowOnMultiple' => false,
 				'url' => 'menuaction=resources.resources_ui.edit&res_id=$id',
-				'popup' => egw_link::get_registry('resources', 'add_popup'),
+				'popup' => Link::get_registry('resources', 'add_popup'),
 				'group' => $group=1,
 				'disableClass' => 'rowNoEdit',
+				'onExecute' => Api\Header\UserAgent::mobile()?'javaScript:app.resources.viewEntry':'',
+				'mobileViewTemplate' => 'view?'.filemtime(Api\Etemplate\Widget\Template::rel2path('/resources/templates/mobile/view.xet'))
 			),
 			'add' => array(
 				'caption' => 'New resource',
 				'url' => 'menuaction=resources.resources_ui.edit&accessory_of=-1',
-				'popup' => egw_link::get_registry('resources', 'add_popup'),
+				'popup' => Link::get_registry('resources', 'add_popup'),
 				'group' => $group,
+				'hideOnMobile' => true
 			),
 			'view-acc' => array(
 				'caption' => 'View accessories',
@@ -212,7 +219,7 @@ class resources_ui
 				'icon' => 'new',
 				'group' => $group,
 				'url' => 'menuaction=resources.resources_ui.edit&res_id=0&accessory_of=$id',
-				'popup' => egw_link::get_registry('resources', 'add_popup'),
+				'popup' => Link::get_registry('resources', 'add_popup'),
 				'disableClass' => 'no_new_accessory',
 				'allowOnMultiple' => false
 			),
@@ -459,16 +466,16 @@ class resources_ui
 						break;
 					}
 			}
-			egw_framework::refresh_opener($msg, 'resources',$content['res_id'],($button == 'delete'?'delete':'edit'));
+			Framework::refresh_opener($msg, 'resources',$content['res_id'],($button == 'delete'?'delete':'edit'));
 
 			if($button != 'apply')
 			{
-				egw_framework::window_close();
+				Framework::window_close();
 			}
 
 		}
 
-		$nm_session_data = $GLOBALS['egw']->session->appsession('session_data','resources_index_nm');
+		$nm_session_data = Api\Cache::getSession('resources', 'index_nm');
 		$res_id = is_numeric($content) ? (int)$content : $content['res_id'];
 		if (isset($_GET['res_id'])) $res_id = $_GET['res_id'];
 		if (isset($nm_session_data['filter2']) && $nm_session_data['filter2'] > 0) $accessory_of = $nm_session_data['filter2'];
@@ -521,7 +528,7 @@ class resources_ui
 		$sel_options['status'] = resources_bo::$field2label;
 
 		//$sel_options['gen_src_list'] = $this->bo->get_genpicturelist();
-		$sel_options['cat_id'] =  $this->bo->acl->get_cats(EGW_ACL_ADD);
+		$sel_options['cat_id'] =  $this->bo->acl->get_cats(Acl::ADD);
 		$sel_options['cat_id'] = count($sel_options['cat_id']) == 1 ? $sel_options['cat_id'] :
 			array('' => lang('select one')) + $sel_options['cat_id'];
 		if($accessory_of > 0 || $content['accessory_of'] > 0)
@@ -546,12 +553,12 @@ class resources_ui
 
 		// Permissions
 		$read_only = array();
-		if($res_id && !$this->bo->acl->is_permitted($content['cat_id'],EGW_ACL_EDIT))
+		if($res_id && !$this->bo->acl->is_permitted($content['cat_id'],Acl::EDIT))
 		{
 			$read_only['__ALL__'] = true;
 		}
-		$config = config::read('resources');
-		if(!$this->bo->acl->is_permitted($content['cat_id'],EGW_ACL_DELETE) ||
+		$config = Api\Config::read('resources');
+		if(!$this->bo->acl->is_permitted($content['cat_id'],Acl::DELETE) ||
 			($content['deleted'] && !$GLOBALS['egw_info']['user']['apps']['admin'] && $config['history'] == 'history'))
 		{
 			$read_only['delete'] = true;
@@ -565,7 +572,7 @@ class resources_ui
 		}
 
 		// Disable custom tab if there are no custom fields defined
-		$read_only['tabs']['custom'] = !(config::get_customfields('resources',true));
+		$read_only['tabs']['custom'] = !(Api\Storage\Customfields::get('resources',true));
 		$read_only['tabs']['history'] = ($content['history']['id'] != 0?false:true);
 
 		$preserv = $content;
@@ -574,98 +581,5 @@ class resources_ui
 		return $this->tmpl->exec('resources.resources_ui.edit',$content,$sel_options,$read_only,$preserv,2);
 	}
 
-	/**
-	 * get_calendar_sidebox
-	 * get data für calendar sidebox
-	 *
-	 * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
-	 * @param array $param with keys menuaction, owner and optional date and return_array
-	 * @return array with: label=>link or array with text
-	 */
-	function get_calendar_sidebox($param)
-	{
-		$cats = $this->bo->acl->get_cats(EGW_ACL_CALREAD);
-		if (!$cats) return array();
-
-		if(array_key_exists('return_array', $param))
-		{
-			$return_array = $param['return_array'];
-			unset($param['return_array']);
-		}
-
-		$owners = explode(',',$param['owner']);
-		unset($param['owner']);
-		$res_cats = $selected = array();
-
-		// this gets the resource-ids of the cats and implodes them to the array-key of the selectbox,
-		// so it is possible to select all resources of a category
-		$allowed_list = array();
-		foreach($cats as $cat_id => $cat_name)
-		{
-			if ($resources = $this->bo->so->search(array('cat_id' => $cat_id, 'bookable' => '1'),'res_id',
-				'','','',False,'AND',false, array('deleted' => null))
-			)
-			{
-				$keys = array();
-				foreach($resources as $res)
-				{
-					$keys[] = 'r'.$res['res_id'];
-					$allowed_list[] = $res['res_id'];
-				}
-				$res_cats[implode(',',$keys)] = $cat_name;
-
-				if (count(array_intersect($keys,$owners)) == count($keys))
-				{
-					$selected[] = implode(',',$keys);
-					$owners = array_diff($owners,$keys);
-				}
-			}
-		}
-		// add already selected single resources to the selectbox, eg. call of the resource-calendar from the resources app
-		$resources = array();
-		$res_ids = array();
-		foreach($owners as $key => $owner)
-		{
-			if ($owner{0} == 'r')
-			{
-				$res_ids[] = (int) substr($owner,1);
-				$selected[] = $owner;
-			}
-		}
-
-		// Take out resources not allowed by perms, above
-		$res_ids = array_intersect($res_ids,$allowed_list);
-		if (count($res_ids))
-		{
-			foreach($this->bo->so->search(array('res_id' => $res_ids),'res_id,name') as $data)
-			{
-				$resources['r'.$data['res_id']] = $data['name'];
-			}
-		}
-		if(!isset($return_array))
-		{
-			$selectbox = html::select(
-				'owner',
-				$selected,
-				$options=array_merge(array('r0' => lang('None')),$resources,$res_cats),
-				true,	// no lang
-				' style="width: 100%;" id="uical_select_resource"',
-				min(4, count($options)),	// multiple
-				false
-			);
-			return array(
-				array(
-					// Add some jQuery to make sure dropdown is displayed
-					'text' => $selectbox,
-					'no_lang' => True,
-					'link' => False
-				)
-			);
-		}
-		else
-		{
-			return array_merge($resources,$res_cats);
-		}
-	}
 }
 
