@@ -13,7 +13,7 @@
 
 $setup_info['resources']['name']	= 'resources';
 $setup_info['resources']['title']	= 'Resources';
-$setup_info['resources']['version']	= '14.1';
+$setup_info['resources']['version']	= '16.1';
 $setup_info['resources']['app_order']	= 5;
 $setup_info['resources']['tables']	= array('egw_resources','egw_resources_extra');
 $setup_info['resources']['enable']	= 1;
@@ -37,12 +37,8 @@ $setup_info['resources']['hooks']['delete_category']	= 'resources.resources_hook
 $setup_info['resources']['hooks']['settings'] = 'resources_hooks::settings';
 
 $setup_info['resources']['depends'][]	= array(
-	 'appname' => 'phpgwapi',
-	 'versions' => Array('14.1')
-);
-$setup_info['resources']['depends'][]	= array( // cause eTemplates is not in the api yet
-	 'appname' => 'etemplate',
-	 'versions' => Array('14.1')
+	 'appname' => 'api',
+	 'versions' => Array('16.1')
 );
 
 
