@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupware Setup - create admin account
+ * EGroupware Setup - create admin account
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -10,13 +10,16 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+
 if (strpos($_SERVER['PHP_SELF'],'admin_account.php') !== false)
 {
 	include('./inc/functions.inc.php');
 
 	// Authorize the user to use setup app and load the database
 	// Does not return unless user is authorized
-	if(!$GLOBALS['egw_setup']->auth('Config') || get_var('cancel',Array('POST')))
+	if(!$GLOBALS['egw_setup']->auth('Config') || $_POST['cancel'])
 	{
 		Header('Location: index.php');
 		exit;
@@ -29,16 +32,16 @@ if ($_POST['submit'])
 	// for POST (not GET or cli call via setup_cmd_admin) validate CSRF token
 	if ($_SERVER['REQUEST_METHOD'] == 'POST')
 	{
-		egw_csrf::validate($_POST['csrf_token'], __FILE__);
+		Api\Csrf::validate($_POST['csrf_token'], __FILE__);
 	}
 
 	/* Posted admin data */
-	$passwd   = get_var('passwd',Array('POST'));
-	$passwd2  = get_var('passwd2',Array('POST'));
-	$username = get_var('username',Array('POST'));
-	$fname    = get_var('fname',Array('POST'));
-	$lname    = get_var('lname',Array('POST'));
-	$email    = get_var('email',Array('POST'));
+	$passwd   = $_POST['passwd'];
+	$passwd2  = $_POST['passwd2'];
+	$username = $_POST['username'];
+	$fname    = $_POST['fname'];
+	$lname    = $_POST['lname'];
+	$email    = $_POST['email'];
 
 	if($passwd != $passwd2 || !$username)
 	{
@@ -52,7 +55,7 @@ if ($_POST['submit'])
 if(!$_POST['submit'] || $error)
 {
 	$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
-	$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
+	$setup_tpl = new Framework\Template($tpl_root);
 	$setup_tpl->set_file(array(
 		'T_head'       => 'head.tpl',
 		'T_footer'     => 'footer.tpl',
@@ -89,7 +92,7 @@ if(!$_POST['submit'] || $error)
 	$setup_tpl->set_var('create_demo_accounts',lang('Create demo accounts'));
 	$setup_tpl->set_var('demo_desc',lang('The username/passwords are: demo/guest, demo2/guest and demo3/guest.'));
 
-	$setup_tpl->set_var('hidden_vars', html::input_hidden('csrf_token', egw_csrf::token(__FILE__)));
+	$setup_tpl->set_var('hidden_vars', Api\Html::input_hidden('csrf_token', Api\Csrf::token(__FILE__)));
 
 	$setup_tpl->set_var('lang_submit',lang('Save'));
 	$setup_tpl->set_var('lang_cancel',lang('Cancel'));
@@ -150,7 +153,7 @@ else
 	$GLOBALS['egw_setup']->add_acl($apps,'run',$admingroupid);
 
 	/* Creation of the demo accounts is optional - the checkbox is on by default. */
-	if(get_var('create_demo',Array('POST')))
+	if($_POST['create_demo'])
 	{
 		// Create 3 demo accounts
 		$GLOBALS['egw_setup']->add_account('demo','Demo','Account','guest');
