@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupware Setup - Install, update & remove single apps
+ * EGroupware Setup - Install, update & remove single apps
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -10,6 +10,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+
 $DEBUG = @$_POST['debug'] || @$_GET['debug'];
 /*
  TODO: We allow a user to hose their setup here, need to make use
@@ -31,7 +34,7 @@ if (!$GLOBALS['egw_setup']->auth('Config'))
 // Does not return unless user is authorized
 
 $tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
-$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
+$setup_tpl = new Framework\Template($tpl_root);
 $setup_tpl->set_file(array(
 	'T_head' => 'head.tpl',
 	'T_footer' => 'footer.tpl',
@@ -40,12 +43,12 @@ $setup_tpl->set_file(array(
 	'T_login_stage_header' => 'login_stage_header.tpl',
 	'T_setup_main' => 'applications.tpl'
 ));
-$setup_tpl->set_var('hidden_vars', html::input_hidden('csrf_token', egw_csrf::token(__FILE__)));
+$setup_tpl->set_var('hidden_vars', Api\Html::input_hidden('csrf_token', Api\Csrf::token(__FILE__)));
 
 // check CSRF token for POST requests with any content (setup uses empty POST to call it's modules!)
 if ($_SERVER['REQUEST_METHOD'] == 'POST' && $_POST)
 {
-	egw_csrf::validate($_POST['csrf_token'], __FILE__);
+	Api\Csrf::validate($_POST['csrf_token'], __FILE__);
 }
 
 $setup_tpl->set_block('T_login_stage_header','B_multi_domain','V_multi_domain');
@@ -66,7 +69,7 @@ $bgcolor = array('#DDDDDD','#EEEEEE');
 function parsedep($depends,$main=True)
 {
 	$depstring = '(';
-	foreach($depends as $a => $b)
+	foreach($depends as $b)
 	{
 		foreach($b as $c => $d)
 		{
@@ -96,36 +99,35 @@ function parsedep($depends,$main=True)
 $GLOBALS['egw_setup']->loaddb();
 $GLOBALS['egw_info']['setup']['stage']['db'] = $GLOBALS['egw_setup']->detection->check_db();
 
-$setup_info = $GLOBALS['egw_setup']->detection->get_versions();
-//var_dump($setup_info);exit;
-$setup_info = $GLOBALS['egw_setup']->detection->get_db_versions($setup_info);
-//var_dump($setup_info);exit;
-$setup_info = $GLOBALS['egw_setup']->detection->compare_versions($setup_info);
-//var_dump($setup_info);exit;
-$setup_info = $GLOBALS['egw_setup']->detection->check_depends($setup_info);
-//var_dump($setup_info);exit;
+$setup_info = $GLOBALS['egw_setup']->detection->check_depends(
+	$GLOBALS['egw_setup']->detection->compare_versions(
+		$GLOBALS['egw_setup']->detection->get_db_versions(
+			$GLOBALS['egw_setup']->detection->get_versions())));
+
 @ksort($setup_info);
 
-if(@get_var('cancel',Array('POST')))
+if(@$_POST['cancel'])
 {
 	Header("Location: index.php");
 	exit;
 }
 
-if(@get_var('submit',Array('POST')))
+if(@$_POST['submit'])
 {
 	$GLOBALS['egw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['egw_setup']->ConfigDomain . '(' . $GLOBALS['egw_domain'][$GLOBALS['egw_setup']->ConfigDomain]['db_type'] . ')');
 	$setup_tpl->set_var('description',lang('App install/remove/upgrade') . ':');
 	$setup_tpl->pparse('out','header');
 
-	$appname = get_var('appname',Array('POST'));
-	$remove  = get_var('remove',Array('POST'));
-	$install = get_var('install',Array('POST'));
-	$upgrade = get_var('upgrade',Array('POST'));
+	$appname = $_POST['appname'];
+	$remove  = $_POST['remove'];
+	$install = $_POST['install'];
+	$upgrade = $_POST['upgrade'];
+
+	$register_hooks = false;
 
 	if(!empty($remove) && is_array($remove))
 	{
-		$historylog = CreateObject('phpgwapi.historylog');
+		$historylog = new Api\Storage\History();
 		$historylog->db = $GLOBALS['egw_setup']->db;
 
 		foreach($remove as $appname => $key)
@@ -143,10 +145,7 @@ if(@get_var('submit',Array('POST')))
 			$GLOBALS['egw_setup']->deregister_app($setup_info[$appname]['name']);
 			echo '<br />' . $app_title . ' ' . lang('deregistered') . '.';
 
-			if ($GLOBALS['egw_setup']->deregister_hooks($setup_info[$appname]['name']))
-			{
-				echo '<br />' . $app_title . ' ' . lang('hooks deregistered') . '.';
-			}
+			$register_hooks = true;
 
 			$historylog->appname = $appname;
 			if ($historylog->delete(null))
@@ -170,8 +169,8 @@ if(@get_var('submit',Array('POST')))
 
 			if ($setup_info[$appname]['tables'])
 			{
-				$terror = $GLOBALS['egw_setup']->process->current($terror,$DEBUG);
-				$terror = $GLOBALS['egw_setup']->process->default_records($terror,$DEBUG);
+				$terror_c = $GLOBALS['egw_setup']->process->current($terror, $DEBUG);
+				$terror = $GLOBALS['egw_setup']->process->default_records($terror_c, $DEBUG);
 				echo '<br />' . $app_title . ' '
 					. lang('tables installed, unless there are errors printed above') . '.';
 			}
@@ -191,8 +190,7 @@ if(@get_var('submit',Array('POST')))
 
 				if ($setup_info[$appname]['hooks'])
 				{
-					$GLOBALS['egw_setup']->register_hooks($setup_info[$appname]['name']);
-					echo '<br />' . $app_title . ' ' . lang('hooks registered') . '.';
+					$register_hooks = true;
 				}
 			}
 		}
@@ -216,8 +214,16 @@ if(@get_var('submit',Array('POST')))
 			{
 				echo '<br />' . $app_title . ' ' . lang('upgraded') . '.';
 			}
+			$register_hooks = true;
 		}
 	}
+
+	if ($register_hooks)
+	{
+		Api\Hooks::read(true);
+		echo '<br />' . $app_title . ' ' . lang('hooks registered') . '.';
+	}
+
 	//$setup_tpl->set_var('goback',
 	echo '<br /><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
 	//$setup_tpl->pparse('out','submit');
@@ -229,19 +235,14 @@ else
 	$GLOBALS['egw_setup']->html->show_header(lang('Application Management'),False,'config',$GLOBALS['egw_setup']->ConfigDomain . '(' . $GLOBALS['egw_domain'][$GLOBALS['egw_setup']->ConfigDomain]['db_type'] . ')');
 }
 
-if(@get_var('hooks', Array('GET')))
+if(@$_GET['hooks'])
 {
-	egw_cache::flush(egw_cache::INSTANCE);
+	Api\Cache::flush(Api\Cache::INSTANCE);
 
-	// Find & register all application hooks
-	foreach($setup_info as $appname => $info)
-	{
-		if ($info['currentver']) $GLOBALS['egw_setup']->register_hooks($appname);
-	}
-	echo lang('All hooks registered') . '<br />';
+	echo lang('Cached cleared') . '<br />';
 }
-$detail = get_var('detail',Array('GET'));
-$resolve = get_var('resolve',Array('GET'));
+$detail = $_GET['detail'];
+$resolve = $_GET['resolve'];
 if(@$detail)
 {
 	@ksort($setup_info[$detail]);
@@ -254,28 +255,43 @@ if(@$detail)
 
 	foreach($setup_info[$detail] as $key => $val)
 	{
-		if($key != 'title')
+		switch($key)
 		{
-			$i = ($i ? 0 : 1);
-
-			if ($key == 'tables')
-			{
+			case 'title':
+				continue 2;
+			case 'tables':
 				$tblcnt = count($setup_info[$detail][$key]);
 				if(is_array($val))
 				{
 					$key = '<a href="sqltoarray.php?appname=' . $detail . '&submit=True&apps=True">' . $key . '(' . $tblcnt . ')</a>' . "\n";
 					$val = implode(',' . "\n",$val);
 				}
-			}
-			if ($key == 'hooks')   { $val = implode(',',$val); }
-			if ($key == 'depends') { $val = parsedep($val); }
-			if (is_array($val))    { $val = implode(',',$val); }
-
-			$setup_tpl->set_var('bg_color',$bgcolor[$i]);
-			$setup_tpl->set_var('name',$key);
-			$setup_tpl->set_var('details',$val);
-			$setup_tpl->pparse('out','detail');
+				break;
+			case 'hooks':
+				foreach($val as &$hooks)
+				{
+					$hooks = (array)$hooks;
+				}
+				$val = str_replace('EGroupware\\', '', implode(', ', call_user_func_array('array_merge', $val)));
+				break;
+			case 'depends':
+				foreach($val as &$dep)
+				{
+					$dep = $dep['appname'].': '.implode(', ', $dep['versions']);
+				}
+				$val = implode('; ', $val);
+				break;
+			case 'check_install':
+				$val = array2string($val);
+				break;
+			default:
+				if (is_array($val)) $val = implode(', ', $val);
+				break;
 		}
+		$setup_tpl->set_var('bg_color', $bgcolor[++$i & 1]);
+		$setup_tpl->set_var('name',$key);
+		$setup_tpl->set_var('details',$val);
+		$setup_tpl->pparse('out','detail');
 	}
 
 	echo '<br /><a href="applications.php?debug='.$DEBUG.'">' . lang('Go back') . '</a>';
@@ -284,13 +300,13 @@ if(@$detail)
 }
 elseif (@$resolve)
 {
-	$version  = get_var('version',Array('GET'));
-	$notables = get_var('notables',Array('GET'));
+	$version  = $_GET['version'];
+	$notables = $_GET['notables'];
 	$setup_tpl->set_var('description',lang('Problem resolution'). ':');
 	$setup_tpl->pparse('out','header');
 	$app_title = $setup_info[$resolve]['title'] ? $setup_info[$resolve]['title'] : $setup_info[$resolve]['name'];
 
-	if(get_var('post',Array('GET')))
+	if($_GET['post'])
 	{
 		echo '"' . $app_title . '" ' . lang('may be broken') . ' ';
 		echo lang('because an application it depends upon was upgraded');
@@ -299,7 +315,7 @@ elseif (@$resolve)
 		echo '<br />';
 		echo lang('However, the application may still work') . '.';
 	}
-	elseif(get_var('badinstall',Array('GET')))
+	elseif($_GET['badinstall'])
 	{
 		echo '"' . $app_title . '" ' . lang('is broken') . ' ';
 		echo lang('because of a failed upgrade or install') . '.';
@@ -308,7 +324,7 @@ elseif (@$resolve)
 		echo '<br />';
 		echo lang('You should either uninstall and then reinstall it, or attempt manual repairs') . '.';
 	}
-	elseif(get_var('deleted',Array('GET')))
+	elseif($_GET['deleted'])
 	{
 		echo '"' . $app_title . '" ' . lang('is broken') . ' ';
 		echo lang('because its sources are missing') . '!';
@@ -343,8 +359,7 @@ elseif (@$resolve)
 					{
 						$list .= $y . ', ';
 					}
-					$list = substr($list,0,-2);
-					echo "$list\n";
+					echo substr($list,0,-2)."\n";
 				}
 				echo '<br /><br />' . lang('The table definition was correct, and the tables were installed') . '.';
 			}
@@ -421,7 +436,7 @@ else
 			switch($value['status'])
 			{
 				case 'C':
-					$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+					$setup_tpl->set_var('remove', $key == 'api' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 					$setup_tpl->set_var('upgrade','&nbsp;');
 					if (!$GLOBALS['egw_setup']->detection->check_app_tables($value['name']))
 					{
@@ -464,7 +479,7 @@ else
 						if ($value['tables'] && $GLOBALS['egw_setup']->detection->check_app_tables($value['name'],True))
 						{
 							// Some tables missing
-							$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+							$setup_tpl->set_var('remove',$key == 'api' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 							$setup_tpl->set_var('resolution','<a href="applications.php?resolve=' . $value['name'] . '&badinstall=True">' . lang('Potential Problem') . '</a>');
 							$status = lang('Requires reinstall or manual repair') . ' - ' . $value['status'];
 						}
@@ -488,7 +503,7 @@ else
 						$setup_tpl->set_var('install','&nbsp;');
 						// TODO display some info about breakage if you mess with this app
 						$setup_tpl->set_var('upgrade','<input type="checkbox" name="upgrade[' . $value['name'] . ']" />');
-						$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+						$setup_tpl->set_var('remove',$key == 'api' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 						$setup_tpl->set_var('resolution','');
 						$status = lang('Requires upgrade') . ' - ' . $value['status'];
 					}
@@ -497,7 +512,7 @@ else
 					$setup_tpl->set_var('instimg','incomplete.png');
 					$setup_tpl->set_var('instalt',lang('Not Completed'));
 					$setup_tpl->set_var('install','&nbsp;');
-					$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+					$setup_tpl->set_var('remove',$key == 'api' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 					if ($value['version'] == 'deleted')
 					{
 						$setup_tpl->set_var('bg_color','CCAAAA');
@@ -521,7 +536,7 @@ else
 					$setup_tpl->set_var('install','&nbsp;');
 					if ($values['currentver'])
 					{
-						$setup_tpl->set_var('remove',$key == 'phpgwapi' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
+						$setup_tpl->set_var('remove',$key == 'api' ? '&nbsp;' : '<input type="checkbox" name="remove[' . $value['name'] . ']" />');
 						$setup_tpl->set_var('resolution','<a href="applications.php?resolve=' . $value['name'] . '">' . lang('Possible Solutions') . '</a>');
 					}
 					else
