@@ -1,6 +1,6 @@
 <?php
 /**
- * eGroupWare Setup - System configuration
+ * EGroupWare Setup - System configuration
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -10,6 +10,9 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Framework;
+
 include('./inc/functions.inc.php');
 
 /*
@@ -23,7 +26,7 @@ if(!$GLOBALS['egw_setup']->auth('Config') || @$_POST['cancel'])
 }
 
 $tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
-$setup_tpl = CreateObject('phpgwapi.Template',$tpl_root);
+$setup_tpl = new Framework\Template($tpl_root);
 
 $setup_tpl->set_file(array(
 	'T_head' => 'head.tpl',
@@ -32,12 +35,12 @@ $setup_tpl->set_file(array(
 	'T_config_pre_script' => 'config_pre_script.tpl',
 	'T_config_post_script' => 'config_post_script.tpl'
 ));
-$setup_tpl->set_var('hidden_vars', html::input_hidden('csrf_token', egw_csrf::token(__FILE__)));
+$setup_tpl->set_var('hidden_vars', Api\Html::input_hidden('csrf_token', Api\Csrf::token(__FILE__)));
 
 // check CSRF token for POST requests with any content (setup uses empty POST to call it's modules!)
 if ($_SERVER['REQUEST_METHOD'] == 'POST' && $_POST)
 {
-	egw_csrf::validate($_POST['csrf_token'], __FILE__);
+	Api\Csrf::validate($_POST['csrf_token'], __FILE__);
 }
 
 /* Following to ensure windows file paths are saved correctly */
@@ -52,27 +55,12 @@ $setup_info = $GLOBALS['egw_setup']->detection->get_db_versions();
 
 $newsettings = $_POST['newsettings'];
 
-if(@get_var('submit',Array('POST')) && @$newsettings)
+if(@$_POST['submit'] && @$newsettings)
 {
 	/* Load hook file with functions to validate each config (one/none/all) */
 	$GLOBALS['egw_setup']->hook('config_validate','setup');
 
-	$datetime = CreateObject('phpgwapi.egw_datetime');
-	switch((int)$newsettings['daytime_port'])
-	{
-		case 13:
-			$newsettings['tz_offset'] = $datetime->getntpoffset();
-			break;
-		case 80:
-			$newsettings['tz_offset'] = $datetime->gethttpoffset();
-			break;
-		default:
-			$newsettings['tz_offset'] = $datetime->getbestguess();
-			break;
-	}
-	unset($datetime);
-
-	print_debug('TZ_OFFSET',$newsettings['tz_offset']);
+	$newsettings['tz_offset'] = date('Z')/3600;
 
 	$GLOBALS['egw_setup']->db->transaction_begin();
 	foreach($newsettings as $setting => $value)
@@ -92,14 +80,14 @@ if(@get_var('submit',Array('POST')) && @$newsettings)
 		/* Don't erase passwords, since we also do not print them below */
 		if(!empty($value) || !(stristr($setting,'passwd') || stristr($setting,'password') || stristr($setting,'root_pw')))
 		{
-			config::save_value($setting, $value, 'phpgwapi');
+			Api\Config::save_value($setting, $value, 'phpgwapi');
 		}
 	}
 	if(!$GLOBALS['error'])
 	{
 		$GLOBALS['egw_setup']->db->transaction_commit();
 		// unset cached config, as this is the primary source for configuration now
-		egw_cache::unsetInstance('config', 'configs');
+		Api\Cache::unsetInstance('config', 'configs');
 
 		Header('Location: index.php');
 		exit;
@@ -115,10 +103,9 @@ if($GLOBALS['error'] && is_array($newsettings))
 }
 else
 {
-	$GLOBALS['egw_setup']->db->select($GLOBALS['egw_setup']->config_table,'*',false,__LINES__,__FILES__);
-	while($GLOBALS['egw_setup']->db->next_record())
+	foreach($GLOBALS['egw_setup']->db->select($GLOBALS['egw_setup']->config_table,'*',false,__LINES__,__FILES__) as $row)
 	{
-		$GLOBALS['current_config'][$GLOBALS['egw_setup']->db->f('config_name')] = $GLOBALS['egw_setup']->db->f('config_value');
+		$GLOBALS['current_config'][$row['config_name']] = $row['config_value'];
 	}
 }
 $setup_tpl->pparse('out','T_config_pre_script');
@@ -133,7 +120,7 @@ class phpgw
 $GLOBALS['egw'] = new phpgw;
 $GLOBALS['egw']->db     =& $GLOBALS['egw_setup']->db;
 
-$t = CreateObject('phpgwapi.Template', common::get_tpl_dir('setup'));
+$t = new Framework\Template(Framework\Template::get_dir('setup'));
 
 $t->set_unknowns('keep');
 $t->set_file(array('config' => 'config.tpl'));
