@@ -13,6 +13,11 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Vfs;
+
 class setup
 {
 	var $db;
@@ -28,13 +33,6 @@ class setup
 	var $oProc;
 	var $cookie_domain;
 
-	/**
-	 * Instance of the hooks class
-	 *
-	 * @var hooks
-	 */
-	var $hooks;
-
 	/**
 	 * @var setup_detection
 	 */
@@ -67,13 +65,13 @@ class setup
 	 *
 	 * @var float
 	 */
-	var $required_php_version = 5.3;
+	var $required_php_version = 5.4;
 	/**
 	 * PHP Version recommended for eGroupware
 	 *
 	 * @var string
 	 */
-	var $recommended_php_version = '5.5';
+	var $recommended_php_version = '5.6';
 
 	function __construct($html=False, $translation=False)
 	{
@@ -82,8 +80,7 @@ class setup
 
 		if (!is_object($GLOBALS['egw']))
 		{
-			require_once(EGW_API_INC.'/class.egw.inc.php');
-			$GLOBALS['phpgw'] = $GLOBALS['egw'] = new egw_minimal();
+			$GLOBALS['phpgw'] = $GLOBALS['egw'] = new Egw\Base();
 		}
 		$this->detection = new setup_detection();
 		$this->process   = new setup_process();
@@ -102,7 +99,7 @@ class setup
 	{
 		if(!isset($this->ConfigDomain) || empty($this->ConfigDomain))
 		{
-			$this->ConfigDomain = get_var('ConfigDomain',array('COOKIE','POST'),$_POST['FormDomain']);
+			$this->ConfigDomain = isset($_REQUEST['ConfigDomain']) ? $_REQUEST['ConfigDomain'] : $_POST['FormDomain'];
 		}
 		$GLOBALS['egw_info']['server']['db_type'] = $GLOBALS['egw_domain'][$this->ConfigDomain]['db_type'];
 
@@ -112,13 +109,14 @@ class setup
 		}
 
 		try {
-			$GLOBALS['egw']->db = $this->db = new egw_db($GLOBALS['egw_domain'][$this->ConfigDomain]);
+			$GLOBALS['egw']->db = $this->db = new Api\Db\Deprecated($GLOBALS['egw_domain'][$this->ConfigDomain]);
 			$this->db->connect();
 		}
 		catch (Exception $e) {
+			unset($e);
 			return;
 		}
-		$this->db->set_app('phpgwapi');
+		$this->db->set_app(Api\Db::API_APPNAME);
 
 		if ($connect_and_setcharset)
 		{
@@ -126,22 +124,19 @@ class setup
 				$this->set_table_names();		// sets/checks config- and applications-table-name
 
 				// Set the DB's client charset if a system-charset is set
-				$this->db->select($this->config_table,'config_value',array(
-					'config_app'  => 'phpgwapi',
-					'config_name' => 'system_charset',
-				),__LINE__,__FILE__);
-				if ($this->db->next_record() && $this->db->f(0))
+				if (($this->system_charset = $this->db->select($this->config_table,'config_value',array(
+						'config_app'  => 'phpgwapi',
+						'config_name' => 'system_charset',
+					),__LINE__,__FILE__)->fetchColumn()))
 				{
-					$this->system_charset = $this->db->f(0);
 					$this->db_charset_was = $this->db->Link_ID->GetCharSet();	// needed for the update
 
 					// we can NOT set the DB charset for mysql, if the api version < 1.0.1.019, as it would mess up the DB content!!!
 					if (substr($this->db->Type,0,5) == 'mysql')	// we need to check the api version
 					{
-						$this->db->select($this->applications_table,'app_version',array(
-							'app_name'  => 'phpgwapi',
-						),__LINE__,__FILE__);
-						$api_version = $this->db->next_record() ? $this->db->f(0) : false;
+						$api_version = $this->db->select($this->applications_table,'app_version',array(
+								'app_name'  => 'phpgwapi',
+							),__LINE__,__FILE__)->fetchColumn();
 					}
 					if (!$api_version || !$this->alessthanb($api_version,'1.0.1.019'))
 					{
@@ -149,7 +144,7 @@ class setup
 					}
 				}
 			}
-			catch (egw_exception_db $e) {
+			catch (Api\Db\Exception $e) {
 				// table might not be created at that stage
 			}
 		}
@@ -249,7 +244,7 @@ class setup
 
 		$ok = @session_start();	// suppress notice if session already started or warning in CLI
 		// need to decrypt session, in case session encryption is switched on in header.inc.php
-		egw_session::decrypt();
+		Api\Session::decrypt();
 		//error_log(__METHOD__."() returning ".array2string($ok).' _SESSION='.array2string($_SESSION));
 		return $ok;
 	}
@@ -375,7 +370,7 @@ class setup
 			{
 				$hash = '{plain}'.$hash;
 			}
-			$ret = auth::compare_password($pw, $hash, 'md5');
+			$ret = Api\Auth::compare_password($pw, $hash, 'md5');
 		}
 		//error_log(__METHOD__."('$user', '$pw', '$conf_user', '$hash') returning ".array2string($ret));
 		return $ret;
@@ -452,12 +447,13 @@ class setup
 	/**
 	 * Add an application to the phpgw_applications table
 	 *
-	 * @param $appname Application 'name' with a matching $setup_info[$appname] array slice
+	 * @param string $appname Application 'name' with a matching $setup_info[$appname] array slice
 	 * @param $_enable =99 set to True/False to override setup.inc.php setting
+	 * @param array $setup_info =null default use $GLOBALS['setup_info']
 	 */
-	function register_app($appname, $_enable=99)
+	function register_app($appname, $_enable=99, array $setup_info=null)
 	{
-		$setup_info = $GLOBALS['setup_info'];
+		if (!isset($setup_info)) $setup_info = $GLOBALS['setup_info'];
 
 		if(!$appname)
 		{
@@ -528,8 +524,7 @@ class setup
 			// _debug_array($setup_info[$appname]);
 		}
 
-		$this->db->select($this->applications_table,'COUNT(*)',array('app_name' => $appname),__LINE__,__FILE__);
-		if($this->db->next_record() && $this->db->f(0))
+		if ($this->db->select($this->applications_table,'COUNT(*)',array('app_name' => $appname),__LINE__,__FILE__)->fetchColumn())
 		{
 			if(@$GLOBALS['DEBUG'])
 			{
@@ -547,12 +542,12 @@ class setup
 	/**
 	 * Update application info in the db
 	 *
-	 * @param	$appname	Application 'name' with a matching $setup_info[$appname] array slice
-	 * @param	$enabled	optional, set to False to not enable this app
+	 * @param string $appname	Application 'name' with a matching $setup_info[$appname] array slice
+	 * @param array $setup_info =null default use $GLOBALS['setup_info']
 	 */
-	function update_app($appname)
+	function update_app($appname, array $setup_info=null)
 	{
-		$setup_info = $GLOBALS['setup_info'];
+		if (!isset($setup_info)) $setup_info = $GLOBALS['setup_info'];
 
 		if(!$appname)
 		{
@@ -629,16 +624,19 @@ class setup
 		}
 
 		// Remove categories
-		$this->db->delete(categories::TABLE, array('cat_appname'=>$appname),__LINE__,__FILE__);
-		categories::invalidate_cache($appname);
+		$this->db->delete(Api\Categories::TABLE, array('cat_appname'=>$appname),__LINE__,__FILE__);
+		Api\Categories::invalidate_cache($appname);
 
-		// Remove config
-		$this->db->delete(config::TABLE, array('config_app'=>$appname),__LINE__,__FILE__);
+		// Remove config, if we are not deinstalling old phpgwapi (as that's global api config!)
+		if ($appname != 'phpgwapi')
+		{
+			$this->db->delete(Api\Config::TABLE, array('config_app'=>$appname),__LINE__,__FILE__);
+		}
 		//echo 'DELETING application: ' . $appname;
 		$this->db->delete($this->applications_table,array('app_name'=>$appname),__LINE__,__FILE__);
 
 		// Remove links to the app
-		egw_link::unlink(0, $appname);
+		Link::unlink(0, $appname);
 
 		$this->clear_session_cache();
 	}
@@ -650,23 +648,12 @@ class setup
 	 */
 	function register_hooks($appname)
 	{
-		$setup_info = $GLOBALS['setup_info'];
-
 		if(!$appname)
 		{
 			return False;
 		}
 
-		if(!$this->hooks_table)	// No hooks table yet
-		{
-			return False;
-		}
-
-		if (!is_object($this->hooks))
-		{
-			$this->hooks =& CreateObject('phpgwapi.hooks',$this->db,$this->hooks_table);
-		}
-		$this->hooks->register_hooks($appname,$setup_info[$appname]['hooks']);
+		Api\Hooks::read(true);
 	}
 
 	/**
@@ -684,9 +671,10 @@ class setup
 			return false;	// app not found or no hook
 		}
 		$GLOBALS['settings'] = array();
+		$hook_data = array('location' => 'settings','setup' => true);
 		if (isset($setup_info['hooks']['settings']))
 		{
-			$settings = ExecMethod($setup_info['hooks']['settings'],array('location' => 'settings','setup' => true));
+			$settings = ExecMethod($setup_info['hooks']['settings'],$hook_data);
 		}
 		elseif(in_array('settings',$setup_info['hooks']) && file_exists($file = EGW_INCLUDE_ROOT.'/'.$appname.'/inc/hook_settings.inc.php'))
 		{
@@ -701,7 +689,9 @@ class setup
 			return false;
 		}
 		// include idots template prefs for (common) preferences
-		if ($appname == 'preferences' && file_exists($file = EGW_INCLUDE_ROOT.'/phpgwapi/templates/idots/hook_settings.inc.php'))
+		if ($appname == 'preferences' && (file_exists($file = EGW_INCLUDE_ROOT.'/pixelegg/hook_settings.inc.php') ||
+			file_exists($file = EGW_INCLUDE_ROOT.'/jdots/hook_settings.inc.php') ||
+			file_exists($file = EGW_INCLUDE_ROOT.'/phpgwapi/templates/idots/hook_settings.inc.php')))
 		{
 			$GLOBALS['settings'] = array();
 			include_once($file);
@@ -720,7 +710,7 @@ class setup
 			}
 		}
 		// store default/forced preferences, if any found
-		$preferences = new preferences();
+		$preferences = new Api\Preferences();
 		$preferences->read_repository(false);
 		foreach(array(
 			'default' => $default,
@@ -740,55 +730,15 @@ class setup
 		return true;
 	}
 
-	/**
-	 * Update an application's hooks
-	 *
-	 * @param	$appname	Application 'name' with a matching $setup_info[$appname] array slice
-	 */
-	function update_hooks($appname)
-	{
-		$this->register_hooks($appname);
-	}
-
-	/**
-	 * de-Register an application's hooks
-	 *
-	 * @param	$appname	Application 'name' with a matching $setup_info[$appname] array slice
-	 * @return boolean|int false on error or number of removed hooks
-	 */
-	function deregister_hooks($appname)
-	{
-		if(!$this->hooks_table)	// No hooks table yet
-		{
-			return False;
-		}
-
-		if(!$appname)
-		{
-			return False;
-		}
-
-		//echo "DELETING hooks for: " . $setup_info[$appname]['name'];
-		if (!is_object($this->hooks))
-		{
-			$this->hooks =& CreateObject('phpgwapi.hooks',$this->db,$this->hooks_table);
-		}
-		return $this->hooks->register_hooks($appname);
-	}
-
 	/**
 	  * call the hooks for a single application
 	  *
 	  * @param $location hook location - required
 	  * @param $appname application name - optional
 	 */
-	function hook($location, $appname='')
+	static function hook($location, $appname='')
 	{
-		if (!is_object($this->hooks))
-		{
-			$this->hooks =& CreateObject('phpgwapi.hooks',$this->db,$this->hooks_table);
-		}
-		return $this->hooks->single($location,$appname,True,True);
+		return Api\Hooks::single($location,$appname,True,True);
 	}
 
 	/**
@@ -961,7 +911,7 @@ class setup
 	/**
 	 * Own instance of the accounts class
 	 *
-	 * @var accounts
+	 * @var Api\Accounts
 	 */
 	var $accounts;
 
@@ -984,14 +934,14 @@ class setup
 				}
 			}
 			try {
-				$this->accounts = new accounts($config);
+				$this->accounts = new Api\Accounts($config);
 			}
 			catch (Exception $e) {
 				echo "<p><b>".$e->getMessage()."</b></p>\n";
 				return false;
 			}
 			if (!isset($GLOBALS['egw']->accounts)) $GLOBALS['egw']->accounts = $this->accounts;
-			accounts::cache_invalidate();	// the cache is shared for all instances of the class
+			Api\Accounts::cache_invalidate();	// the cache is shared for all instances of the class
 		}
 		return true;
 	}
@@ -1025,7 +975,7 @@ class setup
 
 		if ($username == 'anonymous')
 		{
-			if (!isset($this->anonpw)) $this->anonpw = auth::randomstring(16);
+			if (!isset($this->anonpw)) $this->anonpw = Api\Auth::randomstring(16);
 			$passwd = $anonpw = $this->anonpw;
 		}
 
@@ -1053,7 +1003,7 @@ class setup
 		elseif($passwd && $passwd != '*unchanged*')
 		{
 			try {
-				$auth = new auth;
+				$auth = new Api\Auth;
 				$pw_changed = $auth->change_password(null, $passwd, $accountid);
 			}
 			catch (Exception $e)
@@ -1067,19 +1017,19 @@ class setup
 				return false;
 			}
 		}
-		// call vfs_home_hooks::add{account|group} hook to create the vfs-home-dirs
+		// call Vfs\Hooks::add{account|group} hook to create the vfs-home-dirs
 		// calling general add{account|group} hook fails, as we are only in setup
 		// --> setup_cmd_admin execs "admin/admin-cli.php --edit-user" to run them
 		if ($primary_group)
 		{
-			vfs_home_hooks::addAccount(array(
+			Vfs\Hooks::addAccount(array(
 				'account_id' => $accountid,
 				'account_lid' => $username,
 			));
 		}
 		else
 		{
-			vfs_home_hooks::addGroup(array(
+			Vfs\Hooks::addGroup(array(
 				'account_id' => $accountid,
 				'account_lid' => $username,
 			));
@@ -1126,25 +1076,27 @@ class setup
 	{
 		if (!$this->setup_account_object()) return false;
 
-		$accounts = $this->accounts->search(array(
+		$this->accounts->search(array(
 			'type'   => 'accounts',
 			'start'  => 0,
 			'offset' => 2	// we only need to check 2 accounts, if we just check for not anonymous
 		));
 
-		if (!$accounts || !is_array($accounts) || !count($accounts))
+		if ($this->accounts->total != 1)
 		{
-			return false;
+			return $this->accounts->total > 1;
 		}
-		foreach($accounts as $account)
-		{
-			if ($account['account_lid'] != 'anonymous')
-			{
-				// we might add further checks, eg. if the account really has admin rights here
-				return true;
-			}
-		}
-		return false;
+
+		// one account, need to check it's not the anonymous one
+		$this->accounts->search(array(
+			'type'   => 'accounts',
+			'start'  => 0,
+			'offset' => 0,
+			'query_type' => 'lid',
+			'query'  => 'anonymous',
+		));
+
+		return !$this->accounts->total;
 	}
 
 	/**
