@@ -5,11 +5,13 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package setup
- * @copyright (c) 2007-14 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * setup command: create / change eGW configuration
  */
@@ -99,7 +101,7 @@ class setup_cmd_config extends setup_cmd
 			if ($save_mail_account) $this->_save_mail_account($values);
 
 			// flush instance cache, so above config get read from database not cache
-			egw_cache::flush();
+			Api\Cache::flush();
 
 			$this->restore_db();
 
@@ -171,7 +173,7 @@ class setup_cmd_config extends setup_cmd
 			'acc_imap_type',
 		),
 		'--folder' => array(
-			'acc_folder_sent','acc_folder_trash','acc_folder_draft','acc_folder_template','acc_folder_junk',
+			'acc_folder_sent','acc_folder_trash','acc_folder_draft','acc_folder_template','acc_folder_junk','acc_folder_archive'
 		),
 		'--sieve' => array(
 			array('name' => 'acc_sieve_host'),
@@ -286,7 +288,7 @@ class setup_cmd_config extends setup_cmd
 		{
 			if (!isset(self::$options[$arg]))
 			{
-				throw new egw_exception_wrong_userinput(lang("Unknown option '%1' !!!",$arg),90);
+				throw new Api\Exception\WrongUserinput(lang("Unknown option '%1' !!!",$arg),90);
 			}
 			$options = is_array(self::$options[$arg]) ? explode(',',array_shift($args)) : array(array_shift($args));
 
@@ -330,7 +332,7 @@ class setup_cmd_config extends setup_cmd
 
 			if (isset($name['allowed']) && !in_array($value,$name['allowed']))
 			{
-				throw new egw_exception_wrong_userinput(lang("'%1' is not allowed as %2. arguments of option %3 !!!",$value,1+$n,$arg)." ($name[name])",91);
+				throw new Api\Exception\WrongUserinput(lang("'%1' is not allowed as %2. arguments of option %3 !!!",$value,1+$n,$arg)." ($name[name])",91);
 			}
 			$name = $name['name'];
 		}
@@ -346,15 +348,15 @@ class setup_cmd_config extends setup_cmd
 	 */
 	function _save_mail_account(array $data)
 	{
-		// convert ssl textual values to nummerical ones used in emailadmin_account
+		// convert ssl textual values to nummerical ones used in Api\Mail\Account
 		foreach(array('acc_imap_ssl', 'acc_sieve_ssl', 'acc_smtp_ssl') as $name)
 		{
 			switch(strtolower($data[$name]))
 			{
-				case 'no':       $data[$name] = emailadmin_account::SSL_NONE; break;
-				case 'starttls': $data[$name] = emailadmin_account::SSL_STARTTLS; break;
-				case 'ssl':      $data[$name] = emailadmin_account::SSL_SSL; break;
-				case 'tls':      $data[$name] = emailadmin_account::SSL_TLS; break;
+				case 'no':       $data[$name] = Api\Mail\Account::SSL_NONE; break;
+				case 'starttls': $data[$name] = Api\Mail\Account::SSL_STARTTLS; break;
+				case 'ssl':      $data[$name] = Api\Mail\Account::SSL_SSL; break;
+				case 'tls':      $data[$name] = Api\Mail\Account::SSL_TLS; break;
 			}
 		}
 		// convert 'yes', 'no' to boolean
@@ -375,7 +377,7 @@ class setup_cmd_config extends setup_cmd
 		$data['acc_name'] = 'Created by setup';
 		$data['account_id'] = 0;	// 0 = valid for all users
 
-		emailadmin_account::write($data);
+		Api\Mail\Account::write($data);
 
 		if ($this->verbose)
 		{
@@ -449,13 +451,13 @@ class setup_cmd_config extends setup_cmd
 		if (!$scan_done++)
 		{
 			// now add auth backends found in filesystem
-			foreach(scandir(EGW_INCLUDE_ROOT.'/phpgwapi/inc') as $class)
+			foreach(scandir(EGW_INCLUDE_ROOT.'/api/src/Auth') as $file)
 			{
 				$matches = null;
-				if (preg_match('/^class\.auth_([a-z]+)\.inc\.php$/', $class, $matches) &&
-					!isset($auth_types[$matches[1]]))
+				if (preg_match('/^([a-z0-9]+)\.php$/i', $file, $matches) &&
+					!isset($auth_types[strtolower($matches[1])]) && $matches[1] != 'Backend')
 				{
-					$auth_types[$matches[1]] = ucfirst($matches[1]);
+					$auth_types[strtolower($matches[1])] = $matches[1];
 				}
 			}
 			foreach(self::$options['--account-auth'] as &$param)
@@ -487,15 +489,15 @@ class setup_cmd_config extends setup_cmd
 		if (!$scan_done++)
 		{
 			// now add auth backends found in filesystem
-			foreach(scandir(EGW_INCLUDE_ROOT.'/phpgwapi/inc') as $file)
+			foreach(scandir(EGW_INCLUDE_ROOT.'/api/src/Accounts') as $file)
 			{
 				$matches = null;
-				if (preg_match('/^class\.accounts_([a-z]+)\.inc\.php$/', $file, $matches) &&
-					!isset($account_repositories[$matches[1]]) &&
-					class_exists($class='accounts_'.$matches[1]) &&
-					($matches[1] == $current || !is_callable($callable=$class.'::available') || call_user_func($callable)))
+				if (preg_match('/^([a-z0-9]+)\.php$/', $file, $matches) &&
+					!isset($account_repositories[strtolower($matches[1])]) &&
+					class_exists($class='EGroupware\\Api\\Accounts\\'.$matches[1]) &&
+					(strtolower($matches[1]) == $current || !is_callable($callable=$class.'::available') || call_user_func($callable)))
 				{
-					$account_repositories[$matches[1]] = ucfirst($matches[1]);
+					$account_repositories[strtolower($matches[1])] = $matches[1];
 				}
 			}
 		}
