@@ -1,6 +1,6 @@
 <?php
 /**
- * Setup
+ * EGroupware Setup
  *
  * @link http://www.egroupware.org
  * @package setup
@@ -10,6 +10,8 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * Get the options for vfs_storage_mode, select the right one depending on vfs_fstab
  *
@@ -157,7 +159,7 @@ function passwdhashes($config,$return_hashes=false)
 
 function sql_passwdhashes($config, $return_hashes=false, &$securest=null)
 {
-	$hashes = auth::passwdhashes($securest);
+	$hashes = Api\Auth::passwdhashes($securest);
 
 	return $return_hashes ? $hashes : _options_from($hashes, $config['sql_encryption_type'] ? $config['sql_encryption_type'] : 'md5');
 }
@@ -172,10 +174,6 @@ function auth_types($config)
 {
 	return _options_from(setup_cmd_config::auth_types(),$config['auth_type']);
 }
-function auth_type_syncml($config)
-{
-	return _options_from(setup_cmd_config::auth_types(),$config['auth_type_syncml']);
-}
 function auth_type_groupdav($config)
 {
 	return _options_from(setup_cmd_config::auth_types(),$config['auth_type_groupdav']);
