@@ -1,4 +1,4 @@
-#!/usr/bin/php -qC
+#!/usr/bin/env php -qC
 <?php
 /**
  * Setup - Command line interface
@@ -6,18 +6,20 @@
  * @link http://www.egroupware.org
  * @package setup
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2006-14 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 chdir(dirname(__FILE__));	// to enable our relative pathes to work
 
 if (php_sapi_name() !== 'cli')	// security precaution: forbit calling setup-cli as web-page
 {
 	die('<h1>setup-cli.php must NOT be called as web-page --> exiting !!!</h1>');
 }
-error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
+error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT);
 
 $dry_run = false;
 array_shift($_SERVER['argv']);
@@ -61,7 +63,7 @@ $GLOBALS['egw_setup']->system_charset = $charset;
 
 if ((float) PHP_VERSION < $GLOBALS['egw_setup']->required_php_version)
 {
-	throw new egw_exception_wrong_userinput(lang('You are using PHP version %1. EGroupware now requires %2 or later, recommended is PHP %3.',PHP_VERSION,$GLOBALS['egw_setup']->required_php_version,$GLOBALS['egw_setup']->recommended_php_version),98);
+	throw new Api\Exception\WrongUserinput(lang('You are using PHP version %1. EGroupware now requires %2 or later, recommended is PHP %3.',PHP_VERSION,$GLOBALS['egw_setup']->required_php_version,$GLOBALS['egw_setup']->recommended_php_version),98);
 }
 
 switch($action)
@@ -132,7 +134,7 @@ switch($action)
 				list($name,$value) = explode('=',$arg,2);
 				if(property_exists('admin_cmd',$name))		// dont allow to overwrite admin_cmd properties
 				{
-					throw new egw_exception_wrong_userinput(lang("Invalid argument '%1' !!!",$arg),90);
+					throw new Api\Exception\WrongUserinput(lang("Invalid argument '%1' !!!",$arg),90);
 				}
 				if (substr($name,-1) == ']')	// allow 1-dim. arrays
 				{
@@ -150,7 +152,7 @@ switch($action)
 			echo "$msg\n";
 			break;
 		}
-		throw new egw_exception_wrong_userinput(lang("Unknown option '%1' !!!",$action),90);
+		throw new Api\Exception\WrongUserinput(lang("Unknown option '%1' !!!",$action),90);
 }
 exit(0);
 
@@ -203,33 +205,6 @@ function do_hooks($arg)
 	echo "\n";
 }
 
-/**
- * Updates the default EMailAdmin profile
- *
- * @param array $values
- */
-function do_emailadmin()
-{
-	$GLOBALS['egw_setup']->db->select($GLOBALS['egw_setup']->config_table,'config_name,config_value',array(
-		'config_app'  => 'phpgwapi',
-		"((config_name LIKE 'mail%' AND config_name != 'mail_footer') OR config_name LIKE 'smtp%' OR config_name LIKE 'imap%' OR config_name='editforwardingaddress')",
-	),__LINE__,__FILE__);
-	while (($row = $GLOBALS['egw_setup']->db->row(true)))
-	{
-		$config[$row['config_name']] = $row['config_value'];
-	}
-	$config['smtpAuth'] = $config['smtp_auth_user'] ? 'yes' : null;
-
-	$emailadmin = new emailadmin_bo(false,false);	// false=no session stuff
-	$emailadmin->setDefaultProfile($config);
-
-	echo "\n".lang('EMailAdmin profile updated:')."\n";
-	foreach($config as $name => $value)
-	{
-		echo str_pad($name.':',22).$value."\n";
-	}
-}
-
 /**
  * Create an admin account
  *
@@ -273,7 +248,7 @@ function do_backup($arg,$quite_check=false)
 		}
 		else
 		{
-			$db_backup = new db_backup();
+			$db_backup = new Api\Db\Backup();
 			if (is_resource($f = $db_backup->fopen_backup($backup)))
 			{
 				echo lang('Backup started, this might take a few minutes ...')."\n";
@@ -282,7 +257,7 @@ function do_backup($arg,$quite_check=false)
 			}
 			else	// backup failed ==> dont start the upgrade
 			{
-				throw new egw_exception_wrong_userinput(lang('Backup failed').': '.$f,50);
+				throw new Api\Exception\WrongUserinput(lang('Backup failed').': '.$f,50);
 			}
 		}
 	}
@@ -319,7 +294,7 @@ function do_update($arg)
 		{
 			do_backup($arg,true);
 
-			$cmd = new setup_cmd_update($domain,$user,$password,$backup,true,$app);
+			$cmd = new setup_cmd_update($domain,$user,$password,$backup,false,$app);
 			echo $cmd->run()."\n";
 		}
 	}
