@@ -36,7 +36,7 @@ class site_controler
 		{
 			// we need this to avoid the "attempt to access ..." errors if users contribute to multiple websites.
 			// This does not solve the Problem if they work simultanus in two browsers :-(
-			$GLOBALS['egw']->preferences->change('sitemgr','currentsite', $Common_BO->sites->urltoid($site_url));
+			$GLOBALS['egw']->preferences->add('sitemgr','currentsite', $Common_BO->sites->urltoid($site_url));
 			$GLOBALS['egw']->preferences->save_repository(True);
 		}
 		$sitemgr_info = $sitemgr_info + $Common_BO->sites->current_site;
