@@ -9,6 +9,8 @@
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 $site_id=0;
 /**
  * Determine the site from the URL ($_SERVER['PHP_SELF'])
@@ -88,10 +90,9 @@ if (!file_exists($sitemgr_info['egw_path'] . 'header.inc.php'))
 	die("Header file not found.  Either your path to eGroupWare in the config.inc.php file is bad, or you have not setup eGroupWare.");
 }
 // do we use a different domain and are already loged in?
-require_once($sitemgr_info['egw_path'].'phpgwapi/inc/class.egw_session.inc.php');
+require_once($sitemgr_info['egw_path'].'api/src/Session.php');
 if (isset($GLOBALS['egw_info']['server']['default_domain']) &&
-	egw_session::get_request('domain') != $GLOBALS['egw_info']['server']['default_domain'])
-	//$_COOKIE['domain'] != $GLOBALS['egw_info']['server']['default_domain'])
+	Api\Session::get_request('domain') != $GLOBALS['egw_info']['server']['default_domain'])
 {
 	// force our default domain
 	$_GET['domain'] = $_COOKIE['domain'] = $_REQUEST['domain'] = $GLOBALS['egw_info']['server']['default_domain'];
@@ -114,7 +115,7 @@ if (!$site_id)
 if ($GLOBALS['egw_info']['user']['preferences']['sitemgr']['currentsite'] != $site_id)
 {
 	$GLOBALS['egw_info']['user']['preferences']['sitemgr']['currentsite'] = $site_id;
-	$GLOBALS['egw']->preferences->change('sitemgr','currentsite', $site_id);
+	$GLOBALS['egw']->preferences->add('sitemgr','currentsite', $site_id);
 	$GLOBALS['egw']->preferences->save_repository(True);
 }
 
