@@ -11,6 +11,8 @@
  * @version $Id: class.egw_addressbook_record.inc.php 22827 2006-11-10 15:35:35Z nelius_weiss $
  */
 
+use EGroupware\Api\Link;
+
 /**
  * class egw_addressbook_record
  * compability layer for iface_egw_record needet for importexport
@@ -42,10 +44,13 @@ class timesheet_egw_record implements importexport_iface_egw_record
 	public function __construct( $_identifier='' ){
 		$this->identifier = $_identifier;
 		$this->botimesheet = new timesheet_bo();
-		$data = $this->botimesheet->read($this->identifier);
-		// set ts_project from ts_project_blur, where it get moved, if it is no custom value
-		if (empty($data['ts_project'])) $data['ts_project'] = $data['ts_project_blur'];
-		$this->set_record($data);
+
+		if (($data = $this->botimesheet->read($this->identifier)))
+		{
+			// set ts_project from ts_project_blur, where it get moved, if it is no custom value
+			if (empty($data['ts_project'])) $data['ts_project'] = $data['ts_project_blur'];
+			$this->set_record($data);
+		}
 	}
 
 	/**
@@ -84,7 +89,8 @@ class timesheet_egw_record implements importexport_iface_egw_record
 	 *
 	 *@return string title
 	 */
-	public function get_title() {
+	public function get_title()
+	{
 // TODO get_record gibts nicht ?
 //		if (empty($this->timesheetentry)) {
 //			$this->get_record();
@@ -102,8 +108,8 @@ class timesheet_egw_record implements importexport_iface_egw_record
 		$this->timesheetentry = $_record;
 		// Check for linked project ID
 		if($this->timesheetentry['ts_project']) {
-			$links = egw_link::get_links('timesheet', $_record['ts_id'], 'projectmanager');
-			foreach($links as $link_id => $app_id) {
+			$links = Link::get_links('timesheet', $_record['ts_id'], 'projectmanager');
+			foreach($links as $app_id) {
 				$this->timesheetentry['pm_id'] = $app_id;
 				break;
 			}
@@ -135,7 +141,7 @@ class timesheet_egw_record implements importexport_iface_egw_record
 	 * @return string identifier
 	 */
 	public function save ( $_dst_identifier ) {
-
+		unset($_dst_identifier);
 	}
 
 	/**
@@ -145,7 +151,7 @@ class timesheet_egw_record implements importexport_iface_egw_record
 	 * @return string dst_identifier
 	 */
 	public function copy ( $_dst_identifier ) {
-
+		unset($_dst_identifier);
 	}
 
 	/**
@@ -156,7 +162,7 @@ class timesheet_egw_record implements importexport_iface_egw_record
 	 * @return string dst_identifier
 	 */
 	public function move ( $_dst_identifier ) {
-
+		unset($_dst_identifier);
 	}
 
 	/**
