@@ -4,7 +4,7 @@
  * @link http://www.egroupware.org
  * @package timesheet
  * @author Hadi Nategh	<hn-AT-stylite.de>
- * @copyright (c) 2008-13 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -76,7 +76,12 @@ app.classes.timesheet = AppJS.extend(
 		if (filter && dates)
 		{
 			dates.set_disabled(filter.value !== "custom");
+			if (filter.value == "custom")
+			{				
+				jQuery(this.et2.getWidgetById('startdate').getDOMNode()).find('input').focus();
+			}
 		}
+		return true;
 	},
 
 	/**
@@ -118,7 +123,28 @@ app.classes.timesheet = AppJS.extend(
 			ts_project.set_blur(_widget.getValue() ? _widget.search.val() : '');
 		}
 	},
-	
+
+	/**
+	 * Update custom filter timespan, without triggering a change
+	 */
+	update_timespan: function(start, end)
+	{
+		if(this && this.et2)
+		{
+			var nm = this.et2.getWidgetById('nm');
+			if(nm)
+			{
+				// Toggle update_in_progress to avoid another request
+				nm.update_in_progress = true;
+				this.et2.getWidgetById('startdate').set_value(start);
+				this.et2.getWidgetById('enddate').set_value(end);
+				nm.activeFilters.startdate = start;
+				nm.activeFilters.enddate = end;
+				nm.update_in_progress = false;
+			}
+		}
+	},
+
 	/**
 	 * Get title in order to set it as document title
 	 * @returns {string}
