@@ -1,21 +1,23 @@
 <?php
 /**
- * eGroupWare Tracker - Escalation of tickets
+ * EGroupware Tracker - Escalation of tickets
  *
  * Sponsored by Hexagon Metrolegy (www.hexagonmetrology.net)
  *
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package tracker
- * @copyright (c) 2008 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * Escalation of tickets
  */
-class tracker_escalations extends so_sql2
+class tracker_escalations extends Api\Storage\Base2
 {
 	/**
 	 * Name of escalations table
@@ -76,7 +78,7 @@ class tracker_escalations extends so_sql2
 
 		if (!is_null($id) && !$this->read($id))
 		{
-			throw new egw_exception_not_found();
+			throw new Api\Exception\NotFound();
 		}
 	}
 
@@ -133,7 +135,7 @@ class tracker_escalations extends so_sql2
 				$data['set'][substr($key,4)] = $value;
 				if (!is_null($value))
 				{
-					static $col2action;
+					static $col2action=null;
 					if (is_null($col2action))
 					{
 						$col2action = array(
@@ -153,7 +155,7 @@ class tracker_escalations extends so_sql2
 							$users = array();
 							foreach((array)$value as $uid)
 							{
-								$users[] = $GLOBALS['egw']->common->grab_owner_name($uid);
+								$users[] = Api\Accounts::username($uid);
 							}
 							$action .= implode(', ',$users);
 							break;
@@ -231,7 +233,7 @@ class tracker_escalations extends so_sql2
 	/**
 	 * Get an SQL filter to include in a tracker search returning only matches of a given escalation
 	 *
-	 * @param boolean $due=false true = return only tickets due to escalate, default false = return all tickets matching the escalation filter
+	 * @param boolean $due =false true = return only tickets due to escalate, default false = return all tickets matching the escalation filter
 	 * @return array|boolean array with filter or false if escalation not found
 	 */
 	function get_filter($due=false)
@@ -370,7 +372,7 @@ class tracker_escalations extends so_sql2
 		}
 		self::$tracker->init($ticket);
 
-		if ($result = self::$tracker->save() != 0)
+		if (($result = self::$tracker->save()) != 0)
 		{
 			return false;	// error saving the ticket
 		}
@@ -476,7 +478,8 @@ class tracker_escalations extends so_sql2
 		// filter only due tickets
 		$filter = $this->get_filter(true);
 		// not having this escalation already done
-		$filter[] = tracker_bo::escalated_filter($this->id,$join,
+		$join = null;
+		$filter[] = self::$tracker->escalated_filter($this->id,$join,
 			$this->data['esc_match_repeat'] ? time() - $this->data['esc_match_repeat']*60 : false
 		);
 
@@ -518,13 +521,13 @@ class tracker_escalations extends so_sql2
 	/**
 	 * Check if exist and if not start or stop an async job to close pending items
 	 *
-	 * @param boolean $start=true true=start, false=stop
+	 * @param boolean $start =true true=start, false=stop
 	 */
 	static function set_async_job($start=true)
 	{
 		//echo '<p>'.__METHOD__.'('.($start?'true':'false').")</p>\n";
 
-		$async = new asyncservice();
+		$async = new Api\Asyncservice();
 
 		if ($start === !$async->read(self::ASYNC_JOB_NAME))
 		{
@@ -565,7 +568,8 @@ class tracker_escalations extends so_sql2
 		// filter only due tickets
 		$filter = $this->get_filter(true);
 		// not having this escalation already done
-		$filter[] = tracker_bo::escalated_filter($this->id,$join,
+		$join = null;
+		$filter[] = self::$tracker->escalated_filter($this->id,$join,
 			$this->data['esc_match_repeat'] ? time() - $this->data['esc_match_repeat']*60 : false
 		);
 
@@ -618,33 +622,34 @@ class tracker_escalations extends so_sql2
 		{
 				unset(self::$tracker->tracking->skip_notify);
 		}
-		
+
 		// Get a list of users
 		$users = self::$tracker->users_with_open_entries();
 
+		$notified = null;
 		foreach($users as $user)
 		{
 			if (isset($notified)) $notified=array();
 			// Create environment for user
 			if (!($email = $GLOBALS['egw']->accounts->id2name($user,'account_email'))) continue;
-			
+
 			self::$tracker->user = $GLOBALS['egw_info']['user']['account_id'] = $user;
-			$GLOBALS['egw']->preferences->preferences($user);
+			$GLOBALS['egw']->preferences->__construct($user);
 			$GLOBALS['egw_info']['user']['preferences'] = $GLOBALS['egw']->preferences->read_repository();
-			$GLOBALS['egw']->acl->acl($user);
+			$GLOBALS['egw']->acl->__construct($user);
 			$GLOBALS['egw']->acl->read_repository();
-			
+
 			// load the right language if needed
-			if ($GLOBALS['egw_info']['user']['preferences']['common']['lang'] != translation::$userlang)	
+			if ($GLOBALS['egw_info']['user']['preferences']['common']['lang'] != Api\Translation::$userlang)
 			{
-				translation::init();
+				Api\Translation::init();
 				// Make sure translations are loaded
-				translation::add_app('tracker');
+				Api\Translation::add_app('tracker');
 			}
 
-			// Load date/time preferences into egw_time
-			egw_time::init();
-			
+			// Load date/time preferences into Api\DateTime
+			Api\DateTime::init();
+
 			// Keep a list of tickets so we only send the user one notification / ticket
 			$notified = array();
 
@@ -688,14 +693,14 @@ class tracker_escalations extends so_sql2
 							$ticket['prefix'] = lang('Starting').' ';
 							$ticket['message'] = lang('%1 is starting %2',
 								self::$tracker->link_title($ticket['tr_id']),
-								$ticket['tr_startdate'] ? egw_time::to($ticket['tr_startdate']) : ''
+								$ticket['tr_startdate'] ? Api\DateTime::to($ticket['tr_startdate']) : ''
 							);
 							break;
 						case 'notify_due':
 							$ticket['prefix'] = lang('Due') . ' ';
 							$ticket['message'] = lang('%1 is due %2',
 								self::$tracker->link_title($ticket['tr_id']),
-								$ticket['tr_duedate'] ? egw_time::to($ticket['tr_duedate']) : ''
+								$ticket['tr_duedate'] ? Api\DateTime::to($ticket['tr_duedate']) : ''
 							);
 							break;
 					}
