@@ -5,11 +5,16 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package tracker
- * @copyright (c) 2006-11 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Egw;
+
 /**
  * diverse tracker hooks, all static
  */
@@ -23,6 +28,8 @@ class tracker_hooks
 	 */
 	static function search_link($location)
 	{
+		unset($location);	// not used, but required by function signature
+
 		$link = array(
 			'query' => 'tracker.tracker_bo.link_query',
 			'title' => 'tracker.tracker_bo.link_title',
@@ -31,14 +38,14 @@ class tracker_hooks
 				'menuaction' => 'tracker.tracker_ui.edit',
 			),
 			'view_id' => 'tr_id',
-			'view_popup'  => '780x535',
+			'view_popup'  => '760x580',
 			'view_list' => 'tracker.tracker_ui.index',
 			'add' => array(
 				'menuaction' => 'tracker.tracker_ui.edit',
 			),
 			'add_app'    => 'link_app',
 			'add_id'     => 'link_id',
-			'add_popup'  => '750x500',
+			'add_popup'  => '760x580',
 			'file_access' => 'tracker.tracker_bo.file_access',
 			'file_access_user' => true,	// file_access supports 4th parameter $user
 			'merge' => true,
@@ -70,30 +77,30 @@ class tracker_hooks
 		if ($location == 'sidebox_menu')
 		{
 			// Magic etemplate2 favorites menu (from nextmatch widget)
-			display_sidebox($appname, lang('Favorites'), egw_framework::favorite_list($appname));
+			display_sidebox($appname, lang('Favorites'), Framework\Favorites::list_favorites($appname));
 
 			$file = array(
-				'Tracker list' => egw::link('/index.php',array(
+				'Tracker list' => Egw::link('/index.php',array(
 					'menuaction' => 'tracker.tracker_ui.index',
 					'ajax' => 'true')
 				),
 				array(
-					'text' => lang('Add %1',lang(egw_link::get_registry($appname, 'entry'))),
+					'text' => lang('Add %1',lang(Link::get_registry($appname, 'entry'))),
 					'no_lang' => true,
 					'link' => "javascript:egw.open('','$appname','add')"
 				),
 			);
 
-			$file['Placeholders'] = egw::link('/index.php','menuaction=tracker.tracker_merge.show_replacements');
+			$file['Placeholders'] = Egw::link('/index.php','menuaction=tracker.tracker_merge.show_replacements');
 			display_sidebox($appname,$GLOBALS['egw_info']['apps'][$appname]['title'].' '.lang('Menu'),$file);
 		}
 
 		if ($GLOBALS['egw_info']['user']['apps']['admin'])
 		{
 			$file = Array(
-				'Site configuration' => egw::link('/index.php','menuaction=tracker.tracker_admin.admin'),
-				'Define escalations' => egw::link('/index.php','menuaction=tracker.tracker_admin.escalations'),
-				'Custom fields' => egw::link('/index.php','menuaction=tracker.tracker_customfields.index&use_private=1&ajax=true'),
+				'Site configuration' => Egw::link('/index.php','menuaction=tracker.tracker_admin.admin'),
+				'Define escalations' => Egw::link('/index.php','menuaction=tracker.tracker_admin.escalations'),
+				'Custom fields' => Egw::link('/index.php','menuaction=tracker.tracker_customfields.index&use_private=1&ajax=true'),
 			);
 			if ($location == 'admin')
 			{
@@ -241,8 +248,6 @@ class tracker_hooks
 		// Merge print
 		if ($GLOBALS['egw_info']['user']['apps']['filemanager'])
 		{
-			$link = egw::link('/index.php','menuaction=tracker.tracker_merge.show_replacements');
-
 			$settings['default_document'] = array(
 				'type'   => 'vfs_file',
 				'size'   => 60,
@@ -250,7 +255,7 @@ class tracker_hooks
 				'name'   => 'default_document',
 				'help'   => lang('If you specify a document (full vfs path) here, %1 displays an extra document icon for each entry. That icon allows to download the specified document with the data inserted.',lang('tracker')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','tr_summary').' '.
-					lang('The following document-types are supported:'). implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:'). implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -262,7 +267,7 @@ class tracker_hooks
 				'name'   => 'document_dir',
 				'help'   => lang('If you specify a directory (full vfs path) here, %1 displays an action for each document. That action allows to download the specified document with the data inserted.', lang('tracker')).' '.
 					lang('The document can contain placeholder like {{%1}}, to be replaced with the data.','tr_summary').' '.
-					lang('The following document-types are supported:') . implode(',',bo_merge::get_file_extensions()),
+					lang('The following document-types are supported:') . implode(',',Api\Storage\Merge::get_file_extensions()),
 				'run_lang' => false,
 				'xmlrpc' => True,
 				'admin'  => False,
@@ -288,10 +293,11 @@ class tracker_hooks
 				}
 				catch (Exception $e)
 				{
+					unset($e);	// not used
 					// permission error
 					continue;
 				}
-				if ($title = $definition->get_title())
+				if (($title = $definition->get_title()))
 				{
 					$options[$title] = $title;
 				}
@@ -324,7 +330,7 @@ class tracker_hooks
 	{
 		if ($data['prefs']['notify_due'] || $data['prefs']['notify_start'])
 		{
-			$async = new asyncservice();
+			$async = new Api\Asyncservice();
 
 			if (!$async->read(tracker_escalations::ASYNC_NOTIFICATION))
 			{
@@ -333,7 +339,7 @@ class tracker_hooks
 			}
 		}
 	}
-	
+
 	/**
 	 * Mail integration hook to import mail message contents into a tracker entry
 	 *
@@ -341,9 +347,11 @@ class tracker_hooks
 	 */
 	public static function mail_import($args)
 	{
+		unset($args);	// not used, but required by function signature
+
 		return array(
 			'menuaction' => 'tracker.tracker_ui.mail_import',
-			'popup' => egw_link::get_registry('tracker', 'add_popup'),
+			'popup' => Link::get_registry('tracker', 'add_popup'),
 			'app_entry_method' => 'tracker.tracker_bo.ajax_getTicketId'
 		);
 	}
