@@ -5,11 +5,18 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package tracker
- * @copyright (c) 2006-12 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Link;
+use EGroupware\Api\Framework;
+use EGroupware\Api\Egw;
+use EGroupware\Api\Acl;
+use EGroupware\Api\Etemplate;
+
 /**
  * User Interface of the tracker
  */
@@ -59,7 +66,7 @@ class tracker_ui extends tracker_bo
 		// read the duration format from project-manager
 		if ($GLOBALS['egw_info']['apps']['projectmanager'])
 		{
-			$pm_config = config::read('projectmanager');
+			$pm_config = Api\Config::read('projectmanager');
 			$this->duration_format = str_replace(',','',implode('', (array)$pm_config['duration_units'])).','.$pm_config['hours_per_workday'];
 			unset($pm_config);
 		}
@@ -132,10 +139,10 @@ class tracker_ui extends tracker_bo
 			// edit or new?
 			if ((int)$_GET['tr_id'])
 			{
-				$own_referer = common::get_referer();
+				$own_referer = Api\Header\Referer::get();
 				if (!$this->read($_GET['tr_id']))
 				{
-					egw_framework::window_close(lang('Tracker item not found !!!'));
+					Framework::window_close(lang('Tracker item not found !!!'));
 				}
 				else
 				{
@@ -160,7 +167,7 @@ class tracker_ui extends tracker_bo
 					{
 						if (!($this->htmledit || $this->data['tr_edit_mode'] == 'html')|| (strlen($reply['reply_message'])==strlen(strip_tags($reply['reply_message'])))) //(stripos($reply['reply_message'], '<br') === false && stripos($reply['reply_message'], '<p>') === false))
 						{
-							$reply['reply_message'] = html::htmlspecialchars($reply['reply_message']);
+							$reply['reply_message'] = Api\Html::htmlspecialchars($reply['reply_message']);
 						}
 					}
 				}
@@ -175,7 +182,7 @@ class tracker_ui extends tracker_bo
 			if (!$this->data['tr_id'])
 			{
 				$regardInInit = array();
-				if (($state = egw_session::appsession('index','tracker'.
+				if (($state = Api\Cache::getSession('tracker','index'.
 					(isset($this->trackers[(int)$_GET['only_tracker']]) ? '-'.$_GET['only_tracker'] : ''))))
 				{
 					$this->data['tr_tracker'] = $regardInInit['tr_tracker'] = $state['col_filter']['tr_tracker'] ? $state['col_filter']['tr_tracker'] : $this->data['tr_tracker'];
@@ -202,7 +209,7 @@ class tracker_ui extends tracker_bo
 				if ($popup)
 				{
 					$GLOBALS['egw']->framework->render('<h1 style="color: red;">'.$msg."</h1>\n",null,true);
-					common::egw_exit();
+					exit();
 				}
 				else
 				{
@@ -244,7 +251,7 @@ class tracker_ui extends tracker_bo
 				if ($popup)
 				{
 					$GLOBALS['egw']->framework->render('<h1 style="color: red;">'.$msg."</h1>\n",null,false);
-					common::egw_exit();
+					exit();
 				}
 				else
 				{
@@ -303,8 +310,8 @@ class tracker_ui extends tracker_bo
 					if ($ret === false)
 					{
 						$msg = lang('Nothing to save.');
-						$state = egw_session::appsession('index','tracker');
-						egw_framework::refresh_opener($msg,'tracker',$this->data['tr_id'],'edit');
+						$state = Api\Cache::getSession('tracker', 'index');
+						Framework::refresh_opener($msg,'tracker',$this->data['tr_id'],'edit');
 
 						// only change to current tracker, if not all trackers displayed
 						($state['col_filter']['tr_tracker'] ? '&tracker='.$this->data['tr_tracker'] : '')."';";
@@ -313,7 +320,7 @@ class tracker_ui extends tracker_bo
 					{
 						$msg .= ($msg ? ', ' : '') .lang('Error: the entry has been updated since you opened it for editing!').'<br />'.
 							lang('Copy your changes to the clipboard, %1reload the entry%2 and merge them.','<a href="'.
-								htmlspecialchars(egw::link('/index.php',array(
+								htmlspecialchars(Egw::link('/index.php',array(
 									'menuaction' => 'tracker.tracker_ui.edit',
 									'tr_id'    => $this->data['tr_id'],
 									//'referer'    => $referer,
@@ -335,18 +342,18 @@ class tracker_ui extends tracker_bo
 
 							if ($cat['parent'] == $this->data['tr_tracker'] && $data['type'] != 'tracker' && $data['type']=='project')
 							{
-								if (!egw_link::get_link('tracker',$this->data['tr_id'],'projectmanager',$data['projectlist']))
+								if (!Link::get_link('tracker',$this->data['tr_id'],'projectmanager',$data['projectlist']))
 								{
-									egw_link::link('tracker',$this->data['tr_id'],'projectmanager',$data['projectlist']);
+									Link::link('tracker',$this->data['tr_id'],'projectmanager',$data['projectlist']);
 								}
 							}
 						}
 						if (is_array($content['link_to']['to_id']) && count($content['link_to']['to_id']))
 						{
-							egw_link::link('tracker',$this->data['tr_id'],$content['link_to']['to_id']);
+							Link::link('tracker',$this->data['tr_id'],$content['link_to']['to_id']);
 
 							// check if we have dragged in images and fix their image urls
-							if (etemplate_widget_vfs::fix_html_dragins('tracker', $this->data['tr_id'],
+							if (Etemplate\Widget\Vfs::fix_html_dragins('tracker', $this->data['tr_id'],
 								$content['link_to']['to_id'], $content['tr_description']))
 							{
 								$this->update(array(
@@ -354,8 +361,8 @@ class tracker_ui extends tracker_bo
 								));
 							}
 						}
-						$state = egw_session::appsession('index','tracker');
-						egw_framework::refresh_opener($msg, 'tracker',$this->data['tr_id'],'edit');
+						$state = Api\Cache::getSession('tracker', 'index');
+						Framework::refresh_opener($msg, 'tracker',$this->data['tr_id'],'edit');
 					}
 					else
 					{
@@ -365,20 +372,26 @@ class tracker_ui extends tracker_bo
 					if ($button == 'apply')
 					{
 						$_GET['tr_id'] = $this->data['tr_id'];
-						return $this->edit($_GET['tr_id'], $msg);
+						return $this->edit($_GET['tr_id'], $msg, $popup);
 					}
 					// fall-through for save
 				case 'cancel':
 					if ($popup)
 					{
-						egw_framework::window_close();
-						common::egw_exit();
+						Framework::window_close();
+						exit();
 					}
 					unset($_GET['tr_id']);	// in case it's still set
-					if($own_referer && strpos($own_referer,'cd=yes') === false)
+					if($own_referer && strpos($own_referer,'cd=yes') === false &&
+						strpos($own_referer,'tr_id='.$this->data['tr_id']) === FALSE)
 					{
 						// Go back to where you came from
-						egw::redirect_link($own_referer);
+						Egw::redirect_link($own_referer);
+					}
+					if (Api\Json\Response::isJSONResponse())
+					{
+						Api\Json\Response::get()->call('egw.open_link','tracker.tracker_ui.index&ajax=true','_self',false,'tracker');
+						exit();
 					}
 					return $this->index(null,$this->data['tr_tracker'],$msg);
 
@@ -388,7 +401,7 @@ class tracker_ui extends tracker_bo
 						$msg = lang('Thank you for voting.');
 						if ($popup)
 						{
-							egw_framework::refresh_opener($msg, 'tracker',$this->data['tr_id'], 'edit');
+							Framework::refresh_opener($msg, 'tracker',$this->data['tr_id'], 'edit');
 						}
 					}
 					break;
@@ -452,7 +465,7 @@ class tracker_ui extends tracker_bo
 									if ($this->save_bounty($this->data['bounties'][$n]))
 									{
 										$msg = lang('Bounty confirmed');
-										egw_framework::refresh_opener($msg, 'tracker',$this->data['tr_id'], 'edit');
+										Framework::refresh_opener($msg, 'tracker',$this->data['tr_id'], 'edit');
 									}
 									else
 									{
@@ -508,7 +521,7 @@ class tracker_ui extends tracker_bo
 			'tr_description_options' => $tr_description_options,
 			'tr_description_mode'    => $readonlys['tr_description'],
 			'tr_reply_options' => $tr_reply_options,
-			'on_cancel' => $popup ? 'egw(window).close();' : '',
+			'on_cancel' => $popup ? 'egw(window).close();' : 'egw.open_link("tracker.tracker_ui.index&ajax=true","_self",false,"tracker")',
 			'no_vote' => '',
 			'show_dates' => $this->show_dates,
 			'link_to' => array(
@@ -574,7 +587,7 @@ class tracker_ui extends tracker_bo
 									'field'	=> 'tr_tracker',
 									'source'=> $this->trackers
 								),
-								categories::id2name($infolog['info_cat']) => array(
+								Api\Categories::id2name($infolog['info_cat']) => array(
 									'field'	=> 'cat_id',
 									'source'=> $this->get_tracker_labels('cat',$tracker)
 								)
@@ -600,22 +613,22 @@ class tracker_ui extends tracker_bo
 							}
 
 							// Copy infolog's links
-							foreach(egw_link::get_links('infolog',$link_id) as $copy_link)
+							foreach(Link::get_links('infolog',$link_id) as $copy_link)
 							{
-								egw_link::link('tracker', $content['link_to']['to_id'], $copy_link['app'], $copy_link['id'],$copy_link['remark']);
+								Link::link('tracker', $content['link_to']['to_id'], $copy_link['app'], $copy_link['id'],$copy_link['remark']);
 							}
 							break;
 
 					}
 					// Copy same custom fields
-					$_cfs = config::get_customfields('tracker');
-					$link_app_cfs = config::get_customfields($link_app);
+					$_cfs = Api\Storage\Customfields::get('tracker');
+					$link_app_cfs = Api\Storage\Customfields::get($link_app);
 					foreach($_cfs as $name => $settings)
 					{
 						unset($settings);
 						if($link_app_cfs[$name]) $content['#'.$name] = $app_entry['#'.$name];
 					}
-					egw_link::link('tracker',$content['link_to']['to_id'],$link_app,$link_id);
+					Link::link('tracker',$content['link_to']['to_id'],$link_app,$link_id);
 				}
 			}
 		}
@@ -630,7 +643,7 @@ class tracker_ui extends tracker_bo
 		}
 		if ($content['tr_creator'] && !isset($creators[$content['tr_creator']]))
 		{
-			$creators[$content['tr_creator']] = common::grab_owner_name($content['tr_creator']);
+			$creators[$content['tr_creator']] = Api\Accounts::username($content['tr_creator']);
 		}
 
 		// Comment visibility
@@ -674,10 +687,10 @@ class tracker_ui extends tracker_bo
 			'add_comment' => !$tr_id || $readonlys['reply_message'],
 			'history'  => !$tr_id,
 			'bounties' => !$this->allow_bounties,
-			'custom'   => !config::get_customfields('tracker', false, $content['tr_tracker']),
+			'custom'   => !Api\Storage\Customfields::get('tracker', false, $content['tr_tracker']),
 		);
 		// Make link_to readonly if the user has no EDIT access
-		$readonlys['link_to'] = !$this->file_access($tr_id, EGW_ACL_EDIT);
+		$readonlys['link_to'] = !$this->file_access($tr_id, Acl::EDIT);
 
 		if ($tr_id && $readonlys['reply_message'])
 		{
@@ -716,7 +729,7 @@ class tracker_ui extends tracker_bo
 		$what = ($tracker && isset($this->trackers[(is_array($tracker)?$tracker[0]:$tracker)]) ? $this->trackers[(is_array($tracker)?$tracker[0]:$tracker)] : lang('Tracker'));
 		$GLOBALS['egw_info']['flags']['app_header'] = $tr_id ? lang('Edit %1',$what) : lang('New %1',$what);
 
-		$tpl = new etemplate_new('tracker.edit');
+		$tpl = new Etemplate('tracker.edit');
 		// use a type-specific template (tracker.edit.xyz), if one exists, otherwise fall back to the generic one
 		if (!$tpl->read('tracker.edit'.(isset($this->trackers[(is_array($tracker)?$tracker[0]:$tracker)])?'.'.trim($this->trackers[(is_array($tracker)?$tracker[0]:$tracker)]):'')))
 		{
@@ -751,7 +764,7 @@ class tracker_ui extends tracker_bo
 	 * @param array $query with keys 'start', 'search', 'order', 'sort', 'col_filter'
 	 *	For other keys like 'filter', 'cat_id' you have to reimplement this method in a derived class.
 	 * @param array &$rows returned rows/competitions
-	 * @param array &$readonlys eg. to disable buttons based on acl
+	 * @param array &$readonlys eg. to disable buttons based on Acl
 	 * @return int total number of rows
 	 */
 	function get_rows(&$query_in,&$rows,&$readonlys)
@@ -762,7 +775,7 @@ class tracker_ui extends tracker_bo
 		$query = $query_in;
 		if (!$query['csv_export'])	// do not store query for csv-export in session
 		{
-			egw_session::appsession($query['session_for'] ? $query['session_for'] : 'index','tracker'.($query_in['only_tracker'] ? '-'.$query_in['only_tracker'] : ''),$query);
+			Api\Cache::setSession('tracker',$query['session_for'] ? $query['session_for'] : 'index'.($query_in['only_tracker'] ? '-'.$query_in['only_tracker'] : ''),$query);
 		}
 		// save the state of the index page (filters) in the user prefs
 		// need to save state, before resolving diverse col-filters, eg. to all group-members or sub-cats
@@ -819,7 +832,7 @@ class tracker_ui extends tracker_bo
 				$id = $link['id'];
 			}
 			if(!is_array($id)) $id = explode(',',$id);
-			if (!($linked = egw_link::get_links_multiple($app,$id,true,'tracker')))
+			if (!($linked = Link::get_links_multiple($app,$id,true,'tracker')))
 			{
 				$rows = array();	// no entries linked to selected link --> no rows to return
 				$this->get_rows_options($rows, $tracker);
@@ -834,7 +847,7 @@ class tracker_ui extends tracker_bo
 			$links[$key] = array_unique($links[$key]);
 			if($key == 'linked')
 			{
-				$linked = array('app' => $app, 'id' => $id, 'title' => (count($id) == 1 ? egw_link::title($app, $id) : lang('multiple')));
+				$linked = array('app' => $app, 'id' => $id, 'title' => (count($id) == 1 ? Link::title($app, $id) : lang('multiple')));
 			}
 		}
 		if(count($links))
@@ -868,22 +881,19 @@ class tracker_ui extends tracker_bo
 
 		if (empty($query['col_filter']['tr_tracker']))
 		{
-			$trtofilter = array_keys($this->trackers);
-			//_debug_array($trtofilter);
-			$query['col_filter']['tr_tracker'] = $tracker = $trtofilter;
+			$tracker = $query['col_filter']['tr_tracker'] = array_keys($this->trackers);
 		}
 
 		// Get list of currently displayed trackers, so we can get all valid statuses
-		if($query['col_filter']['tr_tracker']) {
-			$trackers = is_array($query['col_filter']['tr_tracker']) ? $query['col_filter']['tr_tracker'] : array($query['col_filter']['tr_tracker']);
+		if ($tracker)
+		{
+			$trackers = is_array($tracker) ? $tracker : array($tracker);
 		}
 		else
 		{
 			$trackers = array();
 		}
 
-		if ($query['col_filter']['multi_queue']) unset($query['col_filter']['multi_queue']);
-
 		//echo "<p align=right>uitracker::get_rows() order='$query[order]', sort='$query[sort]', search='$query[search]', start=$query[start], num_rows=$query[num_rows], col_filter=".print_r($query['col_filter'],true)."</p>\n";
 		$total = parent::get_rows($query,$rows,$readonlys,$this->allow_voting||$this->allow_bounties);	// true = count votes and/or bounties
 		$prio_labels = $prio_tracker = $prio_cat = null;
@@ -921,7 +931,7 @@ class tracker_ui extends tracker_bo
 			if (isset($GLOBALS['egw_info']['user']['apps']['timesheet']))
 			{
 				unset($links);
-				if (($links = egw_link::get_links('tracker',$row['tr_id'])) &&
+				if (($links = Link::get_links('tracker',$row['tr_id'])) &&
 					isset($GLOBALS['egw_info']['user']['apps']['timesheet']))
 				{
 					// loop through all links of the entries
@@ -974,7 +984,7 @@ class tracker_ui extends tracker_bo
 		}
 		else
 		{
-			$tracker = $selected_trackers ? $selected_trackers : array_keys($this->trackers);
+			$tracker = $selected_trackers;
 		}
 		$rows['sel_options']['tr_assigned'] = array('not' => lang('Not assigned'));
 
@@ -986,7 +996,7 @@ class tracker_ui extends tracker_bo
 		$rows['sel_options']['assigned'] = $rows['sel_options']['tr_assigned']; // For context menu popup
 		unset($rows['sel_options']['assigned']['not']);
 
-		$cats =array('' => lang('all'));
+		$cats =array('' => lang('All categories'));
 		$versions =  $resolutions = $statis = array();
 		foreach((array)$tracker as $tr_id)
 		{
@@ -1008,31 +1018,31 @@ class tracker_ui extends tracker_bo
 
 		$rows['sel_options']['tr_status'] = $this->filters+$statis;
 		$rows['sel_options']['cat_id'] = $cats;
-		$rows['sel_options']['filter2'] = array(lang('All'))+$versions;
+		$rows['sel_options']['filter2'] = array(lang('All versions'))+$versions;
 		$rows['sel_options']['tr_version'] =& $versions;
 		$rows['sel_options']['tr_resolution'] =& $resolutions;
 
+		$rows['is_admin'] = $this->is_admin($tracker);
 		if ($this->is_admin($tracker))
 		{
 			$rows['sel_options']['canned_response'] = $this->get_tracker_labels('response',$tracker);
 			$rows['sel_options']['tr_status_admin'] =& $statis;
-			$rows['is_admin'] = true;
 		}
+		$rows['no_votes'] = !$this->allow_voting;
 		if (!$this->allow_voting)
 		{
-			$rows['no_votes'] = true;
 			$query_in['options-selectcols']['votes'] = false;
 		}
+		$rows['no_bounties'] = !$this->allow_bounties;
 		if (!$this->allow_bounties)
 		{
-			$rows['no_bounties'] = true;
 			$query_in['options-selectcols']['bounties'] = false;
 		}
 
-		if ($query['col_filter']['cat_id']) $rows['no_cat_id'] = true;
+		$rows['no_cat_id'] = !!$rows['col_filter']['cat_id'];
 
 		// enable tracker column if all trackers are shown
-		if ($tracker && !$query['multi_queue']) $rows['no_tr_tracker'] = true;
+		$rows['no_tr_tracker'] = ($tracker && count($tracker) == 1);
 	}
 
 	/**
@@ -1048,10 +1058,10 @@ class tracker_ui extends tracker_bo
 		if ((int)$data['id'] && ($ticket = $this->read($data['id'])))
 		{
 			//error_log(__METHOD__.__LINE__.$this->exclude_app_on_timesheetcreation);
-			foreach(egw_link::get_links('tracker',$ticket['tr_id'],'','link_lastmod DESC',true) as $link)
+			foreach(Link::get_links('tracker',$ticket['tr_id'],'','link_lastmod DESC',true) as $link)
 			{
-				//if ($link['app'] != 'timesheet' && $link['app'] != egw_link::VFS_APPNAME)
-				if (stripos($this->exclude_app_on_timesheetcreation.','.'timesheet'.','.egw_link::VFS_APPNAME,$link['app'])===false)
+				//if ($link['app'] != 'timesheet' && $link['app'] != Link::VFS_APPNAME)
+				if (stripos($this->exclude_app_on_timesheetcreation.','.'timesheet'.','.Link::VFS_APPNAME,$link['app'])===false)
 				{
 					$set['link_app'][] = $link['app'];
 					$set['link_id'][]  = $link['id'];
@@ -1080,7 +1090,7 @@ class tracker_ui extends tracker_bo
 			'info_contact' => 'tracker:'.$tracker['tr_id'],
 		);
 		// copy links
-		foreach(egw_link::get_links('tracker',$tracker['tr_id'],'','link_lastmod DESC',true) as $link)
+		foreach(Link::get_links('tracker',$tracker['tr_id'],'','link_lastmod DESC',true) as $link)
 		{
 			$set['link_app'][] = $link['app'];
 			$set['link_id'][]  = $link['id'];
@@ -1093,7 +1103,7 @@ class tracker_ui extends tracker_bo
 			}
 		}
 		// copy same named customfields
-		foreach(config::get_customfields('infolog') as $name => $nul)
+		foreach(Api\Storage\Customfields::get('infolog') as $name => $nul)
 		{
 			unset($nul);
 			if(array_key_exists('#'.$name, $tracker))
@@ -1174,11 +1184,10 @@ class tracker_ui extends tracker_bo
 			// if there is no tracker specified, try the tracker submitted
 			if (!$tracker && (int)$_GET['tracker']) $tracker = $_GET['tracker'];
 			// if there is still no tracker, use the last tracker that was applied and saved to/with the view with the appsession
-			if (!$tracker && ($state=egw_session::appsession('index','tracker'.($only_tracker ? '-'.$only_tracker : ''))))
+			if (!$tracker && ($state=  Api\Cache::getSession('tracker','index'.($only_tracker ? '-'.$only_tracker : ''))))
 			{
 			      $tracker=$state['col_filter']['tr_tracker'];
 			}
-			$multi_queue = $this->prefs['multi_queue'];
 		}
 		else
 		{
@@ -1186,24 +1195,6 @@ class tracker_ui extends tracker_bo
 			$tracker = $content['nm']['col_filter']['tr_tracker'];
 			$this->called_by = $content['called_by']; unset($content['called_by']);
 
-			// Multiple queues at once
-			list($multi_queue_filter) = @each($content['nm']['col_filter']['multi_queue']);
-			$multi_queue = $multi_queue_filter == 'true' ? true : ($multi_queue_filter == 'false' ? false : $this->prefs['multi_queue']);
-			if($multi_queue != $this->prefs['multi_queue'])
-			{
-				// Store in preferences
-				$this->prefs['multi_queue'] = $multi_queue;
-				$GLOBALS['egw']->preferences->add('tracker','multi_queue',$multi_queue);
-				// save prefs, but do NOT invalid the cache (unnecessary)
-				$GLOBALS['egw']->preferences->save_repository(false,'user',false);
-				if(!$multi_queue)
-				{
-					// Only select 1 queue when going from multi to single
-					if (!is_array($tracker)) $tracker = explode(',', $tracker);
-					$tracker = $content['nm']['col_filter']['tr_tracker'] = $tracker[0];
-				}
-			}
-
 			if (is_array($content) && isset($content['nm']['rows']['document']))  // handle insert in default document button like an action
 			{
 				list($id) = @each($content['nm']['rows']['document']);
@@ -1294,27 +1285,29 @@ class tracker_ui extends tracker_bo
 		}
 
 		if (!is_array($content)) $content = array();
-		$content['nm'] = egw_session::appsession($this->called_by ? $this->called_by : 'index', 'tracker'.($only_tracker ? '-'.$only_tracker : ''));
+		$content['nm'] = Api\Cache::getSession('tracker', $this->called_by ? $this->called_by : 'index'.($only_tracker ? '-'.$only_tracker : ''));
 		$content['msg'] = $msg;
 		$content['status_help'] = !$this->pending_close_days ? lang('Pending items never get close automatic.') :
 				lang('Pending items will be closed automatic after %1 days without response.',$this->pending_close_days);
 
 		if (!is_array($content['nm']) || !$content['nm']['get_rows'])
 		{
-			$date_filters = array(lang('All'));
+			$date_filters = array(lang('Date filter'));
 			foreach(array_keys($this->date_filters) as $name)
 			{
 				$date_filters[$name] = lang($name);
 			}
+			$date_filters['custom'] = 'custom';
 			$content['nm'] = array(
 				'get_rows'       =>	'tracker.tracker_ui.get_rows',
 				'cat_is_select'  => 'no_lang',
 				'filter'         => 0,  // all
 				'options-filter' => $date_filters,
-				'filter_label'   => lang('Date filter'),
+				'filter_onchange' => "app.tracker.filter_change();",
+				//'filter_label'   => lang('Date filter'),
 				'filter_no_lang'=> true,
 				'filter2'        => 0,	// all
-				'filter2_label'  => lang('Version'),
+				//'filter2_label'  => lang('Version'),
 				'filter2_no_lang'=> true,
 				'order'          =>	$this->allow_bounties ? 'bounties' : ($this->allow_voting ? 'votes' : 'tr_id'),// IO name of the column to sort after (optional for the sortheaders)
 				'sort'           =>	'DESC',// IO direction of the sort: 'ASC' or 'DESC'
@@ -1322,16 +1315,16 @@ class tracker_ui extends tracker_bo
 				'col_filter'     => array(
 					'tr_status'  => 'not-closed',	// default filter: not closed
 				),
-	 			'header_left'    =>	$only_tracker ? null : 'tracker.index.left', // I  template to show left of the range-value, left-aligned (optional)
 	 			'only_tracker'   => $only_tracker,
-	 			'header_right'   =>	'tracker.index.right', // I  template to show right of the range-value, left-aligned (optional)
 	 			'default_cols'   => '!esc_id,legacy_actions,tr_summary_tr_description,tr_resolution,tr_completion,tr_sum_timesheets,votes,bounties',
 				'row_id'         => 'tr_id',
-				'row_modified'   => 'tr_modified'
+				'row_modified'   => 'tr_modified',
+				'placeholder_actions' => array('add')
 			);
 			// use the state of the last session stored in the user prefs
 			if (!$this->called_by && ($state = @unserialize($GLOBALS['egw_info']['user']['preferences']['tracker']['index_state'])))
 			{
+				unset($state['header_left']); unset($state['header_right']);
 				$content['nm'] = array_merge($content['nm'],$state);
 				$tracker = $content['nm']['col_filter']['tr_tracker'];
 			}
@@ -1352,6 +1345,9 @@ class tracker_ui extends tracker_bo
 				$content['nm']['options-selectcols']['tr_startdate'] = false;
 				$content['nm']['options-selectcols']['tr_duedate'] = false;
 			}
+			$content['nm']['no_votes'] = !$this->allow_voting;
+			$content['nm']['no_bounties'] = !$this->allow_bounties;
+			$content['nm']['no_tr_sum_timesheets'] = false;
 		}
 		if (!$content['nm']['session_for'] && $this->called_by) $content['nm']['session_for'] = $this->called_by;
 		if($_GET['search'])
@@ -1384,12 +1380,12 @@ class tracker_ui extends tracker_bo
 		{
 			$content['nm']['favorites'] = true; // Enable favorites
 		}
-		$content['duration_format'] = ','.$this->duration_format.',,1';
+		$content['duration_format'] = $this->duration_format;
 
 		$content['is_admin'] = $this->is_admin($tracker);
 		//_debug_array($content);
 		$readonlys['add'] = $readonlys['nm']['add'] = !$this->check_rights($this->field_acl['add'],$tracker,null,null,'add');
-		$tpl = new etemplate_new();
+		$tpl = new Etemplate();
 		if (!$tpl->sitemgr || !$tpl->read('tracker.index.sitemgr'))
 		{
 			$tpl->read('tracker.index');
@@ -1398,14 +1394,11 @@ class tracker_ui extends tracker_bo
 		// Apply link / avoid DOM conflicts
 		if($this->called_by)
 		{
-			$content['nm'] = array_merge($content['nm'], egw_session::appsession($this->called_by,'tracker'));
+			$content['nm'] = array_merge($content['nm'], Api\Cache::getSession('tracker', $this->called_by));
 			$tpl->set_dom_id("{$tpl->name}-{$this->called_by}");
 		}
 
 		$content['nm']['actions'] = $this->get_actions($tracker, $content['cat_id']);
-		$content['nm']['multi_queue'] = $multi_queue;
-		// Turn on multi-queue widget
-		$content['nm']['header_left'] = $content['nm']['multi_queue'] ? 'tracker.index.left_multiqueue' : 'tracker.index.left';
 
 		// disable filemanager icon, if user has no access to it
 		$readonlys['filemanager/navbar'] = !isset($GLOBALS['egw_info']['user']['apps']['filemanager']);
@@ -1417,14 +1410,14 @@ class tracker_ui extends tracker_bo
 			$tpl->disable_cells('use_all', true);
 		}
 
-		// Show only own groups in group popup if queue acl
+		// Show only own groups in group popup if queue Acl
 		if($this->enabled_queue_acl_access)
 		{
 			$group = explode(',',$tpl->get_cell_attribute('group', 'size'));
 			$group[1] = 'owngroups';
 			$tpl->set_cell_attribute('group', 'size', implode(',',$group));
 		}
-		egw_framework::validate_file('.','app','tracker');
+		Framework::includeJS('.','app','tracker');
 		// add scrollbar to long description, if user choose so in his prefs
 		/* @kl: why is an if used, if it is effectily commented by a semicolon?
 		if ($this->prefs['limit_des_lines'] > 0 || (string)$this->prefs['limit_des_lines'] == '');
@@ -1466,20 +1459,24 @@ width:100%;
 				'default' => true,
 				'allowOnMultiple' => false,
 				'url' => 'menuaction=tracker.tracker_ui.edit&tr_id=$id',
-				'popup' => egw_link::get_registry('tracker', 'add_popup'),
+				'popup' => Link::get_registry('tracker', 'add_popup'),
 				'group' => $group=1,
+				'onExecute' => Api\Header\UserAgent::mobile()?'javaScript:app.tracker.viewEntry':'',
+				'mobileViewTemplate' => 'view?'.filemtime(Api\Etemplate\Widget\Template::rel2path('/tracker/templates/mobile/view.xet'))
 			),
 			'print' => array(
 				'caption' => 'Print',
 				'allowOnMultiple' => false,
 				'onExecute' => 'javaScript:app.tracker.tprint',
 				'group' => $group,
+				'hideOnMobile' => true
 			),
 			'add' => array(
 				'caption' => 'Add',
 				'group' => $group,
 				'url' => 'menuaction=tracker.tracker_ui.edit',
-				'popup' => egw_link::get_registry('tracker', 'add_popup'),
+				'popup' => Link::get_registry('tracker', 'add_popup'),
+				'hideOnMobile' => true
 			),
 			'no_notifications' => array(
 				'caption' => 'Do not notify',
@@ -1528,6 +1525,7 @@ width:100%;
 						'caption' => 'Assigned to',
 						'icon' => 'users',
 						'nm_action' => 'open_popup',
+						'onExecute' => 'javaScript:app.tracker.change_assigned'
 					),
 					'priority' => array(
 						'caption' => 'Priority',
@@ -1566,6 +1564,7 @@ width:100%;
 						'nm_action' => 'open_popup',
 					),
 				),
+				'hideOnMobile' => true
 			),
 			'close' => array(
 				'caption' => 'Close',
@@ -1602,7 +1601,7 @@ width:100%;
 				'url' => 'menuaction=timesheet.timesheet_ui.edit&link_app[]=tracker&link_id[]=$id',
 				'group' => $group,
 				'allowOnMultiple' => false,
-				'popup' => egw_link::get_registry('timesheet', 'add_popup'),
+				'popup' => Link::get_registry('timesheet', 'add_popup'),
 			);
 		}
 		if ($GLOBALS['egw_info']['user']['apps']['infolog'] && $this->allow_infolog)
@@ -1613,7 +1612,7 @@ width:100%;
 				'url' => 'menuaction=infolog.infolog_ui.edit&action=tracker&action_id=$id',
 				'group' => $group,
 				'allowOnMultiple' => false,
-				'popup' => egw_link::get_registry('infolog', 'add_popup'),
+				'popup' => Link::get_registry('infolog', 'add_popup'),
 			);
 		}
 
@@ -1638,7 +1637,7 @@ width:100%;
 		if (!is_array($mailContent) && ($_GET['egw_data']))
 		{
 			// get the mail raw data
-			egw_link::get_data ($_GET['egw_data']);
+			Link::get_data ($_GET['egw_data']);
 			return false;
 		}
 		// Wrap a pre tag if we are using html editor
@@ -1672,7 +1671,7 @@ width:100%;
 		if ($use_all)
 		{
 			// get the whole selection
-			$query = is_array($session_name) ? $session_name : $GLOBALS['egw']->session->appsession($session_name,'tracker');
+			$query = is_array($session_name) ? $session_name : Api\Cache::getSession('tracker', $session_name);
 
 			if ($use_all)
 			{
@@ -1795,9 +1794,16 @@ width:100%;
 						if (!$this->read($tr_id)) continue;
 						list($add_remove, $idstr) = explode('_', $settings, 2);
 						$ids = explode(',',$idstr);
-						$this->data['tr_assigned'] = $add_remove == 'add' ?
-							array_merge($this->data['tr_assigned'],$ids) :
-							array_diff($this->data['tr_assigned'],$ids);
+						if($add_remove == 'ok')
+						{
+							$this->data['tr_assigned'] = $ids;
+						}
+						else
+						{
+							$this->data['tr_assigned'] = $add_remove == 'add' ?
+								array_merge($this->data['tr_assigned'],$ids) :
+								array_diff($this->data['tr_assigned'],$ids);
+						}
 						// No 0 allowed
 						$this->data['tr_assigned'] = array_unique(array_diff($this->data['tr_assigned'], array(0)));
 						if($no_notification) $this->data['no_notifications'] = true;
@@ -1821,7 +1827,7 @@ width:100%;
 						break;
 					}
 					error_log("APp: $app ID: $link_id");
-					$title = egw_link::title($app, $link_id);
+					$title = Link::title($app, $link_id);
 					foreach($checked as $id)
 					{
 						if (!$this->read($id))
@@ -1832,7 +1838,7 @@ width:100%;
 						if($add_remove == 'add')
 						{
 							$action_msg = lang('linked to %1', $title);
-							if(egw_link::link('tracker', $id, $app, $link_id))
+							if(Link::link('tracker', $id, $app, $link_id))
 							{
 								$success++;
 							}
@@ -1844,7 +1850,7 @@ width:100%;
 						else
 						{
 							$action_msg = lang('unlinked from %1', $title);
-							$count = egw_link::unlink(0, 'tracker', $id, '', $app, $link_id);
+							$count = Link::unlink(0, 'tracker', $id, '', $app, $link_id);
 							$success += $count;
 						}
 					}
@@ -1868,7 +1874,7 @@ width:100%;
 	 */
 	public function ajax_canned_comment($id, $ckeditor=true)
 	{
-		$response = egw_json_response::get();
+		$response = Api\Json\Response::get();
 
 		if($ckeditor)
 		{
@@ -1889,7 +1895,7 @@ width:100%;
 	 * @param $args['view_id']  name of the id-var for location == 'infolog'
 	 * @param $args[$args['view_id']] id of the entry
 	 * this function can be called for any app, which should include infolog: \
-	 * 	$GLOBALS['egw']->hooks->process(array( \
+	 * 	Api\Hooks::process(array( \
 	 * 		 * 'location' => 'infolog', \
 	 * 		 * 'app'      => <your app>, \
 	 * 		 * 'view_id'  => <id name>, \
@@ -1900,7 +1906,7 @@ width:100%;
 	public function hook_view($args)
 	{
 		// Load JS for tracker actions
-		egw_framework::validate_file('.','app','tracker');
+		Framework::includeJS('.','app','tracker');
 
 		switch ($args['location'])
 		{
@@ -1910,7 +1916,7 @@ width:100%;
 				// Just set the filter
 				$state['action'] = $app;
 				$state['action_id'] = $args[$view_id];
-				egw_session::appsession($app,'tracker',$state);
+				Api\Cache::setSession('tracker', $app, $state);
 				break;
 		}
 		if (!isset($app) || !isset($args[$view_id]))
@@ -1922,7 +1928,7 @@ width:100%;
 		// Set to calling app, so actions wind up in the correct place client side
 		$GLOBALS['egw_info']['flags']['currentapp'] = $app;
 
-		translation::add_app('tracker');
+		Api\Translation::add_app('tracker');
 
 		$this->index(null);
 	}
