@@ -4,7 +4,7 @@
  * @link http://www.egroupware.org
  * @package tracker
  * @author Hadi Nategh	<hn-AT-stylite.de>
- * @copyright (c) 2008-13 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2008-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
@@ -14,7 +14,7 @@
  *
  * @augments AppJS
  */
-app.classes.tracker = AppJS.extend(
+app.classes.tracker = (function(){ "use strict"; return AppJS.extend(
 {
 	appname: 'tracker',
 	/**
@@ -50,20 +50,32 @@ app.classes.tracker = AppJS.extend(
 	 * and ready.  If you must store a reference to the et2 object,
 	 * make sure to clean it up in destroy().
 	 *
-	 * @param et2 etemplate2 Newly ready object
+	 * @param {etemplate2} _et2
+	 * @param {string} _name name of template loaded
 	 */
-	et2_ready: function(et2)
+	et2_ready: function(_et2, _name)
 	{
 		// call parent
 		this._super.apply(this, arguments);
-		if (et2.name === 'tracker.admin')
-		{
-			this.acl_queue_access();
-		}
 
-		if (et2.name === 'tracker.edit')
+		switch(_name)
 		{
-			this.edit_popup();
+			case 'tracker.admin':
+				this.acl_queue_access();
+				break;
+
+			case 'tracker.edit':
+				this.edit_popup();
+				break;
+
+			case 'tracker.index':
+				this.filter_change();
+				if (this.et2.getArrayMgr('content').getEntry('nm[only_tracker]'))
+					// there's no this.et2.getWidgetById('colfilter[tr_tracker]').hide() and
+					// jQuery(this.et2.getWidgetById('colfilter[tr_tracker]').getDOMNode()).hide()
+					// hides already hiden selectbox and not the choosen container :(
+					jQuery('#tracker_index_col_filter_tr_tracker__chzn').hide();
+				break;
 		}
 	},
 
@@ -101,40 +113,25 @@ app.classes.tracker = AppJS.extend(
 	},
 
 	/**
-	 * Set the state / apply a favorite
-	 * Overridden from the parent to set the queue to multiple if there are
-	 * more than one in the state
+	 * Tracker list filter change, used to toggle date fields
 	 */
-	setState: function(state)
+	filter_change: function()
 	{
-		// State should be an object, not a string, but we'll parse
-		if(typeof state == "string")
+		var filter = this.et2.getWidgetById('filter');
+		var dates = this.et2.getWidgetById('tracker.index.dates');
+
+		if (filter && dates)
 		{
-			if(state.indexOf('{') != -1 || state =='null')
+			dates.set_disabled(filter.value !== "custom");
+			if (filter.value == "custom")
 			{
-				state = JSON.parse(state);
+				jQuery(this.et2.getWidgetById('startdate').getDOMNode()).find('input').focus();
 			}
 		}
-		if(typeof state == "object" && state != null && state.state && state.state.col_filter)
-		{
-			if(typeof state.state.col_filter.tr_tracker == 'object'
-					&& state.state.col_filter.tr_tracker &&
-					Object.keys(state.state.col_filter.tr_tracker).length > 1)
-			{
-				var template = etemplate2.getById('tracker-index') || null;
-				if(template)
-				{
-					var nm = template.widgetContainer.getWidgetById('nm');
-					nm.set_header_left('tracker.index.left_multiqueue');
-				}
-			}
-		}
-		// call parent
-		this._super.apply(this, arguments);
+		return true;
 	},
 
 	/**
-	 * expand_filter
 	 * Used in escalations on buttons to change filters from a single select to a multi-select
 	 *
 	 * @param {object} _event
@@ -171,14 +168,13 @@ app.classes.tracker = AppJS.extend(
 	},
 
 	/**
-	 * edit_popup
 	 * Check if the edit window is a popup, then set window focus
 	 */
 	edit_popup: function()
 	{
 		if (typeof this.et2.node !='undefined' && typeof this.et2.node.baseURI != 'undefined')
 		{
-			if (!this.et2.node.baseURI.match('[no][no_]popup'))
+			if (!this.et2.node.baseURI.match(/no_?popup/))
 			{
 				window.focus();
 
@@ -248,5 +244,42 @@ app.classes.tracker = AppJS.extend(
 	{
 		var widget = this.et2.getWidgetById('tr_summary');
 		if(widget) return widget.options.value;
-	}
-});
+	},
+
+	/**
+	 * Action handler for context menu change assigned action
+	 *
+	 * We populate the dialog with the current value.
+	 *
+	 * @param {egwAction} _action
+	 * @param {egwActionObject[]} _selected
+	 */
+	change_assigned: function(_action, _selected)
+	{
+		var et2 = _selected[0].manager.data.nextmatch.getInstanceManager();
+		var assigned = et2.widgetContainer.getWidgetById('assigned');
+		if(assigned)
+		{
+			assigned.set_value([]);
+			et2.widgetContainer.getWidgetById('assigned_action[title]').set_value('');
+			et2.widgetContainer.getWidgetById('assigned_action[title]').set_class('');
+			et2.widgetContainer.getWidgetById('assigned_action[ok]').set_disabled(_selected.length !== 1);
+			et2.widgetContainer.getWidgetById('assigned_action[add]').set_disabled(_selected.length === 1)
+			et2.widgetContainer.getWidgetById('assigned_action[delete]').set_disabled(_selected.length === 1)
+		}
+
+		if(_selected.length === 1)
+		{
+			var data = egw.dataGetUIDdata(_selected[0].id);
+
+			if(assigned && data && data.data)
+			{
+				et2.widgetContainer.getWidgetById('assigned_action[title]').set_value(data.data.tr_summary);
+				et2.widgetContainer.getWidgetById('assigned_action[title]').set_class(data.data.class)
+				assigned.set_value(data.data.tr_assigned);
+			}
+		}
+
+		nm_open_popup(_action, _selected);
+	},
+});}).call(this);
