@@ -16,10 +16,13 @@
  * @package api
  * @subpackage vfs
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2006-10 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2006-16 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @version $Id$
  */
 
+use EGroupware\Api;
+use EGroupware\Api\Vfs;
+
 $starttime = microtime(true);
 
 /**
@@ -36,7 +39,7 @@ function check_access(&$account)
 	{
 		list($_SERVER['PHP_AUTH_USER'],$_SERVER['PHP_AUTH_PW']) = explode(':',base64_decode($_GET['auth']),2);
 	}
-	return egw_digest_auth::autocreate_session_callback($account);
+	return Api\Header\Authenticate::autocreate_session_callback($account);
 }
 
 $GLOBALS['egw_info'] = array(
@@ -46,17 +49,16 @@ $GLOBALS['egw_info'] = array(
 		'currentapp' => preg_match('|/webdav.php/apps/([A-Za-z0-9_-]+)/|', $_SERVER['REQUEST_URI'], $matches) ? $matches[1] : 'filemanager',
 		'autocreate_session_callback' => 'check_access',
 		'no_exception_handler' => 'basic_auth',	// we use a basic auth exception handler (sends exception message as basic auth realm)
-		'auth_realm' => 'EGroupware WebDAV server',	// cant use vfs_webdav_server::REALM as autoloading and include path not yet setup!
+		'auth_realm' => 'EGroupware WebDAV server',	// cant use Vfs\WebDAV::REALM as autoloading and include path not yet setup!
 	)
 );
-require_once('phpgwapi/inc/class.egw_digest_auth.inc.php');
 
 // if you move this file somewhere else, you need to adapt the path to the header!
 try
 {
 	include(dirname(__FILE__).'/header.inc.php');
 }
-catch (egw_exception_no_permission_app $e)
+catch (Api\Exception\NoPermission\App $e)
 {
 	if (isset($GLOBALS['egw_info']['user']['apps']['filemanager']))
 	{
@@ -76,6 +78,6 @@ catch (egw_exception_no_permission_app $e)
 // webdav is stateless: we dont need to keep the session open, it only blocks other calls to same basic-auth session
 $GLOBALS['egw']->session->commit_session();
 
-$webdav_server = new vfs_webdav_server();
+$webdav_server = new Vfs\WebDAV();
 $webdav_server->ServeRequest();
 //error_log(sprintf('WebDAV %s request: status "%s", took %5.3f s'.($headertime?' (header include took %5.3f s)':''),$_SERVER['REQUEST_METHOD'].' '.$_SERVER['PATH_INFO'],$webdav_server->_http_status,microtime(true)-$starttime,$headertime-$starttime));
