@@ -5,11 +5,13 @@
  * @link http://www.egroupware.org
  * @package wiki
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (C) 2004-9 by RalfBecker-AT-outdoor-training.de
+ * @copyright (C) 2004-16 by RalfBecker-AT-outdoor-training.de
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @version $Id$
  */
 
+use EGroupware\Api;
+
 /**
  * Static hooks for wiki
  */
@@ -22,26 +24,17 @@ class wiki_hooks
 	 */
 	static public function settings($hook_data)
 	{
+		unset($hook_data);	// not used
+
 		$options = array(
 			// Defines not defined here
 			/*WIKI_ACL_ALL*/  '_0' => lang('everyone'),
 			/*WIKI_ACL_USER*/ '_1' => lang('users'),
 			/*WIKI_ACL_ADMIN*/'_2' => lang('admins'),
 		);
-		$accs = $GLOBALS['egw']->accounts->get_list('groups');
-		foreach($accs as $acc)
+		foreach($GLOBALS['egw']->accounts->search(array('type' => 'groups')) as $acc)
 		{
-			if ($acc['account_type'] == 'u')
-			{
-				$options[$acc['account_id']] = common::grab_owner_name($acc['account_id']);
-			}
-		}
-		foreach($accs as $acc)
-		{
-			if ($acc['account_type'] == 'g' && (!$owngroups || ($owngroups && in_array($acc['account_id'],(array)$mygroups))))
-			{
-				$options[$acc['account_id']] = common::grab_owner_name($acc['account_id']);
-			}
+			$options[$acc['account_id']] = Api\Accounts::format_username($acc);
 		}
 		$settings = array(
 			'default_read' => array(
@@ -141,10 +134,16 @@ $$Content$$'
 	{
 		$title = $appname = 'wiki';
 		$file = Array(
-			'Site Configuration' => egw::link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
+			'Site Configuration' => egw::link('/index.php','menuaction=admin.admin_config.index&appname=' . $appname.'&ajax=true'),
 		//	'Lock / Unlock Pages' => $GLOBALS['egw']->link('/wiki/index.php','action=admin&locking=1'),
 			'Block / Unblock hosts' => egw::link('/wiki/index.php','action=admin&blocking=1'),
-			'Rebuild Links' => egw::link('/wiki/index.php','menuaction=wiki.wiki_hooks.rebuildlinks'),
+			array(
+				'id' => 'apps/wiki/rebuild_links',
+				'text' => lang('Rebuild Links'),
+				'no_lang' => true,
+				'link' => "javascript:egw.message('".lang('Rebuild Links') . "<br />" .lang('Please wait...')."','info'); " .
+					"egw.json('wiki.wiki_hooks.ajax_rebuildlinks').sendRequest(true);"
+			)
 		);
 		//Do not modify below this line
 		display_section($appname,$title,$file);
@@ -167,7 +166,7 @@ $$Content$$'
 		{
 			$menu_title = lang('Wiki Administration');
 			$file = Array(
-				'Site Configuration' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
+				'Site Configuration' => $GLOBALS['egw']->link('/index.php','menuaction=admin.admin_config.index&appname=' . $appname.'&ajax=true'),
 			//	'Lock / Unlock Pages' => $GLOBALS['egw']->link('/wiki/index.php','action=admin&locking=1'),
 				'Block / Unblock Hosts' => $GLOBALS['egw']->link('/wiki/index.php','action=admin&blocking=1')
 			);
@@ -193,11 +192,18 @@ $$Content$$'
 		);
 	}
 
+	static function ajax_rebuildlinks() {
+		$wiki = new wiki_hooks();
+		$message = $wiki->_rebuildlinks();
+
+		egw_json_response::get()->apply('egw.message', array(lang('Done') . "<br />".$message,'success'));
+	}
+
 	/**
 	 * rebuildlinks
 	 *
 	 */
-	function rebuildlinks()
+	private function _rebuildlinks()
 	{
 		@set_time_limit(0);
 
@@ -255,30 +261,7 @@ $$Content$$'
 
 			//if ($i >100) break;
 		}
-		error_log(__METHOD__.__LINE__.' '.$i." Pages processed. $l Links inserted (or count updated).");
-		error_log(__METHOD__.__LINE__. ' Redirect back to Admin Page ');
-		$GLOBALS['egw']->redirect_link('/admin/index.php');
+		$message = "$i Pages processed. $l Links inserted (or count updated).";
+		return $message;
 	}
-
-	/**
-         * Hook returning options for new_page_permission groups
-         *
-         * @param array $config
-         */
-        public static function hook_new_page_permission($config)
-        {
-		// Definitions in wiki_so
-		$groups = array(
-			'_0' =>   lang('everyone'),
-			'_1' =>  lang('users'),
-			'_2' => lang('admins'),
-		);
-		$accs = $GLOBALS['egw']->accounts->get_list('groups');
-		foreach($accs as $acc)
-		{
-			$groups[$acc['account_id']] = lang('group').' '.$acc['account_lid'];
-		}
-		return html::select('newsettings[new_page_permission]',$config['new_page_permission'],
-                        $groups,true,'',4);
-        }
 }
